/* avatar-details.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from avatar-details.vala, do not modify */

/*
 * Copyright (C) 2011, 2015 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <gio/gio.h>


#define TYPE_AVATAR_DETAILS_TESTS (avatar_details_tests_get_type ())
#define AVATAR_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTests))
#define AVATAR_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTestsClass))
#define IS_AVATAR_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AVATAR_DETAILS_TESTS))
#define IS_AVATAR_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AVATAR_DETAILS_TESTS))
#define AVATAR_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTestsClass))

typedef struct _AvatarDetailsTests AvatarDetailsTests;
typedef struct _AvatarDetailsTestsClass AvatarDetailsTestsClass;
typedef struct _AvatarDetailsTestsPrivate AvatarDetailsTestsPrivate;
typedef struct _Block1Data Block1Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AvatarDetailsTests {
	EdsTestTestCase parent_instance;
	AvatarDetailsTestsPrivate * priv;
};

struct _AvatarDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	AvatarDetailsTests* self;
	gboolean avatars_are_equal;
};

struct _Block2Data {
	int _ref_count_;
	Block1Data * _data1_;
	GMainLoop* main_loop;
};


static gpointer avatar_details_tests_parent_class = NULL;

GType avatar_details_tests_get_type (void) G_GNUC_CONST;
enum  {
	AVATAR_DETAILS_TESTS_DUMMY_PROPERTY
};
AvatarDetailsTests* avatar_details_tests_new (void);
AvatarDetailsTests* avatar_details_tests_construct (GType object_type);
void avatar_details_tests_test_avatar (AvatarDetailsTests* self);
static void _avatar_details_tests_test_avatar_folks_test_case_test_method (gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void ___lambda4_ (Block2Data* _data2_, GObject* s, GAsyncResult* r);
static void ____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _avatar_details_tests_test_avatar_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	avatar_details_tests_test_avatar ((AvatarDetailsTests*) self);
#line 103 "avatar-details.c"
}


AvatarDetailsTests* avatar_details_tests_construct (GType object_type) {
	AvatarDetailsTests * self = NULL;
#line 30 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self = (AvatarDetailsTests*) eds_test_test_case_construct (object_type, "AvatarDetails");
#line 32 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "avatar details interface", _avatar_details_tests_test_avatar_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 28 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self;
#line 115 "avatar-details.c"
}


AvatarDetailsTests* avatar_details_tests_new (void) {
#line 28 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return avatar_details_tests_construct (TYPE_AVATAR_DETAILS_TESTS);
#line 122 "avatar-details.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return _data1_;
#line 131 "avatar-details.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 140 "avatar-details.c"
		AvatarDetailsTests* self;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		self = _data1_->self;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (self);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_slice_free (Block1Data, _data1_);
#line 148 "avatar-details.c"
	}
}


static GValue* _g_value_dup (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 156 "avatar-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_unset (self);
#line 38 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_free (self);
#line 165 "avatar-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 172 "avatar-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 179 "avatar-details.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return _data2_;
#line 188 "avatar-details.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 197 "avatar-details.c"
		AvatarDetailsTests* self;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		self = _data2_->_data1_->self;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		block1_data_unref (_data2_->_data1_);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_->_data1_ = NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_slice_free (Block2Data, _data2_);
#line 209 "avatar-details.c"
	}
}


static void ___lambda4_ (Block2Data* _data2_, GObject* s, GAsyncResult* r) {
	Block1Data* _data1_;
	AvatarDetailsTests* self;
	GAsyncResult* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GMainLoop* _tmp2_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_ = _data2_->_data1_;
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self = _data1_->self;
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (r != NULL);
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = r;
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = folks_test_utils_loadable_icons_content_equal_finish (_tmp0_);
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_->avatars_are_equal = _tmp1_;
#line 75 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp2_ = _data2_->main_loop;
#line 75 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_main_loop_quit (_tmp2_);
#line 236 "avatar-details.c"
}


static void ____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	___lambda4_ (self, source_object, res);
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	block2_data_unref (self);
#line 245 "avatar-details.c"
}


void avatar_details_tests_test_avatar (AvatarDetailsTests* self) {
	Block1Data* _data1_;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	gchar* avatar_path = NULL;
	gchar* _tmp1_ = NULL;
	GValue* v = NULL;
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	GValue* _tmp4_ = NULL;
	GValue* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue _tmp9_ = {0};
	GValue _tmp10_ = {0};
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	GeeHashMap* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	EdsTestBackend* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GeeHashMap* _tmp19_ = NULL;
	EdsTestBackend* _tmp20_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp21_ = NULL;
	FolksIndividualAggregator* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar** _tmp24_ = NULL;
	gchar** _tmp25_ = NULL;
	gint _tmp25__length1 = 0;
	FolksIndividual* i = NULL;
	FolksIndividualAggregator* _tmp26_ = NULL;
	FolksIndividual* _tmp27_ = NULL;
	FolksIndividual* _tmp28_ = NULL;
	GLoadableIcon* _tmp29_ = NULL;
	GLoadableIcon* _tmp30_ = NULL;
	gboolean _tmp42_ = FALSE;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (self != NULL);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_->_ref_count_ = 1;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_->self = g_object_ref (self);
#line 38 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	c1 = _tmp0_;
#line 39 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = folks_test_utils_get_source_test_data ("data/avatar-01.jpg");
#line 39 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	avatar_path = _tmp1_;
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_init (&_tmp2_, G_TYPE_STRING);
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp3_ = _tmp2_;
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp4_ = __g_value_dup0 (&_tmp3_);
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = _tmp4_;
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_IS_VALUE (&_tmp3_) ? (g_value_unset (&_tmp3_), NULL) : NULL;
#line 44 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp5_ = v;
#line 44 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_set_string (_tmp5_, "bernie h. innocenti");
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp6_ = c1;
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp7_ = v;
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = NULL;
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp8_ = _tmp7_;
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, "full_name", _tmp8_);
#line 45 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (_tmp8_);
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_init (&_tmp9_, G_TYPE_STRING);
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp10_ = _tmp9_;
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp11_ = __g_value_dup0 (&_tmp10_);
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = _tmp11_;
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_IS_VALUE (&_tmp10_) ? (g_value_unset (&_tmp10_), NULL) : NULL;
#line 47 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp12_ = v;
#line 47 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp13_ = avatar_path;
#line 47 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_set_string (_tmp12_, _tmp13_);
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp14_ = c1;
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp15_ = v;
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = NULL;
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp16_ = _tmp15_;
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp14_, "avatar", _tmp16_);
#line 48 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (_tmp16_);
#line 50 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp17_ = ((EdsTestTestCase*) self)->eds_backend;
#line 50 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp18_ = c1;
#line 50 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp19_ = _g_object_ref0 (_tmp18_);
#line 50 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_add_contact (_tmp17_, _tmp19_);
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp20_ = ((EdsTestTestCase*) self)->eds_backend;
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_sync (_tmp20_);
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_->avatars_are_equal = FALSE;
#line 58 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp21_ = folks_individual_aggregator_dup ();
#line 58 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	aggregator = _tmp21_;
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp22_ = aggregator;
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp23_ = g_strdup ("bernie h. innocenti");
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp24_ = g_new0 (gchar*, 1 + 1);
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp24_[0] = _tmp23_;
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp25_ = _tmp24_;
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp25__length1 = 1;
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_individuals_sync_with_timeout (_tmp22_, _tmp25_, 1, 5);
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp26_ = aggregator;
#line 63 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp27_ = folks_test_utils_get_individual_by_name (_tmp26_, "bernie h. innocenti");
#line 63 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	i = _tmp27_;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp28_ = i;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp29_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp28_);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp30_ = _tmp29_;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (_tmp30_ != NULL) {
#line 411 "avatar-details.c"
		Block2Data* _data2_;
		GFileIcon* b = NULL;
		const gchar* _tmp31_ = NULL;
		GFile* _tmp32_ = NULL;
		GFile* _tmp33_ = NULL;
		GFileIcon* _tmp34_ = NULL;
		GFileIcon* _tmp35_ = NULL;
		GMainLoop* _tmp36_ = NULL;
		FolksIndividual* _tmp37_ = NULL;
		GLoadableIcon* _tmp38_ = NULL;
		GLoadableIcon* _tmp39_ = NULL;
		GFileIcon* _tmp40_ = NULL;
		GMainLoop* _tmp41_ = NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_ = g_slice_new0 (Block2Data);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_->_ref_count_ = 1;
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_->_data1_ = block1_data_ref (_data1_);
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp31_ = avatar_path;
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp32_ = g_file_new_for_path (_tmp31_);
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp33_ = _tmp32_;
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp34_ = (GFileIcon*) g_file_icon_new (_tmp33_);
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp35_ = _tmp34_;
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_tmp33_);
#line 67 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		b = _tmp35_;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp36_ = g_main_loop_new (NULL, FALSE);
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_->main_loop = _tmp36_;
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp37_ = i;
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp38_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp37_);
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp39_ = _tmp38_;
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp40_ = b;
#line 70 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		folks_test_utils_loadable_icons_content_equal (_tmp39_, (GLoadableIcon*) _tmp40_, -1, ____lambda4__gasync_ready_callback, block2_data_ref (_data2_));
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp41_ = _data2_->main_loop;
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		folks_test_utils_loop_run_with_timeout (_tmp41_, 5);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (b);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		block2_data_unref (_data2_);
#line 65 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data2_ = NULL;
#line 469 "avatar-details.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp42_ = _data1_->avatars_are_equal;
#line 81 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_vala_assert (_tmp42_, "avatars_are_equal");
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (i);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (aggregator);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_free0 (avatar_path);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (c1);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	block1_data_unref (_data1_);
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data1_ = NULL;
#line 489 "avatar-details.c"
}


static void avatar_details_tests_class_init (AvatarDetailsTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	avatar_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 496 "avatar-details.c"
}


static void avatar_details_tests_instance_init (AvatarDetailsTests * self) {
}


GType avatar_details_tests_get_type (void) {
	static volatile gsize avatar_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&avatar_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AvatarDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) avatar_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AvatarDetailsTests), 0, (GInstanceInitFunc) avatar_details_tests_instance_init, NULL };
		GType avatar_details_tests_type_id;
		avatar_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "AvatarDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&avatar_details_tests_type_id__volatile, avatar_details_tests_type_id);
	}
	return avatar_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AvatarDetailsTests* tests = NULL;
	AvatarDetailsTests* _tmp0_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 89 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = avatar_details_tests_new ();
#line 89 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	tests = _tmp0_;
#line 90 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 91 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_test_run ();
#line 92 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	result = 0;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (tests);
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return result;
#line 538 "avatar-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 85 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return _vala_main (argv, argc);
#line 548 "avatar-details.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



