/* interaction-details.c generated by valac 0.34.0.3-63fa6, the Vala compiler
 * generated from interaction-details.vala, do not modify */

/*
 * Copyright (C) 2012 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Seif Lotfy <seif.lotfy@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>


#define FOLKS_TYPE_INTERACTION_DETAILS (folks_interaction_details_get_type ())
#define FOLKS_INTERACTION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_TYPE_INTERACTION_DETAILS, FolksInteractionDetails))
#define FOLKS_IS_INTERACTION_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_TYPE_INTERACTION_DETAILS))
#define FOLKS_INTERACTION_DETAILS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), FOLKS_TYPE_INTERACTION_DETAILS, FolksInteractionDetailsIface))

typedef struct _FolksInteractionDetails FolksInteractionDetails;
typedef struct _FolksInteractionDetailsIface FolksInteractionDetailsIface;

struct _FolksInteractionDetailsIface {
	GTypeInterface parent_iface;
	guint (*get_im_interaction_count) (FolksInteractionDetails* self);
	GDateTime* (*get_last_im_interaction_datetime) (FolksInteractionDetails* self);
	guint (*get_call_interaction_count) (FolksInteractionDetails* self);
	GDateTime* (*get_last_call_interaction_datetime) (FolksInteractionDetails* self);
};



GType folks_interaction_details_get_type (void) G_GNUC_CONST;
guint folks_interaction_details_get_im_interaction_count (FolksInteractionDetails* self);
GDateTime* folks_interaction_details_get_last_im_interaction_datetime (FolksInteractionDetails* self);
guint folks_interaction_details_get_call_interaction_count (FolksInteractionDetails* self);
GDateTime* folks_interaction_details_get_last_call_interaction_datetime (FolksInteractionDetails* self);


guint folks_interaction_details_get_im_interaction_count (FolksInteractionDetails* self) {
	g_return_val_if_fail (self != NULL, 0U);
	return FOLKS_INTERACTION_DETAILS_GET_INTERFACE (self)->get_im_interaction_count (self);
}


GDateTime* folks_interaction_details_get_last_im_interaction_datetime (FolksInteractionDetails* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return FOLKS_INTERACTION_DETAILS_GET_INTERFACE (self)->get_last_im_interaction_datetime (self);
}


guint folks_interaction_details_get_call_interaction_count (FolksInteractionDetails* self) {
	g_return_val_if_fail (self != NULL, 0U);
	return FOLKS_INTERACTION_DETAILS_GET_INTERFACE (self)->get_call_interaction_count (self);
}


GDateTime* folks_interaction_details_get_last_call_interaction_datetime (FolksInteractionDetails* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return FOLKS_INTERACTION_DETAILS_GET_INTERFACE (self)->get_last_call_interaction_datetime (self);
}


static void folks_interaction_details_base_init (FolksInteractionDetailsIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		/**
		   * The IM interaction associated with a Persona
		   *
		   * @since 0.7.1
		   */
		g_object_interface_install_property (iface, g_param_spec_uint ("im-interaction-count", "im-interaction-count", "im-interaction-count", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		/**
		   * The latest IM interaction timestamp associated with a Persona
		   *
		   * @since 0.7.1
		   */
		g_object_interface_install_property (iface, g_param_spec_boxed ("last-im-interaction-datetime", "last-im-interaction-datetime", "last-im-interaction-datetime", G_TYPE_DATE_TIME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		/**
		   * The call interaction associated with a Persona
		   *
		   * @since 0.7.1
		   */
		g_object_interface_install_property (iface, g_param_spec_uint ("call-interaction-count", "call-interaction-count", "call-interaction-count", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		/**
		   * The latest call interaction timestamp associated with a Persona
		   *
		   * @since 0.7.1
		   */
		g_object_interface_install_property (iface, g_param_spec_boxed ("last-call-interaction-datetime", "last-call-interaction-datetime", "last-call-interaction-datetime", G_TYPE_DATE_TIME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	}
}


/**
 * Interaction details of a contact.
 *
 * Interaction details are the number and date/time of calls or IM interactions
 * with a contact, giving an idea of the recent interactions the user has had
 * with that contact.
 *
 * @since 0.7.1
 */
GType folks_interaction_details_get_type (void) {
	static volatile gsize folks_interaction_details_type_id__volatile = 0;
	if (g_once_init_enter (&folks_interaction_details_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FolksInteractionDetailsIface), (GBaseInitFunc) folks_interaction_details_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType folks_interaction_details_type_id;
		folks_interaction_details_type_id = g_type_register_static (G_TYPE_INTERFACE, "FolksInteractionDetails", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (folks_interaction_details_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&folks_interaction_details_type_id__volatile, folks_interaction_details_type_id);
	}
	return folks_interaction_details_type_id__volatile;
}



