/* init.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from init.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Guillaume Desmottes <guillaume.desmottes@collabora.co.uk>
 *          Philip Withnall <philip@tecnocode.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <folks-test.h>
#include <tp-test-contactlist.h>
#include <kf-test.h>
#include <folks/folks.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>


#define TYPE_INIT_TESTS (init_tests_get_type ())
#define INIT_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INIT_TESTS, InitTests))
#define INIT_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INIT_TESTS, InitTestsClass))
#define IS_INIT_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INIT_TESTS))
#define IS_INIT_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INIT_TESTS))
#define INIT_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INIT_TESTS, InitTestsClass))

typedef struct _InitTests InitTests;
typedef struct _InitTestsClass InitTestsClass;
typedef struct _InitTestsPrivate InitTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _InitTestsTestIndividualCountLoopData InitTestsTestIndividualCountLoopData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _InitTests {
	TpfTestMixedTestCase parent_instance;
	InitTestsPrivate * priv;
};

struct _InitTestsClass {
	TpfTestMixedTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	InitTests* self;
	GMainLoop* main_loop;
};

struct _InitTestsTestIndividualCountLoopData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	InitTests* self;
	gchar** previous_individual_ids;
	gint previous_individual_ids_length1;
	gint _previous_individual_ids_size_;
	guint i;
	gboolean _tmp0_;
	guint _tmp1_;
	guint _tmp2_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e1;
	GError* _tmp5_;
	const gchar* _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	FolksIndividualAggregator* _tmp8_;
	GeeMap* _tmp9_;
	GeeMap* _tmp10_;
	GeeSet* _tmp11_;
	GeeSet* _tmp12_;
	GeeSet* _tmp13_;
	gint _tmp14_;
	gpointer* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	FolksIndividualAggregator* _tmp17_;
	GeeMap* _tmp18_;
	GeeMap* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	gchar** _tmp22_;
	gint _tmp22__length1;
	FolksIndividualAggregator* _tmp23_;
	GeeMap* _tmp24_;
	GeeMap* _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	FolksIndividualAggregator* _tmp28_;
	GeeMap* _tmp29_;
	GeeMap* _tmp30_;
	gint _tmp31_;
	gint _tmp32_;
	gchar** _tmp33_;
	gint _tmp33__length1;
	gchar** id_collection;
	gint id_collection_length1;
	gint _id_collection_size_;
	gint id_it;
	gchar* _tmp34_;
	gchar* id;
	const gchar* _tmp35_;
	FolksIndividualAggregator* _tmp36_;
	GeeMap* _tmp37_;
	GeeMap* _tmp38_;
	const gchar* _tmp39_;
	gboolean _tmp40_;
	GError * _inner_error_;
};


static gpointer init_tests_parent_class = NULL;

GType init_tests_get_type (void) G_GNUC_CONST;
enum  {
	INIT_TESTS_DUMMY_PROPERTY
};
InitTests* init_tests_new (void);
InitTests* init_tests_construct (GType object_type);
void init_tests_test_looped (InitTests* self);
static void _init_tests_test_looped_folks_test_case_test_method (gpointer self);
void init_tests_test_individual_count (InitTests* self);
static void _init_tests_test_individual_count_folks_test_case_test_method (gpointer self);
static void init_tests_real_set_up_kf (TpfTestTestCase* base);
static void init_tests_real_set_up_tp (TpfTestTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static gboolean __lambda4_ (Block1Data* _data1_);
static void _init_tests_test_individual_count_loop (InitTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _init_tests_test_individual_count_loop_finish (InitTests* self, GAsyncResult* _res_);
static void __lambda5_ (Block1Data* _data1_, GObject* obj, GAsyncResult* res);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda4__gsource_func (gpointer self);
static void _init_tests_test_individual_count_loop_data_free (gpointer _data);
static gboolean _init_tests_test_individual_count_loop_co (InitTestsTestIndividualCountLoopData* _data_);
static void _init_tests_test_individual_count_loop_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _init_tests_test_looped_folks_test_case_test_method (gpointer self) {
#line 31 "/opt/gnome3/source/folks/tests/folks/init.vala"
	init_tests_test_looped ((InitTests*) self);
#line 170 "init.c"
}


static void _init_tests_test_individual_count_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/folks/init.vala"
	init_tests_test_individual_count ((InitTests*) self);
#line 177 "init.c"
}


InitTests* init_tests_construct (GType object_type) {
	InitTests * self = NULL;
#line 28 "/opt/gnome3/source/folks/tests/folks/init.vala"
	self = (InitTests*) tpf_test_mixed_test_case_construct (object_type, "Init");
#line 31 "/opt/gnome3/source/folks/tests/folks/init.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "looped", _init_tests_test_looped_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 32 "/opt/gnome3/source/folks/tests/folks/init.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual-count", _init_tests_test_individual_count_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 26 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return self;
#line 191 "init.c"
}


InitTests* init_tests_new (void) {
#line 26 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return init_tests_construct (TYPE_INIT_TESTS);
#line 198 "init.c"
}


static void init_tests_real_set_up_kf (TpfTestTestCase* base) {
	InitTests * self;
#line 35 "/opt/gnome3/source/folks/tests/folks/init.vala"
	self = (InitTests*) base;
#line 206 "init.c"
}


static void init_tests_real_set_up_tp (TpfTestTestCase* base) {
	InitTests * self;
	TpTestsBackend* _tmp0_ = NULL;
#line 40 "/opt/gnome3/source/folks/tests/folks/init.vala"
	self = (InitTests*) base;
#line 43 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = ((TpfTestTestCase*) self)->tp_backend;
#line 43 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_tests_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, tp_tests_backend_get_type (), TpTestsBackend));
#line 219 "init.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 56 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return self ? g_object_ref (self) : NULL;
#line 226 "init.c"
}


void init_tests_test_looped (InitTests* self) {
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	GMainLoop* _tmp13_ = NULL;
	TpTestsBackend* _tmp14_ = NULL;
	void* _tmp15_ = NULL;
	TpTestsBackend* _tmp16_ = NULL;
	void* _tmp17_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_return_if_fail (self != NULL);
#line 52 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 52 "/opt/gnome3/source/folks/tests/folks/init.vala"
	main_loop = _tmp0_;
#line 54 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 54 "/opt/gnome3/source/folks/tests/folks/init.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 56 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 56 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 56 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_backend = _tmp3_;
#line 57 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp4_ = tp_backend;
#line 57 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 57 "/opt/gnome3/source/folks/tests/folks/init.vala"
	account1_handle = _tmp5_;
#line 59 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp6_ = tp_backend;
#line 59 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol", "me2@example.com", "cm", "account2");
#line 59 "/opt/gnome3/source/folks/tests/folks/init.vala"
	account2_handle = _tmp7_;
#line 276 "init.c"
	{
		guint i = 0U;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
		i = (guint) 0;
#line 281 "init.c"
		{
			gboolean _tmp8_ = FALSE;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
			_tmp8_ = TRUE;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
			while (TRUE) {
#line 288 "init.c"
				guint _tmp10_ = 0U;
				FolksIndividualAggregator* aggregator = NULL;
				FolksIndividualAggregator* _tmp11_ = NULL;
				FolksIndividualAggregator* _tmp12_ = NULL;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (!_tmp8_) {
#line 295 "init.c"
					guint _tmp9_ = 0U;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_tmp9_ = i;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
					i = _tmp9_ + 1;
#line 301 "init.c"
				}
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_tmp8_ = FALSE;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_tmp10_ = i;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (!(_tmp10_ < ((guint) 10))) {
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
					break;
#line 311 "init.c"
				}
#line 65 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_tmp11_ = folks_individual_aggregator_dup ();
#line 65 "/opt/gnome3/source/folks/tests/folks/init.vala"
				aggregator = _tmp11_;
#line 66 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_tmp12_ = aggregator;
#line 66 "/opt/gnome3/source/folks/tests/folks/init.vala"
				folks_individual_aggregator_prepare (_tmp12_, NULL, NULL);
#line 67 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_g_object_unref0 (aggregator);
#line 67 "/opt/gnome3/source/folks/tests/folks/init.vala"
				aggregator = NULL;
#line 63 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_g_object_unref0 (aggregator);
#line 327 "init.c"
			}
		}
	}
#line 70 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp13_ = main_loop;
#line 70 "/opt/gnome3/source/folks/tests/folks/init.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp13_, 5);
#line 73 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp14_ = tp_backend;
#line 73 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp15_ = account2_handle;
#line 73 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_tests_backend_remove_account (_tmp14_, _tmp15_);
#line 74 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp16_ = tp_backend;
#line 74 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp17_ = account1_handle;
#line 74 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_tests_backend_remove_account (_tmp16_, _tmp17_);
#line 50 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_g_object_unref0 (tp_backend);
#line 50 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_g_main_loop_unref0 (main_loop);
#line 351 "init.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return _data1_;
#line 360 "init.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 369 "init.c"
		InitTests* self;
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
		self = _data1_->self;
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
		_g_object_unref0 (self);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
		g_slice_free (Block1Data, _data1_);
#line 379 "init.c"
	}
}


static void __lambda5_ (Block1Data* _data1_, GObject* obj, GAsyncResult* res) {
	InitTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/folks/init.vala"
	self = _data1_->self;
#line 105 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_return_if_fail (res != NULL);
#line 107 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = res;
#line 107 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_init_tests_test_individual_count_loop_finish (self, _tmp0_);
#line 108 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 397 "init.c"
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 105 "/opt/gnome3/source/folks/tests/folks/init.vala"
	__lambda5_ (self, source_object, res);
#line 105 "/opt/gnome3/source/folks/tests/folks/init.vala"
	block1_data_unref (self);
#line 406 "init.c"
}


static gboolean __lambda4_ (Block1Data* _data1_) {
	InitTests* self;
	gboolean result = FALSE;
#line 103 "/opt/gnome3/source/folks/tests/folks/init.vala"
	self = _data1_->self;
#line 105 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_init_tests_test_individual_count_loop (self, ___lambda5__gasync_ready_callback, block1_data_ref (_data1_));
#line 111 "/opt/gnome3/source/folks/tests/folks/init.vala"
	result = FALSE;
#line 111 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return result;
#line 421 "init.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ (self);
#line 103 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return result;
#line 430 "init.c"
}


void init_tests_test_individual_count (InitTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	void* _tmp4_ = NULL;
	void* account2_handle = NULL;
	void* _tmp5_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_return_if_fail (self != NULL);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data1_->_ref_count_ = 1;
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data1_->self = g_object_ref (self);
#line 87 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 87 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data1_->main_loop = _tmp0_;
#line 89 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 89 "/opt/gnome3/source/folks/tests/folks/init.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "msn=foo@hotmail.com\n" "[1]\n" "__alias=Bar McBadgerson\n" "jabber=bar@jabber.org\n");
#line 96 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 96 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 96 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_backend = _tmp3_;
#line 97 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp4_ = tp_tests_backend_add_account (tp_backend, "protocol", "me@example.com", "cm", "account");
#line 97 "/opt/gnome3/source/folks/tests/folks/init.vala"
	account1_handle = _tmp4_;
#line 99 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp5_ = tp_tests_backend_add_account (tp_backend, "protocol", "me2@example.com", "cm", "account2");
#line 99 "/opt/gnome3/source/folks/tests/folks/init.vala"
	account2_handle = _tmp5_;
#line 103 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda4__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 114 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_main_loop_run (_data1_->main_loop);
#line 117 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_tests_backend_remove_account (tp_backend, account2_handle);
#line 118 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tp_tests_backend_remove_account (tp_backend, account1_handle);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_g_object_unref0 (tp_backend);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	block1_data_unref (_data1_);
#line 85 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data1_ = NULL;
#line 489 "init.c"
}


static void _init_tests_test_individual_count_loop_data_free (gpointer _data) {
	InitTestsTestIndividualCountLoopData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_slice_free (InitTestsTestIndividualCountLoopData, _data_);
#line 500 "init.c"
}


static void _init_tests_test_individual_count_loop (InitTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	InitTestsTestIndividualCountLoopData* _data_;
	InitTests* _tmp0_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_ = g_slice_new0 (InitTestsTestIndividualCountLoopData);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _init_tests_test_individual_count_loop);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _init_tests_test_individual_count_loop_data_free);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_init_tests_test_individual_count_loop_co (_data_);
#line 519 "init.c"
}


static void _init_tests_test_individual_count_loop_finish (InitTests* self, GAsyncResult* _res_) {
	InitTestsTestIndividualCountLoopData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 527 "init.c"
}


static void _init_tests_test_individual_count_loop_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	InitTestsTestIndividualCountLoopData* _data_;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_ = _user_data_;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->_source_object_ = source_object;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->_res_ = _res_;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_init_tests_test_individual_count_loop_co (_data_);
#line 541 "init.c"
}


static gboolean _init_tests_test_individual_count_loop_co (InitTestsTestIndividualCountLoopData* _data_) {
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
	switch (_data_->_state_) {
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
		case 0:
#line 550 "init.c"
		goto _state_0;
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
		case 1:
#line 554 "init.c"
		goto _state_1;
		default:
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
		g_assert_not_reached ();
#line 559 "init.c"
	}
	_state_0:
#line 123 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->previous_individual_ids_length1 = 0;
#line 123 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->_previous_individual_ids_size_ = 0;
#line 123 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->previous_individual_ids = NULL;
#line 123 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->previous_individual_ids_length1 = 0;
#line 123 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->_previous_individual_ids_size_ = _data_->previous_individual_ids_length1;
#line 572 "init.c"
	{
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
		_data_->i = (guint) 0;
#line 576 "init.c"
		{
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
			_data_->_tmp0_ = TRUE;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
			while (TRUE) {
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (!_data_->_tmp0_) {
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp1_ = 0U;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp1_ = _data_->i;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->i = _data_->_tmp1_ + 1;
#line 590 "init.c"
				}
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp0_ = FALSE;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp2_ = 0U;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp2_ = _data_->i;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (!(_data_->_tmp2_ < ((guint) 10))) {
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
					break;
#line 602 "init.c"
				}
#line 127 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp3_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp3_ = folks_individual_aggregator_dup ();
#line 127 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->aggregator = _data_->_tmp3_;
#line 610 "init.c"
				{
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp4_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp4_ = _data_->aggregator;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_state_ = 1;
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					folks_test_utils_aggregator_prepare_and_wait_for_quiescence (_data_->_tmp4_, _init_tests_test_individual_count_loop_ready, _data_);
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					return FALSE;
#line 622 "init.c"
					_state_1:
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					folks_test_utils_aggregator_prepare_and_wait_for_quiescence_finish (_data_->_res_, &_data_->_inner_error_);
#line 131 "/opt/gnome3/source/folks/tests/folks/init.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 628 "init.c"
						goto __catch0_g_error;
					}
				}
				goto __finally0;
				__catch0_g_error:
				{
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->e1 = _data_->_inner_error_;
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_inner_error_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp5_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp5_ = _data_->e1;
#line 136 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp6_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp6_ = _data_->_tmp5_->message;
#line 136 "/opt/gnome3/source/folks/tests/folks/init.vala"
					g_critical ("init.vala:136: Error preparing aggregator: %s", _data_->_tmp6_);
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_g_error_free0 (_data_->e1);
#line 651 "init.c"
				}
				__finally0:
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_g_object_unref0 (_data_->aggregator);
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->previous_individual_ids = (_vala_array_free (_data_->previous_individual_ids, _data_->previous_individual_ids_length1, (GDestroyNotify) g_free), NULL);
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					g_clear_error (&_data_->_inner_error_);
#line 129 "/opt/gnome3/source/folks/tests/folks/init.vala"
					return FALSE;
#line 666 "init.c"
				}
#line 139 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp7_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp7__length1 = 0;
#line 139 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp7_ = _data_->previous_individual_ids;
#line 139 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->_tmp7__length1 = _data_->previous_individual_ids_length1;
#line 139 "/opt/gnome3/source/folks/tests/folks/init.vala"
				if (_data_->_tmp7_ == NULL) {
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp8_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp8_ = _data_->aggregator;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp9_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp9_ = folks_individual_aggregator_get_individuals (_data_->_tmp8_);
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp10_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp10_ = _data_->_tmp9_;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp11_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp11_ = gee_map_get_keys (_data_->_tmp10_);
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp12_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp12_ = _data_->_tmp11_;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp13_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp13_ = _data_->_tmp12_;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp14_ = 0;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp15_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp15_ = gee_collection_to_array ((GeeCollection*) _data_->_tmp13_, &_data_->_tmp14_);
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->previous_individual_ids = (_vala_array_free (_data_->previous_individual_ids, _data_->previous_individual_ids_length1, (GDestroyNotify) g_free), NULL);
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->previous_individual_ids = _data_->_tmp15_;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->previous_individual_ids_length1 = _data_->_tmp14_;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_previous_individual_ids_size_ = _data_->previous_individual_ids_length1;
#line 142 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_g_object_unref0 (_data_->_tmp13_);
#line 718 "init.c"
				} else {
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp16_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp16__length1 = 0;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp16_ = _data_->previous_individual_ids;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp16__length1 = _data_->previous_individual_ids_length1;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp17_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp17_ = _data_->aggregator;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp18_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp18_ = folks_individual_aggregator_get_individuals (_data_->_tmp17_);
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp19_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp19_ = _data_->_tmp18_;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp20_ = 0;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp20_ = gee_map_get_size (_data_->_tmp19_);
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp21_ = 0;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp21_ = _data_->_tmp20_;
#line 147 "/opt/gnome3/source/folks/tests/folks/init.vala"
					g_debug ("init.vala:147: %u vs %u individuals:", (guint) _data_->_tmp16__length1, (guint) _data_->_tmp21_);
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp22_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp22__length1 = 0;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp22_ = _data_->previous_individual_ids;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp22__length1 = _data_->previous_individual_ids_length1;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp23_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp23_ = _data_->aggregator;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp24_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp24_ = folks_individual_aggregator_get_individuals (_data_->_tmp23_);
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp25_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp25_ = _data_->_tmp24_;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp26_ = 0;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp26_ = gee_map_get_size (_data_->_tmp25_);
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp27_ = 0;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp27_ = _data_->_tmp26_;
#line 149 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_vala_assert (_data_->_tmp22__length1 == _data_->_tmp27_, "previous_individual_ids.length ==                   aggregator.individuals.size");
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp28_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp28_ = _data_->aggregator;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp29_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp29_ = folks_individual_aggregator_get_individuals (_data_->_tmp28_);
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp30_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp30_ = _data_->_tmp29_;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp31_ = 0;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp31_ = gee_map_get_size (_data_->_tmp30_);
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp32_ = 0;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp32_ = _data_->_tmp31_;
#line 151 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_vala_assert (_data_->_tmp32_ > 0, "aggregator.individuals.size > 0");
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp33_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp33__length1 = 0;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp33_ = _data_->previous_individual_ids;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
					_data_->_tmp33__length1 = _data_->previous_individual_ids_length1;
#line 810 "init.c"
					{
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
						_data_->id_collection_length1 = 0;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
						_data_->_id_collection_size_ = 0;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
						_data_->id_collection = _data_->_tmp33_;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
						_data_->id_collection_length1 = _data_->_tmp33__length1;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
						for (_data_->id_it = 0; _data_->id_it < _data_->_tmp33__length1; _data_->id_it = _data_->id_it + 1) {
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
							_data_->_tmp34_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
							_data_->_tmp34_ = g_strdup (_data_->id_collection[_data_->id_it]);
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
							_data_->id = _data_->_tmp34_;
#line 828 "init.c"
							{
#line 155 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp35_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp35_ = _data_->id;
#line 155 "/opt/gnome3/source/folks/tests/folks/init.vala"
								g_debug ("init.vala:155:   %s", _data_->_tmp35_);
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp36_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp36_ = _data_->aggregator;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp37_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp37_ = folks_individual_aggregator_get_individuals (_data_->_tmp36_);
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp38_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp38_ = _data_->_tmp37_;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp39_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp39_ = _data_->id;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp40_ = FALSE;
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_data_->_tmp40_ = gee_map_has_key (_data_->_tmp38_, _data_->_tmp39_);
#line 156 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_vala_assert (_data_->_tmp40_ == TRUE, "aggregator.individuals.has_key (id) == true");
#line 153 "/opt/gnome3/source/folks/tests/folks/init.vala"
								_g_free0 (_data_->id);
#line 860 "init.c"
							}
						}
					}
				}
#line 161 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_g_object_unref0 (_data_->aggregator);
#line 161 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_data_->aggregator = NULL;
#line 125 "/opt/gnome3/source/folks/tests/folks/init.vala"
				_g_object_unref0 (_data_->aggregator);
#line 871 "init.c"
			}
		}
	}
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_data_->previous_individual_ids = (_vala_array_free (_data_->previous_individual_ids, _data_->previous_individual_ids_length1, (GDestroyNotify) g_free), NULL);
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
	if (_data_->_state_ == 0) {
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 881 "init.c"
	} else {
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 885 "init.c"
	}
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_object_unref (_data_->_async_result);
#line 121 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return FALSE;
#line 891 "init.c"
}


static void init_tests_class_init (InitTestsClass * klass) {
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	init_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	((TpfTestTestCaseClass *) klass)->set_up_kf = init_tests_real_set_up_kf;
#line 24 "/opt/gnome3/source/folks/tests/folks/init.vala"
	((TpfTestTestCaseClass *) klass)->set_up_tp = init_tests_real_set_up_tp;
#line 902 "init.c"
}


static void init_tests_instance_init (InitTests * self) {
}


GType init_tests_get_type (void) {
	static volatile gsize init_tests_type_id__volatile = 0;
	if (g_once_init_enter (&init_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (InitTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) init_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (InitTests), 0, (GInstanceInitFunc) init_tests_instance_init, NULL };
		GType init_tests_type_id;
		init_tests_type_id = g_type_register_static (TPF_TEST_TYPE_MIXED_TEST_CASE, "InitTests", &g_define_type_info, 0);
		g_once_init_leave (&init_tests_type_id__volatile, init_tests_type_id);
	}
	return init_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	InitTests* tests = NULL;
	InitTests* _tmp0_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_test_init (&args_length1, &args, NULL);
#line 170 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_tmp0_ = init_tests_new ();
#line 170 "/opt/gnome3/source/folks/tests/folks/init.vala"
	tests = _tmp0_;
#line 171 "/opt/gnome3/source/folks/tests/folks/init.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 172 "/opt/gnome3/source/folks/tests/folks/init.vala"
	g_test_run ();
#line 173 "/opt/gnome3/source/folks/tests/folks/init.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 175 "/opt/gnome3/source/folks/tests/folks/init.vala"
	result = 0;
#line 175 "/opt/gnome3/source/folks/tests/folks/init.vala"
	_g_object_unref0 (tests);
#line 175 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return result;
#line 944 "init.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 166 "/opt/gnome3/source/folks/tests/folks/init.vala"
	return _vala_main (argv, argc);
#line 954 "init.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



