/* standalone-individuals.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from standalone-individuals.vala, do not modify */

/*
 * Copyright (C) 2013 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Philip Withnall <philip.withnall@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <folks/folks-dummy.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_STANDALONE_INDIVIDUALS_TESTS (standalone_individuals_tests_get_type ())
#define STANDALONE_INDIVIDUALS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STANDALONE_INDIVIDUALS_TESTS, StandaloneIndividualsTests))
#define STANDALONE_INDIVIDUALS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STANDALONE_INDIVIDUALS_TESTS, StandaloneIndividualsTestsClass))
#define IS_STANDALONE_INDIVIDUALS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STANDALONE_INDIVIDUALS_TESTS))
#define IS_STANDALONE_INDIVIDUALS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STANDALONE_INDIVIDUALS_TESTS))
#define STANDALONE_INDIVIDUALS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STANDALONE_INDIVIDUALS_TESTS, StandaloneIndividualsTestsClass))

typedef struct _StandaloneIndividualsTests StandaloneIndividualsTests;
typedef struct _StandaloneIndividualsTestsClass StandaloneIndividualsTestsClass;
typedef struct _StandaloneIndividualsTestsPrivate StandaloneIndividualsTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _StandaloneIndividualsTests {
	FolksTestCase parent_instance;
	StandaloneIndividualsTestsPrivate * priv;
};

struct _StandaloneIndividualsTestsClass {
	FolksTestCaseClass parent_class;
};


static gpointer standalone_individuals_tests_parent_class = NULL;

GType standalone_individuals_tests_get_type (void) G_GNUC_CONST;
enum  {
	STANDALONE_INDIVIDUALS_TESTS_DUMMY_PROPERTY
};
StandaloneIndividualsTests* standalone_individuals_tests_new (void);
StandaloneIndividualsTests* standalone_individuals_tests_construct (GType object_type);
void standalone_individuals_tests_test_create_empty_individual (StandaloneIndividualsTests* self);
static void _standalone_individuals_tests_test_create_empty_individual_folks_test_case_test_method (gpointer self);
void standalone_individuals_tests_test_create_singleton_individual (StandaloneIndividualsTests* self);
static void _standalone_individuals_tests_test_create_singleton_individual_folks_test_case_test_method (gpointer self);
void standalone_individuals_tests_test_create_multi_individual (StandaloneIndividualsTests* self);
static void _standalone_individuals_tests_test_create_multi_individual_folks_test_case_test_method (gpointer self);
void standalone_individuals_tests_test_persona_transferral (StandaloneIndividualsTests* self);
static void _standalone_individuals_tests_test_persona_transferral_folks_test_case_test_method (gpointer self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _standalone_individuals_tests_test_create_empty_individual_folks_test_case_test_method (gpointer self) {
#line 30 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	standalone_individuals_tests_test_create_empty_individual ((StandaloneIndividualsTests*) self);
#line 81 "standalone-individuals.c"
}


static void _standalone_individuals_tests_test_create_singleton_individual_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	standalone_individuals_tests_test_create_singleton_individual ((StandaloneIndividualsTests*) self);
#line 88 "standalone-individuals.c"
}


static void _standalone_individuals_tests_test_create_multi_individual_folks_test_case_test_method (gpointer self) {
#line 34 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	standalone_individuals_tests_test_create_multi_individual ((StandaloneIndividualsTests*) self);
#line 95 "standalone-individuals.c"
}


static void _standalone_individuals_tests_test_persona_transferral_folks_test_case_test_method (gpointer self) {
#line 36 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	standalone_individuals_tests_test_persona_transferral ((StandaloneIndividualsTests*) self);
#line 102 "standalone-individuals.c"
}


StandaloneIndividualsTests* standalone_individuals_tests_construct (GType object_type) {
	StandaloneIndividualsTests * self = NULL;
#line 27 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	self = (StandaloneIndividualsTests*) folks_test_case_construct (object_type, "StandaloneIndividuals");
#line 30 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "create empty individual", _standalone_individuals_tests_test_create_empty_individual_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 32 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "create singleton individual", _standalone_individuals_tests_test_create_singleton_individual_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 34 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "create multi individual", _standalone_individuals_tests_test_create_multi_individual_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 36 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "persona transferral", _standalone_individuals_tests_test_persona_transferral_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 25 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	return self;
#line 120 "standalone-individuals.c"
}


StandaloneIndividualsTests* standalone_individuals_tests_new (void) {
#line 25 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	return standalone_individuals_tests_construct (TYPE_STANDALONE_INDIVIDUALS_TESTS);
#line 127 "standalone-individuals.c"
}


void standalone_individuals_tests_test_create_empty_individual (StandaloneIndividualsTests* self) {
	FolksIndividual* individual = NULL;
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	FolksTrustLevel _tmp5_ = 0;
	FolksTrustLevel _tmp6_ = 0;
	GLoadableIcon* _tmp7_ = NULL;
	GLoadableIcon* _tmp8_ = NULL;
	FolksPresenceType _tmp9_ = 0;
	FolksPresenceType _tmp10_ = 0;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar** _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
	gchar** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp18_ = FALSE;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	FolksStructuredName* _tmp25_ = NULL;
	FolksStructuredName* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	FolksGender _tmp31_ = 0;
	FolksGender _tmp32_ = 0;
	GeeSet* _tmp33_ = NULL;
	GeeSet* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	gint _tmp36_ = 0;
	GeeSet* _tmp37_ = NULL;
	GeeSet* _tmp38_ = NULL;
	gint _tmp39_ = 0;
	gint _tmp40_ = 0;
	GeeSet* _tmp41_ = NULL;
	GeeSet* _tmp42_ = NULL;
	gint _tmp43_ = 0;
	gint _tmp44_ = 0;
	GeeSet* _tmp45_ = NULL;
	GeeSet* _tmp46_ = NULL;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	GeeSet* _tmp49_ = NULL;
	GeeSet* _tmp50_ = NULL;
	gint _tmp51_ = 0;
	gint _tmp52_ = 0;
	FolksLocation* _tmp53_ = NULL;
	FolksLocation* _tmp54_ = NULL;
	GDateTime* _tmp55_ = NULL;
	GDateTime* _tmp56_ = NULL;
	const gchar* _tmp57_ = NULL;
	const gchar* _tmp58_ = NULL;
	GeeSet* _tmp59_ = NULL;
	GeeSet* _tmp60_ = NULL;
	gint _tmp61_ = 0;
	gint _tmp62_ = 0;
	GeeSet* _tmp63_ = NULL;
	GeeSet* _tmp64_ = NULL;
	gint _tmp65_ = 0;
	gint _tmp66_ = 0;
	gboolean _tmp67_ = FALSE;
	gboolean _tmp68_ = FALSE;
	GeeSet* _tmp69_ = NULL;
	GeeSet* _tmp70_ = NULL;
	gint _tmp71_ = 0;
	gint _tmp72_ = 0;
	GeeMultiMap* _tmp73_ = NULL;
	GeeMultiMap* _tmp74_ = NULL;
	gint _tmp75_ = 0;
	gint _tmp76_ = 0;
	GeeMultiMap* _tmp77_ = NULL;
	GeeMultiMap* _tmp78_ = NULL;
	gint _tmp79_ = 0;
	gint _tmp80_ = 0;
	guint _tmp81_ = 0U;
	guint _tmp82_ = 0U;
	GDateTime* _tmp83_ = NULL;
	GDateTime* _tmp84_ = NULL;
	guint _tmp85_ = 0U;
	guint _tmp86_ = 0U;
	GDateTime* _tmp87_ = NULL;
	GDateTime* _tmp88_ = NULL;
	GeeSet* _tmp89_ = NULL;
	GeeSet* _tmp90_ = NULL;
	gint _tmp91_ = 0;
	gint _tmp92_ = 0;
#line 40 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_return_if_fail (self != NULL);
#line 42 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp0_ = folks_individual_new (NULL);
#line 42 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	individual = _tmp0_;
#line 43 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = folks_individual_get_personas (individual);
#line 43 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp2_ = _tmp1_;
#line 43 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 43 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp4_ = _tmp3_;
#line 43 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp4_ == 0, "individual.personas.size == 0");
#line 46 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp5_ = folks_individual_get_trust_level (individual);
#line 46 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = _tmp5_;
#line 46 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp6_ == FOLKS_TRUST_LEVEL_NONE, "individual.trust_level == TrustLevel.NONE");
#line 47 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp7_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) individual);
#line 47 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp8_ = _tmp7_;
#line 47 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp8_ == NULL, "individual.avatar == null");
#line 48 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp9_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) individual);
#line 48 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp10_ = _tmp9_;
#line 48 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp10_ == FOLKS_PRESENCE_TYPE_UNSET, "individual.presence_type == PresenceType.UNSET");
#line 49 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) individual);
#line 49 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp12_ = _tmp11_;
#line 49 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp12_, "") == 0, "individual.presence_status == \"\"");
#line 50 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp13_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) individual);
#line 50 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp14_ = _tmp13_;
#line 50 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp14_, "") == 0, "individual.presence_message == \"\"");
#line 51 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp15_ = folks_presence_details_get_client_types ((FolksPresenceDetails*) individual, &_tmp15__length1);
#line 51 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp16_ = _tmp15_;
#line 51 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp16__length1 = _tmp15__length1;
#line 51 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp16__length1 == 0, "individual.client_types.length == 0");
#line 52 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp17_ = folks_individual_get_is_user (individual);
#line 52 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp18_ = _tmp17_;
#line 52 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp18_ == FALSE, "individual.is_user == false");
#line 53 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp19_ = folks_individual_get_id (individual);
#line 53 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp20_ = _tmp19_;
#line 53 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp20_, "") == 0, "individual.id == \"\"");
#line 54 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp21_ = folks_individual_get_display_name (individual);
#line 54 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp22_ = _tmp21_;
#line 54 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp22_, "") == 0, "individual.display_name == \"\"");
#line 55 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp23_ = folks_alias_details_get_alias ((FolksAliasDetails*) individual);
#line 55 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp24_ = _tmp23_;
#line 55 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp24_, "") == 0, "individual.alias == \"\"");
#line 56 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp25_ = folks_name_details_get_structured_name ((FolksNameDetails*) individual);
#line 56 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp26_ = _tmp25_;
#line 56 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp26_ == NULL, "individual.structured_name == null");
#line 57 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp27_ = folks_name_details_get_full_name ((FolksNameDetails*) individual);
#line 57 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp28_ = _tmp27_;
#line 57 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp28_, "") == 0, "individual.full_name == \"\"");
#line 58 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp29_ = folks_name_details_get_nickname ((FolksNameDetails*) individual);
#line 58 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp30_ = _tmp29_;
#line 58 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (g_strcmp0 (_tmp30_, "") == 0, "individual.nickname == \"\"");
#line 59 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp31_ = folks_gender_details_get_gender ((FolksGenderDetails*) individual);
#line 59 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp32_ = _tmp31_;
#line 59 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp32_ == FOLKS_GENDER_UNSPECIFIED, "individual.gender == Gender.UNSPECIFIED");
#line 60 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp33_ = folks_url_details_get_urls ((FolksUrlDetails*) individual);
#line 60 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp34_ = _tmp33_;
#line 60 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 60 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp36_ = _tmp35_;
#line 60 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp36_ == 0, "individual.urls.size == 0");
#line 61 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp37_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) individual);
#line 61 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp38_ = _tmp37_;
#line 61 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 61 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp40_ = _tmp39_;
#line 61 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp40_ == 0, "individual.phone_numbers.size == 0");
#line 62 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp41_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) individual);
#line 62 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp42_ = _tmp41_;
#line 62 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp43_ = gee_collection_get_size ((GeeCollection*) _tmp42_);
#line 62 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp44_ = _tmp43_;
#line 62 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp44_ == 0, "individual.email_addresses.size == 0");
#line 63 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp45_ = folks_role_details_get_roles ((FolksRoleDetails*) individual);
#line 63 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp46_ = _tmp45_;
#line 63 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp47_ = gee_collection_get_size ((GeeCollection*) _tmp46_);
#line 63 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp48_ = _tmp47_;
#line 63 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp48_ == 0, "individual.roles.size == 0");
#line 64 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp49_ = folks_local_id_details_get_local_ids ((FolksLocalIdDetails*) individual);
#line 64 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp50_ = _tmp49_;
#line 64 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp51_ = gee_collection_get_size ((GeeCollection*) _tmp50_);
#line 64 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp52_ = _tmp51_;
#line 64 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp52_ == 0, "individual.local_ids.size == 0");
#line 65 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp53_ = folks_location_details_get_location ((FolksLocationDetails*) individual);
#line 65 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp54_ = _tmp53_;
#line 65 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp54_ == NULL, "individual.location ==null");
#line 66 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp55_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) individual);
#line 66 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp56_ = _tmp55_;
#line 66 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp56_ == NULL, "individual.birthday == null");
#line 67 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp57_ = folks_birthday_details_get_calendar_event_id ((FolksBirthdayDetails*) individual);
#line 67 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp58_ = _tmp57_;
#line 67 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp58_ == NULL, "individual.calendar_event_id == null");
#line 68 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp59_ = folks_note_details_get_notes ((FolksNoteDetails*) individual);
#line 68 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp60_ = _tmp59_;
#line 68 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp61_ = gee_collection_get_size ((GeeCollection*) _tmp60_);
#line 68 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp62_ = _tmp61_;
#line 68 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp62_ == 0, "individual.notes.size == 0");
#line 69 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp63_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) individual);
#line 69 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp64_ = _tmp63_;
#line 69 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp65_ = gee_collection_get_size ((GeeCollection*) _tmp64_);
#line 69 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp66_ = _tmp65_;
#line 69 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp66_ == 0, "individual.postal_addresses.size == 0");
#line 70 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp67_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) individual);
#line 70 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp68_ = _tmp67_;
#line 70 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp68_ == FALSE, "individual.is_favourite == false");
#line 71 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp69_ = folks_group_details_get_groups ((FolksGroupDetails*) individual);
#line 71 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp70_ = _tmp69_;
#line 71 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp71_ = gee_collection_get_size ((GeeCollection*) _tmp70_);
#line 71 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp72_ = _tmp71_;
#line 71 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp72_ == 0, "individual.groups.size == 0");
#line 72 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp73_ = folks_im_details_get_im_addresses ((FolksImDetails*) individual);
#line 72 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp74_ = _tmp73_;
#line 72 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp75_ = gee_multi_map_get_size (_tmp74_);
#line 72 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp76_ = _tmp75_;
#line 72 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp76_ == 0, "individual.im_addresses.size == 0");
#line 73 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp77_ = folks_web_service_details_get_web_service_addresses ((FolksWebServiceDetails*) individual);
#line 73 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp78_ = _tmp77_;
#line 73 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp79_ = gee_multi_map_get_size (_tmp78_);
#line 73 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp80_ = _tmp79_;
#line 73 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp80_ == 0, "individual.web_service_addresses.size == 0");
#line 74 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp81_ = folks_interaction_details_get_im_interaction_count ((FolksInteractionDetails*) individual);
#line 74 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp82_ = _tmp81_;
#line 74 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp82_ == ((guint) 0), "individual.im_interaction_count == 0");
#line 75 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp83_ = folks_interaction_details_get_last_im_interaction_datetime ((FolksInteractionDetails*) individual);
#line 75 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp84_ = _tmp83_;
#line 75 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp84_ == NULL, "individual.last_im_interaction_datetime == null");
#line 76 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp85_ = folks_interaction_details_get_call_interaction_count ((FolksInteractionDetails*) individual);
#line 76 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp86_ = _tmp85_;
#line 76 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp86_ == ((guint) 0), "individual.call_interaction_count == 0");
#line 77 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp87_ = folks_interaction_details_get_last_call_interaction_datetime ((FolksInteractionDetails*) individual);
#line 77 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp88_ = _tmp87_;
#line 77 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp88_ == NULL, "individual.last_call_interaction_datetime == null");
#line 79 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp89_ = folks_individual_get_personas (individual);
#line 79 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp90_ = _tmp89_;
#line 79 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp91_ = gee_collection_get_size ((GeeCollection*) _tmp90_);
#line 79 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp92_ = _tmp91_;
#line 79 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp92_ == 0, "individual.personas.size == 0");
#line 40 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (individual);
#line 490 "standalone-individuals.c"
}


void standalone_individuals_tests_test_create_singleton_individual (StandaloneIndividualsTests* self) {
	FolksDummyPersonaStore* persona_store = NULL;
	gchar** _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	FolksDummyPersonaStore* _tmp2_ = NULL;
	FolksDummyPersonaStore* _tmp3_ = NULL;
	FolksDummyPersona* persona = NULL;
	FolksDummyPersonaStore* _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	FolksDummyPersona* _tmp7_ = NULL;
	FolksDummyPersona* _tmp8_ = NULL;
	GeeHashSet* personas = NULL;
	GeeHashSet* _tmp9_ = NULL;
	GeeHashSet* _tmp10_ = NULL;
	FolksDummyPersona* _tmp11_ = NULL;
	FolksIndividual* individual = NULL;
	GeeHashSet* _tmp12_ = NULL;
	FolksIndividual* _tmp13_ = NULL;
	FolksIndividual* _tmp14_ = NULL;
	GeeSet* _tmp15_ = NULL;
	GeeSet* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
#line 84 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = _tmp0_;
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1__length1 = 0;
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp2_ = folks_dummy_persona_store_new ("store0", "Store 0", _tmp1_, 0);
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp3_ = _tmp2_;
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = (_vala_array_free (_tmp1_, _tmp1__length1, (GDestroyNotify) g_free), NULL);
#line 86 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona_store = _tmp3_;
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp4_ = persona_store;
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp5_ = g_new0 (gchar*, 0 + 1);
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = _tmp5_;
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6__length1 = 0;
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp7_ = folks_dummy_persona_new (_tmp4_, "persona0", FALSE, _tmp6_, 0);
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp8_ = _tmp7_;
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 87 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona = _tmp8_;
#line 88 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp9_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 88 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	personas = _tmp9_;
#line 89 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp10_ = personas;
#line 89 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11_ = persona;
#line 89 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, (FolksPersona*) _tmp11_);
#line 91 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp12_ = personas;
#line 91 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp13_ = folks_individual_new ((GeeSet*) _tmp12_);
#line 91 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	individual = _tmp13_;
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp14_ = individual;
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp15_ = folks_individual_get_personas (_tmp14_);
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp16_ = _tmp15_;
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp18_ = _tmp17_;
#line 92 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp18_ == 1, "individual.personas.size == 1");
#line 580 "standalone-individuals.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp19_ = NULL;
		GeeSet* _tmp20_ = NULL;
		GeeSet* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp19_ = individual;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp21_ = _tmp20_;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_p_it = _tmp22_;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		while (TRUE) {
#line 599 "standalone-individuals.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			FolksPersona* _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			FolksIndividual* _tmp29_ = NULL;
			FolksIndividual* _tmp30_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp23_ = _p_it;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			if (!_tmp24_) {
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
				break;
#line 617 "standalone-individuals.c"
			}
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp25_ = _p_it;
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			p = (FolksPersona*) _tmp26_;
#line 94 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp27_ = p;
#line 94 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp28_ = folks_persona_get_individual (_tmp27_);
#line 94 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp29_ = _tmp28_;
#line 94 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp30_ = individual;
#line 94 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_vala_assert (_tmp29_ == _tmp30_, "p.individual == individual");
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_g_object_unref0 (p);
#line 637 "standalone-individuals.c"
		}
#line 93 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_g_object_unref0 (_p_it);
#line 641 "standalone-individuals.c"
	}
#line 84 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (individual);
#line 84 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (personas);
#line 84 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona);
#line 84 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona_store);
#line 651 "standalone-individuals.c"
}


void standalone_individuals_tests_test_create_multi_individual (StandaloneIndividualsTests* self) {
	FolksDummyPersonaStore* persona_store = NULL;
	gchar** _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	FolksDummyPersonaStore* _tmp2_ = NULL;
	FolksDummyPersonaStore* _tmp3_ = NULL;
	FolksDummyPersona* persona1 = NULL;
	FolksDummyPersonaStore* _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	FolksDummyPersona* _tmp7_ = NULL;
	FolksDummyPersona* _tmp8_ = NULL;
	FolksDummyPersona* persona2 = NULL;
	FolksDummyPersonaStore* _tmp9_ = NULL;
	gchar** _tmp10_ = NULL;
	gchar** _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	FolksDummyPersona* _tmp12_ = NULL;
	FolksDummyPersona* _tmp13_ = NULL;
	GeeHashSet* personas = NULL;
	GeeHashSet* _tmp14_ = NULL;
	GeeHashSet* _tmp15_ = NULL;
	FolksDummyPersona* _tmp16_ = NULL;
	GeeHashSet* _tmp17_ = NULL;
	FolksDummyPersona* _tmp18_ = NULL;
	FolksIndividual* individual = NULL;
	GeeHashSet* _tmp19_ = NULL;
	FolksIndividual* _tmp20_ = NULL;
	FolksIndividual* _tmp21_ = NULL;
	GeeSet* _tmp22_ = NULL;
	GeeSet* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gint _tmp25_ = 0;
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_return_if_fail (self != NULL);
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = _tmp0_;
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1__length1 = 0;
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp2_ = folks_dummy_persona_store_new ("store0", "Store 0", _tmp1_, 0);
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp3_ = _tmp2_;
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = (_vala_array_free (_tmp1_, _tmp1__length1, (GDestroyNotify) g_free), NULL);
#line 101 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona_store = _tmp3_;
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp4_ = persona_store;
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp5_ = g_new0 (gchar*, 0 + 1);
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = _tmp5_;
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6__length1 = 0;
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp7_ = folks_dummy_persona_new (_tmp4_, "persona0", FALSE, _tmp6_, 0);
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp8_ = _tmp7_;
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 102 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona1 = _tmp8_;
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp9_ = persona_store;
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp10_ = g_new0 (gchar*, 0 + 1);
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11_ = _tmp10_;
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11__length1 = 0;
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp12_ = folks_dummy_persona_new (_tmp9_, "persona1", FALSE, _tmp11_, 0);
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp13_ = _tmp12_;
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11_ = (_vala_array_free (_tmp11_, _tmp11__length1, (GDestroyNotify) g_free), NULL);
#line 103 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona2 = _tmp13_;
#line 105 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp14_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 105 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	personas = _tmp14_;
#line 106 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp15_ = personas;
#line 106 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp16_ = persona1;
#line 106 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, (FolksPersona*) _tmp16_);
#line 107 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp17_ = personas;
#line 107 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp18_ = persona2;
#line 107 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp17_, (FolksPersona*) _tmp18_);
#line 109 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp19_ = personas;
#line 109 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp20_ = folks_individual_new ((GeeSet*) _tmp19_);
#line 109 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	individual = _tmp20_;
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp21_ = individual;
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp23_ = _tmp22_;
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp25_ = _tmp24_;
#line 110 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp25_ == 2, "individual.personas.size == 2");
#line 772 "standalone-individuals.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp26_ = NULL;
		GeeSet* _tmp27_ = NULL;
		GeeSet* _tmp28_ = NULL;
		GeeIterator* _tmp29_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp26_ = individual;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp27_ = folks_individual_get_personas (_tmp26_);
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp28_ = _tmp27_;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp29_ = gee_iterable_iterator ((GeeIterable*) _tmp28_);
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_p_it = _tmp29_;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		while (TRUE) {
#line 791 "standalone-individuals.c"
			GeeIterator* _tmp30_ = NULL;
			gboolean _tmp31_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp32_ = NULL;
			gpointer _tmp33_ = NULL;
			FolksPersona* _tmp34_ = NULL;
			FolksIndividual* _tmp35_ = NULL;
			FolksIndividual* _tmp36_ = NULL;
			FolksIndividual* _tmp37_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp30_ = _p_it;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp31_ = gee_iterator_next (_tmp30_);
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			if (!_tmp31_) {
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
				break;
#line 809 "standalone-individuals.c"
			}
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp32_ = _p_it;
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp33_ = gee_iterator_get (_tmp32_);
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			p = (FolksPersona*) _tmp33_;
#line 112 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp34_ = p;
#line 112 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp35_ = folks_persona_get_individual (_tmp34_);
#line 112 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp36_ = _tmp35_;
#line 112 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp37_ = individual;
#line 112 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_vala_assert (_tmp36_ == _tmp37_, "p.individual == individual");
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_g_object_unref0 (p);
#line 829 "standalone-individuals.c"
		}
#line 111 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_g_object_unref0 (_p_it);
#line 833 "standalone-individuals.c"
	}
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (individual);
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (personas);
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona2);
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona1);
#line 99 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona_store);
#line 845 "standalone-individuals.c"
}


void standalone_individuals_tests_test_persona_transferral (StandaloneIndividualsTests* self) {
	FolksDummyPersonaStore* persona_store = NULL;
	gchar** _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	FolksDummyPersonaStore* _tmp2_ = NULL;
	FolksDummyPersonaStore* _tmp3_ = NULL;
	FolksDummyPersona* persona = NULL;
	FolksDummyPersonaStore* _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	FolksDummyPersona* _tmp7_ = NULL;
	FolksDummyPersona* _tmp8_ = NULL;
	GeeHashSet* personas = NULL;
	GeeHashSet* _tmp9_ = NULL;
	GeeHashSet* _tmp10_ = NULL;
	FolksDummyPersona* _tmp11_ = NULL;
	FolksIndividual* individual1 = NULL;
	GeeHashSet* _tmp12_ = NULL;
	FolksIndividual* _tmp13_ = NULL;
	FolksIndividual* _tmp14_ = NULL;
	GeeSet* _tmp15_ = NULL;
	GeeSet* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	FolksIndividual* individual2 = NULL;
	GeeHashSet* _tmp31_ = NULL;
	FolksIndividual* _tmp32_ = NULL;
	FolksIndividual* _tmp33_ = NULL;
	GeeSet* _tmp34_ = NULL;
	GeeSet* _tmp35_ = NULL;
	gint _tmp36_ = 0;
	gint _tmp37_ = 0;
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_return_if_fail (self != NULL);
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = _tmp0_;
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1__length1 = 0;
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp2_ = folks_dummy_persona_store_new ("store0", "Store 0", _tmp1_, 0);
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp3_ = _tmp2_;
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp1_ = (_vala_array_free (_tmp1_, _tmp1__length1, (GDestroyNotify) g_free), NULL);
#line 119 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona_store = _tmp3_;
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp4_ = persona_store;
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp5_ = g_new0 (gchar*, 0 + 1);
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = _tmp5_;
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6__length1 = 0;
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp7_ = folks_dummy_persona_new (_tmp4_, "persona0", FALSE, _tmp6_, 0);
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp8_ = _tmp7_;
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 120 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	persona = _tmp8_;
#line 122 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp9_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 122 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	personas = _tmp9_;
#line 123 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp10_ = personas;
#line 123 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp11_ = persona;
#line 123 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, (FolksPersona*) _tmp11_);
#line 126 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp12_ = personas;
#line 126 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp13_ = folks_individual_new ((GeeSet*) _tmp12_);
#line 126 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	individual1 = _tmp13_;
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp14_ = individual1;
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp15_ = folks_individual_get_personas (_tmp14_);
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp16_ = _tmp15_;
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp18_ = _tmp17_;
#line 127 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp18_ == 1, "individual1.personas.size == 1");
#line 943 "standalone-individuals.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp19_ = NULL;
		GeeSet* _tmp20_ = NULL;
		GeeSet* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp19_ = individual1;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp21_ = _tmp20_;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_p_it = _tmp22_;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		while (TRUE) {
#line 962 "standalone-individuals.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			FolksPersona* _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			FolksIndividual* _tmp29_ = NULL;
			FolksIndividual* _tmp30_ = NULL;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp23_ = _p_it;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			if (!_tmp24_) {
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
				break;
#line 980 "standalone-individuals.c"
			}
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp25_ = _p_it;
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			p = (FolksPersona*) _tmp26_;
#line 129 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp27_ = p;
#line 129 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp28_ = folks_persona_get_individual (_tmp27_);
#line 129 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp29_ = _tmp28_;
#line 129 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp30_ = individual1;
#line 129 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_vala_assert (_tmp29_ == _tmp30_, "p.individual == individual1");
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_g_object_unref0 (p);
#line 1000 "standalone-individuals.c"
		}
#line 128 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_g_object_unref0 (_p_it);
#line 1004 "standalone-individuals.c"
	}
#line 133 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp31_ = personas;
#line 133 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp32_ = folks_individual_new ((GeeSet*) _tmp31_);
#line 133 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	individual2 = _tmp32_;
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp33_ = individual2;
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp35_ = _tmp34_;
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp36_ = gee_collection_get_size ((GeeCollection*) _tmp35_);
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp37_ = _tmp36_;
#line 134 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_vala_assert (_tmp37_ == 1, "individual2.personas.size == 1");
#line 1024 "standalone-individuals.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp38_ = NULL;
		GeeSet* _tmp39_ = NULL;
		GeeSet* _tmp40_ = NULL;
		GeeIterator* _tmp41_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp38_ = individual2;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp39_ = folks_individual_get_personas (_tmp38_);
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp40_ = _tmp39_;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_tmp41_ = gee_iterable_iterator ((GeeIterable*) _tmp40_);
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_p_it = _tmp41_;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		while (TRUE) {
#line 1043 "standalone-individuals.c"
			GeeIterator* _tmp42_ = NULL;
			gboolean _tmp43_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp44_ = NULL;
			gpointer _tmp45_ = NULL;
			FolksPersona* _tmp46_ = NULL;
			FolksIndividual* _tmp47_ = NULL;
			FolksIndividual* _tmp48_ = NULL;
			FolksIndividual* _tmp49_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp42_ = _p_it;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp43_ = gee_iterator_next (_tmp42_);
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			if (!_tmp43_) {
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
				break;
#line 1061 "standalone-individuals.c"
			}
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp44_ = _p_it;
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp45_ = gee_iterator_get (_tmp44_);
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			p = (FolksPersona*) _tmp45_;
#line 136 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp46_ = p;
#line 136 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp47_ = folks_persona_get_individual (_tmp46_);
#line 136 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp48_ = _tmp47_;
#line 136 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_tmp49_ = individual2;
#line 136 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_vala_assert (_tmp48_ == _tmp49_, "p.individual == individual2");
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
			_g_object_unref0 (p);
#line 1081 "standalone-individuals.c"
		}
#line 135 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
		_g_object_unref0 (_p_it);
#line 1085 "standalone-individuals.c"
	}
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (individual2);
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (individual1);
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (personas);
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona);
#line 117 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (persona_store);
#line 1097 "standalone-individuals.c"
}


static void standalone_individuals_tests_class_init (StandaloneIndividualsTestsClass * klass) {
#line 23 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	standalone_individuals_tests_parent_class = g_type_class_peek_parent (klass);
#line 1104 "standalone-individuals.c"
}


static void standalone_individuals_tests_instance_init (StandaloneIndividualsTests * self) {
}


GType standalone_individuals_tests_get_type (void) {
	static volatile gsize standalone_individuals_tests_type_id__volatile = 0;
	if (g_once_init_enter (&standalone_individuals_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (StandaloneIndividualsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) standalone_individuals_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (StandaloneIndividualsTests), 0, (GInstanceInitFunc) standalone_individuals_tests_instance_init, NULL };
		GType standalone_individuals_tests_type_id;
		standalone_individuals_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "StandaloneIndividualsTests", &g_define_type_info, 0);
		g_once_init_leave (&standalone_individuals_tests_type_id__volatile, standalone_individuals_tests_type_id);
	}
	return standalone_individuals_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	StandaloneIndividualsTests* tests = NULL;
	StandaloneIndividualsTests* _tmp0_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_test_init (&args_length1, &args, NULL);
#line 154 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_tmp0_ = standalone_individuals_tests_new ();
#line 154 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	tests = _tmp0_;
#line 155 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 156 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	g_test_run ();
#line 157 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 159 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	result = 0;
#line 159 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	_g_object_unref0 (tests);
#line 159 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	return result;
#line 1146 "standalone-individuals.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 150 "/opt/gnome3/source/folks/tests/folks/standalone-individuals.vala"
	return _vala_main (argv, argc);
#line 1156 "standalone-individuals.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



