/* tr-backend-factory.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from tr-backend-factory.vala, do not modify */

/*
 * Copyright (C) 2009 Zeeshan Ali (Khattak) <zeeshanak@gnome.org>.
 * Copyright (C) 2009 Nokia Corporation.
 * Copyright (C) 2010 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
 *          Travis Reitter <travis.reitter@collabora.co.uk>
 *          Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 * This file was originally part of Rygel.
 */

#include <glib.h>
#include <glib-object.h>
#include <folks/folks.h>


#define FOLKS_BACKENDS_TR_TYPE_BACKEND (folks_backends_tr_backend_get_type ())
#define FOLKS_BACKENDS_TR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_BACKENDS_TR_TYPE_BACKEND, FolksBackendsTrBackend))
#define FOLKS_BACKENDS_TR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_BACKENDS_TR_TYPE_BACKEND, FolksBackendsTrBackendClass))
#define FOLKS_BACKENDS_TR_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_BACKENDS_TR_TYPE_BACKEND))
#define FOLKS_BACKENDS_TR_IS_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_BACKENDS_TR_TYPE_BACKEND))
#define FOLKS_BACKENDS_TR_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_BACKENDS_TR_TYPE_BACKEND, FolksBackendsTrBackendClass))

typedef struct _FolksBackendsTrBackend FolksBackendsTrBackend;
typedef struct _FolksBackendsTrBackendClass FolksBackendsTrBackendClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))



void module_init (FolksBackendStore* backend_store);
FolksBackendsTrBackend* folks_backends_tr_backend_new (void);
FolksBackendsTrBackend* folks_backends_tr_backend_construct (GType object_type);
GType folks_backends_tr_backend_get_type (void) G_GNUC_CONST;
void module_finalize (FolksBackendStore* backend_store);


/**
 * The Tracker backend module entry point.
 *
 * @backend_store a store to add the Tracker backends to
 */
void module_init (FolksBackendStore* backend_store) {
	FolksBackendStore* _tmp0_ = NULL;
	FolksBackendsTrBackend* _tmp1_ = NULL;
	FolksBackendsTrBackend* _tmp2_ = NULL;
	g_return_if_fail (backend_store != NULL);
	_tmp0_ = backend_store;
	_tmp1_ = folks_backends_tr_backend_new ();
	_tmp2_ = _tmp1_;
	folks_backend_store_add_backend (_tmp0_, (FolksBackend*) _tmp2_);
	_g_object_unref0 (_tmp2_);
}


/**
 * The tracker backend module exit point.
 *
 * @param backend_store the store to remove the backends from
 */
void module_finalize (FolksBackendStore* backend_store) {
	g_return_if_fail (backend_store != NULL);
}



