/* phones-updates.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from phones-updates.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_PHONES_UPDATES_TESTS (phones_updates_tests_get_type ())
#define PHONES_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHONES_UPDATES_TESTS, PhonesUpdatesTests))
#define PHONES_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHONES_UPDATES_TESTS, PhonesUpdatesTestsClass))
#define IS_PHONES_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHONES_UPDATES_TESTS))
#define IS_PHONES_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHONES_UPDATES_TESTS))
#define PHONES_UPDATES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHONES_UPDATES_TESTS, PhonesUpdatesTestsClass))

typedef struct _PhonesUpdatesTests PhonesUpdatesTests;
typedef struct _PhonesUpdatesTestsClass PhonesUpdatesTestsClass;
typedef struct _PhonesUpdatesTestsPrivate PhonesUpdatesTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PhonesUpdatesTestsTestPhonesUpdatesAsyncData PhonesUpdatesTestsTestPhonesUpdatesAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PhonesUpdatesTests {
	TrackerTestTestCase parent_instance;
	PhonesUpdatesTestsPrivate * priv;
};

struct _PhonesUpdatesTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _PhonesUpdatesTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _initial_fullname_1;
	gchar* _contact_urn_1;
	gchar* _phone_1;
	gchar* _phone_2;
	gchar* _individual_id;
	gboolean _initial_phone_found;
	gboolean _initial_phone_found_again;
	gboolean _updated_phone_found;
};

struct _PhonesUpdatesTestsTestPhonesUpdatesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PhonesUpdatesTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer phones_updates_tests_parent_class = NULL;

GType phones_updates_tests_get_type (void) G_GNUC_CONST;
#define PHONES_UPDATES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHONES_UPDATES_TESTS, PhonesUpdatesTestsPrivate))
enum  {
	PHONES_UPDATES_TESTS_DUMMY_PROPERTY
};
PhonesUpdatesTests* phones_updates_tests_new (void);
PhonesUpdatesTests* phones_updates_tests_construct (GType object_type);
void phones_updates_tests_test_phones_updates (PhonesUpdatesTests* self);
static void _phones_updates_tests_test_phones_updates_folks_test_case_test_method (gpointer self);
static void _phones_updates_tests_test_phones_updates_async (PhonesUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _phones_updates_tests_test_phones_updates_finish (PhonesUpdatesTests* self, GAsyncResult* _res_);
static void _phones_updates_tests_test_phones_updates_async_data_free (gpointer _data);
static gboolean _phones_updates_tests_test_phones_updates_async_co (PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_);
static void _phones_updates_tests_test_phones_updates_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _phones_updates_tests_individuals_changed_cb (PhonesUpdatesTests* self, GeeMultiMap* changes);
static void __phones_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _phones_updates_tests_notify_phones_cb (PhonesUpdatesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __phones_updates_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _phones_updates_tests_update_phone (PhonesUpdatesTests* self);
static void phones_updates_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _phones_updates_tests_test_phones_updates_folks_test_case_test_method (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	phones_updates_tests_test_phones_updates ((PhonesUpdatesTests*) self);
#line 122 "phones-updates.c"
}


PhonesUpdatesTests* phones_updates_tests_construct (GType object_type) {
	PhonesUpdatesTests * self = NULL;
#line 41 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self = (PhonesUpdatesTests*) tracker_test_test_case_construct (object_type, "PhonesUpdates");
#line 43 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "phones updates", _phones_updates_tests_test_phones_updates_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 39 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return self;
#line 134 "phones-updates.c"
}


PhonesUpdatesTests* phones_updates_tests_new (void) {
#line 39 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return phones_updates_tests_construct (TYPE_PHONES_UPDATES_TESTS);
#line 141 "phones-updates.c"
}


void phones_updates_tests_test_phones_updates (PhonesUpdatesTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	TrackerTestBackend* _tmp9_ = NULL;
	TrackerTestBackend* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GMainLoop* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
#line 46 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (self != NULL);
#line 48 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 48 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 48 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_main_loop = _tmp0_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 49 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	c1 = _tmp1_;
#line 50 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 50 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 50 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_initial_fullname_1 = _tmp2_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp3_ = g_strdup ("<urn:contact001>");
#line 51 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_contact_urn_1);
#line 51 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_contact_urn_1 = _tmp3_;
#line 52 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp4_ = g_strdup ("12345");
#line 52 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_phone_1);
#line 52 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_phone_1 = _tmp4_;
#line 53 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp5_ = g_strdup ("54321");
#line 53 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_phone_2);
#line 53 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_phone_2 = _tmp5_;
#line 55 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp6_ = self->priv->_contact_urn_1;
#line 55 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRACKER_TEST_BACKEND_URN, _tmp6_);
#line 56 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp7_ = self->priv->_initial_fullname_1;
#line 56 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp7_);
#line 57 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp8_ = self->priv->_phone_1;
#line 57 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_PHONE_PROP, _tmp8_);
#line 58 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 58 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 60 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp10_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 60 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 62 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp11_ = g_strdup ("");
#line 62 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_individual_id);
#line 62 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_individual_id = _tmp11_;
#line 63 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_initial_phone_found = FALSE;
#line 64 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_initial_phone_found_again = FALSE;
#line 65 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv->_updated_phone_found = FALSE;
#line 67 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_phones_updates_tests_test_phones_updates_async (self, NULL, NULL);
#line 69 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp12_ = self->priv->_main_loop;
#line 69 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_test_utils_loop_run_with_timeout (_tmp12_, 5);
#line 71 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp13_ = self->priv->_initial_phone_found;
#line 71 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_vala_assert (_tmp13_ == TRUE, "this._initial_phone_found == true");
#line 72 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp14_ = self->priv->_initial_phone_found_again;
#line 72 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_vala_assert (_tmp14_ == FALSE, "this._initial_phone_found_again == false");
#line 73 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp15_ = self->priv->_updated_phone_found;
#line 73 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_vala_assert (_tmp15_ == TRUE, "this._updated_phone_found == true");
#line 46 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (c1);
#line 251 "phones-updates.c"
}


static void _phones_updates_tests_test_phones_updates_async_data_free (gpointer _data) {
	PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_slice_free (PhonesUpdatesTestsTestPhonesUpdatesAsyncData, _data_);
#line 262 "phones-updates.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return self ? g_object_ref (self) : NULL;
#line 269 "phones-updates.c"
}


static void _phones_updates_tests_test_phones_updates_async (PhonesUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_;
	PhonesUpdatesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_ = g_slice_new0 (PhonesUpdatesTestsTestPhonesUpdatesAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _phones_updates_tests_test_phones_updates_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _phones_updates_tests_test_phones_updates_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_phones_updates_tests_test_phones_updates_async_co (_data_);
#line 288 "phones-updates.c"
}


static void _phones_updates_tests_test_phones_updates_finish (PhonesUpdatesTests* self, GAsyncResult* _res_) {
	PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 296 "phones-updates.c"
}


static void _phones_updates_tests_test_phones_updates_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_ = _user_data_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_source_object_ = source_object;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_res_ = _res_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_phones_updates_tests_test_phones_updates_async_co (_data_);
#line 310 "phones-updates.c"
}


static void __phones_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 81 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_phones_updates_tests_individuals_changed_cb ((PhonesUpdatesTests*) self, changes);
#line 317 "phones-updates.c"
}


static gboolean _phones_updates_tests_test_phones_updates_async_co (PhonesUpdatesTestsTestPhonesUpdatesAsyncData* _data_) {
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	switch (_data_->_state_) {
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		case 0:
#line 326 "phones-updates.c"
		goto _state_0;
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		case 1:
#line 330 "phones-updates.c"
		goto _state_1;
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		case 2:
#line 334 "phones-updates.c"
		goto _state_2;
		default:
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_assert_not_reached ();
#line 339 "phones-updates.c"
	}
	_state_0:
#line 78 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp0_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 78 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->store = _data_->_tmp0_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_state_ = 1;
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_backend_store_prepare (_data_->store, _phones_updates_tests_test_phones_updates_async_ready, _data_);
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return FALSE;
#line 354 "phones-updates.c"
	_state_1:
#line 79 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 80 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp1_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 80 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 80 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 81 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp2_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 81 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __phones_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 372 "phones-updates.c"
	{
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp3_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_state_ = 2;
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _phones_updates_tests_test_phones_updates_async_ready, _data_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		return FALSE;
#line 384 "phones-updates.c"
		_state_2:
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 390 "phones-updates.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->e = _data_->_inner_error_;
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_inner_error_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp4_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp4_ = _data_->e;
#line 89 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp5_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 89 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_warning ("phones-updates.vala:89: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_g_error_free0 (_data_->e);
#line 413 "phones-updates.c"
	}
	__finally0:
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_g_object_unref0 (_data_->store);
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_clear_error (&_data_->_inner_error_);
#line 83 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		return FALSE;
#line 426 "phones-updates.c"
	}
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (_data_->store);
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	if (_data_->_state_ == 0) {
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 434 "phones-updates.c"
	} else {
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 438 "phones-updates.c"
	}
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_object_unref (_data_->_async_result);
#line 76 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return FALSE;
#line 444 "phones-updates.c"
}


static void __phones_updates_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 107 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_phones_updates_tests_notify_phones_cb ((PhonesUpdatesTests*) self, _sender, pspec);
#line 451 "phones-updates.c"
}


static void _phones_updates_tests_individuals_changed_cb (PhonesUpdatesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	gint _tmp36_ = 0;
#line 93 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (self != NULL);
#line 93 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (changes != NULL);
#line 96 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = changes;
#line 96 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	added = _tmp1_;
#line 97 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp2_ = changes;
#line 97 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 97 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	removed = _tmp3_;
#line 481 "phones-updates.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp4_ = added;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_i_it = _tmp5_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		while (TRUE) {
#line 494 "phones-updates.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp6_ = _i_it;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (!_tmp7_) {
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				break;
#line 513 "phones-updates.c"
			}
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp8_ = _i_it;
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			i = (FolksIndividual*) _tmp9_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp10_ = i;
#line 101 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 103 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp11_ = i;
#line 103 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 103 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp13_ = _tmp12_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp14_ = self->priv->_initial_fullname_1;
#line 103 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 535 "phones-updates.c"
				FolksIndividual* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				FolksIndividual* _tmp19_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp15_ = i;
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp16_ = folks_individual_get_id (_tmp15_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp17_ = _tmp16_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_g_free0 (self->priv->_individual_id);
#line 105 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				self->priv->_individual_id = _tmp18_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp19_ = i;
#line 107 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				g_signal_connect_object ((GObject*) _tmp19_, "notify::phone-numbers", (GCallback) __phones_updates_tests_notify_phones_cb_g_object_notify, self, 0);
#line 557 "phones-updates.c"
				{
					GeeIterator* _fd_it = NULL;
					FolksIndividual* _tmp20_ = NULL;
					GeeSet* _tmp21_ = NULL;
					GeeSet* _tmp22_ = NULL;
					GeeIterator* _tmp23_ = NULL;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_tmp20_ = i;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_tmp21_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp20_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_tmp22_ = _tmp21_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_fd_it = _tmp23_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					while (TRUE) {
#line 576 "phones-updates.c"
						GeeIterator* _tmp24_ = NULL;
						gboolean _tmp25_ = FALSE;
						FolksPhoneFieldDetails* fd = NULL;
						GeeIterator* _tmp26_ = NULL;
						gpointer _tmp27_ = NULL;
						gchar* phone = NULL;
						FolksPhoneFieldDetails* _tmp28_ = NULL;
						gconstpointer _tmp29_ = NULL;
						const gchar* _tmp30_ = NULL;
						gchar* _tmp31_ = NULL;
						const gchar* _tmp32_ = NULL;
						const gchar* _tmp33_ = NULL;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp24_ = _fd_it;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp25_ = gee_iterator_next (_tmp24_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						if (!_tmp25_) {
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
							break;
#line 597 "phones-updates.c"
						}
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp26_ = _fd_it;
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp27_ = gee_iterator_get (_tmp26_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						fd = (FolksPhoneFieldDetails*) _tmp27_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp28_ = fd;
#line 111 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp29_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp28_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp30_ = _tmp29_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp31_ = g_strdup ((const gchar*) _tmp30_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						phone = _tmp31_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp32_ = phone;
#line 112 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_tmp33_ = self->priv->_phone_1;
#line 112 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						if (g_strcmp0 (_tmp32_, _tmp33_) == 0) {
#line 114 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
							self->priv->_initial_phone_found = TRUE;
#line 115 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
							_phones_updates_tests_update_phone (self);
#line 625 "phones-updates.c"
						}
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_g_free0 (phone);
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
						_g_object_unref0 (fd);
#line 631 "phones-updates.c"
					}
#line 109 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
					_g_object_unref0 (_fd_it);
#line 635 "phones-updates.c"
				}
			}
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_g_object_unref0 (i);
#line 640 "phones-updates.c"
		}
#line 99 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_g_object_unref0 (_i_it);
#line 644 "phones-updates.c"
	}
#line 121 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp34_ = removed;
#line 121 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp36_ = _tmp35_;
#line 121 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_vala_assert (_tmp36_ == 1, "removed.size == 1");
#line 654 "phones-updates.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp37_ = NULL;
		GeeIterator* _tmp38_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp37_ = removed;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_i_it = _tmp38_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		while (TRUE) {
#line 667 "phones-updates.c"
			GeeIterator* _tmp39_ = NULL;
			gboolean _tmp40_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp41_ = NULL;
			gpointer _tmp42_ = NULL;
			FolksIndividual* _tmp43_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp39_ = _i_it;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp40_ = gee_iterator_next (_tmp39_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (!_tmp40_) {
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				break;
#line 682 "phones-updates.c"
			}
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp41_ = _i_it;
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp42_ = gee_iterator_get (_tmp41_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			i = (FolksIndividual*) _tmp42_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp43_ = i;
#line 125 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_vala_assert (_tmp43_ == NULL, "i == null");
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_g_object_unref0 (i);
#line 696 "phones-updates.c"
		}
#line 123 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_g_object_unref0 (_i_it);
#line 700 "phones-updates.c"
	}
#line 93 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (removed);
#line 93 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (added);
#line 706 "phones-updates.c"
}


static void _phones_updates_tests_notify_phones_cb (PhonesUpdatesTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (self != NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (individual_obj != NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (ps != NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = individual_obj;
#line 131 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 131 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	i = _tmp1_;
#line 726 "phones-updates.c"
	{
		GeeIterator* _fd_it = NULL;
		FolksIndividual* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp2_ = i;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp3_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp2_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp4_ = _tmp3_;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_fd_it = _tmp5_;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		while (TRUE) {
#line 745 "phones-updates.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksPhoneFieldDetails* fd = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			gchar* phone = NULL;
			FolksPhoneFieldDetails* _tmp10_ = NULL;
			gconstpointer _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp6_ = _fd_it;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (!_tmp7_) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				break;
#line 768 "phones-updates.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp8_ = _fd_it;
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			fd = (FolksPhoneFieldDetails*) _tmp9_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp10_ = fd;
#line 134 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp11_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp10_);
#line 134 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp12_ = _tmp11_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp13_ = g_strdup ((const gchar*) _tmp12_);
#line 134 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			phone = _tmp13_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp14_ = phone;
#line 135 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp15_ = self->priv->_phone_1;
#line 135 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (g_strcmp0 (_tmp14_, _tmp15_) == 0) {
#line 137 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				self->priv->_initial_phone_found_again = TRUE;
#line 794 "phones-updates.c"
			}
#line 139 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp16_ = phone;
#line 139 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_tmp17_ = self->priv->_phone_2;
#line 139 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			if (g_strcmp0 (_tmp16_, _tmp17_) == 0) {
#line 802 "phones-updates.c"
				GMainLoop* _tmp18_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				self->priv->_updated_phone_found = TRUE;
#line 142 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				_tmp18_ = self->priv->_main_loop;
#line 142 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
				g_main_loop_quit (_tmp18_);
#line 810 "phones-updates.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_g_free0 (phone);
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
			_g_object_unref0 (fd);
#line 816 "phones-updates.c"
		}
#line 132 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
		_g_object_unref0 (_fd_it);
#line 820 "phones-updates.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (i);
#line 824 "phones-updates.c"
}


static void _phones_updates_tests_update_phone (PhonesUpdatesTests* self) {
	gchar* urn_phone_1 = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	TrackerTestBackend* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* urn_phone_2 = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	TrackerTestBackend* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* affl_2 = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	TrackerTestBackend* _tmp19_ = NULL;
	TrackerTestBackend* _tmp20_ = NULL;
	TrackerTestBackend* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_return_if_fail (self != NULL);
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = self->priv->_phone_1;
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp1_ = g_strconcat ("<", _tmp0_, NULL);
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp2_ = _tmp1_;
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp3_ = g_strconcat (_tmp2_, ">", NULL);
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp4_ = _tmp3_;
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (_tmp2_);
#line 149 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	urn_phone_1 = _tmp4_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp5_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 150 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp6_ = self->priv->_contact_urn_1;
#line 150 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_remove_triplet (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp6_, TRF_ONTOLOGY_DEFS_NCO_HAS_AFFILIATION, urn_phone_1);
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp7_ = self->priv->_phone_2;
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp8_ = g_strconcat ("<phone:", _tmp7_, NULL);
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp9_ = _tmp8_;
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp10_ = g_strconcat (_tmp9_, ">", NULL);
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp11_ = _tmp10_;
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (_tmp9_);
#line 153 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	urn_phone_2 = _tmp11_;
#line 154 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp12_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 154 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp13_ = self->priv->_phone_2;
#line 154 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_insert_triplet (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), urn_phone_2, "a", TRF_ONTOLOGY_DEFS_NCO_PHONE, TRF_ONTOLOGY_DEFS_NCO_PHONE_PROP, _tmp13_, NULL, NULL);
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp14_ = self->priv->_phone_2;
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp15_ = g_strconcat ("<", _tmp14_, NULL);
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp16_ = _tmp15_;
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp17_ = g_strconcat (_tmp16_, ">", NULL);
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp18_ = _tmp17_;
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (_tmp16_);
#line 159 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	affl_2 = _tmp18_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp19_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 160 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_insert_triplet (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), affl_2, "a", TRF_ONTOLOGY_DEFS_NCO_AFFILIATION, NULL, NULL, NULL, NULL);
#line 163 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp20_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 163 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_insert_triplet (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), affl_2, TRF_ONTOLOGY_DEFS_NCO_HAS_PHONE, urn_phone_2, NULL, NULL, NULL, NULL);
#line 167 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp21_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 167 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp22_ = self->priv->_contact_urn_1;
#line 167 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tracker_test_backend_insert_triplet (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp22_, TRF_ONTOLOGY_DEFS_NCO_HAS_AFFILIATION, affl_2, NULL, NULL, NULL, NULL);
#line 147 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (affl_2);
#line 147 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (urn_phone_2);
#line 147 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (urn_phone_1);
#line 931 "phones-updates.c"
}


static void phones_updates_tests_class_init (PhonesUpdatesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	phones_updates_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_type_class_add_private (klass, sizeof (PhonesUpdatesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	G_OBJECT_CLASS (klass)->finalize = phones_updates_tests_finalize;
#line 942 "phones-updates.c"
}


static void phones_updates_tests_instance_init (PhonesUpdatesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self->priv = PHONES_UPDATES_TESTS_GET_PRIVATE (self);
#line 949 "phones-updates.c"
}


static void phones_updates_tests_finalize (GObject* obj) {
	PhonesUpdatesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHONES_UPDATES_TESTS, PhonesUpdatesTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_initial_fullname_1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_contact_urn_1);
#line 32 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_phone_1);
#line 33 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_phone_2);
#line 34 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_free0 (self->priv->_individual_id);
#line 26 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	G_OBJECT_CLASS (phones_updates_tests_parent_class)->finalize (obj);
#line 973 "phones-updates.c"
}


GType phones_updates_tests_get_type (void) {
	static volatile gsize phones_updates_tests_type_id__volatile = 0;
	if (g_once_init_enter (&phones_updates_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhonesUpdatesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) phones_updates_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhonesUpdatesTests), 0, (GInstanceInitFunc) phones_updates_tests_instance_init, NULL };
		GType phones_updates_tests_type_id;
		phones_updates_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "PhonesUpdatesTests", &g_define_type_info, 0);
		g_once_init_leave (&phones_updates_tests_type_id__volatile, phones_updates_tests_type_id);
	}
	return phones_updates_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PhonesUpdatesTests* tests = NULL;
	PhonesUpdatesTests* _tmp0_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_test_init (&args_length1, &args, NULL);
#line 177 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_tmp0_ = phones_updates_tests_new ();
#line 177 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	tests = _tmp0_;
#line 178 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 179 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	g_test_run ();
#line 180 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 182 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	result = 0;
#line 182 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	_g_object_unref0 (tests);
#line 182 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return result;
#line 1011 "phones-updates.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 173 "/opt/gnome3/source/folks/tests/tracker/phones-updates.vala"
	return _vala_main (argv, argc);
#line 1021 "phones-updates.c"
}



