/* set-phones.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from set-phones.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_SET_PHONES_TESTS (set_phones_tests_get_type ())
#define SET_PHONES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_PHONES_TESTS, SetPhonesTests))
#define SET_PHONES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_PHONES_TESTS, SetPhonesTestsClass))
#define IS_SET_PHONES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_PHONES_TESTS))
#define IS_SET_PHONES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_PHONES_TESTS))
#define SET_PHONES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_PHONES_TESTS, SetPhonesTestsClass))

typedef struct _SetPhonesTests SetPhonesTests;
typedef struct _SetPhonesTestsClass SetPhonesTestsClass;
typedef struct _SetPhonesTestsPrivate SetPhonesTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetPhonesTestsTestSetPhonesAsyncData SetPhonesTestsTestSetPhonesAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetPhonesTests {
	TrackerTestTestCase parent_instance;
	SetPhonesTestsPrivate * priv;
};

struct _SetPhonesTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _SetPhonesTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	gchar* _phone_1;
	gchar* _phone_2;
	gboolean _phone_1_found;
	gboolean _phone_2_found;
};

struct _SetPhonesTestsTestSetPhonesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetPhonesTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer set_phones_tests_parent_class = NULL;

GType set_phones_tests_get_type (void) G_GNUC_CONST;
#define SET_PHONES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_PHONES_TESTS, SetPhonesTestsPrivate))
enum  {
	SET_PHONES_TESTS_DUMMY_PROPERTY
};
SetPhonesTests* set_phones_tests_new (void);
SetPhonesTests* set_phones_tests_construct (GType object_type);
void set_phones_tests_test_set_phones (SetPhonesTests* self);
static void _set_phones_tests_test_set_phones_folks_test_case_test_method (gpointer self);
static void _set_phones_tests_test_set_phones_async (SetPhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_phones_tests_test_set_phones_finish (SetPhonesTests* self, GAsyncResult* _res_);
static void _set_phones_tests_test_set_phones_async_data_free (gpointer _data);
static gboolean _set_phones_tests_test_set_phones_async_co (SetPhonesTestsTestSetPhonesAsyncData* _data_);
static void _set_phones_tests_test_set_phones_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_phones_tests_individuals_changed_cb (SetPhonesTests* self, GeeMultiMap* changes);
static void __set_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_phones_tests_notify_phones_cb (SetPhonesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __set_phones_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void set_phones_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_phones_tests_test_set_phones_folks_test_case_test_method (gpointer self) {
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	set_phones_tests_test_set_phones ((SetPhonesTests*) self);
#line 120 "set-phones.c"
}


SetPhonesTests* set_phones_tests_construct (GType object_type) {
	SetPhonesTests * self = NULL;
#line 38 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self = (SetPhonesTests*) tracker_test_test_case_construct (object_type, "SetPhonesTests");
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test setting phones ", _set_phones_tests_test_set_phones_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 36 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return self;
#line 132 "set-phones.c"
}


SetPhonesTests* set_phones_tests_new (void) {
#line 36 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return set_phones_tests_construct (TYPE_SET_PHONES_TESTS);
#line 139 "set-phones.c"
}


void set_phones_tests_test_set_phones (SetPhonesTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	TrackerTestBackend* _tmp6_ = NULL;
	TrackerTestBackend* _tmp7_ = NULL;
	GMainLoop* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
#line 43 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (self != NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_main_loop = _tmp0_;
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	c1 = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 47 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 47 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_persona_fullname = _tmp2_;
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp3_ = g_strdup ("12345");
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_phone_1);
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_phone_1 = _tmp3_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp4_ = g_strdup ("54321");
#line 49 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_phone_2);
#line 49 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_phone_2 = _tmp4_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp5_ = self->priv->_persona_fullname;
#line 51 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp5_);
#line 52 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp6_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 52 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 54 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp7_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 54 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 56 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_phone_1_found = FALSE;
#line 57 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv->_phone_2_found = FALSE;
#line 59 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_set_phones_tests_test_set_phones_async (self, NULL, NULL);
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp8_ = self->priv->_main_loop;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_test_utils_loop_run_with_timeout (_tmp8_, 5);
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp9_ = self->priv->_phone_1_found;
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_vala_assert (_tmp9_, "this._phone_1_found");
#line 64 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp10_ = self->priv->_phone_2_found;
#line 64 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_vala_assert (_tmp10_, "this._phone_2_found");
#line 43 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (c1);
#line 218 "set-phones.c"
}


static void _set_phones_tests_test_set_phones_async_data_free (gpointer _data) {
	SetPhonesTestsTestSetPhonesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_slice_free (SetPhonesTestsTestSetPhonesAsyncData, _data_);
#line 229 "set-phones.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return self ? g_object_ref (self) : NULL;
#line 236 "set-phones.c"
}


static void _set_phones_tests_test_set_phones_async (SetPhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetPhonesTestsTestSetPhonesAsyncData* _data_;
	SetPhonesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_ = g_slice_new0 (SetPhonesTestsTestSetPhonesAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_phones_tests_test_set_phones_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_phones_tests_test_set_phones_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_set_phones_tests_test_set_phones_async_co (_data_);
#line 255 "set-phones.c"
}


static void _set_phones_tests_test_set_phones_finish (SetPhonesTests* self, GAsyncResult* _res_) {
	SetPhonesTestsTestSetPhonesAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 263 "set-phones.c"
}


static void _set_phones_tests_test_set_phones_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetPhonesTestsTestSetPhonesAsyncData* _data_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_ = _user_data_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_source_object_ = source_object;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_res_ = _res_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_set_phones_tests_test_set_phones_async_co (_data_);
#line 277 "set-phones.c"
}


static void __set_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_set_phones_tests_individuals_changed_cb ((SetPhonesTests*) self, changes);
#line 284 "set-phones.c"
}


static gboolean _set_phones_tests_test_set_phones_async_co (SetPhonesTestsTestSetPhonesAsyncData* _data_) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	switch (_data_->_state_) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		case 0:
#line 293 "set-phones.c"
		goto _state_0;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		case 1:
#line 297 "set-phones.c"
		goto _state_1;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		case 2:
#line 301 "set-phones.c"
		goto _state_2;
		default:
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_assert_not_reached ();
#line 306 "set-phones.c"
	}
	_state_0:
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp0_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->store = _data_->_tmp0_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_state_ = 1;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_backend_store_prepare (_data_->store, _set_phones_tests_test_set_phones_async_ready, _data_);
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return FALSE;
#line 321 "set-phones.c"
	_state_1:
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp1_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp2_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __set_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 339 "set-phones.c"
	{
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp3_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_state_ = 2;
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _set_phones_tests_test_set_phones_async_ready, _data_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		return FALSE;
#line 351 "set-phones.c"
		_state_2:
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 357 "set-phones.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->e = _data_->_inner_error_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_inner_error_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp4_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp4_ = _data_->e;
#line 80 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp5_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 80 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_warning ("set-phones.vala:80: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_g_error_free0 (_data_->e);
#line 380 "set-phones.c"
	}
	__finally0:
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_g_object_unref0 (_data_->store);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_clear_error (&_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		return FALSE;
#line 393 "set-phones.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (_data_->store);
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	if (_data_->_state_ == 0) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 401 "set-phones.c"
	} else {
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 405 "set-phones.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_object_unref (_data_->_async_result);
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return FALSE;
#line 411 "set-phones.c"
}


static void __set_phones_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_set_phones_tests_notify_phones_cb ((SetPhonesTests*) self, _sender, pspec);
#line 418 "set-phones.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return result;
#line 427 "set-phones.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return result;
#line 436 "set-phones.c"
}


static void _set_phones_tests_individuals_changed_cb (SetPhonesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp35_ = NULL;
	gint _tmp36_ = 0;
	gint _tmp37_ = 0;
#line 84 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (self != NULL);
#line 84 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (changes != NULL);
#line 87 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp0_ = changes;
#line 87 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 87 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	added = _tmp1_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp2_ = changes;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	removed = _tmp3_;
#line 466 "set-phones.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp4_ = added;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_i_it = _tmp5_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		while (TRUE) {
#line 479 "set-phones.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp6_ = _i_it;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			if (!_tmp7_) {
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				break;
#line 498 "set-phones.c"
			}
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp8_ = _i_it;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			i = (FolksIndividual*) _tmp9_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp10_ = i;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp11_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp13_ = _tmp12_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp14_ = self->priv->_persona_fullname;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 520 "set-phones.c"
				FolksIndividual* _tmp15_ = NULL;
				GeeHashSet* phones = NULL;
				GeeHashSet* _tmp16_ = NULL;
				FolksPhoneFieldDetails* p1 = NULL;
				const gchar* _tmp17_ = NULL;
				FolksPhoneFieldDetails* _tmp18_ = NULL;
				GeeHashSet* _tmp19_ = NULL;
				FolksPhoneFieldDetails* _tmp20_ = NULL;
				FolksPhoneFieldDetails* p2 = NULL;
				const gchar* _tmp21_ = NULL;
				FolksPhoneFieldDetails* _tmp22_ = NULL;
				GeeHashSet* _tmp23_ = NULL;
				FolksPhoneFieldDetails* _tmp24_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp15_ = i;
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::phone-numbers", (GCallback) __set_phones_tests_notify_phones_cb_g_object_notify, self, 0);
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp16_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				phones = _tmp16_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp17_ = self->priv->_phone_1;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp18_ = folks_phone_field_details_new (_tmp17_, NULL);
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				p1 = _tmp18_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp19_ = phones;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp20_ = p1;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, _tmp20_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp21_ = self->priv->_phone_2;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp22_ = folks_phone_field_details_new (_tmp21_, NULL);
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				p2 = _tmp22_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp23_ = phones;
#line 105 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp24_ = p2;
#line 105 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, _tmp24_);
#line 566 "set-phones.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp25_ = NULL;
					GeeSet* _tmp26_ = NULL;
					GeeSet* _tmp27_ = NULL;
					GeeIterator* _tmp28_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp25_ = i;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp26_ = folks_individual_get_personas (_tmp25_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp27_ = _tmp26_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_p_it = _tmp28_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					while (TRUE) {
#line 585 "set-phones.c"
						GeeIterator* _tmp29_ = NULL;
						gboolean _tmp30_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp31_ = NULL;
						gpointer _tmp32_ = NULL;
						FolksPersona* _tmp33_ = NULL;
						GeeHashSet* _tmp34_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp29_ = _p_it;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp30_ = gee_iterator_next (_tmp29_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						if (!_tmp30_) {
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
							break;
#line 601 "set-phones.c"
						}
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp31_ = _p_it;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp32_ = gee_iterator_get (_tmp31_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						p = (FolksPersona*) _tmp32_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp33_ = p;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_tmp34_ = phones;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						folks_phone_details_set_phone_numbers (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, FOLKS_TYPE_PHONE_DETAILS, FolksPhoneDetails), (GeeSet*) _tmp34_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						_g_object_unref0 (p);
#line 617 "set-phones.c"
					}
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_g_object_unref0 (_p_it);
#line 621 "set-phones.c"
				}
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_g_object_unref0 (p2);
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_g_object_unref0 (p1);
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_g_object_unref0 (phones);
#line 629 "set-phones.c"
			}
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_g_object_unref0 (i);
#line 633 "set-phones.c"
		}
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_g_object_unref0 (_i_it);
#line 637 "set-phones.c"
	}
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp35_ = removed;
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp36_ = gee_collection_get_size ((GeeCollection*) _tmp35_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp37_ = _tmp36_;
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_vala_assert (_tmp37_ == 1, "removed.size == 1");
#line 647 "set-phones.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp38_ = NULL;
		GeeIterator* _tmp39_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp38_ = removed;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp39_ = gee_iterable_iterator ((GeeIterable*) _tmp38_);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_i_it = _tmp39_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		while (TRUE) {
#line 660 "set-phones.c"
			GeeIterator* _tmp40_ = NULL;
			gboolean _tmp41_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp42_ = NULL;
			gpointer _tmp43_ = NULL;
			FolksIndividual* _tmp44_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp40_ = _i_it;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp41_ = gee_iterator_next (_tmp40_);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			if (!_tmp41_) {
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				break;
#line 675 "set-phones.c"
			}
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp42_ = _i_it;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp43_ = gee_iterator_get (_tmp42_);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			i = (FolksIndividual*) _tmp43_;
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp44_ = i;
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_vala_assert (_tmp44_ == NULL, "i == null");
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_g_object_unref0 (i);
#line 689 "set-phones.c"
		}
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_g_object_unref0 (_i_it);
#line 693 "set-phones.c"
	}
#line 84 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (removed);
#line 84 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (added);
#line 699 "set-phones.c"
}


static void _set_phones_tests_notify_phones_cb (SetPhonesTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (self != NULL);
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (individual_obj != NULL);
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_return_if_fail (ps != NULL);
#line 124 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp0_ = individual_obj;
#line 124 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 124 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	i = _tmp1_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp2_ = i;
#line 125 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 125 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp4_ = _tmp3_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp5_ = self->priv->_persona_fullname;
#line 125 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 735 "set-phones.c"
		{
			GeeIterator* _p_it = NULL;
			FolksIndividual* _tmp6_ = NULL;
			GeeSet* _tmp7_ = NULL;
			GeeSet* _tmp8_ = NULL;
			GeeIterator* _tmp9_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp6_ = i;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp7_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp6_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp8_ = _tmp7_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_tmp9_ = gee_iterable_iterator ((GeeIterable*) _tmp8_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_p_it = _tmp9_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			while (TRUE) {
#line 754 "set-phones.c"
				GeeIterator* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				FolksPhoneFieldDetails* p = NULL;
				GeeIterator* _tmp12_ = NULL;
				gpointer _tmp13_ = NULL;
				FolksPhoneFieldDetails* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				FolksPhoneFieldDetails* _tmp16_ = NULL;
				FolksPhoneFieldDetails* _tmp17_ = NULL;
				gboolean _tmp18_ = FALSE;
				gboolean _tmp19_ = FALSE;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp10_ = _p_it;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp11_ = gee_iterator_next (_tmp10_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				if (!_tmp11_) {
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					break;
#line 774 "set-phones.c"
				}
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp12_ = _p_it;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp13_ = gee_iterator_get (_tmp12_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				p = (FolksPhoneFieldDetails*) _tmp13_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp14_ = p;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp15_ = self->priv->_phone_1;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp16_ = folks_phone_field_details_new (_tmp15_, NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp17_ = _tmp16_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp18_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp14_, (FolksAbstractFieldDetails*) _tmp17_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_tmp19_ = _tmp18_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_g_object_unref0 (_tmp17_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				if (_tmp19_) {
#line 130 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					self->priv->_phone_1_found = TRUE;
#line 800 "set-phones.c"
				} else {
					FolksPhoneFieldDetails* _tmp20_ = NULL;
					const gchar* _tmp21_ = NULL;
					FolksPhoneFieldDetails* _tmp22_ = NULL;
					FolksPhoneFieldDetails* _tmp23_ = NULL;
					gboolean _tmp24_ = FALSE;
					gboolean _tmp25_ = FALSE;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp20_ = p;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp21_ = self->priv->_phone_2;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp22_ = folks_phone_field_details_new (_tmp21_, NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp23_ = _tmp22_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp24_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp20_, (FolksAbstractFieldDetails*) _tmp23_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_tmp25_ = _tmp24_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					_g_object_unref0 (_tmp23_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
					if (_tmp25_) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
						self->priv->_phone_2_found = TRUE;
#line 826 "set-phones.c"
					}
				}
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
				_g_object_unref0 (p);
#line 831 "set-phones.c"
			}
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
			_g_object_unref0 (_p_it);
#line 835 "set-phones.c"
		}
	}
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp27_ = self->priv->_phone_1_found;
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	if (_tmp27_) {
#line 842 "set-phones.c"
		gboolean _tmp28_ = FALSE;
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp28_ = self->priv->_phone_2_found;
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp26_ = _tmp28_;
#line 848 "set-phones.c"
	} else {
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp26_ = FALSE;
#line 852 "set-phones.c"
	}
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	if (_tmp26_) {
#line 856 "set-phones.c"
		GMainLoop* _tmp29_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		_tmp29_ = self->priv->_main_loop;
#line 138 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
		g_main_loop_quit (_tmp29_);
#line 862 "set-phones.c"
	}
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (i);
#line 866 "set-phones.c"
}


static void set_phones_tests_class_init (SetPhonesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	set_phones_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_type_class_add_private (klass, sizeof (SetPhonesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	G_OBJECT_CLASS (klass)->finalize = set_phones_tests_finalize;
#line 877 "set-phones.c"
}


static void set_phones_tests_instance_init (SetPhonesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self->priv = SET_PHONES_TESTS_GET_PRIVATE (self);
#line 884 "set-phones.c"
}


static void set_phones_tests_finalize (GObject* obj) {
	SetPhonesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_PHONES_TESTS, SetPhonesTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 31 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_phone_1);
#line 32 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_free0 (self->priv->_phone_2);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	G_OBJECT_CLASS (set_phones_tests_parent_class)->finalize (obj);
#line 904 "set-phones.c"
}


GType set_phones_tests_get_type (void) {
	static volatile gsize set_phones_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_phones_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetPhonesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_phones_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetPhonesTests), 0, (GInstanceInitFunc) set_phones_tests_instance_init, NULL };
		GType set_phones_tests_type_id;
		set_phones_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "SetPhonesTests", &g_define_type_info, 0);
		g_once_init_leave (&set_phones_tests_type_id__volatile, set_phones_tests_type_id);
	}
	return set_phones_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetPhonesTests* tests = NULL;
	SetPhonesTests* _tmp0_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_test_init (&args_length1, &args, NULL);
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_tmp0_ = set_phones_tests_new ();
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	tests = _tmp0_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 149 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	g_test_run ();
#line 150 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	result = 0;
#line 152 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	_g_object_unref0 (tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return result;
#line 942 "set-phones.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-phones.vala"
	return _vala_main (argv, argc);
#line 952 "set-phones.c"
}



