/* im-details-interface.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from im-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_IM_DETAILS_INTERFACE_TESTS (im_details_interface_tests_get_type ())
#define IM_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IM_DETAILS_INTERFACE_TESTS, ImDetailsInterfaceTests))
#define IM_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IM_DETAILS_INTERFACE_TESTS, ImDetailsInterfaceTestsClass))
#define IS_IM_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IM_DETAILS_INTERFACE_TESTS))
#define IS_IM_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IM_DETAILS_INTERFACE_TESTS))
#define IM_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IM_DETAILS_INTERFACE_TESTS, ImDetailsInterfaceTestsClass))

typedef struct _ImDetailsInterfaceTests ImDetailsInterfaceTests;
typedef struct _ImDetailsInterfaceTestsClass ImDetailsInterfaceTestsClass;
typedef struct _ImDetailsInterfaceTestsPrivate ImDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ImDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	ImDetailsInterfaceTestsPrivate * priv;
};

struct _ImDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _ImDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _num_addrs;
	gboolean _found_addr_1;
	gboolean _found_addr_2;
	gchar* _fullname;
};

struct _ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ImDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer im_details_interface_tests_parent_class = NULL;

GType im_details_interface_tests_get_type (void) G_GNUC_CONST;
#define IM_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_IM_DETAILS_INTERFACE_TESTS, ImDetailsInterfaceTestsPrivate))
enum  {
	IM_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
ImDetailsInterfaceTests* im_details_interface_tests_new (void);
ImDetailsInterfaceTests* im_details_interface_tests_construct (GType object_type);
void im_details_interface_tests_test_im_details_interface (ImDetailsInterfaceTests* self);
static void _im_details_interface_tests_test_im_details_interface_folks_test_case_test_method (gpointer self);
static void _im_details_interface_tests_test_im_details_interface_async (ImDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _im_details_interface_tests_test_im_details_interface_finish (ImDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _im_details_interface_tests_test_im_details_interface_async_data_free (gpointer _data);
static gboolean _im_details_interface_tests_test_im_details_interface_async_co (ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_);
static void _im_details_interface_tests_test_im_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _im_details_interface_tests_individuals_changed_cb (ImDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __im_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void im_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _im_details_interface_tests_test_im_details_interface_folks_test_case_test_method (gpointer self) {
#line 39 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	im_details_interface_tests_test_im_details_interface ((ImDetailsInterfaceTests*) self);
#line 115 "im-details-interface.c"
}


ImDetailsInterfaceTests* im_details_interface_tests_construct (GType object_type) {
	ImDetailsInterfaceTests * self = NULL;
#line 37 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self = (ImDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "ImDetailsInterfaceTests");
#line 39 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test im details interface", _im_details_interface_tests_test_im_details_interface_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 35 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return self;
#line 127 "im-details-interface.c"
}


ImDetailsInterfaceTests* im_details_interface_tests_new (void) {
#line 35 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return im_details_interface_tests_construct (TYPE_IM_DETAILS_INTERFACE_TESTS);
#line 134 "im-details-interface.c"
}


void im_details_interface_tests_test_im_details_interface (ImDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	TrackerTestBackend* _tmp4_ = NULL;
	TrackerTestBackend* _tmp5_ = NULL;
	GMainLoop* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
#line 43 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 45 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 45 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 46 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 46 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	c1 = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 47 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 47 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv->_fullname = _tmp2_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp3_ = self->priv->_fullname;
#line 49 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp3_);
#line 50 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_IMADDRESS, "jabber#test1@example.org,aim#test2@example.org");
#line 52 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp4_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 52 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 54 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp5_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 54 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 56 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv->_num_addrs = 0;
#line 57 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv->_found_addr_1 = FALSE;
#line 58 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv->_found_addr_2 = FALSE;
#line 60 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_im_details_interface_tests_test_im_details_interface_async (self, NULL, NULL);
#line 62 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp6_ = self->priv->_main_loop;
#line 62 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp6_, 5);
#line 64 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp7_ = self->priv->_num_addrs;
#line 64 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_vala_assert (_tmp7_ == 2, "this._num_addrs == 2");
#line 65 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp8_ = self->priv->_found_addr_1;
#line 65 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_vala_assert (_tmp8_ == TRUE, "this._found_addr_1 == true");
#line 66 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp9_ = self->priv->_found_addr_2;
#line 66 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_vala_assert (_tmp9_ == TRUE, "this._found_addr_2 == true");
#line 43 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (c1);
#line 208 "im-details-interface.c"
}


static void _im_details_interface_tests_test_im_details_interface_async_data_free (gpointer _data) {
	ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_slice_free (ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData, _data_);
#line 219 "im-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 226 "im-details-interface.c"
}


static void _im_details_interface_tests_test_im_details_interface_async (ImDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_;
	ImDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_ = g_slice_new0 (ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _im_details_interface_tests_test_im_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _im_details_interface_tests_test_im_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_im_details_interface_tests_test_im_details_interface_async_co (_data_);
#line 245 "im-details-interface.c"
}


static void _im_details_interface_tests_test_im_details_interface_finish (ImDetailsInterfaceTests* self, GAsyncResult* _res_) {
	ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 253 "im-details-interface.c"
}


static void _im_details_interface_tests_test_im_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_ = _user_data_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_res_ = _res_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_im_details_interface_tests_test_im_details_interface_async_co (_data_);
#line 267 "im-details-interface.c"
}


static void __im_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_im_details_interface_tests_individuals_changed_cb ((ImDetailsInterfaceTests*) self, changes);
#line 274 "im-details-interface.c"
}


static gboolean _im_details_interface_tests_test_im_details_interface_async_co (ImDetailsInterfaceTestsTestImDetailsInterfaceAsyncData* _data_) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	switch (_data_->_state_) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		case 0:
#line 283 "im-details-interface.c"
		goto _state_0;
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		case 1:
#line 287 "im-details-interface.c"
		goto _state_1;
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		case 2:
#line 291 "im-details-interface.c"
		goto _state_2;
		default:
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_assert_not_reached ();
#line 296 "im-details-interface.c"
	}
	_state_0:
#line 71 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 71 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_state_ = 1;
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _im_details_interface_tests_test_im_details_interface_async_ready, _data_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return FALSE;
#line 311 "im-details-interface.c"
	_state_1:
#line 72 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 73 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 73 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 73 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 74 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __im_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 329 "im-details-interface.c"
	{
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_state_ = 2;
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _im_details_interface_tests_test_im_details_interface_async_ready, _data_);
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		return FALSE;
#line 341 "im-details-interface.c"
		_state_2:
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 78 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 347 "im-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 82 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 82 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_warning ("im-details-interface.vala:82: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 370 "im-details-interface.c"
	}
	__finally0:
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		return FALSE;
#line 383 "im-details-interface.c"
	}
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 391 "im-details-interface.c"
	} else {
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 395 "im-details-interface.c"
	}
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 69 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return FALSE;
#line 401 "im-details-interface.c"
}


static void _im_details_interface_tests_individuals_changed_cb (ImDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp55_ = FALSE;
	gboolean _tmp56_ = FALSE;
	gint _tmp57_ = 0;
	GeeSet* _tmp61_ = NULL;
	gint _tmp62_ = 0;
	gint _tmp63_ = 0;
#line 86 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 89 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp0_ = changes;
#line 89 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 89 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	added = _tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp2_ = changes;
#line 90 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	removed = _tmp3_;
#line 434 "im-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp4_ = added;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_i_it = _tmp5_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		while (TRUE) {
#line 447 "im-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp6_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			if (!_tmp7_) {
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
				break;
#line 469 "im-details-interface.c"
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp8_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp10_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 96 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp11_ = i;
#line 96 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			full_name = _tmp14_;
#line 97 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp15_ = full_name;
#line 97 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp16_ = self->priv->_fullname;
#line 97 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			if (g_strcmp0 (_tmp15_, _tmp16_) == 0) {
#line 497 "im-details-interface.c"
				{
					GeeIterator* _proto_it = NULL;
					FolksIndividual* _tmp17_ = NULL;
					GeeMultiMap* _tmp18_ = NULL;
					GeeMultiMap* _tmp19_ = NULL;
					GeeSet* _tmp20_ = NULL;
					GeeSet* _tmp21_ = NULL;
					GeeIterator* _tmp22_ = NULL;
					GeeIterator* _tmp23_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp17_ = i;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp18_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp17_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp19_ = _tmp18_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp20_ = gee_multi_map_get_keys (_tmp19_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp21_ = _tmp20_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_tmp23_ = _tmp22_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_g_object_unref0 (_tmp21_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_proto_it = _tmp23_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					while (TRUE) {
#line 527 "im-details-interface.c"
						GeeIterator* _tmp24_ = NULL;
						gboolean _tmp25_ = FALSE;
						gchar* proto = NULL;
						GeeIterator* _tmp26_ = NULL;
						gpointer _tmp27_ = NULL;
						GeeCollection* addrs = NULL;
						FolksIndividual* _tmp28_ = NULL;
						GeeMultiMap* _tmp29_ = NULL;
						GeeMultiMap* _tmp30_ = NULL;
						const gchar* _tmp31_ = NULL;
						GeeCollection* _tmp32_ = NULL;
						const gchar* _tmp33_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp24_ = _proto_it;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp25_ = gee_iterator_next (_tmp24_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						if (!_tmp25_) {
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
							break;
#line 548 "im-details-interface.c"
						}
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp26_ = _proto_it;
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp27_ = gee_iterator_get (_tmp26_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						proto = (gchar*) _tmp27_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp28_ = i;
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp29_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp28_);
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp30_ = _tmp29_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp31_ = proto;
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp32_ = gee_multi_map_get (_tmp30_, _tmp31_);
#line 101 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						addrs = _tmp32_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_tmp33_ = proto;
#line 103 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						if (g_strcmp0 (_tmp33_, "jabber") == 0) {
#line 572 "im-details-interface.c"
							{
								GeeIterator* _im_fd_it = NULL;
								GeeCollection* _tmp34_ = NULL;
								GeeIterator* _tmp35_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
								_tmp34_ = addrs;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
								_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
								_im_fd_it = _tmp35_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
								while (TRUE) {
#line 585 "im-details-interface.c"
									GeeIterator* _tmp36_ = NULL;
									gboolean _tmp37_ = FALSE;
									FolksImFieldDetails* im_fd = NULL;
									GeeIterator* _tmp38_ = NULL;
									gpointer _tmp39_ = NULL;
									FolksImFieldDetails* _tmp40_ = NULL;
									gconstpointer _tmp41_ = NULL;
									const gchar* _tmp42_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp36_ = _im_fd_it;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp37_ = gee_iterator_next (_tmp36_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									if (!_tmp37_) {
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										break;
#line 602 "im-details-interface.c"
									}
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp38_ = _im_fd_it;
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp39_ = gee_iterator_get (_tmp38_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									im_fd = (FolksImFieldDetails*) _tmp39_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp40_ = im_fd;
#line 107 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp41_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp40_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp42_ = _tmp41_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									if (g_strcmp0 ((const gchar*) _tmp42_, "test1@example.org") == 0) {
#line 618 "im-details-interface.c"
										gint _tmp43_ = 0;
#line 109 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										self->priv->_found_addr_1 = TRUE;
#line 110 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp43_ = self->priv->_num_addrs;
#line 110 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										self->priv->_num_addrs = _tmp43_ + 1;
#line 111 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_g_object_unref0 (im_fd);
#line 111 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										break;
#line 630 "im-details-interface.c"
									}
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_g_object_unref0 (im_fd);
#line 634 "im-details-interface.c"
								}
#line 105 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
								_g_object_unref0 (_im_fd_it);
#line 638 "im-details-interface.c"
							}
						} else {
							const gchar* _tmp44_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
							_tmp44_ = proto;
#line 115 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
							if (g_strcmp0 (_tmp44_, "aim") == 0) {
#line 646 "im-details-interface.c"
								{
									GeeIterator* _im_fd_it = NULL;
									GeeCollection* _tmp45_ = NULL;
									GeeIterator* _tmp46_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp45_ = addrs;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_tmp46_ = gee_iterable_iterator ((GeeIterable*) _tmp45_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_im_fd_it = _tmp46_;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									while (TRUE) {
#line 659 "im-details-interface.c"
										GeeIterator* _tmp47_ = NULL;
										gboolean _tmp48_ = FALSE;
										FolksImFieldDetails* im_fd = NULL;
										GeeIterator* _tmp49_ = NULL;
										gpointer _tmp50_ = NULL;
										FolksImFieldDetails* _tmp51_ = NULL;
										gconstpointer _tmp52_ = NULL;
										const gchar* _tmp53_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp47_ = _im_fd_it;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp48_ = gee_iterator_next (_tmp47_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										if (!_tmp48_) {
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											break;
#line 676 "im-details-interface.c"
										}
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp49_ = _im_fd_it;
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp50_ = gee_iterator_get (_tmp49_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										im_fd = (FolksImFieldDetails*) _tmp50_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp51_ = im_fd;
#line 119 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp52_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp51_);
#line 119 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_tmp53_ = _tmp52_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										if (g_strcmp0 ((const gchar*) _tmp53_, "test2@example.org") == 0) {
#line 692 "im-details-interface.c"
											gint _tmp54_ = 0;
#line 121 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											self->priv->_found_addr_2 = TRUE;
#line 122 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											_tmp54_ = self->priv->_num_addrs;
#line 122 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											self->priv->_num_addrs = _tmp54_ + 1;
#line 123 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											_g_object_unref0 (im_fd);
#line 123 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
											break;
#line 704 "im-details-interface.c"
										}
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
										_g_object_unref0 (im_fd);
#line 708 "im-details-interface.c"
									}
#line 117 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
									_g_object_unref0 (_im_fd_it);
#line 712 "im-details-interface.c"
								}
							}
						}
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_g_object_unref0 (addrs);
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
						_g_free0 (proto);
#line 720 "im-details-interface.c"
					}
#line 99 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
					_g_object_unref0 (_proto_it);
#line 724 "im-details-interface.c"
				}
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_g_free0 (full_name);
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_g_object_unref0 (i);
#line 731 "im-details-interface.c"
		}
#line 92 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 735 "im-details-interface.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp57_ = self->priv->_num_addrs;
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	if (_tmp57_ == 2) {
#line 741 "im-details-interface.c"
		gboolean _tmp58_ = FALSE;
#line 132 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp58_ = self->priv->_found_addr_1;
#line 132 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp56_ = _tmp58_ == TRUE;
#line 747 "im-details-interface.c"
	} else {
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp56_ = FALSE;
#line 751 "im-details-interface.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	if (_tmp56_) {
#line 755 "im-details-interface.c"
		gboolean _tmp59_ = FALSE;
#line 133 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp59_ = self->priv->_found_addr_2;
#line 133 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp55_ = _tmp59_ == TRUE;
#line 761 "im-details-interface.c"
	} else {
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp55_ = FALSE;
#line 765 "im-details-interface.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	if (_tmp55_) {
#line 769 "im-details-interface.c"
		GMainLoop* _tmp60_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp60_ = self->priv->_main_loop;
#line 134 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		g_main_loop_quit (_tmp60_);
#line 775 "im-details-interface.c"
	}
#line 136 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp61_ = removed;
#line 136 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp62_ = gee_collection_get_size ((GeeCollection*) _tmp61_);
#line 136 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp63_ = _tmp62_;
#line 136 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_vala_assert (_tmp63_ == 1, "removed.size == 1");
#line 785 "im-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp64_ = NULL;
		GeeIterator* _tmp65_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp64_ = removed;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_tmp65_ = gee_iterable_iterator ((GeeIterable*) _tmp64_);
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_i_it = _tmp65_;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		while (TRUE) {
#line 798 "im-details-interface.c"
			GeeIterator* _tmp66_ = NULL;
			gboolean _tmp67_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp68_ = NULL;
			gpointer _tmp69_ = NULL;
			FolksIndividual* _tmp70_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp66_ = _i_it;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp67_ = gee_iterator_next (_tmp66_);
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			if (!_tmp67_) {
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
				break;
#line 813 "im-details-interface.c"
			}
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp68_ = _i_it;
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp69_ = gee_iterator_get (_tmp68_);
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			i = (FolksIndividual*) _tmp69_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_tmp70_ = i;
#line 140 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_vala_assert (_tmp70_ == NULL, "i == null");
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
			_g_object_unref0 (i);
#line 827 "im-details-interface.c"
		}
#line 138 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 831 "im-details-interface.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (removed);
#line 86 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (added);
#line 837 "im-details-interface.c"
}


static void im_details_interface_tests_class_init (ImDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	im_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_type_class_add_private (klass, sizeof (ImDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = im_details_interface_tests_finalize;
#line 848 "im-details-interface.c"
}


static void im_details_interface_tests_instance_init (ImDetailsInterfaceTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self->priv = IM_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 855 "im-details-interface.c"
}


static void im_details_interface_tests_finalize (GObject* obj) {
	ImDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_IM_DETAILS_INTERFACE_TESTS, ImDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 33 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 26 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	G_OBJECT_CLASS (im_details_interface_tests_parent_class)->finalize (obj);
#line 871 "im-details-interface.c"
}


GType im_details_interface_tests_get_type (void) {
	static volatile gsize im_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&im_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) im_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImDetailsInterfaceTests), 0, (GInstanceInitFunc) im_details_interface_tests_instance_init, NULL };
		GType im_details_interface_tests_type_id;
		im_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "ImDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&im_details_interface_tests_type_id__volatile, im_details_interface_tests_type_id);
	}
	return im_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	ImDetailsInterfaceTests* tests = NULL;
	ImDetailsInterfaceTests* _tmp0_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 149 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_tmp0_ = im_details_interface_tests_new ();
#line 149 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	tests = _tmp0_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 151 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	g_test_run ();
#line 152 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 154 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	result = 0;
#line 154 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	_g_object_unref0 (tests);
#line 154 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return result;
#line 909 "im-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 145 "/opt/gnome3/source/folks/tests/tracker/im-details-interface.vala"
	return _vala_main (argv, argc);
#line 919 "im-details-interface.c"
}



