/* link-personas.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from link-personas.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <folks-test.h>
#include <gio/gio.h>


#define TYPE_LINK_PERSONAS_TESTS (link_personas_tests_get_type ())
#define LINK_PERSONAS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTests))
#define LINK_PERSONAS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsClass))
#define IS_LINK_PERSONAS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINK_PERSONAS_TESTS))
#define IS_LINK_PERSONAS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINK_PERSONAS_TESTS))
#define LINK_PERSONAS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsClass))

typedef struct _LinkPersonasTests LinkPersonasTests;
typedef struct _LinkPersonasTestsClass LinkPersonasTestsClass;
typedef struct _LinkPersonasTestsPrivate LinkPersonasTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkPersonasTestsTestLinkingPersonasAsyncData LinkPersonasTestsTestLinkingPersonasAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _LinkPersonasTestsAddPersonasData LinkPersonasTestsAddPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LinkPersonasTests {
	TrackerTestTestCase parent_instance;
	LinkPersonasTestsPrivate * priv;
};

struct _LinkPersonasTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _LinkPersonasTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gchar* _proto;
	gchar* _im_address_1;
	gchar* _im_address_2;
	gboolean _linking_fired;
	gboolean _persona_found_1;
	gboolean _persona_found_2;
	gchar* _persona_iid_1;
	gchar* _persona_iid_2;
	GeeHashSet* _personas;
	GeeHashMap* _linking_props;
};

struct _LinkPersonasTestsTestLinkingPersonasAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksPersonaStore* pstore;
	GeeIterator* _backend_it;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	FolksBackend* backend;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	FolksPersonaStore* _tmp19_;
	FolksPersonaStore* _tmp20_;
	FolksPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _LinkPersonasTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksPersonaStore* pstore;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GeeHashMultiMap* im_addrs1;
	GeeHashMultiMap* _tmp7_;
	GeeHashMultiMap* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	FolksImFieldDetails* _tmp11_;
	FolksImFieldDetails* _tmp12_;
	GValue* _tmp13_;
	GeeHashMultiMap* _tmp14_;
	GHashTable* _tmp15_;
	gchar* _tmp16_;
	GValue* _tmp17_;
	GValue* v2;
	GValue _tmp18_;
	GValue _tmp19_;
	GValue* _tmp20_;
	GValue* _tmp21_;
	GValue* _tmp22_;
	const gchar* _tmp23_;
	GHashTable* _tmp24_;
	gchar* _tmp25_;
	GValue* _tmp26_;
	GHashTable* details2;
	GHashFunc _tmp27_;
	GEqualFunc _tmp28_;
	GHashTable* _tmp29_;
	GValue* v3;
	GValue _tmp30_;
	GValue _tmp31_;
	GValue* _tmp32_;
	GValue* _tmp33_;
	GeeHashMultiMap* im_addrs2;
	GeeHashMultiMap* _tmp34_;
	GeeHashMultiMap* _tmp35_;
	const gchar* _tmp36_;
	const gchar* _tmp37_;
	FolksImFieldDetails* _tmp38_;
	FolksImFieldDetails* _tmp39_;
	GValue* _tmp40_;
	GeeHashMultiMap* _tmp41_;
	GHashTable* _tmp42_;
	gchar* _tmp43_;
	GValue* _tmp44_;
	GValue* v4;
	GValue _tmp45_;
	GValue _tmp46_;
	GValue* _tmp47_;
	GValue* _tmp48_;
	GValue* _tmp49_;
	const gchar* _tmp50_;
	GHashTable* _tmp51_;
	gchar* _tmp52_;
	GValue* _tmp53_;
	FolksIndividualAggregator* _tmp54_;
	FolksPersonaStore* _tmp55_;
	GHashTable* _tmp56_;
	FolksPersona* _tmp57_;
	FolksPersona* _tmp58_;
	FolksIndividualAggregator* _tmp59_;
	FolksPersonaStore* _tmp60_;
	GHashTable* _tmp61_;
	FolksPersona* _tmp62_;
	FolksPersona* _tmp63_;
	GError* e;
	GError* _tmp64_;
	const gchar* _tmp65_;
	GError * _inner_error_;
};


static gpointer link_personas_tests_parent_class = NULL;

GType link_personas_tests_get_type (void) G_GNUC_CONST;
#define LINK_PERSONAS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsPrivate))
enum  {
	LINK_PERSONAS_TESTS_DUMMY_PROPERTY
};
LinkPersonasTests* link_personas_tests_new (void);
LinkPersonasTests* link_personas_tests_construct (GType object_type);
void link_personas_tests_test_linking_personas (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_personas_folks_test_case_test_method (gpointer self);
static void link_personas_tests_real_set_up (FolksTestCase* base);
static void link_personas_tests_real_tear_down (FolksTestCase* base);
static void _link_personas_tests_test_linking_personas_async (LinkPersonasTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_test_linking_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_test_linking_personas_async_data_free (gpointer _data);
static gboolean _link_personas_tests_test_linking_personas_async_co (LinkPersonasTestsTestLinkingPersonasAsyncData* _data_);
static void _link_personas_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_tests_individuals_changed_cb (LinkPersonasTests* self, GeeMultiMap* changes);
static void __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _link_personas_tests_persona_store_prepared_cb (LinkPersonasTests* self, GObject* obj, GParamSpec* params);
static void __link_personas_tests_persona_store_prepared_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _link_personas_tests_add_personas (LinkPersonasTests* self, FolksPersonaStore* pstore, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_add_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_add_personas_data_free (gpointer _data);
static gboolean _link_personas_tests_add_personas_co (LinkPersonasTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _link_personas_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_tests_check_personas (LinkPersonasTests* self, FolksIndividual* i);
static void _link_personas_tests_notify_cb (LinkPersonasTests* self, GObject* individual_obj, GParamSpec* ps);
static void __link_personas_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ___lambda4_ (LinkPersonasTests* self);
static gboolean ____lambda4__gsource_func (gpointer self);
static void link_personas_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _link_personas_tests_test_linking_personas_folks_test_case_test_method (gpointer self) {
#line 47 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	link_personas_tests_test_linking_personas ((LinkPersonasTests*) self);
#line 251 "link-personas.c"
}


LinkPersonasTests* link_personas_tests_construct (GType object_type) {
	LinkPersonasTests * self = NULL;
#line 45 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self = (LinkPersonasTests*) tracker_test_test_case_construct (object_type, "LinkPersonasTests");
#line 47 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking personas", _link_personas_tests_test_linking_personas_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 43 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return self;
#line 263 "link-personas.c"
}


LinkPersonasTests* link_personas_tests_new (void) {
#line 43 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return link_personas_tests_construct (TYPE_LINK_PERSONAS_TESTS);
#line 270 "link-personas.c"
}


static void link_personas_tests_real_set_up (FolksTestCase* base) {
	LinkPersonasTests * self;
	TrackerTestBackend* _tmp0_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self = (LinkPersonasTests*) base;
#line 52 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	FOLKS_TEST_CASE_CLASS (link_personas_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TRACKER_TEST_TYPE_TEST_CASE, TrackerTestTestCase));
#line 54 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", "tracker", TRUE);
#line 60 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 60 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 287 "link-personas.c"
}


static void link_personas_tests_real_tear_down (FolksTestCase* base) {
	LinkPersonasTests * self;
#line 63 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self = (LinkPersonasTests*) base;
#line 65 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_unsetenv ("FOLKS_PRIMARY_STORE");
#line 66 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	FOLKS_TEST_CASE_CLASS (link_personas_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TRACKER_TEST_TYPE_TEST_CASE, TrackerTestTestCase));
#line 299 "link-personas.c"
}


void link_personas_tests_test_linking_personas (LinkPersonasTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	GeeHashMap* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GeeHashMap* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GMainLoop* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
#line 69 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 71 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 71 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 71 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_main_loop = _tmp0_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 72 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 72 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_fullname_1 = _tmp1_;
#line 73 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp2_ = g_strdup ("persona #2");
#line 73 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 73 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_fullname_2 = _tmp2_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp3_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 74 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (self->priv->_personas);
#line 74 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_personas = _tmp3_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_found_1 = FALSE;
#line 77 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_found_2 = FALSE;
#line 78 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_linking_fired = FALSE;
#line 80 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 80 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (self->priv->_linking_props);
#line 80 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_linking_props = _tmp4_;
#line 81 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp5_ = self->priv->_linking_props;
#line 81 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp6_ = self->priv->_im_address_1;
#line 81 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, "prop1", _tmp6_);
#line 82 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp7_ = self->priv->_linking_props;
#line 82 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp8_ = self->priv->_im_address_2;
#line 82 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, "prop2", _tmp8_);
#line 84 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_test_linking_personas_async (self, NULL, NULL);
#line 89 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp9_ = self->priv->_main_loop;
#line 89 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_test_utils_loop_run_with_timeout (_tmp9_, 5);
#line 93 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp10_ = self->priv->_linking_props;
#line 93 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp11_ = gee_abstract_map_get_size ((GeeMap*) _tmp10_);
#line 93 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp12_ = _tmp11_;
#line 93 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_vala_assert (_tmp12_ == 0, "this._linking_props.size == 0");
#line 381 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async_data_free (gpointer _data) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_slice_free (LinkPersonasTestsTestLinkingPersonasAsyncData, _data_);
#line 392 "link-personas.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return self ? g_object_ref (self) : NULL;
#line 399 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async (LinkPersonasTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsTestLinkingPersonasAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_test_linking_personas_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_test_linking_personas_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_test_linking_personas_async_co (_data_);
#line 418 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 426 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = _user_data_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_source_object_ = source_object;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_res_ = _res_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_test_linking_personas_async_co (_data_);
#line 440 "link-personas.c"
}


static void __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 101 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_individuals_changed_cb ((LinkPersonasTests*) self, changes);
#line 447 "link-personas.c"
}


static void __link_personas_tests_persona_store_prepared_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 115 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_persona_store_prepared_cb ((LinkPersonasTests*) self, _sender, pspec);
#line 454 "link-personas.c"
}


static gboolean _link_personas_tests_test_linking_personas_async_co (LinkPersonasTestsTestLinkingPersonasAsyncData* _data_) {
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	switch (_data_->_state_) {
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 0:
#line 463 "link-personas.c"
		goto _state_0;
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 1:
#line 467 "link-personas.c"
		goto _state_1;
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 2:
#line 471 "link-personas.c"
		goto _state_2;
		default:
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_assert_not_reached ();
#line 476 "link-personas.c"
	}
	_state_0:
#line 98 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp0_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 98 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->store = _data_->_tmp0_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_state_ = 1;
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_backend_store_prepare (_data_->store, _link_personas_tests_test_linking_personas_async_ready, _data_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return FALSE;
#line 491 "link-personas.c"
	_state_1:
#line 99 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp1_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 100 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 100 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp2_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 101 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 509 "link-personas.c"
	{
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp3_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_state_ = 2;
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _link_personas_tests_test_linking_personas_async_ready, _data_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		return FALSE;
#line 521 "link-personas.c"
		_state_2:
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 527 "link-personas.c"
			goto __catch0_g_error;
		}
#line 107 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->pstore = NULL;
#line 532 "link-personas.c"
		{
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp4_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp5_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp6_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp7_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp8_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp9_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp10_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			while (TRUE) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp11_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp12_ = FALSE;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				if (!_data_->_tmp12_) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					break;
#line 580 "link-personas.c"
				}
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp13_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp14_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp15_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp15_ = _data_->backend;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp16_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp17_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp18_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_g_object_unref0 (_data_->pstore);
#line 110 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->pstore = (FolksPersonaStore*) _data_->_tmp18_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp19_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_data_->_tmp19_ = _data_->pstore;
#line 111 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				if (_data_->_tmp19_ != NULL) {
#line 112 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_g_object_unref0 (_data_->backend);
#line 112 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					break;
#line 622 "link-personas.c"
				}
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_g_object_unref0 (_data_->backend);
#line 626 "link-personas.c"
			}
#line 108 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 630 "link-personas.c"
		}
#line 114 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp20_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp20_ = _data_->pstore;
#line 114 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_vala_assert (_data_->_tmp20_ != NULL, "pstore != null");
#line 115 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp21_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp21_ = _data_->pstore;
#line 115 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __link_personas_tests_persona_store_prepared_cb_g_object_notify, _data_->self, 0);
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->pstore);
#line 646 "link-personas.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->e = _data_->_inner_error_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_inner_error_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp22_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp22_ = _data_->e;
#line 119 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp23_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 119 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_warning ("link-personas.vala:119: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_error_free0 (_data_->e);
#line 667 "link-personas.c"
	}
	__finally0:
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->store);
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_clear_error (&_data_->_inner_error_);
#line 103 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		return FALSE;
#line 680 "link-personas.c"
	}
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->store);
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 688 "link-personas.c"
	} else {
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 692 "link-personas.c"
	}
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 96 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return FALSE;
#line 698 "link-personas.c"
}


static void _link_personas_tests_persona_store_prepared_cb (LinkPersonasTests* self, GObject* obj, GParamSpec* params) {
	FolksPersonaStore* pstore = NULL;
	GObject* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 123 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (obj != NULL);
#line 123 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (params != NULL);
#line 125 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = obj;
#line 125 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, FOLKS_TYPE_PERSONA_STORE) ? ((FolksPersonaStore*) _tmp0_) : NULL, FOLKS_TYPE_PERSONA_STORE, FolksPersonaStore));
#line 125 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	pstore = _tmp1_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_add_personas (self, pstore, NULL, NULL);
#line 123 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (pstore);
#line 722 "link-personas.c"
}


static void _link_personas_tests_add_personas_data_free (gpointer _data) {
	LinkPersonasTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_slice_free (LinkPersonasTestsAddPersonasData, _data_);
#line 735 "link-personas.c"
}


static void _link_personas_tests_add_personas (LinkPersonasTests* self, FolksPersonaStore* pstore, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsAddPersonasData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
	FolksPersonaStore* _tmp2_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsAddPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_add_personas);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_add_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = pstore;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->pstore = _tmp2_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_add_personas_co (_data_);
#line 764 "link-personas.c"
}


static void _link_personas_tests_add_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsAddPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 772 "link-personas.c"
}


static void _g_free0_ (gpointer var) {
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	var = (g_free (var), NULL);
#line 779 "link-personas.c"
}


static void _vala_GValue_free (GValue* self) {
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_unset (self);
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_free (self);
#line 788 "link-personas.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 795 "link-personas.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 802 "link-personas.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return self ? _g_value_dup (self) : NULL;
#line 809 "link-personas.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 143 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return result;
#line 818 "link-personas.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 143 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return result;
#line 827 "link-personas.c"
}


static void _link_personas_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasTestsAddPersonasData* _data_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_ = _user_data_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_source_object_ = source_object;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_res_ = _res_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_add_personas_co (_data_);
#line 841 "link-personas.c"
}


static gboolean _link_personas_tests_add_personas_co (LinkPersonasTestsAddPersonasData* _data_) {
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	switch (_data_->_state_) {
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 0:
#line 850 "link-personas.c"
		goto _state_0;
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 1:
#line 854 "link-personas.c"
		goto _state_1;
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		case 2:
#line 858 "link-personas.c"
		goto _state_2;
		default:
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_assert_not_reached ();
#line 863 "link-personas.c"
	}
	_state_0:
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp0_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp0_ = g_str_hash;
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp1_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp1_ = g_str_equal;
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp2_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->details1 = _data_->_tmp2_;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_init (&_data_->_tmp3_, GEE_TYPE_MULTI_MAP);
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp5_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp6_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v1 = _data_->_tmp6_;
#line 143 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp7_ = NULL;
#line 143 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp7_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 143 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->im_addrs1 = _data_->_tmp7_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp8_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp8_ = _data_->im_addrs1;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp9_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp9_ = _data_->self->priv->_proto;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp10_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp10_ = _data_->self->priv->_im_address_1;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp11_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp11_ = folks_im_field_details_new (_data_->_tmp10_, NULL);
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp12_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->_tmp8_, _data_->_tmp9_, _data_->_tmp12_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->_tmp12_);
#line 147 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp13_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp13_ = _data_->v1;
#line 147 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp14_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp14_ = _data_->im_addrs1;
#line 147 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_set_object (_data_->_tmp13_, (GObject*) _data_->_tmp14_);
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp15_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp15_ = _data_->details1;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp16_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp16_ = g_strdup ("im-addresses");
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp17_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp17_ = _data_->v1;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v1 = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_hash_table_insert (_data_->_tmp15_, _data_->_tmp16_, _data_->_tmp17_);
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp18_, 0, sizeof (GValue));
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_init (&_data_->_tmp18_, G_TYPE_STRING);
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp19_, 0, sizeof (GValue));
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp20_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp20_ = __g_value_dup0 (&_data_->_tmp19_);
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp21_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp21_ = _data_->_tmp20_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp19_) ? (g_value_unset (&_data_->_tmp19_), NULL) : NULL;
#line 150 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v2 = _data_->_tmp21_;
#line 151 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp22_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp22_ = _data_->v2;
#line 151 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp23_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp23_ = _data_->self->priv->_persona_fullname_1;
#line 151 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_set_string (_data_->_tmp22_, _data_->_tmp23_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp24_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp24_ = _data_->details1;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp25_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp25_ = g_strdup ("full-name");
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp26_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp26_ = _data_->v2;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v2 = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_hash_table_insert (_data_->_tmp24_, _data_->_tmp25_, _data_->_tmp26_);
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp27_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp27_ = g_str_hash;
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp28_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp28_ = g_str_equal;
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp29_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp29_ = g_hash_table_new_full (_data_->_tmp27_, _data_->_tmp28_, _g_free0_, __vala_GValue_free0_);
#line 154 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->details2 = _data_->_tmp29_;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp30_, 0, sizeof (GValue));
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_init (&_data_->_tmp30_, GEE_TYPE_MULTI_MAP);
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp31_, 0, sizeof (GValue));
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp32_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp32_ = __g_value_dup0 (&_data_->_tmp31_);
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp33_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp31_) ? (g_value_unset (&_data_->_tmp31_), NULL) : NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v3 = _data_->_tmp33_;
#line 157 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp34_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp34_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 157 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->im_addrs2 = _data_->_tmp34_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp35_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp35_ = _data_->im_addrs2;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp36_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp36_ = _data_->self->priv->_proto;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp37_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp37_ = _data_->self->priv->_im_address_2;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp38_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp38_ = folks_im_field_details_new (_data_->_tmp37_, NULL);
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp39_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->_tmp35_, _data_->_tmp36_, _data_->_tmp39_);
#line 160 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->_tmp39_);
#line 161 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp40_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp40_ = _data_->v3;
#line 161 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp41_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp41_ = _data_->im_addrs2;
#line 161 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_set_object (_data_->_tmp40_, (GObject*) _data_->_tmp41_);
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp42_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp42_ = _data_->details2;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp43_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp43_ = g_strdup ("im-addresses");
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp44_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp44_ = _data_->v3;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v3 = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_hash_table_insert (_data_->_tmp42_, _data_->_tmp43_, _data_->_tmp44_);
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp45_, 0, sizeof (GValue));
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_init (&_data_->_tmp45_, G_TYPE_STRING);
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	memset (&_data_->_tmp46_, 0, sizeof (GValue));
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp46_ = _data_->_tmp45_;
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp47_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp47_ = __g_value_dup0 (&_data_->_tmp46_);
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp48_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp48_ = _data_->_tmp47_;
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp46_) ? (g_value_unset (&_data_->_tmp46_), NULL) : NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v4 = _data_->_tmp48_;
#line 165 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp49_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp49_ = _data_->v4;
#line 165 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp50_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp50_ = _data_->self->priv->_persona_fullname_2;
#line 165 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_value_set_string (_data_->_tmp49_, _data_->_tmp50_);
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp51_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp51_ = _data_->details2;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp52_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp52_ = g_strdup ("full-name");
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp53_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->_tmp53_ = _data_->v4;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_data_->v4 = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_hash_table_insert (_data_->_tmp51_, _data_->_tmp52_, _data_->_tmp53_);
#line 1138 "link-personas.c"
	{
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp54_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp54_ = _data_->self->priv->_aggregator;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp55_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp55_ = _data_->pstore;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp56_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp56_ = _data_->details1;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_state_ = 1;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp54_, NULL, _data_->_tmp55_, _data_->_tmp56_, _link_personas_tests_add_personas_ready, _data_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		return FALSE;
#line 1158 "link-personas.c"
		_state_1:
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp57_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp57_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp54_, _data_->_res_, &_data_->_inner_error_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp58_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp58_ = _data_->_tmp57_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->_tmp58_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1174 "link-personas.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v4);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->im_addrs2);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v3);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v2);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->im_addrs1);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v1);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			g_clear_error (&_data_->_inner_error_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			return FALSE;
#line 1199 "link-personas.c"
		}
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp59_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp59_ = _data_->self->priv->_aggregator;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp60_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp60_ = _data_->pstore;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp61_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp61_ = _data_->details2;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_state_ = 2;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp59_, NULL, _data_->_tmp60_, _data_->_tmp61_, _link_personas_tests_add_personas_ready, _data_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		return FALSE;
#line 1219 "link-personas.c"
		_state_2:
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp62_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp62_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp59_, _data_->_res_, &_data_->_inner_error_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp63_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp63_ = _data_->_tmp62_;
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->_tmp63_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1235 "link-personas.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v4);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->im_addrs2);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v3);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v2);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (_data_->im_addrs1);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			__vala_GValue_free0 (_data_->v1);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			g_clear_error (&_data_->_inner_error_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			return FALSE;
#line 1260 "link-personas.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->e = _data_->_inner_error_;
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_inner_error_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp64_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp64_ = _data_->e;
#line 178 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp65_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_data_->_tmp65_ = _data_->_tmp64_->message;
#line 178 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_warning ("link-personas.vala:178: [AddPersonaError] add_persona_from_details: %s" \
"\n", _data_->_tmp65_);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_error_free0 (_data_->e);
#line 1282 "link-personas.c"
	}
	__finally1:
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		__vala_GValue_free0 (_data_->v4);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->im_addrs2);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		__vala_GValue_free0 (_data_->v3);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		__vala_GValue_free0 (_data_->v2);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_data_->im_addrs1);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		__vala_GValue_free0 (_data_->v1);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_clear_error (&_data_->_inner_error_);
#line 168 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		return FALSE;
#line 1309 "link-personas.c"
	}
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	__vala_GValue_free0 (_data_->v4);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->im_addrs2);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	__vala_GValue_free0 (_data_->v3);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	__vala_GValue_free0 (_data_->v2);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (_data_->im_addrs1);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	__vala_GValue_free0 (_data_->v1);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1331 "link-personas.c"
	} else {
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1335 "link-personas.c"
	}
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 138 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return FALSE;
#line 1341 "link-personas.c"
}


static void __link_personas_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 200 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_notify_cb ((LinkPersonasTests*) self, _sender, pspec);
#line 1348 "link-personas.c"
}


static void _link_personas_tests_individuals_changed_cb (LinkPersonasTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 183 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (changes != NULL);
#line 186 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = changes;
#line 186 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 186 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	added = _tmp1_;
#line 1366 "link-personas.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp2_ = added;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_i_it = _tmp3_;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		while (TRUE) {
#line 1379 "link-personas.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp4_ = _i_it;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (!_tmp5_) {
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				break;
#line 1397 "link-personas.c"
			}
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp6_ = _i_it;
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			i = (FolksIndividual*) _tmp7_;
#line 190 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp8_ = i;
#line 190 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (_tmp8_ == NULL) {
#line 192 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_g_object_unref0 (i);
#line 192 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				continue;
#line 1413 "link-personas.c"
			}
#line 197 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp9_ = i;
#line 197 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp10_ = folks_individual_get_is_user (_tmp9_);
#line 197 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp11_ = _tmp10_;
#line 197 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (!_tmp11_) {
#line 1423 "link-personas.c"
				FolksIndividual* _tmp12_ = NULL;
				FolksIndividual* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp12_ = i;
#line 199 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_link_personas_tests_check_personas (self, _tmp12_);
#line 200 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp13_ = i;
#line 200 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				g_signal_connect_object ((GObject*) _tmp13_, "notify::full-name", (GCallback) __link_personas_tests_notify_cb_g_object_notify, self, 0);
#line 201 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp14_ = i;
#line 201 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				g_signal_connect_object ((GObject*) _tmp14_, "notify::im-addresses", (GCallback) __link_personas_tests_notify_cb_g_object_notify, self, 0);
#line 1439 "link-personas.c"
			}
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (i);
#line 1443 "link-personas.c"
		}
#line 188 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_i_it);
#line 1447 "link-personas.c"
	}
#line 183 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (added);
#line 1451 "link-personas.c"
}


static void _link_personas_tests_notify_cb (LinkPersonasTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 206 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (individual_obj != NULL);
#line 206 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (ps != NULL);
#line 208 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = individual_obj;
#line 208 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 208 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	i = _tmp1_;
#line 209 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_link_personas_tests_check_personas (self, i);
#line 206 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (i);
#line 1475 "link-personas.c"
}


static gboolean ___lambda4_ (LinkPersonasTests* self) {
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
#line 279 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = self->priv->_aggregator;
#line 279 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = self->priv->_personas;
#line 279 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_individual_aggregator_link_personas (_tmp0_, (GeeSet*) _tmp1_, NULL, NULL);
#line 280 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	result = FALSE;
#line 280 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return result;
#line 1493 "link-personas.c"
}


static gboolean ____lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda4_ ((LinkPersonasTests*) self);
#line 277 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return result;
#line 1502 "link-personas.c"
}


static void _link_personas_tests_check_personas (LinkPersonasTests* self, FolksIndividual* i) {
	FolksPersona* first_persona = NULL;
	gboolean _tmp8_ = FALSE;
	FolksIndividual* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gboolean _tmp79_ = FALSE;
	GeeHashSet* _tmp80_ = NULL;
	gint _tmp81_ = 0;
	gint _tmp82_ = 0;
#line 222 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 222 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_return_if_fail (i != NULL);
#line 224 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	first_persona = NULL;
#line 1523 "link-personas.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp0_ = i;
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp1_ = folks_individual_get_personas (_tmp0_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp2_ = _tmp1_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_p_it = _tmp3_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		while (TRUE) {
#line 1542 "link-personas.c"
			gboolean _tmp4_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp5_ = NULL;
			FolksPersona* _tmp6_ = NULL;
			FolksPersona* _tmp7_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp4_ = gee_iterator_next (_p_it);
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (!_tmp4_) {
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				break;
#line 1554 "link-personas.c"
			}
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp5_ = gee_iterator_get (_p_it);
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			p = (FolksPersona*) _tmp5_;
#line 227 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp6_ = p;
#line 227 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp7_ = _g_object_ref0 (_tmp6_);
#line 227 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (first_persona);
#line 227 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			first_persona = _tmp7_;
#line 228 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_object_unref0 (p);
#line 228 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			break;
#line 1572 "link-personas.c"
		}
#line 225 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_object_unref0 (_p_it);
#line 1576 "link-personas.c"
	}
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp9_ = i;
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp10_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp9_);
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp11_ = _tmp10_;
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp12_ = self->priv->_persona_fullname_1;
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 1588 "link-personas.c"
		const gchar* _tmp13_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp13_ = self->priv->_persona_iid_1;
#line 232 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp8_ = g_strcmp0 (_tmp13_, "") == 0;
#line 1594 "link-personas.c"
	} else {
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp8_ = FALSE;
#line 1598 "link-personas.c"
	}
#line 231 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (_tmp8_) {
#line 1602 "link-personas.c"
		FolksPersona* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		GeeHashSet* _tmp18_ = NULL;
		FolksPersona* _tmp19_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp14_ = first_persona;
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp15_ = folks_persona_get_iid (_tmp14_);
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp16_ = _tmp15_;
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp17_ = g_strdup (_tmp16_);
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_g_free0 (self->priv->_persona_iid_1);
#line 234 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		self->priv->_persona_iid_1 = _tmp17_;
#line 235 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp18_ = self->priv->_personas;
#line 235 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp19_ = first_persona;
#line 235 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp18_, _tmp19_);
#line 1627 "link-personas.c"
	} else {
		gboolean _tmp20_ = FALSE;
		FolksIndividual* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp21_ = i;
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp22_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp21_);
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp23_ = _tmp22_;
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp24_ = self->priv->_persona_fullname_2;
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		if (g_strcmp0 (_tmp23_, _tmp24_) == 0) {
#line 1644 "link-personas.c"
			const gchar* _tmp25_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp25_ = self->priv->_persona_iid_2;
#line 238 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp20_ = g_strcmp0 (_tmp25_, "") == 0;
#line 1650 "link-personas.c"
		} else {
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp20_ = FALSE;
#line 1654 "link-personas.c"
		}
#line 237 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		if (_tmp20_) {
#line 1658 "link-personas.c"
			FolksPersona* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			GeeHashSet* _tmp30_ = NULL;
			FolksPersona* _tmp31_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp26_ = first_persona;
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp27_ = folks_persona_get_iid (_tmp26_);
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp28_ = _tmp27_;
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp29_ = g_strdup (_tmp28_);
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_g_free0 (self->priv->_persona_iid_2);
#line 240 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			self->priv->_persona_iid_2 = _tmp29_;
#line 241 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp30_ = self->priv->_personas;
#line 241 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp31_ = first_persona;
#line 241 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 1683 "link-personas.c"
		} else {
			FolksIndividual* _tmp32_ = NULL;
			GeeSet* _tmp33_ = NULL;
			GeeSet* _tmp34_ = NULL;
			gint _tmp35_ = 0;
			gint _tmp36_ = 0;
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp32_ = i;
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp33_ = folks_individual_get_personas (_tmp32_);
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp34_ = _tmp33_;
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			_tmp36_ = _tmp35_;
#line 243 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
			if (_tmp36_ > 1) {
#line 1702 "link-personas.c"
				GeeHashMap* _tmp75_ = NULL;
				gint _tmp76_ = 0;
				gint _tmp77_ = 0;
				{
					GeeIterator* _proto_it = NULL;
					FolksIndividual* _tmp37_ = NULL;
					GeeMultiMap* _tmp38_ = NULL;
					GeeMultiMap* _tmp39_ = NULL;
					GeeSet* _tmp40_ = NULL;
					GeeSet* _tmp41_ = NULL;
					GeeIterator* _tmp42_ = NULL;
					GeeIterator* _tmp43_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp37_ = i;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp38_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp37_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp39_ = _tmp38_;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp40_ = gee_multi_map_get_keys (_tmp39_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp41_ = _tmp40_;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp42_ = gee_iterable_iterator ((GeeIterable*) _tmp41_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp43_ = _tmp42_;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_g_object_unref0 (_tmp41_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_proto_it = _tmp43_;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					while (TRUE) {
#line 1735 "link-personas.c"
						GeeIterator* _tmp44_ = NULL;
						gboolean _tmp45_ = FALSE;
						gchar* proto = NULL;
						GeeIterator* _tmp46_ = NULL;
						gpointer _tmp47_ = NULL;
						GeeCollection* addrs = NULL;
						FolksIndividual* _tmp48_ = NULL;
						GeeMultiMap* _tmp49_ = NULL;
						GeeMultiMap* _tmp50_ = NULL;
						const gchar* _tmp51_ = NULL;
						GeeCollection* _tmp52_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp44_ = _proto_it;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp45_ = gee_iterator_next (_tmp44_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						if (!_tmp45_) {
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							break;
#line 1755 "link-personas.c"
						}
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp46_ = _proto_it;
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp47_ = gee_iterator_get (_tmp46_);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						proto = (gchar*) _tmp47_;
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp48_ = i;
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp49_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp48_);
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp50_ = _tmp49_;
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp51_ = proto;
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_tmp52_ = gee_multi_map_get (_tmp50_, _tmp51_);
#line 248 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						addrs = _tmp52_;
#line 1775 "link-personas.c"
						{
							GeeIterator* _a_it = NULL;
							GeeCollection* _tmp53_ = NULL;
							GeeIterator* _tmp54_ = NULL;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							_tmp53_ = addrs;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							_tmp54_ = gee_iterable_iterator ((GeeIterable*) _tmp53_);
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							_a_it = _tmp54_;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							while (TRUE) {
#line 1788 "link-personas.c"
								GeeIterator* _tmp55_ = NULL;
								gboolean _tmp56_ = FALSE;
								FolksImFieldDetails* a = NULL;
								GeeIterator* _tmp57_ = NULL;
								gpointer _tmp58_ = NULL;
								FolksImFieldDetails* _tmp59_ = NULL;
								gconstpointer _tmp60_ = NULL;
								const gchar* _tmp61_ = NULL;
								GeeHashMap* _tmp62_ = NULL;
								gpointer _tmp63_ = NULL;
								gchar* _tmp64_ = NULL;
								gboolean _tmp65_ = FALSE;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp55_ = _a_it;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp56_ = gee_iterator_next (_tmp55_);
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								if (!_tmp56_) {
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									break;
#line 1809 "link-personas.c"
								}
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp57_ = _a_it;
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp58_ = gee_iterator_get (_tmp57_);
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								a = (FolksImFieldDetails*) _tmp58_;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp59_ = a;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp60_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp59_);
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp61_ = _tmp60_;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp62_ = self->priv->_linking_props;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp63_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp62_, "prop1");
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp64_ = (gchar*) _tmp63_;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_tmp65_ = g_strcmp0 ((const gchar*) _tmp61_, _tmp64_) == 0;
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_g_free0 (_tmp64_);
#line 251 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								if (_tmp65_) {
#line 1835 "link-personas.c"
									GeeHashMap* _tmp66_ = NULL;
#line 253 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp66_ = self->priv->_linking_props;
#line 253 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									gee_abstract_map_unset ((GeeAbstractMap*) _tmp66_, "prop1", NULL);
#line 1841 "link-personas.c"
								} else {
									FolksImFieldDetails* _tmp67_ = NULL;
									gconstpointer _tmp68_ = NULL;
									const gchar* _tmp69_ = NULL;
									GeeHashMap* _tmp70_ = NULL;
									gpointer _tmp71_ = NULL;
									gchar* _tmp72_ = NULL;
									gboolean _tmp73_ = FALSE;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp67_ = a;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp68_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp67_);
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp69_ = _tmp68_;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp70_ = self->priv->_linking_props;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp71_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp70_, "prop2");
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp72_ = (gchar*) _tmp71_;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_tmp73_ = g_strcmp0 ((const gchar*) _tmp69_, _tmp72_) == 0;
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									_g_free0 (_tmp72_);
#line 255 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
									if (_tmp73_) {
#line 1868 "link-personas.c"
										GeeHashMap* _tmp74_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
										_tmp74_ = self->priv->_linking_props;
#line 257 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
										gee_abstract_map_unset ((GeeAbstractMap*) _tmp74_, "prop2", NULL);
#line 1874 "link-personas.c"
									}
								}
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
								_g_object_unref0 (a);
#line 1879 "link-personas.c"
							}
#line 249 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
							_g_object_unref0 (_a_it);
#line 1883 "link-personas.c"
						}
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_g_object_unref0 (addrs);
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
						_g_free0 (proto);
#line 1889 "link-personas.c"
					}
#line 246 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_g_object_unref0 (_proto_it);
#line 1893 "link-personas.c"
				}
#line 262 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp75_ = self->priv->_linking_props;
#line 262 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp76_ = gee_abstract_map_get_size ((GeeMap*) _tmp75_);
#line 262 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				_tmp77_ = _tmp76_;
#line 262 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
				if (_tmp77_ == 0) {
#line 1903 "link-personas.c"
					GMainLoop* _tmp78_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					_tmp78_ = self->priv->_main_loop;
#line 264 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
					g_main_loop_quit (_tmp78_);
#line 1909 "link-personas.c"
				}
			}
		}
	}
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp80_ = self->priv->_personas;
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp81_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp80_);
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp82_ = _tmp81_;
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (_tmp82_ == 2) {
#line 1922 "link-personas.c"
		gboolean _tmp83_ = FALSE;
#line 271 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp83_ = self->priv->_linking_fired;
#line 271 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp79_ = _tmp83_ == FALSE;
#line 1928 "link-personas.c"
	} else {
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		_tmp79_ = FALSE;
#line 1932 "link-personas.c"
	}
#line 270 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	if (_tmp79_) {
#line 273 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		self->priv->_linking_fired = TRUE;
#line 277 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
		g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 2, ____lambda4__gsource_func, g_object_ref (self), g_object_unref);
#line 1940 "link-personas.c"
	}
#line 222 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (first_persona);
#line 1944 "link-personas.c"
}


static void link_personas_tests_class_init (LinkPersonasTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	link_personas_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_type_class_add_private (klass, sizeof (LinkPersonasTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	((FolksTestCaseClass *) klass)->set_up = link_personas_tests_real_set_up;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	((FolksTestCaseClass *) klass)->tear_down = link_personas_tests_real_tear_down;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_OBJECT_CLASS (klass)->finalize = link_personas_tests_finalize;
#line 1959 "link-personas.c"
}


static void link_personas_tests_instance_init (LinkPersonasTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv = LINK_PERSONAS_TESTS_GET_PRIVATE (self);
#line 32 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = g_strdup ("jabber");
#line 32 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_proto = _tmp0_;
#line 33 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp1_ = g_strdup ("someone-1@jabber.example.org");
#line 33 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_im_address_1 = _tmp1_;
#line 34 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp2_ = g_strdup ("someone-2@jabber.example.org");
#line 34 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_im_address_2 = _tmp2_;
#line 38 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp3_ = g_strdup ("");
#line 38 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_iid_1 = _tmp3_;
#line 39 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp4_ = g_strdup ("");
#line 39 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self->priv->_persona_iid_2 = _tmp4_;
#line 1991 "link-personas.c"
}


static void link_personas_tests_finalize (GObject* obj) {
	LinkPersonasTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LINK_PERSONAS_TESTS, LinkPersonasTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 32 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_proto);
#line 33 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_im_address_1);
#line 34 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_im_address_2);
#line 38 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 39 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 40 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (self->priv->_personas);
#line 41 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (self->priv->_linking_props);
#line 26 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	G_OBJECT_CLASS (link_personas_tests_parent_class)->finalize (obj);
#line 2023 "link-personas.c"
}


GType link_personas_tests_get_type (void) {
	static volatile gsize link_personas_tests_type_id__volatile = 0;
	if (g_once_init_enter (&link_personas_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkPersonasTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) link_personas_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkPersonasTests), 0, (GInstanceInitFunc) link_personas_tests_instance_init, NULL };
		GType link_personas_tests_type_id;
		link_personas_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "LinkPersonasTests", &g_define_type_info, 0);
		g_once_init_leave (&link_personas_tests_type_id__volatile, link_personas_tests_type_id);
	}
	return link_personas_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	LinkPersonasTests* tests = NULL;
	LinkPersonasTests* _tmp0_ = NULL;
#line 288 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_test_init (&args_length1, &args, NULL);
#line 290 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_tmp0_ = link_personas_tests_new ();
#line 290 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	tests = _tmp0_;
#line 291 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 292 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	g_test_run ();
#line 293 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 295 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	result = 0;
#line 295 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	_g_object_unref0 (tests);
#line 295 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return result;
#line 2061 "link-personas.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 286 "/opt/gnome3/source/folks/tests/tracker/link-personas.vala"
	return _vala_main (argv, argc);
#line 2071 "link-personas.c"
}



