/* phone-details.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from phone-details.vala, do not modify */

/*
 * Copyright (C) 2011, 2015 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks/folks-eds.h>


#define TYPE_PHONE_DETAILS_TESTS (phone_details_tests_get_type ())
#define PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTests))
#define PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))
#define IS_PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHONE_DETAILS_TESTS))
#define IS_PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHONE_DETAILS_TESTS))
#define PHONE_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))

typedef struct _PhoneDetailsTests PhoneDetailsTests;
typedef struct _PhoneDetailsTestsClass PhoneDetailsTestsClass;
typedef struct _PhoneDetailsTestsPrivate PhoneDetailsTestsPrivate;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PhoneDetailsTests {
	EdsTestTestCase parent_instance;
	PhoneDetailsTestsPrivate * priv;
};

struct _PhoneDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};


static gpointer phone_details_tests_parent_class = NULL;

GType phone_details_tests_get_type (void) G_GNUC_CONST;
enum  {
	PHONE_DETAILS_TESTS_DUMMY_PROPERTY
};
PhoneDetailsTests* phone_details_tests_new (void);
PhoneDetailsTests* phone_details_tests_construct (GType object_type);
void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self);
static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_test_phone_numbers ((PhoneDetailsTests*) self);
#line 83 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_construct (GType object_type) {
	PhoneDetailsTests * self = NULL;
#line 30 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self = (PhoneDetailsTests*) eds_test_test_case_construct (object_type, "PhoneDetails");
#line 32 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "phone details interface", _phone_details_tests_test_phone_numbers_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 28 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self;
#line 95 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_new (void) {
#line 28 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return phone_details_tests_construct (TYPE_PHONE_DETAILS_TESTS);
#line 102 "phone-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 109 "phone-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_unset (self);
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_free (self);
#line 118 "phone-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 125 "phone-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 132 "phone-details.c"
}


static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle) {
	int i;
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	for (i = 0; i < stack_length; i++) {
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			return TRUE;
#line 144 "phone-details.c"
		}
	}
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 149 "phone-details.c"
}


void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* c2 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue* v = NULL;
	gchar** names = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint names_length1 = 0;
	gint _names_size_ = 0;
	GValue _tmp5_ = {0};
	GValue _tmp6_ = {0};
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GeeHashMap* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	GValue _tmp12_ = {0};
	GValue _tmp13_ = {0};
	GValue* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GeeHashMap* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	GValue _tmp19_ = {0};
	GValue _tmp20_ = {0};
	GValue* _tmp21_ = NULL;
	GValue* _tmp22_ = NULL;
	GeeHashMap* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue _tmp26_ = {0};
	GValue _tmp27_ = {0};
	GValue* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	GeeHashMap* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	EdsTestBackend* _tmp33_ = NULL;
	GeeHashMap* _tmp34_ = NULL;
	GeeHashMap* _tmp35_ = NULL;
	GValue _tmp36_ = {0};
	GValue _tmp37_ = {0};
	GValue* _tmp38_ = NULL;
	GValue* _tmp39_ = NULL;
	GeeHashMap* _tmp40_ = NULL;
	GValue* _tmp41_ = NULL;
	GValue* _tmp42_ = NULL;
	GValue _tmp43_ = {0};
	GValue _tmp44_ = {0};
	GValue* _tmp45_ = NULL;
	GValue* _tmp46_ = NULL;
	GeeHashMap* _tmp47_ = NULL;
	GValue* _tmp48_ = NULL;
	GValue* _tmp49_ = NULL;
	GValue _tmp50_ = {0};
	GValue _tmp51_ = {0};
	GValue* _tmp52_ = NULL;
	GValue* _tmp53_ = NULL;
	GeeHashMap* _tmp54_ = NULL;
	GValue* _tmp55_ = NULL;
	GValue* _tmp56_ = NULL;
	GValue _tmp57_ = {0};
	GValue _tmp58_ = {0};
	GValue* _tmp59_ = NULL;
	GValue* _tmp60_ = NULL;
	GeeHashMap* _tmp61_ = NULL;
	GValue* _tmp62_ = NULL;
	GValue* _tmp63_ = NULL;
	EdsTestBackend* _tmp64_ = NULL;
	GeeHashMap* _tmp65_ = NULL;
	GeeHashMap* _tmp66_ = NULL;
	EdsTestBackend* _tmp67_ = NULL;
	gint phones_count = 0;
	GeeHashSet* phone_types = NULL;
	GeeHashSet* _tmp68_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp69_ = NULL;
	FolksIndividualAggregator* _tmp70_ = NULL;
	gchar** _tmp71_ = NULL;
	gint _tmp71__length1 = 0;
	gchar** _tmp72_ = NULL;
	gint _tmp72__length1 = 0;
	gint _tmp126_ = 0;
	GeeHashSet* _tmp127_ = NULL;
	gint _tmp128_ = 0;
	gint _tmp129_ = 0;
	GeeHashMap* _tmp130_ = NULL;
	gint _tmp131_ = 0;
	gint _tmp132_ = 0;
	GeeHashMap* _tmp133_ = NULL;
	gint _tmp134_ = 0;
	gint _tmp135_ = 0;
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (self != NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	c1 = _tmp0_;
#line 39 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 39 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	c2 = _tmp1_;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = g_strdup ("bernie h. innocenti");
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = g_strdup ("richard m. stallman");
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp4_ = g_new0 (gchar*, 2 + 1);
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp4_[0] = _tmp2_;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp4_[1] = _tmp3_;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	names = _tmp4_;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	names_length1 = 2;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_names_size_ = names_length1;
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp5_, G_TYPE_STRING);
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp6_ = _tmp5_;
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp7_ = __g_value_dup0 (&_tmp6_);
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp7_;
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp6_) ? (g_value_unset (&_tmp6_), NULL) : NULL;
#line 44 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp8_ = v;
#line 44 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp8_, "bernie h. innocenti");
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp9_ = c1;
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp10_ = v;
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp11_ = _tmp10_;
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, "full_name", _tmp11_);
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp11_);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp12_, G_TYPE_STRING);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp13_ = _tmp12_;
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp14_ = __g_value_dup0 (&_tmp13_);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp14_;
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp13_) ? (g_value_unset (&_tmp13_), NULL) : NULL;
#line 47 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp15_ = v;
#line 47 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp15_, "123");
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp16_ = c1;
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp17_ = v;
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp18_ = _tmp17_;
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp16_, "car_phone", _tmp18_);
#line 48 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp18_);
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp19_, G_TYPE_STRING);
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp20_ = _tmp19_;
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp21_ = __g_value_dup0 (&_tmp20_);
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp21_;
#line 49 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp20_) ? (g_value_unset (&_tmp20_), NULL) : NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp22_ = v;
#line 50 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp22_, "1234");
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp23_ = c1;
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp24_ = v;
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp25_ = _tmp24_;
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp23_, "company_phone", _tmp25_);
#line 51 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp25_);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp26_, G_TYPE_STRING);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp27_ = _tmp26_;
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp28_ = __g_value_dup0 (&_tmp27_);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp28_;
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp27_) ? (g_value_unset (&_tmp27_), NULL) : NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp29_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp29_, "12345");
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp30_ = c1;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp31_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp32_ = _tmp31_;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp30_, "home_phone", _tmp32_);
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp32_);
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp33_ = ((EdsTestTestCase*) self)->eds_backend;
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp34_ = c1;
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp35_ = _g_object_ref0 (_tmp34_);
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp33_, _tmp35_);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp36_, G_TYPE_STRING);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp37_ = _tmp36_;
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp38_ = __g_value_dup0 (&_tmp37_);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp38_;
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp37_) ? (g_value_unset (&_tmp37_), NULL) : NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp39_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp39_, "richard m. stallman");
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp40_ = c2;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp41_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp42_ = _tmp41_;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp40_, "full_name", _tmp42_);
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp42_);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp43_, G_TYPE_STRING);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp44_ = _tmp43_;
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp45_ = __g_value_dup0 (&_tmp44_);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp45_;
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp44_) ? (g_value_unset (&_tmp44_), NULL) : NULL;
#line 62 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp46_ = v;
#line 62 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp46_, "54321");
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp47_ = c2;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp48_ = v;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp49_ = _tmp48_;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp47_, "car_phone", _tmp49_);
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp49_);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp50_, G_TYPE_STRING);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp51_ = _tmp50_;
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp52_ = __g_value_dup0 (&_tmp51_);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp52_;
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp51_) ? (g_value_unset (&_tmp51_), NULL) : NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp53_ = v;
#line 65 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp53_, "4321");
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp54_ = c2;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp55_ = v;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp56_ = _tmp55_;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp54_, "company_phone", _tmp56_);
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp56_);
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp57_, G_TYPE_STRING);
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp58_ = _tmp57_;
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp59_ = __g_value_dup0 (&_tmp58_);
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp59_;
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp58_) ? (g_value_unset (&_tmp58_), NULL) : NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp60_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp60_, "321");
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp61_ = c2;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp62_ = v;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp63_ = _tmp62_;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp61_, "home_phone", _tmp63_);
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp63_);
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp64_ = ((EdsTestTestCase*) self)->eds_backend;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp65_ = c2;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp66_ = _g_object_ref0 (_tmp65_);
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp64_, _tmp66_);
#line 73 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp67_ = ((EdsTestTestCase*) self)->eds_backend;
#line 73 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_sync (_tmp67_);
#line 76 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phones_count = 0;
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp68_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phone_types = _tmp68_;
#line 81 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp69_ = folks_individual_aggregator_dup ();
#line 81 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	aggregator = _tmp69_;
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp70_ = aggregator;
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp71_ = names;
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp71__length1 = names_length1;
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_individuals_sync_with_timeout (_tmp70_, _tmp71_, _tmp71__length1, 5);
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp72_ = names;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp72__length1 = names_length1;
#line 540 "phone-details.c"
	{
		gchar** n_collection = NULL;
		gint n_collection_length1 = 0;
		gint _n_collection_size_ = 0;
		gint n_it = 0;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		n_collection = _tmp72_;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		n_collection_length1 = _tmp72__length1;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		for (n_it = 0; n_it < _tmp72__length1; n_it = n_it + 1) {
#line 552 "phone-details.c"
			gchar* _tmp73_ = NULL;
			gchar* n = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp73_ = g_strdup (n_collection[n_it]);
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			n = _tmp73_;
#line 559 "phone-details.c"
			{
				FolksIndividual* i = NULL;
				FolksIndividualAggregator* _tmp74_ = NULL;
				const gchar* _tmp75_ = NULL;
				FolksIndividual* _tmp76_ = NULL;
				GeeHashMap* _tmp77_ = NULL;
				const gchar* _tmp78_ = NULL;
				GeeHashMap* contact = NULL;
				GeeHashMap* _tmp81_ = NULL;
				GeeHashMap* _tmp82_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp74_ = aggregator;
#line 88 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp75_ = n;
#line 88 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp76_ = folks_test_utils_get_individual_by_name (_tmp74_, _tmp75_);
#line 88 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				i = _tmp76_;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp78_ = n;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				if (g_strcmp0 (_tmp78_, "bernie h. innocenti") == 0) {
#line 582 "phone-details.c"
					GeeHashMap* _tmp79_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp79_ = c1;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp77_ = _tmp79_;
#line 588 "phone-details.c"
				} else {
					GeeHashMap* _tmp80_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp80_ = c2;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp77_ = _tmp80_;
#line 595 "phone-details.c"
				}
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp81_ = _g_object_ref0 (_tmp77_);
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				contact = _tmp81_;
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp82_ = contact;
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp82_, "full_name", NULL);
#line 605 "phone-details.c"
				{
					GeeIterator* _phone_fd_it = NULL;
					FolksIndividual* _tmp83_ = NULL;
					GeeSet* _tmp84_ = NULL;
					GeeSet* _tmp85_ = NULL;
					GeeIterator* _tmp86_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp83_ = i;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp84_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp83_);
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp85_ = _tmp84_;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp86_ = gee_iterable_iterator ((GeeIterable*) _tmp85_);
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_phone_fd_it = _tmp86_;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					while (TRUE) {
#line 624 "phone-details.c"
						GeeIterator* _tmp87_ = NULL;
						gboolean _tmp88_ = FALSE;
						FolksPhoneFieldDetails* phone_fd = NULL;
						GeeIterator* _tmp89_ = NULL;
						gpointer _tmp90_ = NULL;
						gint _tmp91_ = 0;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp87_ = _phone_fd_it;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp88_ = gee_iterator_next (_tmp87_);
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						if (!_tmp88_) {
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							break;
#line 639 "phone-details.c"
						}
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp89_ = _phone_fd_it;
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp90_ = gee_iterator_get (_tmp89_);
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						phone_fd = (FolksPhoneFieldDetails*) _tmp90_;
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp91_ = phones_count;
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						phones_count = _tmp91_ + 1;
#line 651 "phone-details.c"
						{
							GeeIterator* _t_it = NULL;
							FolksPhoneFieldDetails* _tmp92_ = NULL;
							GeeCollection* _tmp93_ = NULL;
							GeeCollection* _tmp94_ = NULL;
							GeeIterator* _tmp95_ = NULL;
							GeeIterator* _tmp96_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp92_ = phone_fd;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp93_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp92_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp94_ = _tmp93_;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp95_ = gee_iterable_iterator ((GeeIterable*) _tmp94_);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp96_ = _tmp95_;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_g_object_unref0 (_tmp94_);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_t_it = _tmp96_;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							while (TRUE) {
#line 675 "phone-details.c"
								GeeIterator* _tmp97_ = NULL;
								gboolean _tmp98_ = FALSE;
								gchar* t = NULL;
								GeeIterator* _tmp99_ = NULL;
								gpointer _tmp100_ = NULL;
								gchar* t_ = NULL;
								const gchar* _tmp101_ = NULL;
								const gchar* _tmp112_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp97_ = _t_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp98_ = gee_iterator_next (_tmp97_);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								if (!_tmp98_) {
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									break;
#line 692 "phone-details.c"
								}
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp99_ = _t_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp100_ = gee_iterator_get (_tmp99_);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								t = (gchar*) _tmp100_;
#line 99 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								t_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp101_ = t;
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								if (g_strcmp0 (_tmp101_, "car") == 0) {
#line 706 "phone-details.c"
									gchar* _tmp102_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp102_ = g_strdup ("car_phone");
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_g_free0 (t_);
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									t_ = _tmp102_;
#line 714 "phone-details.c"
								} else {
									const gchar* _tmp103_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp103_ = t;
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									if (g_strcmp0 (_tmp103_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME) == 0) {
#line 721 "phone-details.c"
										gchar* _tmp104_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										_tmp104_ = g_strdup ("home_phone");
#line 104 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										_g_free0 (t_);
#line 104 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										t_ = _tmp104_;
#line 729 "phone-details.c"
									} else {
										const gchar* _tmp105_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										_tmp105_ = t;
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										if (g_strcmp0 (_tmp105_, "x-evolution-company") == 0) {
#line 736 "phone-details.c"
											gchar* _tmp106_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
											_tmp106_ = g_strdup ("company_phone");
#line 106 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
											_g_free0 (t_);
#line 106 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
											t_ = _tmp106_;
#line 744 "phone-details.c"
										} else {
											const gchar* _tmp107_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
											_tmp107_ = t;
#line 108 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
											if (g_strcmp0 (_tmp107_, "voice") != 0) {
#line 751 "phone-details.c"
												const gchar* _tmp108_ = NULL;
												FolksPhoneFieldDetails* _tmp109_ = NULL;
												gconstpointer _tmp110_ = NULL;
												const gchar* _tmp111_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												_tmp108_ = t;
#line 110 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												_tmp109_ = phone_fd;
#line 110 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												_tmp110_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp109_);
#line 110 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												_tmp111_ = _tmp110_;
#line 110 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												g_debug ("phone-details.vala:110: Unrecognised type: %s, %s", _tmp108_, (const gchar*) _tmp111_);
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
												g_assert_not_reached ();
#line 768 "phone-details.c"
											}
										}
									}
								}
#line 114 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp112_ = t_;
#line 114 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								if (_tmp112_ != NULL) {
#line 777 "phone-details.c"
									GeeHashSet* _tmp113_ = NULL;
									const gchar* _tmp114_ = NULL;
									GeeHashMap* _tmp115_ = NULL;
									const gchar* _tmp116_ = NULL;
									gpointer _tmp117_ = NULL;
									GValue* _tmp118_ = NULL;
									GValue _tmp119_ = {0};
									const gchar* _tmp120_ = NULL;
									FolksPhoneFieldDetails* _tmp121_ = NULL;
									gconstpointer _tmp122_ = NULL;
									const gchar* _tmp123_ = NULL;
									GeeHashMap* _tmp124_ = NULL;
									const gchar* _tmp125_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp113_ = phone_types;
#line 116 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp114_ = t_;
#line 116 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									gee_abstract_collection_add ((GeeAbstractCollection*) _tmp113_, _tmp114_);
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp115_ = contact;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp116_ = t_;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp117_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp115_, _tmp116_);
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp118_ = (GValue*) _tmp117_;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp119_ = *_tmp118_;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp120_ = g_value_get_string (&_tmp119_);
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp121_ = phone_fd;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp122_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp121_);
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp123_ = _tmp122_;
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_vala_assert (g_strcmp0 (_tmp120_, (const gchar*) _tmp123_) == 0, "contact.get (t_).get_string () == phone_fd.value");
#line 117 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									__vala_GValue_free0 (_tmp118_);
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp124_ = contact;
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp125_ = t_;
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									gee_abstract_map_unset ((GeeAbstractMap*) _tmp124_, _tmp125_, NULL);
#line 825 "phone-details.c"
								}
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_g_free0 (t_);
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_g_free0 (t);
#line 831 "phone-details.c"
							}
#line 96 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_g_object_unref0 (_t_it);
#line 835 "phone-details.c"
						}
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_g_object_unref0 (phone_fd);
#line 839 "phone-details.c"
					}
#line 93 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_g_object_unref0 (_phone_fd_it);
#line 843 "phone-details.c"
				}
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (contact);
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (i);
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_g_free0 (n);
#line 851 "phone-details.c"
			}
		}
	}
#line 124 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp126_ = phones_count;
#line 124 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp126_ == 6, "phones_count == 6");
#line 125 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp127_ = phone_types;
#line 125 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp128_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp127_);
#line 125 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp129_ = _tmp128_;
#line 125 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp129_ == 3, "phone_types.size == 3");
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp130_ = c1;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp131_ = gee_abstract_map_get_size ((GeeMap*) _tmp130_);
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp132_ = _tmp131_;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp132_ == 0, "c1.size == 0");
#line 127 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp133_ = c2;
#line 127 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp134_ = gee_abstract_map_get_size ((GeeMap*) _tmp133_);
#line 127 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp135_ = _tmp134_;
#line 127 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp135_ == 0, "c2.size == 0");
#line 883 "phone-details.c"
	{
		GeeIterator* _pt_it = NULL;
		GeeHashSet* _tmp136_ = NULL;
		GeeIterator* _tmp137_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp136_ = phone_types;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp137_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp136_);
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_pt_it = _tmp137_;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 896 "phone-details.c"
			GeeIterator* _tmp138_ = NULL;
			gboolean _tmp139_ = FALSE;
			gchar* pt = NULL;
			GeeIterator* _tmp140_ = NULL;
			gpointer _tmp141_ = NULL;
			const gchar* _tmp142_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp138_ = _pt_it;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp139_ = gee_iterator_next (_tmp138_);
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (!_tmp139_) {
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				break;
#line 911 "phone-details.c"
			}
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp140_ = _pt_it;
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp141_ = gee_iterator_get (_tmp140_);
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			pt = (gchar*) _tmp141_;
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp142_ = pt;
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_vala_assert (_vala_string_array_contains (EDSF_PERSONA_phone_fields, G_N_ELEMENTS (EDSF_PERSONA_phone_fields), _tmp142_), "pt in Edsf.Persona.phone_fields");
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_g_free0 (pt);
#line 925 "phone-details.c"
		}
#line 129 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_pt_it);
#line 929 "phone-details.c"
	}
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (aggregator);
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (phone_types);
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (c2);
#line 35 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (c1);
#line 943 "phone-details.c"
}


static void phone_details_tests_class_init (PhoneDetailsTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 950 "phone-details.c"
}


static void phone_details_tests_instance_init (PhoneDetailsTests * self) {
}


GType phone_details_tests_get_type (void) {
	static volatile gsize phone_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&phone_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhoneDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) phone_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhoneDetailsTests), 0, (GInstanceInitFunc) phone_details_tests_instance_init, NULL };
		GType phone_details_tests_type_id;
		phone_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "PhoneDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&phone_details_tests_type_id__volatile, phone_details_tests_type_id);
	}
	return phone_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PhoneDetailsTests* tests = NULL;
	PhoneDetailsTests* _tmp0_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 138 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = phone_details_tests_new ();
#line 138 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	tests = _tmp0_;
#line 139 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 140 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_test_run ();
#line 141 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	result = 0;
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (tests);
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return result;
#line 992 "phone-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 134 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return _vala_main (argv, argc);
#line 1002 "phone-details.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



