/* aggregation.c generated by valac 0.34.0.3-63fa6, the Vala compiler
 * generated from aggregation.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Alban Crequy <alban.crequy@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <libsocialweb-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <glib/gstdio.h>
#include <folks/folks.h>
#include <gee.h>


#define TYPE_AGGREGATION_TESTS (aggregation_tests_get_type ())
#define AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AGGREGATION_TESTS, AggregationTests))
#define AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AGGREGATION_TESTS, AggregationTestsClass))
#define IS_AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AGGREGATION_TESTS))
#define IS_AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AGGREGATION_TESTS))
#define AGGREGATION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AGGREGATION_TESTS, AggregationTestsClass))

typedef struct _AggregationTests AggregationTests;
typedef struct _AggregationTestsClass AggregationTestsClass;
typedef struct _AggregationTestsPrivate AggregationTestsPrivate;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
typedef struct _Block3Data Block3Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _libsocialweb_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (libsocialweb_test_backend_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AggregationTests {
	LibsocialwebTestTestCase parent_instance;
	AggregationTestsPrivate * priv;
};

struct _AggregationTestsClass {
	LibsocialwebTestTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	AggregationTests* self;
	GMainLoop* main_loop;
	LibsocialwebTestLibsocialwebServiceTest* mysocialnetwork1;
	LibsocialwebTestLibsocialwebServiceTest* mysocialnetwork2;
	FolksDisconnectionQueue* signals;
	FolksIndividualAggregator* aggregator;
	FolksIndividual** individual_gathered;
	gint individual_gathered_length1;
	gint _individual_gathered_size_;
	GeeHashSet* personas;
};

struct _Block2Data {
	int _ref_count_;
	AggregationTests* self;
	gchar* path;
};

struct _Block3Data {
	int _ref_count_;
	AggregationTests* self;
	gchar* path;
};


static gpointer aggregation_tests_parent_class = NULL;

GType aggregation_tests_get_type (void) G_GNUC_CONST;
enum  {
	AGGREGATION_TESTS_DUMMY_PROPERTY
};
#define AGGREGATION_TESTS_STORE_FILE_PATH "folks-test-libsocialweb-aggregation-store.ini"
#define AGGREGATION_TESTS_KF_RELATIONSHIPS_FILE_PATH "folks-test-libsocialweb-aggregation-relationships.ini"
AggregationTests* aggregation_tests_new (void);
AggregationTests* aggregation_tests_construct (GType object_type);
void aggregation_tests_test_aggregation_libsocialweb (AggregationTests* self);
static void _aggregation_tests_test_aggregation_libsocialweb_folks_test_case_test_method (gpointer self);
static void aggregation_tests_real_set_up (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda4_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path);
static void __lambda5_ (AggregationTests* self, const gchar* path);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static gboolean __lambda6_ (Block2Data* _data2_);
static gboolean ___lambda6__gsource_func (gpointer self);
static void ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self);
static void ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self);
static void __lambda7_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path);
static void __lambda8_ (AggregationTests* self, const gchar* path);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static gboolean __lambda9_ (Block3Data* _data3_);
static gboolean ___lambda9__gsource_func (gpointer self);
static void ___lambda8__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self);
static void ___lambda7__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self);
static void __lambda10_ (Block1Data* _data1_, GeeMultiMap* changes);
static void _vala_array_add1 (FolksIndividual*** array, int* length, int* size, FolksIndividual* value);
static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda11_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda12_ (Block1Data* _data1_);
static gboolean ___lambda12__gsource_func (gpointer self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _aggregation_tests_test_aggregation_libsocialweb_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	aggregation_tests_test_aggregation_libsocialweb ((AggregationTests*) self);
#line 145 "aggregation.c"
}


AggregationTests* aggregation_tests_construct (GType object_type) {
	AggregationTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = (AggregationTests*) libsocialweb_test_test_case_construct (object_type, "Aggregation");
#line 37 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "libsocialweb aggregation", _aggregation_tests_test_aggregation_libsocialweb_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return self;
#line 157 "aggregation.c"
}


AggregationTests* aggregation_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return aggregation_tests_construct (TYPE_AGGREGATION_TESTS);
#line 164 "aggregation.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1398 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 208 "aggregation.c"
	}
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 214 "aggregation.c"
}


static void aggregation_tests_real_set_up (FolksTestCase* base) {
	AggregationTests * self;
	gchar* kf_relationships_path = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* kf_relationships_data = NULL;
	gchar* _tmp2_ = NULL;
	GFile* kf_relationships_f = NULL;
	GFile* _tmp3_ = NULL;
	gchar* kf_path = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GKeyFile* kf = NULL;
	GKeyFile* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = (AggregationTests*) base;
#line 43 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_setenv ("FOLKS_BACKENDS_ALLOWED", "libsocialweb,key-file", TRUE);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", "key-file", TRUE);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = g_build_filename (_tmp0_, AGGREGATION_TESTS_KF_RELATIONSHIPS_FILE_PATH, NULL, NULL);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	kf_relationships_path = _tmp1_;
#line 51 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_setenv ("FOLKS_BACKEND_KEY_FILE_PATH", kf_relationships_path, TRUE);
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = g_strdup ("#\n");
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	kf_relationships_data = _tmp2_;
#line 54 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp3_ = g_file_new_for_path (kf_relationships_path);
#line 54 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	kf_relationships_f = _tmp3_;
#line 255 "aggregation.c"
	{
		guint8* _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
		guint8* _tmp5_ = NULL;
		gint _tmp5__length1 = 0;
#line 57 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp4_ = string_get_data (kf_relationships_data, &_tmp4__length1);
#line 57 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 57 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp5__length1 = _tmp4__length1;
#line 57 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_file_replace_contents (kf_relationships_f, _tmp5_, (gsize) _tmp5__length1, NULL, FALSE, G_FILE_CREATE_PRIVATE, NULL, NULL, &_inner_error_);
#line 57 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "aggregation.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp6_ = NULL;
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp6_ = e->message;
#line 62 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_error ("aggregation.vala:62: Could not write relationship file '%s': %s", kf_relationships_path, _tmp6_);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 290 "aggregation.c"
	}
	__finally0:
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (kf_relationships_f);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (kf_relationships_data);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (kf_relationships_path);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		return;
#line 307 "aggregation.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp7_ = g_get_tmp_dir ();
#line 67 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp8_ = g_build_filename (_tmp7_, AGGREGATION_TESTS_STORE_FILE_PATH, NULL, NULL);
#line 67 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	kf_path = _tmp8_;
#line 70 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_remove (kf_path);
#line 72 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp9_ = g_key_file_new ();
#line 72 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	kf = _tmp9_;
#line 73 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_key_file_set_boolean (kf, "all-others", "enabled", FALSE);
#line 74 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_key_file_set_boolean (kf, "libsocialweb", "enabled", TRUE);
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_key_file_set_boolean (kf, "key-file", "enabled", TRUE);
#line 327 "aggregation.c"
	{
		GFile* backend_f = NULL;
		GFile* _tmp10_ = NULL;
		gchar* data = NULL;
		gchar* _tmp11_ = NULL;
		guint8* _tmp12_ = NULL;
		gint _tmp12__length1 = 0;
		guint8* _tmp13_ = NULL;
		gint _tmp13__length1 = 0;
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp10_ = g_file_new_for_path (kf_path);
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		backend_f = _tmp10_;
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp11_ = g_key_file_to_data (kf, NULL, NULL);
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		data = _tmp11_;
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp12_ = string_get_data (data, &_tmp12__length1);
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp13_ = _tmp12_;
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp13__length1 = _tmp12__length1;
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_file_replace_contents (backend_f, _tmp13_, (gsize) _tmp13__length1, NULL, FALSE, G_FILE_CREATE_PRIVATE, NULL, NULL, &_inner_error_);
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_free0 (data);
#line 81 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (backend_f);
#line 359 "aggregation.c"
			goto __catch1_g_error;
		}
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (data);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (backend_f);
#line 366 "aggregation.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp14_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp14_ = e->message;
#line 86 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_error ("aggregation.vala:86: Could not write updated backend key file '%s': %s", kf_path, _tmp14_);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 383 "aggregation.c"
	}
	__finally1:
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_key_file_unref0 (kf);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (kf_path);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (kf_relationships_f);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (kf_relationships_data);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (kf_relationships_path);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 77 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		return;
#line 404 "aggregation.c"
	}
#line 90 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_setenv ("FOLKS_BACKEND_STORE_KEY_FILE_PATH", kf_path, TRUE);
#line 94 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	FOLKS_TEST_CASE_CLASS (aggregation_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCase));
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_key_file_unref0 (kf);
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (kf_path);
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (kf_relationships_f);
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (kf_relationships_data);
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (kf_relationships_path);
#line 420 "aggregation.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return _data1_;
#line 429 "aggregation.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 438 "aggregation.c"
		AggregationTests* self;
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		self = _data1_->self;
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_data1_->personas);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_data1_->individual_gathered = (_vala_array_free (_data1_->individual_gathered, _data1_->individual_gathered_length1, (GDestroyNotify) g_object_unref), NULL);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_data1_->signals);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_data1_->mysocialnetwork2);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_data1_->mysocialnetwork1);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (self);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_slice_free (Block1Data, _data1_);
#line 460 "aggregation.c"
	}
}


static gpointer _libsocialweb_test_backend_ref0 (gpointer self) {
#line 100 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return self ? libsocialweb_test_backend_ref (self) : NULL;
#line 468 "aggregation.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return _data2_;
#line 477 "aggregation.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 486 "aggregation.c"
		AggregationTests* self;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		self = _data2_->self;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (_data2_->path);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (self);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_slice_free (Block2Data, _data2_);
#line 496 "aggregation.c"
	}
}


static gboolean __lambda6_ (Block2Data* _data2_) {
	AggregationTests* self;
	gboolean result = FALSE;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	GVariant* v = NULL;
	const gchar* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data2_->self;
#line 114 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = g_strdup ("([('mysocialnetwork1', 'garg', %x, " "{'id': ['garg'], 'name': ['Gargantua']})],)");
#line 114 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	text = _tmp0_;
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = text;
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = g_variant_new_parsed (_tmp1_, 1300792578, NULL);
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_variant_ref_sink (_tmp2_);
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	v = _tmp2_;
#line 524 "aggregation.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp3_ = NULL;
		GDBusConnection* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GVariant* _tmp6_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp3_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		conn = _tmp3_;
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 539 "aggregation.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp4_ = conn;
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp5_ = _data2_->path;
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp6_ = v;
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_dbus_connection_emit_signal (_tmp4_, NULL, _tmp5_, "org.gnome.libsocialweb.ContactView", "ContactsAdded", _tmp6_, &_inner_error_);
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (conn);
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 558 "aggregation.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (conn);
#line 565 "aggregation.c"
	}
	goto __finally2;
	__catch2_g_io_error:
	{
		GError* e = NULL;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_assert_not_reached ();
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 579 "aggregation.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_assert_not_reached ();
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 593 "aggregation.c"
	}
	__finally2:
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_variant_unref0 (v);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (text);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		return FALSE;
#line 608 "aggregation.c"
	}
#line 132 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	result = FALSE;
#line 132 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_variant_unref0 (v);
#line 132 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (text);
#line 132 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 618 "aggregation.c"
}


static gboolean ___lambda6__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda6_ (self);
#line 112 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 627 "aggregation.c"
}


static void __lambda5_ (AggregationTests* self, const gchar* path) {
	Block2Data* _data2_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (path != NULL);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data2_->_ref_count_ = 1;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data2_->self = g_object_ref (self);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = path;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (_data2_->path);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data2_->path = _tmp1_;
#line 112 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda6__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	block2_data_unref (_data2_);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data2_ = NULL;
#line 657 "aggregation.c"
}


static void ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self) {
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda5_ ((AggregationTests*) self, path);
#line 664 "aggregation.c"
}


static void __lambda4_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path) {
	AggregationTests* self;
	LibsocialwebTestLibsocialwebContactViewTest* view = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	FolksDisconnectionQueue* _tmp4_ = NULL;
	gulong _tmp5_ = 0UL;
#line 107 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data1_->self;
#line 107 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (query != NULL);
#line 107 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (p != NULL);
#line 107 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (path != NULL);
#line 109 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = _data1_->mysocialnetwork1;
#line 109 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = _tmp0_->contact_views;
#line 109 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = path;
#line 109 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, _tmp2_);
#line 109 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	view = (LibsocialwebTestLibsocialwebContactViewTest*) _tmp3_;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp4_ = _data1_->signals;
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp5_ = g_signal_connect_object (view, "start-called", (GCallback) ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called, self, 0);
#line 110 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_push (_tmp4_, (GObject*) view, _tmp5_);
#line 107 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (view);
#line 703 "aggregation.c"
}


static void ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self) {
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda4_ (self, query, p, path);
#line 710 "aggregation.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return _data3_;
#line 719 "aggregation.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 728 "aggregation.c"
		AggregationTests* self;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		self = _data3_->self;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (_data3_->path);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (self);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_slice_free (Block3Data, _data3_);
#line 738 "aggregation.c"
	}
}


static gboolean __lambda9_ (Block3Data* _data3_) {
	AggregationTests* self;
	gboolean result = FALSE;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	GVariant* v = NULL;
	const gchar* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data3_->self;
#line 146 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = g_strdup ("([('mysocialnetwork2', 'panta', %x, " "{'id': ['panta'], 'name': ['Pantagruel']})],)");
#line 146 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	text = _tmp0_;
#line 148 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = text;
#line 148 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = g_variant_new_parsed (_tmp1_, 1300792579, NULL);
#line 148 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_variant_ref_sink (_tmp2_);
#line 148 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	v = _tmp2_;
#line 766 "aggregation.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp3_ = NULL;
		GDBusConnection* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GVariant* _tmp6_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp3_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		conn = _tmp3_;
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 781 "aggregation.c"
				goto __catch3_g_io_error;
			}
			goto __catch3_g_error;
		}
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp4_ = conn;
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp5_ = _data3_->path;
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp6_ = v;
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_dbus_connection_emit_signal (_tmp4_, NULL, _tmp5_, "org.gnome.libsocialweb.ContactView", "ContactsAdded", _tmp6_, &_inner_error_);
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (conn);
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 800 "aggregation.c"
				goto __catch3_g_io_error;
			}
			goto __catch3_g_error;
		}
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (conn);
#line 807 "aggregation.c"
	}
	goto __finally3;
	__catch3_g_io_error:
	{
		GError* e = NULL;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_assert_not_reached ();
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 821 "aggregation.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e = NULL;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		e = _inner_error_;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_inner_error_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_assert_not_reached ();
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_error_free0 (e);
#line 835 "aggregation.c"
	}
	__finally3:
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_variant_unref0 (v);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_free0 (text);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		return FALSE;
#line 850 "aggregation.c"
	}
#line 164 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	result = FALSE;
#line 164 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_variant_unref0 (v);
#line 164 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (text);
#line 164 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 860 "aggregation.c"
}


static gboolean ___lambda9__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda9_ (self);
#line 144 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 869 "aggregation.c"
}


static void __lambda8_ (AggregationTests* self, const gchar* path) {
	Block3Data* _data3_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (path != NULL);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data3_->_ref_count_ = 1;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data3_->self = g_object_ref (self);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = path;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_free0 (_data3_->path);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data3_->path = _tmp1_;
#line 144 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda9__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	block3_data_unref (_data3_);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data3_ = NULL;
#line 899 "aggregation.c"
}


static void ___lambda8__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self) {
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda8_ ((AggregationTests*) self, path);
#line 906 "aggregation.c"
}


static void __lambda7_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path) {
	AggregationTests* self;
	LibsocialwebTestLibsocialwebContactViewTest* view = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	FolksDisconnectionQueue* _tmp4_ = NULL;
	gulong _tmp5_ = 0UL;
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data1_->self;
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (query != NULL);
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (p != NULL);
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (path != NULL);
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = _data1_->mysocialnetwork2;
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = _tmp0_->contact_views;
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = path;
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, _tmp2_);
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	view = (LibsocialwebTestLibsocialwebContactViewTest*) _tmp3_;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp4_ = _data1_->signals;
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp5_ = g_signal_connect_object (view, "start-called", (GCallback) ___lambda8__libsocialweb_test_libsocialweb_contact_view_test_start_called, self, 0);
#line 142 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_push (_tmp4_, (GObject*) view, _tmp5_);
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (view);
#line 945 "aggregation.c"
}


static void ___lambda7__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self) {
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda7_ (self, query, p, path);
#line 952 "aggregation.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return self ? g_object_ref (self) : NULL;
#line 959 "aggregation.c"
}


static void _vala_array_add1 (FolksIndividual*** array, int* length, int* size, FolksIndividual* value) {
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if ((*length) == (*size)) {
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		*array = g_renew (FolksIndividual*, *array, (*size) + 1);
#line 970 "aggregation.c"
	}
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	(*array)[(*length)++] = value;
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	(*array)[*length] = NULL;
#line 976 "aggregation.c"
}


static void __lambda10_ (Block1Data* _data1_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	FolksIndividual** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
#line 172 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data1_->self;
#line 172 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 174 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = changes;
#line 174 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 174 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	added = _tmp1_;
#line 176 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_debug ("aggregation.vala:176: initial individuals_changed");
#line 999 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp2_ = added;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_i_it = _tmp3_;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		while (TRUE) {
#line 1012 "aggregation.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			FolksIndividual** _tmp9_ = NULL;
			gint _tmp9__length1 = 0;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp4_ = _i_it;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (!_tmp5_) {
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				break;
#line 1031 "aggregation.c"
			}
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp6_ = _i_it;
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			i = (FolksIndividual*) _tmp7_;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp8_ = i;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_tmp8_ == NULL) {
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				_g_object_unref0 (i);
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				continue;
#line 1047 "aggregation.c"
			}
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp9_ = _data1_->individual_gathered;
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp9__length1 = _data1_->individual_gathered_length1;
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp10_ = i;
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp11_ = _g_object_ref0 (_tmp10_);
#line 184 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_vala_array_add1 (&_data1_->individual_gathered, &_data1_->individual_gathered_length1, &_data1_->_individual_gathered_size_, _tmp11_);
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (i);
#line 1061 "aggregation.c"
		}
#line 177 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1065 "aggregation.c"
	}
#line 186 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp12_ = _data1_->individual_gathered;
#line 186 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp12__length1 = _data1_->individual_gathered_length1;
#line 186 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (_tmp12__length1 >= 2) {
#line 1073 "aggregation.c"
		GMainLoop* _tmp13_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp13_ = _data1_->main_loop;
#line 187 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		g_main_loop_quit (_tmp13_);
#line 1079 "aggregation.c"
	}
#line 172 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (added);
#line 1083 "aggregation.c"
}


static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 171 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda10_ (self, changes);
#line 1090 "aggregation.c"
}


static void __lambda11_ (Block1Data* _data1_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	GeeCollection* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
	GeeSet* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	FolksIndividual* added_ind = NULL;
	GMainLoop* _tmp46_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data1_->self;
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 207 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = changes;
#line 207 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 207 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	added = _tmp1_;
#line 208 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = changes;
#line 208 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 208 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	removed = _tmp3_;
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp4_ = added;
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp6_ = _tmp5_;
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp7_ = removed;
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp9_ = _tmp8_;
#line 210 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_debug ("aggregation.vala:210: individuals_changed after link: added:%u removed" \
":%u", (guint) _tmp6_, (guint) _tmp9_);
#line 213 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp10_ = added;
#line 213 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp11_ = gee_collection_get_size (_tmp10_);
#line 213 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp12_ = _tmp11_;
#line 213 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_vala_assert (_tmp12_ == 2, "added.size == 2");
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp13_ = removed;
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp15_ = _tmp14_;
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_vala_assert (_tmp15_ == 2, "removed.size == 2");
#line 216 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	added_ind = NULL;
#line 1164 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp16_ = NULL;
		GeeIterator* _tmp17_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp16_ = added;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_i_it = _tmp17_;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		while (TRUE) {
#line 1177 "aggregation.c"
			GeeIterator* _tmp18_ = NULL;
			gboolean _tmp19_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp20_ = NULL;
			gpointer _tmp21_ = NULL;
			FolksIndividual* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			FolksIndividual* _tmp24_ = NULL;
			FolksIndividual* _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			FolksIndividual* _tmp29_ = NULL;
			GeeSet* _tmp30_ = NULL;
			GeeSet* _tmp31_ = NULL;
			gint _tmp32_ = 0;
			gint _tmp33_ = 0;
			FolksIndividual* _tmp34_ = NULL;
			GeeSet* _tmp35_ = NULL;
			GeeSet* _tmp36_ = NULL;
			gint _tmp37_ = 0;
			gint _tmp38_ = 0;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp18_ = _i_it;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp19_ = gee_iterator_next (_tmp18_);
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (!_tmp19_) {
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				break;
#line 1206 "aggregation.c"
			}
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp20_ = _i_it;
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			i = (FolksIndividual*) _tmp21_;
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp22_ = i;
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_vala_assert (_tmp22_ != NULL, "i != null");
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp24_ = added_ind;
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (_tmp24_ == NULL) {
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				_tmp23_ = TRUE;
#line 1224 "aggregation.c"
			} else {
				FolksIndividual* _tmp25_ = NULL;
				FolksIndividual* _tmp26_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				_tmp25_ = added_ind;
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				_tmp26_ = i;
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				_tmp23_ = _tmp25_ == _tmp26_;
#line 1234 "aggregation.c"
			}
#line 221 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_vala_assert (_tmp23_, "added_ind == null || added_ind == i");
#line 222 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp27_ = i;
#line 222 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp28_ = _g_object_ref0 (_tmp27_);
#line 222 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (added_ind);
#line 222 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			added_ind = _tmp28_;
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp29_ = i;
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp30_ = folks_individual_get_personas (_tmp29_);
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp31_ = _tmp30_;
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp32_ = gee_collection_get_size ((GeeCollection*) _tmp31_);
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp33_ = _tmp32_;
#line 224 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_vala_assert (_tmp33_ == 3, "i.personas.size == 3");
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp34_ = i;
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp35_ = folks_individual_get_personas (_tmp34_);
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp36_ = _tmp35_;
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp37_ = gee_collection_get_size ((GeeCollection*) _tmp36_);
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp38_ = _tmp37_;
#line 225 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			g_debug ("aggregation.vala:225: individuals_changed: 1 individual containing %u " \
"personas", (guint) _tmp38_);
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (i);
#line 1272 "aggregation.c"
		}
#line 218 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1276 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp39_ = NULL;
		GeeIterator* _tmp40_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp39_ = removed;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp40_ = gee_iterable_iterator ((GeeIterable*) _tmp39_);
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_i_it = _tmp40_;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		while (TRUE) {
#line 1290 "aggregation.c"
			GeeIterator* _tmp41_ = NULL;
			gboolean _tmp42_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp43_ = NULL;
			gpointer _tmp44_ = NULL;
			FolksIndividual* _tmp45_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp41_ = _i_it;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp42_ = gee_iterator_next (_tmp41_);
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (!_tmp42_) {
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				break;
#line 1305 "aggregation.c"
			}
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp43_ = _i_it;
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp44_ = gee_iterator_get (_tmp43_);
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			i = (FolksIndividual*) _tmp44_;
#line 231 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp45_ = i;
#line 231 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_vala_assert (_tmp45_ != NULL, "i != null");
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (i);
#line 1319 "aggregation.c"
		}
#line 229 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1323 "aggregation.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp46_ = _data1_->main_loop;
#line 234 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_main_loop_quit (_tmp46_);
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (added_ind);
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (removed);
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (added);
#line 1335 "aggregation.c"
}


static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	__lambda11_ (self, changes);
#line 1342 "aggregation.c"
}


static gboolean __lambda12_ (Block1Data* _data1_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	self = _data1_->self;
#line 258 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = _data1_->aggregator;
#line 258 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = _data1_->personas;
#line 258 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_individual_aggregator_link_personas (_tmp0_, (GeeSet*) _tmp1_, NULL, NULL);
#line 259 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	result = FALSE;
#line 259 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 1363 "aggregation.c"
}


static gboolean ___lambda12__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda12_ (self);
#line 256 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 1372 "aggregation.c"
}


void aggregation_tests_test_aggregation_libsocialweb (AggregationTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	LibsocialwebTestBackend* lsw_backend = NULL;
	LibsocialwebTestBackend* _tmp1_ = NULL;
	LibsocialwebTestBackend* _tmp2_ = NULL;
	LibsocialwebTestBackend* _tmp3_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp4_ = NULL;
	LibsocialwebTestBackend* _tmp5_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp6_ = NULL;
	FolksDisconnectionQueue* _tmp7_ = NULL;
	FolksDisconnectionQueue* _tmp8_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp9_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp10_ = NULL;
	gulong _tmp11_ = 0UL;
	FolksDisconnectionQueue* _tmp12_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp13_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp14_ = NULL;
	gulong _tmp15_ = 0UL;
	FolksIndividualAggregator* _tmp16_ = NULL;
	FolksIndividual** _tmp17_ = NULL;
	gulong handler_id = 0UL;
	FolksIndividualAggregator* _tmp18_ = NULL;
	gulong _tmp19_ = 0UL;
	FolksIndividualAggregator* _tmp20_ = NULL;
	GMainLoop* _tmp21_ = NULL;
	FolksIndividualAggregator* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	FolksIndividual** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	gboolean _tmp25_ = FALSE;
	gboolean _tmp26_ = FALSE;
	FolksIndividual** _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
	FolksIndividual* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	FolksDisconnectionQueue* _tmp44_ = NULL;
	FolksIndividualAggregator* _tmp45_ = NULL;
	FolksIndividualAggregator* _tmp46_ = NULL;
	gulong _tmp47_ = 0UL;
	GeeHashSet* _tmp48_ = NULL;
	GList* personas1 = NULL;
	GList* personas2 = NULL;
	GeeHashSet* _tmp73_ = NULL;
	gint _tmp74_ = 0;
	gint _tmp75_ = 0;
	GMainLoop* _tmp76_ = NULL;
	FolksDisconnectionQueue* _tmp77_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->_ref_count_ = 1;
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->self = g_object_ref (self);
#line 99 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 99 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->main_loop = _tmp0_;
#line 100 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp1_ = ((LibsocialwebTestTestCase*) self)->lsw_backend;
#line 100 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp2_ = _libsocialweb_test_backend_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend));
#line 100 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	lsw_backend = _tmp2_;
#line 101 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp3_ = lsw_backend;
#line 101 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp4_ = libsocialweb_test_backend_add_service (_tmp3_, "mysocialnetwork1");
#line 101 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->mysocialnetwork1 = _tmp4_;
#line 102 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp5_ = lsw_backend;
#line 102 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp6_ = libsocialweb_test_backend_add_service (_tmp5_, "mysocialnetwork2");
#line 102 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->mysocialnetwork2 = _tmp6_;
#line 103 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp7_ = folks_disconnection_queue_new ();
#line 103 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->signals = _tmp7_;
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp8_ = _data1_->signals;
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp9_ = _data1_->mysocialnetwork1;
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp10_ = _data1_->mysocialnetwork1;
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp11_ = g_signal_connect_data (_tmp10_, "open-view-called", (GCallback) ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_push (_tmp8_, (GObject*) _tmp9_, _tmp11_);
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp12_ = _data1_->signals;
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp13_ = _data1_->mysocialnetwork2;
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp14_ = _data1_->mysocialnetwork2;
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp15_ = g_signal_connect_data (_tmp14_, "open-view-called", (GCallback) ___lambda7__libsocialweb_test_libsocialweb_service_test_open_view_called, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 138 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_push (_tmp12_, (GObject*) _tmp13_, _tmp15_);
#line 169 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp16_ = folks_individual_aggregator_dup ();
#line 169 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->aggregator = _tmp16_;
#line 170 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp17_ = g_new0 (FolksIndividual*, 0 + 1);
#line 170 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->individual_gathered = _tmp17_;
#line 170 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->individual_gathered_length1 = 0;
#line 170 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->_individual_gathered_size_ = _data1_->individual_gathered_length1;
#line 171 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp18_ = _data1_->aggregator;
#line 171 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp19_ = g_signal_connect_data (_tmp18_, "individuals-changed-detailed", (GCallback) ___lambda10__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 171 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	handler_id = _tmp19_;
#line 189 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp20_ = _data1_->aggregator;
#line 189 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp20_, NULL, NULL);
#line 191 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp21_ = _data1_->main_loop;
#line 191 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_test_utils_loop_run_with_timeout (_tmp21_, 5);
#line 192 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp22_ = _data1_->aggregator;
#line 192 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp23_ = handler_id;
#line 192 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp22_, _tmp23_);
#line 195 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp24_ = _data1_->individual_gathered;
#line 195 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp24__length1 = _data1_->individual_gathered_length1;
#line 195 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_vala_assert (_tmp24__length1 == 2, "individual_gathered.length == 2");
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp27_ = _data1_->individual_gathered;
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp27__length1 = _data1_->individual_gathered_length1;
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp28_ = _tmp27_[0];
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp29_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp30_ = _tmp29_;
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (g_strcmp0 (_tmp30_, "Gargantua") == 0) {
#line 1529 "aggregation.c"
		FolksIndividual** _tmp31_ = NULL;
		gint _tmp31__length1 = 0;
		FolksIndividual* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp31_ = _data1_->individual_gathered;
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp31__length1 = _data1_->individual_gathered_length1;
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp32_ = _tmp31_[1];
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp33_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp34_ = _tmp33_;
#line 198 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp26_ = g_strcmp0 (_tmp34_, "Pantagruel") == 0;
#line 1547 "aggregation.c"
	} else {
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp26_ = FALSE;
#line 1551 "aggregation.c"
	}
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	if (_tmp26_) {
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp25_ = TRUE;
#line 1557 "aggregation.c"
	} else {
		gboolean _tmp35_ = FALSE;
		FolksIndividual** _tmp36_ = NULL;
		gint _tmp36__length1 = 0;
		FolksIndividual* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp36_ = _data1_->individual_gathered;
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp36__length1 = _data1_->individual_gathered_length1;
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp37_ = _tmp36_[0];
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp38_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp39_ = _tmp38_;
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		if (g_strcmp0 (_tmp39_, "Pantagruel") == 0) {
#line 1577 "aggregation.c"
			FolksIndividual** _tmp40_ = NULL;
			gint _tmp40__length1 = 0;
			FolksIndividual* _tmp41_ = NULL;
			const gchar* _tmp42_ = NULL;
			const gchar* _tmp43_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp40_ = _data1_->individual_gathered;
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp40__length1 = _data1_->individual_gathered_length1;
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp41_ = _tmp40_[1];
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp42_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp43_ = _tmp42_;
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp35_ = g_strcmp0 (_tmp43_, "Gargantua") == 0;
#line 1595 "aggregation.c"
		} else {
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp35_ = FALSE;
#line 1599 "aggregation.c"
		}
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp25_ = _tmp35_;
#line 1603 "aggregation.c"
	}
#line 196 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_vala_assert (_tmp25_, "(((Folks.NameDetails) individual_gathered[0]).nickname == \"Gargantua\"            && ((Folks.NameDetails) individual_gathered[1]).nickname == \"Pantagruel\")           ||           (((Folks.NameDetails) individual_gathered[0]).nickname == \"Pantagruel\"            && ((Folks.NameDetails) individual_gathered[1]).nickname == \"Gargantua\")");
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp44_ = _data1_->signals;
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp45_ = _data1_->aggregator;
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp46_ = _data1_->aggregator;
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp47_ = g_signal_connect_data (_tmp46_, "individuals-changed-detailed", (GCallback) ___lambda11__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_push (_tmp44_, (GObject*) _tmp45_, _tmp47_);
#line 238 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp48_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 238 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_->personas = _tmp48_;
#line 240 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	personas1 = NULL;
#line 1623 "aggregation.c"
	{
		GeeIterator* _p1_it = NULL;
		FolksIndividual** _tmp49_ = NULL;
		gint _tmp49__length1 = 0;
		FolksIndividual* _tmp50_ = NULL;
		GeeSet* _tmp51_ = NULL;
		GeeSet* _tmp52_ = NULL;
		GeeIterator* _tmp53_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp49_ = _data1_->individual_gathered;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp49__length1 = _data1_->individual_gathered_length1;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp50_ = _tmp49_[0];
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp51_ = folks_individual_get_personas (_tmp50_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp52_ = _tmp51_;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp53_ = gee_iterable_iterator ((GeeIterable*) _tmp52_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_p1_it = _tmp53_;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		while (TRUE) {
#line 1648 "aggregation.c"
			GeeIterator* _tmp54_ = NULL;
			gboolean _tmp55_ = FALSE;
			FolksPersona* p1 = NULL;
			GeeIterator* _tmp56_ = NULL;
			gpointer _tmp57_ = NULL;
			GeeHashSet* _tmp58_ = NULL;
			FolksPersona* _tmp59_ = NULL;
			FolksPersona* _tmp60_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp54_ = _p1_it;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp55_ = gee_iterator_next (_tmp54_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (!_tmp55_) {
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				break;
#line 1665 "aggregation.c"
			}
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp56_ = _p1_it;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp57_ = gee_iterator_get (_tmp56_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			p1 = (FolksPersona*) _tmp57_;
#line 243 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp58_ = _data1_->personas;
#line 243 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp59_ = p1;
#line 243 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp58_, _tmp59_);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp60_ = p1;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			personas1 = g_list_append (personas1, _tmp60_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (p1);
#line 1685 "aggregation.c"
		}
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_p1_it);
#line 1689 "aggregation.c"
	}
#line 247 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	personas2 = NULL;
#line 1693 "aggregation.c"
	{
		GeeIterator* _p2_it = NULL;
		FolksIndividual** _tmp61_ = NULL;
		gint _tmp61__length1 = 0;
		FolksIndividual* _tmp62_ = NULL;
		GeeSet* _tmp63_ = NULL;
		GeeSet* _tmp64_ = NULL;
		GeeIterator* _tmp65_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp61_ = _data1_->individual_gathered;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp61__length1 = _data1_->individual_gathered_length1;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp62_ = _tmp61_[1];
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp63_ = folks_individual_get_personas (_tmp62_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp64_ = _tmp63_;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_tmp65_ = gee_iterable_iterator ((GeeIterable*) _tmp64_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_p2_it = _tmp65_;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		while (TRUE) {
#line 1718 "aggregation.c"
			GeeIterator* _tmp66_ = NULL;
			gboolean _tmp67_ = FALSE;
			FolksPersona* p2 = NULL;
			GeeIterator* _tmp68_ = NULL;
			gpointer _tmp69_ = NULL;
			GeeHashSet* _tmp70_ = NULL;
			FolksPersona* _tmp71_ = NULL;
			FolksPersona* _tmp72_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp66_ = _p2_it;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp67_ = gee_iterator_next (_tmp66_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			if (!_tmp67_) {
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
				break;
#line 1735 "aggregation.c"
			}
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp68_ = _p2_it;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp69_ = gee_iterator_get (_tmp68_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			p2 = (FolksPersona*) _tmp69_;
#line 250 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp70_ = _data1_->personas;
#line 250 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp71_ = p2;
#line 250 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp70_, _tmp71_);
#line 251 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_tmp72_ = p2;
#line 251 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			personas2 = g_list_append (personas2, _tmp72_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
			_g_object_unref0 (p2);
#line 1755 "aggregation.c"
		}
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
		_g_object_unref0 (_p2_it);
#line 1759 "aggregation.c"
	}
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp73_ = _data1_->personas;
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp74_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp73_);
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp75_ = _tmp74_;
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_vala_assert (_tmp75_ == 2, "personas.size == 2");
#line 256 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda12__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 262 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp76_ = _data1_->main_loop;
#line 262 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_test_utils_loop_run_with_timeout (_tmp76_, 5);
#line 264 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp77_ = _data1_->signals;
#line 264 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_disconnection_queue_drain (_tmp77_);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_list_free0 (personas2);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_list_free0 (personas1);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_libsocialweb_test_backend_unref0 (lsw_backend);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	block1_data_unref (_data1_);
#line 97 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_data1_ = NULL;
#line 1789 "aggregation.c"
}


static void aggregation_tests_class_init (AggregationTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	aggregation_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	((FolksTestCaseClass *) klass)->set_up = aggregation_tests_real_set_up;
#line 1798 "aggregation.c"
}


static void aggregation_tests_instance_init (AggregationTests * self) {
}


GType aggregation_tests_get_type (void) {
	static volatile gsize aggregation_tests_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AggregationTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aggregation_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AggregationTests), 0, (GInstanceInitFunc) aggregation_tests_instance_init, NULL };
		GType aggregation_tests_type_id;
		aggregation_tests_type_id = g_type_register_static (LIBSOCIALWEB_TEST_TYPE_TEST_CASE, "AggregationTests", &g_define_type_info, 0);
		g_once_init_leave (&aggregation_tests_type_id__volatile, aggregation_tests_type_id);
	}
	return aggregation_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AggregationTests* tests = NULL;
	AggregationTests* _tmp0_ = NULL;
#line 270 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_test_init (&args_length1, &args, NULL);
#line 272 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_tmp0_ = aggregation_tests_new ();
#line 272 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	tests = _tmp0_;
#line 273 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 274 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	g_test_run ();
#line 275 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 277 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	result = 0;
#line 277 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	_g_object_unref0 (tests);
#line 277 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return result;
#line 1840 "aggregation.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 268 "/opt/gnome3/source/folks/tests/libsocialweb/aggregation.vala"
	return _vala_main (argv, argc);
#line 1850 "aggregation.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



