/* async-locking.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from async-locking.vala, do not modify */


#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_ASYNC_LOCKING_TESTS (async_locking_tests_get_type ())
#define ASYNC_LOCKING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ASYNC_LOCKING_TESTS, AsyncLockingTests))
#define ASYNC_LOCKING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ASYNC_LOCKING_TESTS, AsyncLockingTestsClass))
#define IS_ASYNC_LOCKING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ASYNC_LOCKING_TESTS))
#define IS_ASYNC_LOCKING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ASYNC_LOCKING_TESTS))
#define ASYNC_LOCKING_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ASYNC_LOCKING_TESTS, AsyncLockingTestsClass))

typedef struct _AsyncLockingTests AsyncLockingTests;
typedef struct _AsyncLockingTestsClass AsyncLockingTestsClass;
typedef struct _AsyncLockingTestsPrivate AsyncLockingTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _AsyncLockingTestsLockedIncrementData AsyncLockingTestsLockedIncrementData;
typedef struct _AsyncLockingTestsLockedIncrementSafeData AsyncLockingTestsLockedIncrementSafeData;
typedef struct _AsyncLockingTestsSimulateWorkData AsyncLockingTestsSimulateWorkData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AsyncLockingTests {
	FolksTestCase parent_instance;
	AsyncLockingTestsPrivate * priv;
};

struct _AsyncLockingTestsClass {
	FolksTestCaseClass parent_class;
};

struct _AsyncLockingTestsPrivate {
	gint _counter;
	GStaticRecMutex __lock__counter;
	gboolean _counter_increment_pending;
	gint _calls_pending;
	gint _total_calls;
	GMainLoop* _loop;
};

struct _AsyncLockingTestsLockedIncrementData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AsyncLockingTests* self;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GError * _inner_error_;
};

struct _AsyncLockingTestsLockedIncrementSafeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AsyncLockingTests* self;
	gint _tmp0_;
	gboolean _tmp1_;
	gint _tmp2_;
	gboolean _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	GError * _inner_error_;
};

struct _AsyncLockingTestsSimulateWorkData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AsyncLockingTests* self;
};


static gpointer async_locking_tests_parent_class = NULL;

GType async_locking_tests_get_type (void) G_GNUC_CONST;
#define ASYNC_LOCKING_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ASYNC_LOCKING_TESTS, AsyncLockingTestsPrivate))
enum  {
	ASYNC_LOCKING_TESTS_DUMMY_PROPERTY
};
AsyncLockingTests* async_locking_tests_new (void);
AsyncLockingTests* async_locking_tests_construct (GType object_type);
void async_locking_tests_test_many_concurrent_funcs (AsyncLockingTests* self);
static void _async_locking_tests_test_many_concurrent_funcs_folks_test_case_test_method (gpointer self);
void async_locking_tests_test_many_concurrent_funcs_safe (AsyncLockingTests* self);
static void _async_locking_tests_test_many_concurrent_funcs_safe_folks_test_case_test_method (gpointer self);
static void async_locking_tests_real_set_up (FolksTestCase* base);
static gboolean __lambda4_ (AsyncLockingTests* self);
static void async_locking_tests_locked_increment (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void async_locking_tests_locked_increment_finish (AsyncLockingTests* self, GAsyncResult* _res_);
static void async_locking_tests_increment_handler (AsyncLockingTests* self, GObject* source, GAsyncResult* _result_);
static void _async_locking_tests_increment_handler_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda4__gsource_func (gpointer self);
static void async_locking_tests_locked_increment_data_free (gpointer _data);
static gboolean async_locking_tests_locked_increment_co (AsyncLockingTestsLockedIncrementData* _data_);
static void async_locking_tests_simulate_work (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void async_locking_tests_simulate_work_finish (AsyncLockingTests* self, GAsyncResult* _res_);
static void async_locking_tests_locked_increment_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static gboolean __lambda5_ (AsyncLockingTests* self);
static void async_locking_tests_locked_increment_safe (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void async_locking_tests_locked_increment_safe_finish (AsyncLockingTests* self, GAsyncResult* _res_);
static void async_locking_tests_increment_handler_safe (AsyncLockingTests* self, GObject* source, GAsyncResult* _result_);
static void _async_locking_tests_increment_handler_safe_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda5__gsource_func (gpointer self);
static void async_locking_tests_locked_increment_safe_data_free (gpointer _data);
static gboolean async_locking_tests_locked_increment_safe_co (AsyncLockingTestsLockedIncrementSafeData* _data_);
static void async_locking_tests_locked_increment_safe_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void async_locking_tests_simulate_work_data_free (gpointer _data);
static gboolean async_locking_tests_simulate_work_co (AsyncLockingTestsSimulateWorkData* _data_);
static void async_locking_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _async_locking_tests_test_many_concurrent_funcs_folks_test_case_test_method (gpointer self) {
#line 18 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_test_many_concurrent_funcs ((AsyncLockingTests*) self);
#line 129 "async-locking.c"
}


static void _async_locking_tests_test_many_concurrent_funcs_safe_folks_test_case_test_method (gpointer self) {
#line 19 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_test_many_concurrent_funcs_safe ((AsyncLockingTests*) self);
#line 136 "async-locking.c"
}


AsyncLockingTests* async_locking_tests_construct (GType object_type) {
	AsyncLockingTests * self = NULL;
#line 17 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self = (AsyncLockingTests*) folks_test_case_construct (object_type, "AsyncLocking");
#line 18 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "many concurrent funcs", _async_locking_tests_test_many_concurrent_funcs_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 19 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "many concurrent funcs (safe)", _async_locking_tests_test_many_concurrent_funcs_safe_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 15 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return self;
#line 150 "async-locking.c"
}


AsyncLockingTests* async_locking_tests_new (void) {
#line 15 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return async_locking_tests_construct (TYPE_ASYNC_LOCKING_TESTS);
#line 157 "async-locking.c"
}


static void async_locking_tests_real_set_up (FolksTestCase* base) {
	AsyncLockingTests * self;
#line 23 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self = (AsyncLockingTests*) base;
#line 25 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	FOLKS_TEST_CASE_CLASS (async_locking_tests_parent_class)->set_up (G_TYPE_CHECK_INSTANCE_CAST (self, FOLKS_TYPE_TEST_CASE, FolksTestCase));
#line 26 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_counter = 0;
#line 27 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_calls_pending = 0;
#line 28 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_counter_increment_pending = FALSE;
#line 173 "async-locking.c"
}


static void _async_locking_tests_increment_handler_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 41 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_increment_handler ((AsyncLockingTests*) self, source_object, res);
#line 41 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_object_unref (self);
#line 182 "async-locking.c"
}


static gboolean __lambda4_ (AsyncLockingTests* self) {
	gboolean result = FALSE;
	{
		gint i = 0;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		i = 0;
#line 192 "async-locking.c"
		{
			gboolean _tmp0_ = FALSE;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_tmp0_ = TRUE;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			while (TRUE) {
#line 199 "async-locking.c"
				gint _tmp2_ = 0;
				gint _tmp3_ = 0;
				gint _tmp4_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				if (!_tmp0_) {
#line 205 "async-locking.c"
					gint _tmp1_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					_tmp1_ = i;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					i = _tmp1_ + 1;
#line 211 "async-locking.c"
				}
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp0_ = FALSE;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp2_ = i;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp3_ = self->priv->_total_calls;
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				if (!(_tmp2_ < _tmp3_)) {
#line 38 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					break;
#line 223 "async-locking.c"
				}
#line 40 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp4_ = self->priv->_calls_pending;
#line 40 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				self->priv->_calls_pending = _tmp4_ + 1;
#line 41 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_locked_increment (self, _async_locking_tests_increment_handler_gasync_ready_callback, g_object_ref (self));
#line 231 "async-locking.c"
			}
		}
	}
#line 44 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	result = FALSE;
#line 44 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return result;
#line 239 "async-locking.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ ((AsyncLockingTests*) self);
#line 36 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return result;
#line 248 "async-locking.c"
}


void async_locking_tests_test_many_concurrent_funcs (AsyncLockingTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
#line 31 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (self != NULL);
#line 33 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 33 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_main_loop_unref0 (self->priv->_loop);
#line 33 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_loop = _tmp0_;
#line 34 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_total_calls = 100;
#line 36 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda4__gsource_func, g_object_ref (self), g_object_unref);
#line 47 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp1_ = self->priv->_loop;
#line 47 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_main_loop_run (_tmp1_);
#line 271 "async-locking.c"
}


static void async_locking_tests_increment_handler (AsyncLockingTests* self, GObject* source, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 50 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (self != NULL);
#line 50 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (_result_ != NULL);
#line 52 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = _result_;
#line 52 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_finish (self, _tmp0_);
#line 55 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp1_ = self->priv->_counter;
#line 55 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_vala_assert (_tmp1_ >= 1, "this._counter >= 1");
#line 57 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp2_ = self->priv->_calls_pending;
#line 57 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_calls_pending = _tmp2_ - 1;
#line 58 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp3_ = self->priv->_calls_pending;
#line 58 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	if (_tmp3_ == 0) {
#line 300 "async-locking.c"
		gint _tmp4_ = 0;
		GMainLoop* _tmp5_ = NULL;
#line 60 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_tmp4_ = self->priv->_counter;
#line 60 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_print ("\n    final counter value: %d " "(would be 1 if this weren't intentionally broken)\n", _tmp4_);
#line 63 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_tmp5_ = self->priv->_loop;
#line 63 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_main_loop_quit (_tmp5_);
#line 311 "async-locking.c"
	}
}


static void async_locking_tests_locked_increment_data_free (gpointer _data) {
	AsyncLockingTestsLockedIncrementData* _data_;
	_data_ = _data;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_slice_free (AsyncLockingTestsLockedIncrementData, _data_);
#line 323 "async-locking.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return self ? g_object_ref (self) : NULL;
#line 330 "async-locking.c"
}


static void async_locking_tests_locked_increment (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AsyncLockingTestsLockedIncrementData* _data_;
	AsyncLockingTests* _tmp0_ = NULL;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_slice_new0 (AsyncLockingTestsLockedIncrementData);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, async_locking_tests_locked_increment);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, async_locking_tests_locked_increment_data_free);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->self = _tmp0_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_co (_data_);
#line 349 "async-locking.c"
}


static void async_locking_tests_locked_increment_finish (AsyncLockingTests* self, GAsyncResult* _res_) {
	AsyncLockingTestsLockedIncrementData* _data_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 357 "async-locking.c"
}


static void async_locking_tests_locked_increment_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AsyncLockingTestsLockedIncrementData* _data_;
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = _user_data_;
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_source_object_ = source_object;
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_res_ = _res_;
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_co (_data_);
#line 371 "async-locking.c"
}


static gboolean async_locking_tests_locked_increment_co (AsyncLockingTestsLockedIncrementData* _data_) {
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	switch (_data_->_state_) {
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		case 0:
#line 380 "async-locking.c"
		goto _state_0;
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		case 1:
#line 384 "async-locking.c"
		goto _state_1;
		default:
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_assert_not_reached ();
#line 389 "async-locking.c"
	}
	_state_0:
	{
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_data_->_tmp0_ = 0;
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_data_->_tmp0_ = _data_->self->priv->_counter;
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_static_rec_mutex_lock (&_data_->self->priv->__lock__counter);
#line 399 "async-locking.c"
		{
#line 71 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp1_ = 0;
#line 71 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp1_ = _data_->self->priv->_counter;
#line 71 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			if (_data_->_tmp1_ < 1) {
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_state_ = 1;
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_simulate_work (_data_->self, async_locking_tests_locked_increment_ready, _data_);
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				return FALSE;
#line 413 "async-locking.c"
				_state_1:
#line 77 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_simulate_work_finish (_data_->self, _data_->_res_);
#line 82 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp2_ = 0;
#line 82 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp2_ = _data_->self->priv->_counter;
#line 82 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->self->priv->_counter = _data_->_tmp2_ + 1;
#line 423 "async-locking.c"
			}
		}
		__finally0:
		{
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp3_ = 0;
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp3_ = _data_->self->priv->_counter;
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_static_rec_mutex_unlock (&_data_->self->priv->__lock__counter);
#line 434 "async-locking.c"
		}
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_clear_error (&_data_->_inner_error_);
#line 69 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			return FALSE;
#line 444 "async-locking.c"
		}
	}
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	if (_data_->_state_ == 0) {
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 451 "async-locking.c"
	} else {
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 455 "async-locking.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_object_unref (_data_->_async_result);
#line 67 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return FALSE;
#line 461 "async-locking.c"
}


static void _async_locking_tests_increment_handler_safe_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 99 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_increment_handler_safe ((AsyncLockingTests*) self, source_object, res);
#line 99 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_object_unref (self);
#line 470 "async-locking.c"
}


static gboolean __lambda5_ (AsyncLockingTests* self) {
	gboolean result = FALSE;
	{
		gint i = 0;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		i = 0;
#line 480 "async-locking.c"
		{
			gboolean _tmp0_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_tmp0_ = TRUE;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			while (TRUE) {
#line 487 "async-locking.c"
				gint _tmp2_ = 0;
				gint _tmp3_ = 0;
				gint _tmp4_ = 0;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				if (!_tmp0_) {
#line 493 "async-locking.c"
					gint _tmp1_ = 0;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					_tmp1_ = i;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					i = _tmp1_ + 1;
#line 499 "async-locking.c"
				}
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp0_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp2_ = i;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp3_ = self->priv->_total_calls;
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				if (!(_tmp2_ < _tmp3_)) {
#line 96 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
					break;
#line 511 "async-locking.c"
				}
#line 98 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_tmp4_ = self->priv->_calls_pending;
#line 98 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				self->priv->_calls_pending = _tmp4_ + 1;
#line 99 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_locked_increment_safe (self, _async_locking_tests_increment_handler_safe_gasync_ready_callback, g_object_ref (self));
#line 519 "async-locking.c"
			}
		}
	}
#line 102 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	result = FALSE;
#line 102 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return result;
#line 527 "async-locking.c"
}


static gboolean ___lambda5__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda5_ ((AsyncLockingTests*) self);
#line 94 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return result;
#line 536 "async-locking.c"
}


void async_locking_tests_test_many_concurrent_funcs_safe (AsyncLockingTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (self != NULL);
#line 89 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 89 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_main_loop_unref0 (self->priv->_loop);
#line 89 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_loop = _tmp0_;
#line 90 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_total_calls = 100;
#line 91 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_calls_pending = 0;
#line 92 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_counter_increment_pending = FALSE;
#line 94 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda5__gsource_func, g_object_ref (self), g_object_unref);
#line 105 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp1_ = self->priv->_loop;
#line 105 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_main_loop_run (_tmp1_);
#line 563 "async-locking.c"
}


static void async_locking_tests_increment_handler_safe (AsyncLockingTests* self, GObject* source, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 108 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (self != NULL);
#line 108 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_return_if_fail (_result_ != NULL);
#line 111 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = _result_;
#line 111 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_safe_finish (self, _tmp0_);
#line 115 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp1_ = self->priv->_counter;
#line 115 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_vala_assert (_tmp1_ == 1, "this._counter == 1");
#line 117 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp2_ = self->priv->_calls_pending;
#line 117 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv->_calls_pending = _tmp2_ - 1;
#line 118 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp3_ = self->priv->_calls_pending;
#line 118 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	if (_tmp3_ == 0) {
#line 592 "async-locking.c"
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		GMainLoop* _tmp6_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_tmp4_ = self->priv->_counter;
#line 120 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_print ("\n    final counter value: %d\n", _tmp4_);
#line 121 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_tmp5_ = self->priv->_counter;
#line 121 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_vala_assert (_tmp5_ == 1, "this._counter == 1");
#line 123 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_tmp6_ = self->priv->_loop;
#line 123 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_main_loop_quit (_tmp6_);
#line 608 "async-locking.c"
	}
}


static void async_locking_tests_locked_increment_safe_data_free (gpointer _data) {
	AsyncLockingTestsLockedIncrementSafeData* _data_;
	_data_ = _data;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_slice_free (AsyncLockingTestsLockedIncrementSafeData, _data_);
#line 620 "async-locking.c"
}


static void async_locking_tests_locked_increment_safe (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AsyncLockingTestsLockedIncrementSafeData* _data_;
	AsyncLockingTests* _tmp0_ = NULL;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_slice_new0 (AsyncLockingTestsLockedIncrementSafeData);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, async_locking_tests_locked_increment_safe);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, async_locking_tests_locked_increment_safe_data_free);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->self = _tmp0_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_safe_co (_data_);
#line 639 "async-locking.c"
}


static void async_locking_tests_locked_increment_safe_finish (AsyncLockingTests* self, GAsyncResult* _res_) {
	AsyncLockingTestsLockedIncrementSafeData* _data_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 647 "async-locking.c"
}


static void async_locking_tests_locked_increment_safe_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AsyncLockingTestsLockedIncrementSafeData* _data_;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = _user_data_;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_source_object_ = source_object;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_res_ = _res_;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_locked_increment_safe_co (_data_);
#line 661 "async-locking.c"
}


static gboolean async_locking_tests_locked_increment_safe_co (AsyncLockingTestsLockedIncrementSafeData* _data_) {
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	switch (_data_->_state_) {
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		case 0:
#line 670 "async-locking.c"
		goto _state_0;
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		case 1:
#line 674 "async-locking.c"
		goto _state_1;
		default:
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_assert_not_reached ();
#line 679 "async-locking.c"
	}
	_state_0:
	{
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_data_->_tmp0_ = 0;
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		_data_->_tmp0_ = _data_->self->priv->_counter;
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_static_rec_mutex_lock (&_data_->self->priv->__lock__counter);
#line 689 "async-locking.c"
		{
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp2_ = 0;
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp2_ = _data_->self->priv->_counter;
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			if (_data_->_tmp2_ < 1) {
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp3_ = FALSE;
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp3_ = _data_->self->priv->_counter_increment_pending;
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp1_ = !_data_->_tmp3_;
#line 703 "async-locking.c"
			} else {
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp1_ = FALSE;
#line 707 "async-locking.c"
			}
#line 131 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			if (_data_->_tmp1_) {
#line 133 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->self->priv->_counter_increment_pending = TRUE;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_state_ = 1;
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_simulate_work (_data_->self, async_locking_tests_locked_increment_safe_ready, _data_);
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				return FALSE;
#line 719 "async-locking.c"
				_state_1:
#line 134 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				async_locking_tests_simulate_work_finish (_data_->self, _data_->_res_);
#line 139 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp4_ = 0;
#line 139 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->_tmp4_ = _data_->self->priv->_counter;
#line 139 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
				_data_->self->priv->_counter = _data_->_tmp4_ + 1;
#line 729 "async-locking.c"
			}
		}
		__finally1:
		{
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp5_ = 0;
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			_data_->_tmp5_ = _data_->self->priv->_counter;
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_static_rec_mutex_unlock (&_data_->self->priv->__lock__counter);
#line 740 "async-locking.c"
		}
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			g_clear_error (&_data_->_inner_error_);
#line 129 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
			return FALSE;
#line 750 "async-locking.c"
		}
	}
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	if (_data_->_state_ == 0) {
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 757 "async-locking.c"
	} else {
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 761 "async-locking.c"
	}
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_object_unref (_data_->_async_result);
#line 127 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return FALSE;
#line 767 "async-locking.c"
}


static void async_locking_tests_simulate_work_data_free (gpointer _data) {
	AsyncLockingTestsSimulateWorkData* _data_;
	_data_ = _data;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_slice_free (AsyncLockingTestsSimulateWorkData, _data_);
#line 778 "async-locking.c"
}


static void async_locking_tests_simulate_work (AsyncLockingTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AsyncLockingTestsSimulateWorkData* _data_;
	AsyncLockingTests* _tmp0_ = NULL;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_slice_new0 (AsyncLockingTestsSimulateWorkData);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, async_locking_tests_simulate_work);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, async_locking_tests_simulate_work_data_free);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_->self = _tmp0_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_simulate_work_co (_data_);
#line 797 "async-locking.c"
}


static void async_locking_tests_simulate_work_finish (AsyncLockingTests* self, GAsyncResult* _res_) {
	AsyncLockingTestsSimulateWorkData* _data_;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 805 "async-locking.c"
}


static gboolean async_locking_tests_simulate_work_co (AsyncLockingTestsSimulateWorkData* _data_) {
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	switch (_data_->_state_) {
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		case 0:
#line 814 "async-locking.c"
		goto _state_0;
		default:
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_assert_not_reached ();
#line 819 "async-locking.c"
	}
	_state_0:
#line 146 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_usleep ((gulong) (50 * 1000));
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	if (_data_->_state_ == 0) {
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 828 "async-locking.c"
	} else {
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 832 "async-locking.c"
	}
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_object_unref (_data_->_async_result);
#line 144 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return FALSE;
#line 838 "async-locking.c"
}


static void async_locking_tests_class_init (AsyncLockingTestsClass * klass) {
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	async_locking_tests_parent_class = g_type_class_peek_parent (klass);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_type_class_add_private (klass, sizeof (AsyncLockingTestsPrivate));
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	((FolksTestCaseClass *) klass)->set_up = async_locking_tests_real_set_up;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	G_OBJECT_CLASS (klass)->finalize = async_locking_tests_finalize;
#line 851 "async-locking.c"
}


static void async_locking_tests_instance_init (AsyncLockingTests * self) {
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self->priv = ASYNC_LOCKING_TESTS_GET_PRIVATE (self);
#line 6 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_static_rec_mutex_init (&self->priv->__lock__counter);
#line 860 "async-locking.c"
}


static void async_locking_tests_finalize (GObject* obj) {
	AsyncLockingTests * self;
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ASYNC_LOCKING_TESTS, AsyncLockingTests);
#line 6 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_static_rec_mutex_free (&self->priv->__lock__counter);
#line 10 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_main_loop_unref0 (self->priv->_loop);
#line 4 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	G_OBJECT_CLASS (async_locking_tests_parent_class)->finalize (obj);
#line 874 "async-locking.c"
}


GType async_locking_tests_get_type (void) {
	static volatile gsize async_locking_tests_type_id__volatile = 0;
	if (g_once_init_enter (&async_locking_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AsyncLockingTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) async_locking_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AsyncLockingTests), 0, (GInstanceInitFunc) async_locking_tests_instance_init, NULL };
		GType async_locking_tests_type_id;
		async_locking_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "AsyncLockingTests", &g_define_type_info, 0);
		g_once_init_leave (&async_locking_tests_type_id__volatile, async_locking_tests_type_id);
	}
	return async_locking_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AsyncLockingTests* tests = NULL;
	AsyncLockingTests* _tmp0_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_test_init (&args_length1, &args, NULL);
#line 154 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_tmp0_ = async_locking_tests_new ();
#line 154 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	tests = _tmp0_;
#line 155 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 156 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	g_test_run ();
#line 157 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 159 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	result = 0;
#line 159 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	_g_object_unref0 (tests);
#line 159 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return result;
#line 912 "async-locking.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 150 "/opt/gnome3/source/folks/tests/folks/async-locking.vala"
	return _vala_main (argv, argc);
#line 922 "async-locking.c"
}



