/* updating-phones.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from updating-phones.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *               2014 Canonical Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Renato Araujo Oliveira Filho <renato.filho@canonical.com>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>


#define TYPE_CHANGE_PHONES_TESTS (change_phones_tests_get_type ())
#define CHANGE_PHONES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHANGE_PHONES_TESTS, ChangePhonesTests))
#define CHANGE_PHONES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHANGE_PHONES_TESTS, ChangePhonesTestsClass))
#define IS_CHANGE_PHONES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHANGE_PHONES_TESTS))
#define IS_CHANGE_PHONES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHANGE_PHONES_TESTS))
#define CHANGE_PHONES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHANGE_PHONES_TESTS, ChangePhonesTestsClass))

typedef struct _ChangePhonesTests ChangePhonesTests;
typedef struct _ChangePhonesTestsClass ChangePhonesTestsClass;
typedef struct _ChangePhonesTestsPrivate ChangePhonesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ChangePhonesTestsTestChangePhonesAsyncData ChangePhonesTestsTestChangePhonesAsyncData;
typedef struct _ChangePhonesTestsUpdateContactData ChangePhonesTestsUpdateContactData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ChangePhonesTests {
	EdsTestTestCase parent_instance;
	ChangePhonesTestsPrivate * priv;
};

struct _ChangePhonesTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _ChangePhonesTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	GeeHashMap* _c1;
	gboolean _found_before_update;
	gboolean _found_after_update;
};

struct _ChangePhonesTestsTestChangePhonesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ChangePhonesTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};

struct _ChangePhonesTestsUpdateContactData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ChangePhonesTests* self;
	GeeHashMap* updated_data;
	GeeHashMap* _tmp0_;
	GValue* v;
	GValue _tmp1_;
	GValue _tmp2_;
	GValue* _tmp3_;
	GValue* _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	EdsTestBackend* _tmp7_;
	GeeHashMap* _tmp8_;
};


static gpointer change_phones_tests_parent_class = NULL;

GType change_phones_tests_get_type (void) G_GNUC_CONST;
#define CHANGE_PHONES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_CHANGE_PHONES_TESTS, ChangePhonesTestsPrivate))
enum  {
	CHANGE_PHONES_TESTS_DUMMY_PROPERTY
};
ChangePhonesTests* change_phones_tests_new (void);
ChangePhonesTests* change_phones_tests_construct (GType object_type);
static void change_phones_tests_test_change_phones (ChangePhonesTests* self);
static void _change_phones_tests_test_change_phones_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _change_phones_tests_test_change_phones_async (ChangePhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _change_phones_tests_test_change_phones_finish (ChangePhonesTests* self, GAsyncResult* _res_);
static void _change_phones_tests_test_change_phones_async_data_free (gpointer _data);
static gboolean _change_phones_tests_test_change_phones_async_co (ChangePhonesTestsTestChangePhonesAsyncData* _data_);
static void _change_phones_tests_test_change_phones_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _change_phones_tests_individuals_changed_cb (ChangePhonesTests* self, GeeMultiMap* changes);
static void __change_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _change_phones_tests_update_contact_data_free (gpointer _data);
static void _change_phones_tests_update_contact (ChangePhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _change_phones_tests_update_contact_finish (ChangePhonesTests* self, GAsyncResult* _res_);
static gboolean _change_phones_tests_update_contact_co (ChangePhonesTestsUpdateContactData* _data_);
static void _change_phones_tests_update_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _change_phones_tests_notify_phones_cb (ChangePhonesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __change_phones_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void change_phones_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _change_phones_tests_test_change_phones_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	change_phones_tests_test_change_phones ((ChangePhonesTests*) self);
#line 145 "updating-phones.c"
}


ChangePhonesTests* change_phones_tests_construct (GType object_type) {
	ChangePhonesTests * self = NULL;
#line 36 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self = (ChangePhonesTests*) eds_test_test_case_construct (object_type, "ChangePhones");
#line 38 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "changing phones on e-d-s persona", _change_phones_tests_test_change_phones_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 34 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return self;
#line 157 "updating-phones.c"
}


ChangePhonesTests* change_phones_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return change_phones_tests_construct (TYPE_CHANGE_PHONES_TESTS);
#line 164 "updating-phones.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 171 "updating-phones.c"
}


static void _vala_GValue_free (GValue* self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_unset (self);
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_free (self);
#line 180 "updating-phones.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return self ? _g_value_dup (self) : NULL;
#line 187 "updating-phones.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 65 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return self ? g_object_ref (self) : NULL;
#line 194 "updating-phones.c"
}


static void change_phones_tests_test_change_phones (ChangePhonesTests* self) {
	GeeHashMap* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GeeHashMap* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue _tmp10_ = {0};
	GValue _tmp11_ = {0};
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GeeHashMap* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	GValue _tmp17_ = {0};
	GValue _tmp18_ = {0};
	GValue* _tmp19_ = NULL;
	GValue* _tmp20_ = NULL;
	GeeHashMap* _tmp21_ = NULL;
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GValue _tmp24_ = {0};
	GValue _tmp25_ = {0};
	GValue* _tmp26_ = NULL;
	GValue* _tmp27_ = NULL;
	GeeHashMap* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	EdsTestBackend* _tmp31_ = NULL;
	GeeHashMap* _tmp32_ = NULL;
	GeeHashMap* _tmp33_ = NULL;
	GMainLoop* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
#line 41 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (self->priv->_c1);
#line 43 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self->priv->_c1 = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp1_ = g_main_loop_new (NULL, FALSE);
#line 44 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self->priv->_main_loop = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self->priv->_found_before_update = FALSE;
#line 48 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self->priv->_found_after_update = FALSE;
#line 50 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 50 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_reset (_tmp2_);
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp4_ = _tmp3_;
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (v);
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = _tmp5_;
#line 52 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp6_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_set_string (_tmp6_, "bernie h. innocenti");
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp7_ = self->priv->_c1;
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp8_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp9_ = _tmp8_;
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, "full_name", _tmp9_);
#line 54 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_tmp9_);
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_init (&_tmp10_, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp11_ = _tmp10_;
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp12_ = __g_value_dup0 (&_tmp11_);
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (v);
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = _tmp12_;
#line 56 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_IS_VALUE (&_tmp11_) ? (g_value_unset (&_tmp11_), NULL) : NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp13_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_set_string (_tmp13_, "754-3010");
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp14_ = self->priv->_c1;
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp15_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp16_ = _tmp15_;
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp14_, "car_phone", _tmp16_);
#line 58 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_tmp16_);
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_init (&_tmp17_, G_TYPE_STRING);
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp18_ = _tmp17_;
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp19_ = __g_value_dup0 (&_tmp18_);
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (v);
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = _tmp19_;
#line 59 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_IS_VALUE (&_tmp18_) ? (g_value_unset (&_tmp18_), NULL) : NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp20_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_set_string (_tmp20_, "636-4018");
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp21_ = self->priv->_c1;
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp22_ = v;
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp23_ = _tmp22_;
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp21_, "company_phone", _tmp23_);
#line 61 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_tmp23_);
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_init (&_tmp24_, G_TYPE_STRING);
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp25_ = _tmp24_;
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp26_ = __g_value_dup0 (&_tmp25_);
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (v);
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = _tmp26_;
#line 62 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_IS_VALUE (&_tmp25_) ? (g_value_unset (&_tmp25_), NULL) : NULL;
#line 63 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp27_ = v;
#line 63 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_set_string (_tmp27_, "754-4018");
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp28_ = self->priv->_c1;
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp29_ = v;
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	v = NULL;
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp30_ = _tmp29_;
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp28_, "home_phone", _tmp30_);
#line 64 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_tmp30_);
#line 65 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp31_ = ((EdsTestTestCase*) self)->eds_backend;
#line 65 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp32_ = self->priv->_c1;
#line 65 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp33_ = _g_object_ref0 (_tmp32_);
#line 65 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_add_contact (_tmp31_, _tmp33_);
#line 67 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_test_change_phones_async (self, NULL, NULL);
#line 69 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp34_ = self->priv->_main_loop;
#line 69 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_test_utils_loop_run_with_timeout (_tmp34_, 10);
#line 71 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp35_ = self->priv->_found_before_update;
#line 71 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_vala_assert (_tmp35_, "this._found_before_update");
#line 72 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp36_ = self->priv->_found_after_update;
#line 72 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_vala_assert (_tmp36_, "this._found_after_update");
#line 41 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (v);
#line 395 "updating-phones.c"
}


static void _change_phones_tests_test_change_phones_async_data_free (gpointer _data) {
	ChangePhonesTestsTestChangePhonesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_slice_free (ChangePhonesTestsTestChangePhonesAsyncData, _data_);
#line 406 "updating-phones.c"
}


static void _change_phones_tests_test_change_phones_async (ChangePhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ChangePhonesTestsTestChangePhonesAsyncData* _data_;
	ChangePhonesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = g_slice_new0 (ChangePhonesTestsTestChangePhonesAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _change_phones_tests_test_change_phones_async);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _change_phones_tests_test_change_phones_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_test_change_phones_async_co (_data_);
#line 425 "updating-phones.c"
}


static void _change_phones_tests_test_change_phones_finish (ChangePhonesTests* self, GAsyncResult* _res_) {
	ChangePhonesTestsTestChangePhonesAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 433 "updating-phones.c"
}


static void _change_phones_tests_test_change_phones_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ChangePhonesTestsTestChangePhonesAsyncData* _data_;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = _user_data_;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_source_object_ = source_object;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_res_ = _res_;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_test_change_phones_async_co (_data_);
#line 447 "updating-phones.c"
}


static void __change_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 82 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_individuals_changed_cb ((ChangePhonesTests*) self, changes);
#line 454 "updating-phones.c"
}


static gboolean _change_phones_tests_test_change_phones_async_co (ChangePhonesTestsTestChangePhonesAsyncData* _data_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	switch (_data_->_state_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 0:
#line 463 "updating-phones.c"
		goto _state_0;
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 1:
#line 467 "updating-phones.c"
		goto _state_1;
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 2:
#line 471 "updating-phones.c"
		goto _state_2;
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 3:
#line 475 "updating-phones.c"
		goto _state_3;
		default:
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_assert_not_reached ();
#line 480 "updating-phones.c"
	}
	_state_0:
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp0_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_state_ = 1;
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _change_phones_tests_test_change_phones_async_ready, _data_);
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return FALSE;
#line 493 "updating-phones.c"
	_state_1:
#line 77 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 79 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp1_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 79 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->store = _data_->_tmp1_;
#line 80 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_state_ = 2;
#line 80 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_backend_store_prepare (_data_->store, _change_phones_tests_test_change_phones_async_ready, _data_);
#line 80 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return FALSE;
#line 509 "updating-phones.c"
	_state_2:
#line 80 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 81 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp2_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 81 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 81 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 82 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp3_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 82 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __change_phones_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 527 "updating-phones.c"
	{
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp4_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_state_ = 3;
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _change_phones_tests_test_change_phones_async_ready, _data_);
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		return FALSE;
#line 539 "updating-phones.c"
		_state_3:
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 86 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 545 "updating-phones.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->e = _data_->_inner_error_;
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_inner_error_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp5_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp5_ = _data_->e;
#line 90 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp6_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 90 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_warning ("updating-phones.vala:90: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_g_error_free0 (_data_->e);
#line 568 "updating-phones.c"
	}
	__finally0:
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_g_object_unref0 (_data_->store);
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_clear_error (&_data_->_inner_error_);
#line 84 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		return FALSE;
#line 581 "updating-phones.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (_data_->store);
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	if (_data_->_state_ == 0) {
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 589 "updating-phones.c"
	} else {
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 593 "updating-phones.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_object_unref (_data_->_async_result);
#line 75 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return FALSE;
#line 599 "updating-phones.c"
}


static void _change_phones_tests_update_contact_data_free (gpointer _data) {
	ChangePhonesTestsUpdateContactData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_slice_free (ChangePhonesTestsUpdateContactData, _data_);
#line 610 "updating-phones.c"
}


static void _change_phones_tests_update_contact (ChangePhonesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ChangePhonesTestsUpdateContactData* _data_;
	ChangePhonesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = g_slice_new0 (ChangePhonesTestsUpdateContactData);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _change_phones_tests_update_contact);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _change_phones_tests_update_contact_data_free);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_update_contact_co (_data_);
#line 629 "updating-phones.c"
}


static void _change_phones_tests_update_contact_finish (ChangePhonesTests* self, GAsyncResult* _res_) {
	ChangePhonesTestsUpdateContactData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 637 "updating-phones.c"
}


static void _change_phones_tests_update_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ChangePhonesTestsUpdateContactData* _data_;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_ = _user_data_;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_source_object_ = source_object;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_res_ = _res_;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_update_contact_co (_data_);
#line 651 "updating-phones.c"
}


static gboolean _change_phones_tests_update_contact_co (ChangePhonesTestsUpdateContactData* _data_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	switch (_data_->_state_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 0:
#line 660 "updating-phones.c"
		goto _state_0;
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		case 1:
#line 664 "updating-phones.c"
		goto _state_1;
		default:
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_assert_not_reached ();
#line 669 "updating-phones.c"
	}
	_state_0:
#line 96 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp0_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 96 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->updated_data = _data_->_tmp0_;
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	memset (&_data_->_tmp1_, 0, sizeof (GValue));
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_init (&_data_->_tmp1_, G_TYPE_STRING);
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	memset (&_data_->_tmp2_, 0, sizeof (GValue));
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp3_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp3_ = __g_value_dup0 (&_data_->_tmp2_);
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_data_->v);
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->v = _data_->_tmp3_;
#line 100 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_IS_VALUE (&_data_->_tmp2_) ? (g_value_unset (&_data_->_tmp2_), NULL) : NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp4_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp4_ = _data_->v;
#line 101 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_value_set_string (_data_->_tmp4_, "(541) 754-4018");
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp5_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp5_ = _data_->v;
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->v = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp6_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->updated_data, "home_phone", _data_->_tmp6_);
#line 103 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_data_->_tmp6_);
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp7_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp7_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp8_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_tmp8_ = _g_object_ref0 (_data_->updated_data);
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_data_->_state_ = 1;
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_update_contact (_data_->_tmp7_, 0, _data_->_tmp8_, _change_phones_tests_update_contact_ready, _data_);
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return FALSE;
#line 730 "updating-phones.c"
	_state_1:
#line 104 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	eds_test_backend_update_contact_finish (_data_->_tmp7_, _data_->_res_);
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	__vala_GValue_free0 (_data_->v);
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (_data_->updated_data);
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	if (_data_->_state_ == 0) {
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 742 "updating-phones.c"
	} else {
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 746 "updating-phones.c"
	}
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_object_unref (_data_->_async_result);
#line 94 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return FALSE;
#line 752 "updating-phones.c"
}


static void _change_phones_tests_notify_phones_cb (ChangePhonesTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (self != NULL);
#line 107 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (individual_obj != NULL);
#line 107 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (ps != NULL);
#line 109 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = individual_obj;
#line 109 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 109 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	i = _tmp1_;
#line 772 "updating-phones.c"
	{
		GeeIterator* _phone_fd_it = NULL;
		FolksIndividual* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp2_ = i;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp3_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp2_);
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp4_ = _tmp3_;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_phone_fd_it = _tmp5_;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		while (TRUE) {
#line 791 "updating-phones.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksPhoneFieldDetails* phone_fd = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp6_ = _phone_fd_it;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			if (!_tmp7_) {
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				break;
#line 805 "updating-phones.c"
			}
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp8_ = _phone_fd_it;
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			phone_fd = (FolksPhoneFieldDetails*) _tmp9_;
#line 813 "updating-phones.c"
			{
				GeeIterator* _t_it = NULL;
				FolksPhoneFieldDetails* _tmp10_ = NULL;
				GeeCollection* _tmp11_ = NULL;
				GeeCollection* _tmp12_ = NULL;
				GeeIterator* _tmp13_ = NULL;
				GeeIterator* _tmp14_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp10_ = phone_fd;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp11_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp10_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp12_ = _tmp11_;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp13_ = gee_iterable_iterator ((GeeIterable*) _tmp12_);
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp14_ = _tmp13_;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_g_object_unref0 (_tmp12_);
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_t_it = _tmp14_;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				while (TRUE) {
#line 837 "updating-phones.c"
					GeeIterator* _tmp15_ = NULL;
					gboolean _tmp16_ = FALSE;
					gchar* t = NULL;
					GeeIterator* _tmp17_ = NULL;
					gpointer _tmp18_ = NULL;
					gboolean _tmp19_ = FALSE;
					gboolean _tmp20_ = FALSE;
					const gchar* _tmp21_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp15_ = _t_it;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp16_ = gee_iterator_next (_tmp15_);
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					if (!_tmp16_) {
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						break;
#line 854 "updating-phones.c"
					}
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp17_ = _t_it;
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp18_ = gee_iterator_get (_tmp17_);
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					t = (gchar*) _tmp18_;
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp21_ = t;
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					if (g_strcmp0 (_tmp21_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME) == 0) {
#line 866 "updating-phones.c"
						FolksPhoneFieldDetails* _tmp22_ = NULL;
						gconstpointer _tmp23_ = NULL;
						const gchar* _tmp24_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp22_ = phone_fd;
#line 116 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp23_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp22_);
#line 116 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp24_ = _tmp23_;
#line 116 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp20_ = g_strcmp0 ((const gchar*) _tmp24_, "(541) 754-4018") == 0;
#line 878 "updating-phones.c"
					} else {
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp20_ = FALSE;
#line 882 "updating-phones.c"
					}
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					if (_tmp20_) {
#line 886 "updating-phones.c"
						gboolean _tmp25_ = FALSE;
#line 117 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp25_ = self->priv->_found_before_update;
#line 117 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp19_ = _tmp25_;
#line 892 "updating-phones.c"
					} else {
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp19_ = FALSE;
#line 896 "updating-phones.c"
					}
#line 115 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					if (_tmp19_) {
#line 900 "updating-phones.c"
						GMainLoop* _tmp26_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						self->priv->_found_after_update = TRUE;
#line 120 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp26_ = self->priv->_main_loop;
#line 120 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						g_main_loop_quit (_tmp26_);
#line 908 "updating-phones.c"
					}
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_g_free0 (t);
#line 912 "updating-phones.c"
				}
#line 112 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_g_object_unref0 (_t_it);
#line 916 "updating-phones.c"
			}
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_g_object_unref0 (phone_fd);
#line 920 "updating-phones.c"
		}
#line 110 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_g_object_unref0 (_phone_fd_it);
#line 924 "updating-phones.c"
	}
#line 107 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (i);
#line 928 "updating-phones.c"
}


static void __change_phones_tests_notify_phones_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 147 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_change_phones_tests_notify_phones_cb ((ChangePhonesTests*) self, _sender, pspec);
#line 935 "updating-phones.c"
}


static void _change_phones_tests_individuals_changed_cb (ChangePhonesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp38_ = NULL;
	gint _tmp39_ = 0;
	gint _tmp40_ = 0;
#line 126 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (self != NULL);
#line 126 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_return_if_fail (changes != NULL);
#line 129 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = changes;
#line 129 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 129 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	added = _tmp1_;
#line 130 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp2_ = changes;
#line 130 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 130 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	removed = _tmp3_;
#line 965 "updating-phones.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp4_ = added;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_i_it = _tmp5_;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		while (TRUE) {
#line 978 "updating-phones.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksPhoneDetails* phones = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksPhoneDetails* _tmp12_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp6_ = _i_it;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			if (!_tmp7_) {
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				break;
#line 996 "updating-phones.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp8_ = _i_it;
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			i = (FolksIndividual*) _tmp9_;
#line 134 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp10_ = i;
#line 134 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 136 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp11_ = i;
#line 136 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, FOLKS_TYPE_PHONE_DETAILS, FolksPhoneDetails));
#line 136 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			phones = _tmp12_;
#line 1014 "updating-phones.c"
			{
				GeeIterator* _phone_fd_it = NULL;
				FolksPhoneDetails* _tmp13_ = NULL;
				GeeSet* _tmp14_ = NULL;
				GeeSet* _tmp15_ = NULL;
				GeeIterator* _tmp16_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp13_ = phones;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp14_ = folks_phone_details_get_phone_numbers (_tmp13_);
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp15_ = _tmp14_;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_tmp16_ = gee_iterable_iterator ((GeeIterable*) _tmp15_);
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_phone_fd_it = _tmp16_;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				while (TRUE) {
#line 1033 "updating-phones.c"
					GeeIterator* _tmp17_ = NULL;
					gboolean _tmp18_ = FALSE;
					FolksPhoneFieldDetails* phone_fd = NULL;
					GeeIterator* _tmp19_ = NULL;
					gpointer _tmp20_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp17_ = _phone_fd_it;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp18_ = gee_iterator_next (_tmp17_);
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					if (!_tmp18_) {
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						break;
#line 1047 "updating-phones.c"
					}
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp19_ = _phone_fd_it;
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_tmp20_ = gee_iterator_get (_tmp19_);
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					phone_fd = (FolksPhoneFieldDetails*) _tmp20_;
#line 1055 "updating-phones.c"
					{
						GeeIterator* _t_it = NULL;
						FolksPhoneFieldDetails* _tmp21_ = NULL;
						GeeCollection* _tmp22_ = NULL;
						GeeCollection* _tmp23_ = NULL;
						GeeIterator* _tmp24_ = NULL;
						GeeIterator* _tmp25_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp21_ = phone_fd;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp22_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp21_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp23_ = _tmp22_;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_tmp25_ = _tmp24_;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_g_object_unref0 (_tmp23_);
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_t_it = _tmp25_;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						while (TRUE) {
#line 1079 "updating-phones.c"
							GeeIterator* _tmp26_ = NULL;
							gboolean _tmp27_ = FALSE;
							gchar* t = NULL;
							GeeIterator* _tmp28_ = NULL;
							gpointer _tmp29_ = NULL;
							gboolean _tmp30_ = FALSE;
							gboolean _tmp31_ = FALSE;
							const gchar* _tmp32_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_tmp26_ = _t_it;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_tmp27_ = gee_iterator_next (_tmp26_);
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							if (!_tmp27_) {
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								break;
#line 1096 "updating-phones.c"
							}
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_tmp28_ = _t_it;
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_tmp29_ = gee_iterator_get (_tmp28_);
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							t = (gchar*) _tmp29_;
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_tmp32_ = t;
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							if (g_strcmp0 (_tmp32_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME) == 0) {
#line 1108 "updating-phones.c"
								FolksPhoneFieldDetails* _tmp33_ = NULL;
								gconstpointer _tmp34_ = NULL;
								const gchar* _tmp35_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp33_ = phone_fd;
#line 144 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp34_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp33_);
#line 144 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp35_ = _tmp34_;
#line 144 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp31_ = g_strcmp0 ((const gchar*) _tmp35_, "754-4018") == 0;
#line 1120 "updating-phones.c"
							} else {
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp31_ = FALSE;
#line 1124 "updating-phones.c"
							}
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							if (_tmp31_) {
#line 1128 "updating-phones.c"
								gboolean _tmp36_ = FALSE;
#line 145 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp36_ = self->priv->_found_before_update;
#line 145 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp30_ = !_tmp36_;
#line 1134 "updating-phones.c"
							} else {
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp30_ = FALSE;
#line 1138 "updating-phones.c"
							}
#line 143 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							if (_tmp30_) {
#line 1142 "updating-phones.c"
								FolksIndividual* _tmp37_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_tmp37_ = i;
#line 147 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								g_signal_connect_object ((GObject*) _tmp37_, "notify::phone-numbers", (GCallback) __change_phones_tests_notify_phones_cb_g_object_notify, self, 0);
#line 148 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								self->priv->_found_before_update = TRUE;
#line 149 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
								_change_phones_tests_update_contact (self, NULL, NULL);
#line 1152 "updating-phones.c"
							}
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
							_g_free0 (t);
#line 1156 "updating-phones.c"
						}
#line 140 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
						_g_object_unref0 (_t_it);
#line 1160 "updating-phones.c"
					}
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
					_g_object_unref0 (phone_fd);
#line 1164 "updating-phones.c"
				}
#line 138 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
				_g_object_unref0 (_phone_fd_it);
#line 1168 "updating-phones.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_g_object_unref0 (phones);
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
			_g_object_unref0 (i);
#line 1174 "updating-phones.c"
		}
#line 132 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
		_g_object_unref0 (_i_it);
#line 1178 "updating-phones.c"
	}
#line 154 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp38_ = removed;
#line 154 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 154 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp40_ = _tmp39_;
#line 154 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_vala_assert (_tmp40_ == 1, "removed.size == 1");
#line 126 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (removed);
#line 126 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (added);
#line 1192 "updating-phones.c"
}


static void change_phones_tests_class_init (ChangePhonesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	change_phones_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_type_class_add_private (klass, sizeof (ChangePhonesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_OBJECT_CLASS (klass)->finalize = change_phones_tests_finalize;
#line 1203 "updating-phones.c"
}


static void change_phones_tests_instance_init (ChangePhonesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self->priv = CHANGE_PHONES_TESTS_GET_PRIVATE (self);
#line 1210 "updating-phones.c"
}


static void change_phones_tests_finalize (GObject* obj) {
	ChangePhonesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CHANGE_PHONES_TESTS, ChangePhonesTests);
#line 28 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 30 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (self->priv->_c1);
#line 26 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	G_OBJECT_CLASS (change_phones_tests_parent_class)->finalize (obj);
#line 1226 "updating-phones.c"
}


GType change_phones_tests_get_type (void) {
	static volatile gsize change_phones_tests_type_id__volatile = 0;
	if (g_once_init_enter (&change_phones_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ChangePhonesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) change_phones_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ChangePhonesTests), 0, (GInstanceInitFunc) change_phones_tests_instance_init, NULL };
		GType change_phones_tests_type_id;
		change_phones_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "ChangePhonesTests", &g_define_type_info, 0);
		g_once_init_leave (&change_phones_tests_type_id__volatile, change_phones_tests_type_id);
	}
	return change_phones_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	ChangePhonesTests* tests = NULL;
	ChangePhonesTests* _tmp0_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_test_init (&args_length1, &args, NULL);
#line 162 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_tmp0_ = change_phones_tests_new ();
#line 162 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	tests = _tmp0_;
#line 163 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 164 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	g_test_run ();
#line 165 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 167 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	result = 0;
#line 167 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	_g_object_unref0 (tests);
#line 167 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return result;
#line 1264 "updating-phones.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 158 "/opt/gnome3/source/folks/tests/eds/updating-phones.vala"
	return _vala_main (argv, argc);
#line 1274 "updating-phones.c"
}



