/* backend-loading.c generated by valac 0.34.0.3-63fa6, the Vala compiler
 * generated from backend-loading.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <glib/gstdio.h>
#include <gio/gio.h>
#include <gee.h>
#include <folks/folks.h>


#define TYPE_BACKEND_LOADING_TESTS (backend_loading_tests_get_type ())
#define BACKEND_LOADING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKEND_LOADING_TESTS, BackendLoadingTests))
#define BACKEND_LOADING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKEND_LOADING_TESTS, BackendLoadingTestsClass))
#define IS_BACKEND_LOADING_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKEND_LOADING_TESTS))
#define IS_BACKEND_LOADING_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKEND_LOADING_TESTS))
#define BACKEND_LOADING_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKEND_LOADING_TESTS, BackendLoadingTestsClass))

typedef struct _BackendLoadingTests BackendLoadingTests;
typedef struct _BackendLoadingTestsClass BackendLoadingTestsClass;
typedef struct _BackendLoadingTestsPrivate BackendLoadingTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
typedef struct _BackendLoadingTestsTestDisablingAsyncData BackendLoadingTestsTestDisablingAsyncData;
typedef struct _BackendLoadingTestsTestReloadingAsyncData BackendLoadingTestsTestReloadingAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _BackendLoadingTests {
	TpfTestMixedTestCase parent_instance;
	BackendLoadingTestsPrivate * priv;
};

struct _BackendLoadingTestsClass {
	TpfTestMixedTestCaseClass parent_class;
};

struct _BackendLoadingTestsPrivate {
	GMainLoop* main_loop;
};

struct _Block1Data {
	int _ref_count_;
	BackendLoadingTests* self;
	GMainLoop* main_loop;
	GeeHashSet* backends_expected;
	FolksBackendStore* store;
};

struct _BackendLoadingTestsTestDisablingAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BackendLoadingTests* self;
	FolksBackendStore* store;
	GeeHashSet* backends_expected;
	GeeHashSet* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksBackendStore* _tmp2_;
	FolksBackendStore* _tmp3_;
	GeeIterator* _backend_it;
	FolksBackendStore* _tmp4_;
	GeeMap* _tmp5_;
	GeeMap* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeCollection* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	GeeIterator* _tmp12_;
	gboolean _tmp13_;
	FolksBackend* backend;
	GeeIterator* _tmp14_;
	gpointer _tmp15_;
	FolksBackend* _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	gboolean _tmp19_;
	FolksBackend* _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	GMainLoop* _tmp25_;
	GError* e;
	const gchar* _tmp26_;
	GError * _inner_error_;
};

struct _BackendLoadingTestsTestReloadingAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BackendLoadingTests* self;
	FolksBackendStore* store;
	GeeHashSet* backends_expected;
	GeeHashSet* _tmp0_;
	GeeHashSet* _tmp1_;
	GeeHashSet* _tmp2_;
	FolksBackendStore* _tmp3_;
	GeeIterator* _backend1_it;
	FolksBackendStore* _tmp4_;
	GeeMap* _tmp5_;
	GeeMap* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeCollection* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	GeeIterator* _tmp12_;
	gboolean _tmp13_;
	FolksBackend* backend1;
	GeeIterator* _tmp14_;
	gpointer _tmp15_;
	GeeHashSet* _tmp16_;
	FolksBackend* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	GeeHashSet* _tmp21_;
	FolksBackend* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	GeeHashSet* _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	GError* e1;
	const gchar* _tmp28_;
	GeeHashSet* _tmp29_;
	GeeHashSet* _tmp30_;
	FolksBackendStore* _tmp31_;
	FolksBackendStore* _tmp32_;
	GeeIterator* _backend2_it;
	FolksBackendStore* _tmp33_;
	GeeMap* _tmp34_;
	GeeMap* _tmp35_;
	GeeCollection* _tmp36_;
	GeeCollection* _tmp37_;
	GeeCollection* _tmp38_;
	GeeIterator* _tmp39_;
	GeeIterator* _tmp40_;
	GeeIterator* _tmp41_;
	gboolean _tmp42_;
	FolksBackend* backend2;
	GeeIterator* _tmp43_;
	gpointer _tmp44_;
	GeeHashSet* _tmp45_;
	FolksBackend* _tmp46_;
	const gchar* _tmp47_;
	const gchar* _tmp48_;
	gboolean _tmp49_;
	GeeHashSet* _tmp50_;
	FolksBackend* _tmp51_;
	const gchar* _tmp52_;
	const gchar* _tmp53_;
	GeeHashSet* _tmp54_;
	gint _tmp55_;
	gint _tmp56_;
	GError* e2;
	const gchar* _tmp57_;
	GeeHashSet* _tmp58_;
	GeeHashSet* _tmp59_;
	GeeHashSet* _tmp60_;
	FolksBackendStore* _tmp61_;
	FolksBackendStore* _tmp62_;
	GeeIterator* _backend3_it;
	FolksBackendStore* _tmp63_;
	GeeMap* _tmp64_;
	GeeMap* _tmp65_;
	GeeCollection* _tmp66_;
	GeeCollection* _tmp67_;
	GeeCollection* _tmp68_;
	GeeIterator* _tmp69_;
	GeeIterator* _tmp70_;
	GeeIterator* _tmp71_;
	gboolean _tmp72_;
	FolksBackend* backend3;
	GeeIterator* _tmp73_;
	gpointer _tmp74_;
	GeeHashSet* _tmp75_;
	FolksBackend* _tmp76_;
	const gchar* _tmp77_;
	const gchar* _tmp78_;
	gboolean _tmp79_;
	GeeHashSet* _tmp80_;
	FolksBackend* _tmp81_;
	const gchar* _tmp82_;
	const gchar* _tmp83_;
	GeeHashSet* _tmp84_;
	gint _tmp85_;
	gint _tmp86_;
	GError* e3;
	const gchar* _tmp87_;
	GeeHashSet* _tmp88_;
	GeeHashSet* _tmp89_;
	GeeHashSet* _tmp90_;
	FolksBackendStore* _tmp91_;
	GeeIterator* _backend_it;
	FolksBackendStore* _tmp92_;
	GeeMap* _tmp93_;
	GeeMap* _tmp94_;
	GeeCollection* _tmp95_;
	GeeCollection* _tmp96_;
	GeeCollection* _tmp97_;
	GeeIterator* _tmp98_;
	GeeIterator* _tmp99_;
	GeeIterator* _tmp100_;
	gboolean _tmp101_;
	FolksBackend* backend;
	GeeIterator* _tmp102_;
	gpointer _tmp103_;
	GeeHashSet* _tmp104_;
	FolksBackend* _tmp105_;
	const gchar* _tmp106_;
	const gchar* _tmp107_;
	gboolean _tmp108_;
	GeeHashSet* _tmp109_;
	FolksBackend* _tmp110_;
	const gchar* _tmp111_;
	const gchar* _tmp112_;
	GeeHashSet* _tmp113_;
	gint _tmp114_;
	gint _tmp115_;
	GError* e4;
	const gchar* _tmp116_;
	GMainLoop* _tmp117_;
	GError * _inner_error_;
};


static gpointer backend_loading_tests_parent_class = NULL;

GType backend_loading_tests_get_type (void) G_GNUC_CONST;
#define BACKEND_LOADING_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_BACKEND_LOADING_TESTS, BackendLoadingTestsPrivate))
enum  {
	BACKEND_LOADING_TESTS_DUMMY_PROPERTY
};
#define BACKEND_LOADING_TESTS_STORE_FILE_PATH "folks-test-backend-store.ini"
BackendLoadingTests* backend_loading_tests_new (void);
BackendLoadingTests* backend_loading_tests_construct (GType object_type);
void backend_loading_tests_test_load_and_prep (BackendLoadingTests* self);
static void _backend_loading_tests_test_load_and_prep_folks_test_case_test_method (gpointer self);
void backend_loading_tests_test_disabling (BackendLoadingTests* self);
static void _backend_loading_tests_test_disabling_folks_test_case_test_method (gpointer self);
void backend_loading_tests_test_reloading (BackendLoadingTests* self);
static void _backend_loading_tests_test_reloading_folks_test_case_test_method (gpointer self);
static void backend_loading_tests_real_set_up (FolksTestCase* base);
static void backend_loading_tests_real_tear_down (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda5_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void backend_loading_tests_test_disabling_async (BackendLoadingTests* self, FolksBackendStore* store, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void backend_loading_tests_test_disabling_finish (BackendLoadingTests* self, GAsyncResult* _res_);
static void __lambda6_ (BackendLoadingTests* self, GObject* o, GAsyncResult* r);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void backend_loading_tests_test_disabling_async_data_free (gpointer _data);
static gboolean backend_loading_tests_test_disabling_async_co (BackendLoadingTestsTestDisablingAsyncData* _data_);
static void backend_loading_tests_test_disabling_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void backend_loading_tests_test_reloading_async (BackendLoadingTests* self, FolksBackendStore* store, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void backend_loading_tests_test_reloading_finish (BackendLoadingTests* self, GAsyncResult* _res_);
static void __lambda7_ (BackendLoadingTests* self, GObject* o, GAsyncResult* r);
static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void backend_loading_tests_test_reloading_async_data_free (gpointer _data);
static gboolean backend_loading_tests_test_reloading_async_co (BackendLoadingTestsTestReloadingAsyncData* _data_);
static void backend_loading_tests_test_reloading_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void backend_loading_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _backend_loading_tests_test_load_and_prep_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_load_and_prep ((BackendLoadingTests*) self);
#line 308 "backend-loading.c"
}


static void _backend_loading_tests_test_disabling_folks_test_case_test_method (gpointer self) {
#line 33 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_disabling ((BackendLoadingTests*) self);
#line 315 "backend-loading.c"
}


static void _backend_loading_tests_test_reloading_folks_test_case_test_method (gpointer self) {
#line 34 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_reloading ((BackendLoadingTests*) self);
#line 322 "backend-loading.c"
}


BackendLoadingTests* backend_loading_tests_construct (GType object_type) {
	BackendLoadingTests * self = NULL;
#line 30 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = (BackendLoadingTests*) tpf_test_mixed_test_case_construct (object_type, "BackendLoading");
#line 32 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "load and prep", _backend_loading_tests_test_load_and_prep_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "disabling", _backend_loading_tests_test_disabling_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 34 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "reloading", _backend_loading_tests_test_reloading_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 28 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return self;
#line 338 "backend-loading.c"
}


BackendLoadingTests* backend_loading_tests_new (void) {
#line 28 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return backend_loading_tests_construct (TYPE_BACKEND_LOADING_TESTS);
#line 345 "backend-loading.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1398 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1399 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1400 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 389 "backend-loading.c"
	}
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1401 "/opt/gnome3/build/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 395 "backend-loading.c"
}


static void backend_loading_tests_real_set_up (FolksTestCase* base) {
	BackendLoadingTests * self;
	gchar* kf_path = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GKeyFile* kf = NULL;
	GKeyFile* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 37 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = (BackendLoadingTests*) base;
#line 39 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	FOLKS_TEST_CASE_CLASS (backend_loading_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_MIXED_TEST_CASE, TpfTestMixedTestCase));
#line 42 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 42 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = g_build_filename (_tmp0_, BACKEND_LOADING_TESTS_STORE_FILE_PATH, NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	kf_path = _tmp1_;
#line 45 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_remove (kf_path);
#line 47 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = g_key_file_new ();
#line 47 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	kf = _tmp2_;
#line 48 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_key_file_set_boolean (kf, "all-others", "enabled", FALSE);
#line 49 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_key_file_set_boolean (kf, "telepathy", "enabled", TRUE);
#line 50 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_key_file_set_boolean (kf, "key-file", "enabled", TRUE);
#line 429 "backend-loading.c"
	{
		GFile* backend_f = NULL;
		GFile* _tmp3_ = NULL;
		gchar* data = NULL;
		gchar* _tmp4_ = NULL;
		guint8* _tmp5_ = NULL;
		gint _tmp5__length1 = 0;
		guint8* _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 54 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp3_ = g_file_new_for_path (kf_path);
#line 54 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		backend_f = _tmp3_;
#line 55 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp4_ = g_key_file_to_data (kf, NULL, NULL);
#line 55 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		data = _tmp4_;
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp5_ = string_get_data (data, &_tmp5__length1);
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp6_ = _tmp5_;
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp6__length1 = _tmp5__length1;
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_file_replace_contents (backend_f, _tmp6_, (gsize) _tmp6__length1, NULL, FALSE, G_FILE_CREATE_PRIVATE, NULL, NULL, &_inner_error_);
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_free0 (data);
#line 56 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (backend_f);
#line 461 "backend-loading.c"
			goto __catch0_g_error;
		}
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_free0 (data);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (backend_f);
#line 468 "backend-loading.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		e = _inner_error_;
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_inner_error_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp7_ = e;
#line 62 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp8_ = _tmp7_->message;
#line 62 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_warning ("backend-loading.vala:62: Could not write updated backend key file '%s'" \
": %s", kf_path, _tmp8_);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (e);
#line 488 "backend-loading.c"
	}
	__finally0:
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_key_file_unref0 (kf);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_free0 (kf_path);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_inner_error_);
#line 52 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return;
#line 503 "backend-loading.c"
	}
#line 66 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_setenv ("FOLKS_BACKEND_STORE_KEY_FILE_PATH", kf_path, TRUE);
#line 37 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_key_file_unref0 (kf);
#line 37 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_free0 (kf_path);
#line 511 "backend-loading.c"
}


static void backend_loading_tests_real_tear_down (FolksTestCase* base) {
	BackendLoadingTests * self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = (BackendLoadingTests*) base;
#line 72 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 72 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = g_build_filename (_tmp0_, BACKEND_LOADING_TESTS_STORE_FILE_PATH, NULL, NULL);
#line 72 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = _tmp1_;
#line 72 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_remove (_tmp2_);
#line 72 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_free0 (_tmp2_);
#line 75 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	FOLKS_TEST_CASE_CLASS (backend_loading_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_MIXED_TEST_CASE, TpfTestMixedTestCase));
#line 534 "backend-loading.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return _data1_;
#line 543 "backend-loading.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 552 "backend-loading.c"
		BackendLoadingTests* self;
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		self = _data1_->self;
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data1_->store);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data1_->backends_expected);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (self);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_slice_free (Block1Data, _data1_);
#line 566 "backend-loading.c"
	}
}


static void __lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	BackendLoadingTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = _data1_->self;
#line 87 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (r != NULL);
#line 89 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = r;
#line 89 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_prepare_finish (_data1_->store, _tmp0_);
#line 582 "backend-loading.c"
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 87 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	__lambda4_ (self, source_object, res);
#line 87 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	block1_data_unref (self);
#line 591 "backend-loading.c"
}


static void __lambda5_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	BackendLoadingTests* self;
	GError * _inner_error_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = _data1_->self;
#line 92 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (r != NULL);
#line 602 "backend-loading.c"
	{
		GAsyncResult* _tmp0_ = NULL;
		gint _tmp19_ = 0;
		gint _tmp20_ = 0;
#line 96 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp0_ = r;
#line 96 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data1_->store, _tmp0_, &_inner_error_);
#line 96 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 613 "backend-loading.c"
			goto __catch1_g_error;
		}
		{
			GeeIterator* _backend_it = NULL;
			GeeMap* _tmp1_ = NULL;
			GeeMap* _tmp2_ = NULL;
			GeeCollection* _tmp3_ = NULL;
			GeeCollection* _tmp4_ = NULL;
			GeeCollection* _tmp5_ = NULL;
			GeeIterator* _tmp6_ = NULL;
			GeeIterator* _tmp7_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp1_ = folks_backend_store_get_enabled_backends (_data1_->store);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp2_ = _tmp1_;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp3_ = gee_map_get_values (_tmp2_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp4_ = _tmp3_;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp5_ = _tmp4_;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_tmp7_ = _tmp6_;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_tmp5_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_backend_it = _tmp7_;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 645 "backend-loading.c"
				GeeIterator* _tmp8_ = NULL;
				gboolean _tmp9_ = FALSE;
				FolksBackend* backend = NULL;
				GeeIterator* _tmp10_ = NULL;
				gpointer _tmp11_ = NULL;
				FolksBackend* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
				gboolean _tmp15_ = FALSE;
				FolksBackend* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp8_ = _backend_it;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp9_ = gee_iterator_next (_tmp8_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_tmp9_) {
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 666 "backend-loading.c"
				}
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp10_ = _backend_it;
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp11_ = gee_iterator_get (_tmp10_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				backend = (FolksBackend*) _tmp11_;
#line 100 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp12_ = backend;
#line 100 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp13_ = folks_backend_get_name (_tmp12_);
#line 100 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp14_ = _tmp13_;
#line 100 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp15_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data1_->backends_expected, _tmp14_);
#line 100 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_tmp15_, "backends_expected.contains (backend.name)");
#line 101 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp16_ = backend;
#line 101 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp17_ = folks_backend_get_name (_tmp16_);
#line 101 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_tmp18_ = _tmp17_;
#line 101 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data1_->backends_expected, _tmp18_);
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (backend);
#line 694 "backend-loading.c"
			}
#line 98 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_backend_it);
#line 698 "backend-loading.c"
		}
#line 104 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp19_ = gee_abstract_collection_get_size ((GeeCollection*) _data1_->backends_expected);
#line 104 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp20_ = _tmp19_;
#line 104 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_tmp20_ == 0, "backends_expected.size == 0");
#line 105 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_main_loop_quit (_data1_->main_loop);
#line 708 "backend-loading.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp21_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		e = _inner_error_;
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_inner_error_ = NULL;
#line 109 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_tmp21_ = e->message;
#line 109 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:109: Failed to load backends: %s", _tmp21_);
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (e);
#line 725 "backend-loading.c"
	}
	__finally1:
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_inner_error_);
#line 94 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return;
#line 736 "backend-loading.c"
	}
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 92 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	__lambda5_ (self, source_object, res);
#line 92 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	block1_data_unref (self);
#line 746 "backend-loading.c"
}


void backend_loading_tests_test_load_and_prep (BackendLoadingTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	FolksBackendStore* _tmp2_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (self != NULL);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_->_ref_count_ = 1;
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_->self = g_object_ref (self);
#line 80 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 80 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_->main_loop = _tmp0_;
#line 81 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 81 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_->backends_expected = _tmp1_;
#line 83 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data1_->backends_expected, "key-file");
#line 84 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data1_->backends_expected, "telepathy");
#line 86 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = folks_backend_store_dup ();
#line 86 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_->store = _tmp2_;
#line 87 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_prepare (_data1_->store, ___lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 92 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_load_backends (_data1_->store, ___lambda5__gasync_ready_callback, block1_data_ref (_data1_));
#line 113 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_main_loop_run (_data1_->main_loop);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	block1_data_unref (_data1_);
#line 78 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data1_ = NULL;
#line 789 "backend-loading.c"
}


static void __lambda6_ (BackendLoadingTests* self, GObject* o, GAsyncResult* r) {
	GAsyncResult* _tmp0_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (r != NULL);
#line 123 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = r;
#line 123 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_disabling_finish (self, _tmp0_);
#line 801 "backend-loading.c"
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 121 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	__lambda6_ ((BackendLoadingTests*) self, source_object, res);
#line 121 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_object_unref (self);
#line 810 "backend-loading.c"
}


void backend_loading_tests_test_disabling (BackendLoadingTests* self) {
	GMainLoop* _tmp0_ = NULL;
	FolksBackendStore* store = NULL;
	FolksBackendStore* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (self != NULL);
#line 118 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 118 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_main_loop_unref0 (self->priv->main_loop);
#line 118 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self->priv->main_loop = _tmp0_;
#line 120 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = folks_backend_store_dup ();
#line 120 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	store = _tmp1_;
#line 121 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_disabling_async (self, store, ___lambda6__gasync_ready_callback, g_object_ref (self));
#line 126 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = self->priv->main_loop;
#line 126 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_main_loop_run (_tmp2_);
#line 116 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (store);
#line 839 "backend-loading.c"
}


static void backend_loading_tests_test_disabling_async_data_free (gpointer _data) {
	BackendLoadingTestsTestDisablingAsyncData* _data_;
	_data_ = _data;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->store);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->self);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_slice_free (BackendLoadingTestsTestDisablingAsyncData, _data_);
#line 852 "backend-loading.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return self ? g_object_ref (self) : NULL;
#line 859 "backend-loading.c"
}


static void backend_loading_tests_test_disabling_async (BackendLoadingTests* self, FolksBackendStore* store, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BackendLoadingTestsTestDisablingAsyncData* _data_;
	BackendLoadingTests* _tmp0_ = NULL;
	FolksBackendStore* _tmp1_ = NULL;
	FolksBackendStore* _tmp2_ = NULL;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = g_slice_new0 (BackendLoadingTestsTestDisablingAsyncData);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, backend_loading_tests_test_disabling_async);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, backend_loading_tests_test_disabling_async_data_free);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->self = _tmp0_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = store;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->store);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->store = _tmp2_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_disabling_async_co (_data_);
#line 888 "backend-loading.c"
}


static void backend_loading_tests_test_disabling_finish (BackendLoadingTests* self, GAsyncResult* _res_) {
	BackendLoadingTestsTestDisablingAsyncData* _data_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 896 "backend-loading.c"
}


static void backend_loading_tests_test_disabling_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BackendLoadingTestsTestDisablingAsyncData* _data_;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = _user_data_;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_source_object_ = source_object;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_res_ = _res_;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_disabling_async_co (_data_);
#line 910 "backend-loading.c"
}


static gboolean backend_loading_tests_test_disabling_async_co (BackendLoadingTestsTestDisablingAsyncData* _data_) {
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	switch (_data_->_state_) {
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 0:
#line 919 "backend-loading.c"
		goto _state_0;
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 1:
#line 923 "backend-loading.c"
		goto _state_1;
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 2:
#line 927 "backend-loading.c"
		goto _state_2;
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 3:
#line 931 "backend-loading.c"
		goto _state_3;
		default:
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_assert_not_reached ();
#line 936 "backend-loading.c"
	}
	_state_0:
#line 131 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp0_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 131 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->backends_expected = _data_->_tmp0_;
#line 132 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->backends_expected, "key-file");
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp1_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp1_ = _data_->store;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_state_ = 1;
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_prepare (_data_->_tmp1_, backend_loading_tests_test_disabling_async_ready, _data_);
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 957 "backend-loading.c"
	_state_1:
#line 135 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_prepare_finish (_data_->_tmp1_, _data_->_res_);
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp2_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp2_ = _data_->store;
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_state_ = 2;
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_disable_backend (_data_->_tmp2_, "telepathy", backend_loading_tests_test_disabling_async_ready, _data_);
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 971 "backend-loading.c"
	_state_2:
#line 136 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_disable_backend_finish (_data_->_tmp2_, _data_->_res_);
#line 975 "backend-loading.c"
	{
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp3_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp3_ = _data_->store;
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_state_ = 3;
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends (_data_->_tmp3_, backend_loading_tests_test_disabling_async_ready, _data_);
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 987 "backend-loading.c"
		_state_3:
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 140 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 993 "backend-loading.c"
			goto __catch2_g_error;
		}
		{
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp4_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp4_ = _data_->store;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp5_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp5_ = folks_backend_store_get_enabled_backends (_data_->_tmp4_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp6_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp6_ = _data_->_tmp5_;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp7_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp7_ = gee_map_get_values (_data_->_tmp6_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp8_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp9_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp10_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp10_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp9_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp11_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_tmp9_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_backend_it = _data_->_tmp11_;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp12_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp12_ = _data_->_backend_it;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp13_ = FALSE;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp13_ = gee_iterator_next (_data_->_tmp12_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_data_->_tmp13_) {
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 1047 "backend-loading.c"
				}
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp14_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp14_ = _data_->_backend_it;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp15_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp15_ = gee_iterator_get (_data_->_tmp14_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp15_;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp16_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp16_ = _data_->backend;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp17_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp17_ = folks_backend_get_name (_data_->_tmp16_);
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp18_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp18_ = _data_->_tmp17_;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp19_ = FALSE;
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp19_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->backends_expected, _data_->_tmp18_);
#line 144 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_data_->_tmp19_, "backends_expected.contains (backend.name)");
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp20_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp20_ = _data_->backend;
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp21_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp21_ = folks_backend_get_name (_data_->_tmp20_);
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp22_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp22_ = _data_->_tmp21_;
#line 145 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->backends_expected, _data_->_tmp22_);
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (_data_->backend);
#line 1093 "backend-loading.c"
			}
#line 142 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 1097 "backend-loading.c"
		}
#line 148 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp23_ = 0;
#line 148 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp23_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->backends_expected);
#line 148 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp24_ = 0;
#line 148 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp24_ = _data_->_tmp23_;
#line 148 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_data_->_tmp24_ == 0, "backends_expected.size == 0");
#line 149 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp25_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp25_ = _data_->self->priv->main_loop;
#line 149 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_main_loop_quit (_data_->_tmp25_);
#line 1115 "backend-loading.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->e = _data_->_inner_error_;
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_inner_error_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp26_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp26_ = _data_->e->message;
#line 153 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:153: Failed to load backends: %s", _data_->_tmp26_);
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (_data_->e);
#line 1132 "backend-loading.c"
	}
	__finally2:
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data_->backends_expected);
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_data_->_inner_error_);
#line 138 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1145 "backend-loading.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (_data_->_state_ == 0) {
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1153 "backend-loading.c"
	} else {
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1157 "backend-loading.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_object_unref (_data_->_async_result);
#line 129 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 1163 "backend-loading.c"
}


static void __lambda7_ (BackendLoadingTests* self, GObject* o, GAsyncResult* r) {
	GAsyncResult* _tmp0_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (r != NULL);
#line 164 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = r;
#line 164 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_reloading_finish (self, _tmp0_);
#line 1175 "backend-loading.c"
}


static void ___lambda7__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 162 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	__lambda7_ ((BackendLoadingTests*) self, source_object, res);
#line 162 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_object_unref (self);
#line 1184 "backend-loading.c"
}


void backend_loading_tests_test_reloading (BackendLoadingTests* self) {
	GMainLoop* _tmp0_ = NULL;
	FolksBackendStore* store = NULL;
	FolksBackendStore* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_return_if_fail (self != NULL);
#line 159 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 159 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_main_loop_unref0 (self->priv->main_loop);
#line 159 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self->priv->main_loop = _tmp0_;
#line 161 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = folks_backend_store_dup ();
#line 161 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	store = _tmp1_;
#line 162 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_reloading_async (self, store, ___lambda7__gasync_ready_callback, g_object_ref (self));
#line 167 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = self->priv->main_loop;
#line 167 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_main_loop_run (_tmp2_);
#line 157 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (store);
#line 1213 "backend-loading.c"
}


static void backend_loading_tests_test_reloading_async_data_free (gpointer _data) {
	BackendLoadingTestsTestReloadingAsyncData* _data_;
	_data_ = _data;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->store);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->self);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_slice_free (BackendLoadingTestsTestReloadingAsyncData, _data_);
#line 1226 "backend-loading.c"
}


static void backend_loading_tests_test_reloading_async (BackendLoadingTests* self, FolksBackendStore* store, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BackendLoadingTestsTestReloadingAsyncData* _data_;
	BackendLoadingTests* _tmp0_ = NULL;
	FolksBackendStore* _tmp1_ = NULL;
	FolksBackendStore* _tmp2_ = NULL;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = g_slice_new0 (BackendLoadingTestsTestReloadingAsyncData);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, backend_loading_tests_test_reloading_async);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, backend_loading_tests_test_reloading_async_data_free);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->self = _tmp0_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp1_ = store;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->store);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->store = _tmp2_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_reloading_async_co (_data_);
#line 1255 "backend-loading.c"
}


static void backend_loading_tests_test_reloading_finish (BackendLoadingTests* self, GAsyncResult* _res_) {
	BackendLoadingTestsTestReloadingAsyncData* _data_;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1263 "backend-loading.c"
}


static void backend_loading_tests_test_reloading_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BackendLoadingTestsTestReloadingAsyncData* _data_;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_ = _user_data_;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_source_object_ = source_object;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_res_ = _res_;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_test_reloading_async_co (_data_);
#line 1277 "backend-loading.c"
}


static gboolean backend_loading_tests_test_reloading_async_co (BackendLoadingTestsTestReloadingAsyncData* _data_) {
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	switch (_data_->_state_) {
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 0:
#line 1286 "backend-loading.c"
		goto _state_0;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 1:
#line 1290 "backend-loading.c"
		goto _state_1;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 2:
#line 1294 "backend-loading.c"
		goto _state_2;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 3:
#line 1298 "backend-loading.c"
		goto _state_3;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 4:
#line 1302 "backend-loading.c"
		goto _state_4;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 5:
#line 1306 "backend-loading.c"
		goto _state_5;
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		case 6:
#line 1310 "backend-loading.c"
		goto _state_6;
		default:
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_assert_not_reached ();
#line 1315 "backend-loading.c"
	}
	_state_0:
#line 177 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp0_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 177 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 177 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->backends_expected = _data_->_tmp0_;
#line 178 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp1_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp1_ = _data_->backends_expected;
#line 178 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp1_, "key-file");
#line 179 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp2_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp2_ = _data_->backends_expected;
#line 179 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp2_, "telepathy");
#line 1338 "backend-loading.c"
	{
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp3_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp3_ = _data_->store;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_state_ = 1;
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends (_data_->_tmp3_, backend_loading_tests_test_reloading_async_ready, _data_);
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1350 "backend-loading.c"
		_state_1:
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 183 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1356 "backend-loading.c"
			goto __catch3_g_error;
		}
		{
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp4_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp4_ = _data_->store;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp5_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp5_ = folks_backend_store_get_enabled_backends (_data_->_tmp4_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp6_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp6_ = _data_->_tmp5_;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp7_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp7_ = gee_map_get_values (_data_->_tmp6_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp8_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp9_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp10_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp10_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp9_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp11_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_tmp9_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_backend1_it = _data_->_tmp11_;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp12_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp12_ = _data_->_backend1_it;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp13_ = FALSE;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp13_ = gee_iterator_next (_data_->_tmp12_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_data_->_tmp13_) {
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 1410 "backend-loading.c"
				}
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp14_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp14_ = _data_->_backend1_it;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp15_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp15_ = gee_iterator_get (_data_->_tmp14_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->backend1 = (FolksBackend*) _data_->_tmp15_;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp16_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp16_ = _data_->backends_expected;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp17_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp17_ = _data_->backend1;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp18_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp18_ = folks_backend_get_name (_data_->_tmp17_);
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp19_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp19_ = _data_->_tmp18_;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp20_ = FALSE;
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp20_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp16_, _data_->_tmp19_);
#line 187 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_data_->_tmp20_, "backends_expected.contains (backend1.name)");
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp21_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp21_ = _data_->backends_expected;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp22_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp22_ = _data_->backend1;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp23_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp23_ = folks_backend_get_name (_data_->_tmp22_);
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp24_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 188 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->_tmp21_, _data_->_tmp24_);
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (_data_->backend1);
#line 1464 "backend-loading.c"
			}
#line 185 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_backend1_it);
#line 1468 "backend-loading.c"
		}
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp25_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp25_ = _data_->backends_expected;
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp26_ = 0;
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp26_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp25_);
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp27_ = 0;
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 191 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_data_->_tmp27_ == 0, "backends_expected.size == 0");
#line 1484 "backend-loading.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->e1 = _data_->_inner_error_;
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_inner_error_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp28_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp28_ = _data_->e1->message;
#line 195 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:195: Failed to load backends: %s", _data_->_tmp28_);
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (_data_->e1);
#line 1501 "backend-loading.c"
	}
	__finally3:
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data_->backends_expected);
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_data_->_inner_error_);
#line 181 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1514 "backend-loading.c"
	}
#line 201 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp29_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp29_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 201 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 201 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->backends_expected = _data_->_tmp29_;
#line 202 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp30_ = NULL;
#line 202 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp30_ = _data_->backends_expected;
#line 202 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp30_, "telepathy");
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp31_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp31_ = _data_->store;
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_state_ = 2;
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_disable_backend (_data_->_tmp31_, "key-file", backend_loading_tests_test_reloading_async_ready, _data_);
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 1540 "backend-loading.c"
	_state_2:
#line 205 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_disable_backend_finish (_data_->_tmp31_, _data_->_res_);
#line 1544 "backend-loading.c"
	{
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp32_ = NULL;
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp32_ = _data_->store;
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_state_ = 3;
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends (_data_->_tmp32_, backend_loading_tests_test_reloading_async_ready, _data_);
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1556 "backend-loading.c"
		_state_3:
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data_->_tmp32_, _data_->_res_, &_data_->_inner_error_);
#line 210 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1562 "backend-loading.c"
			goto __catch4_g_error;
		}
		{
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp33_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp33_ = _data_->store;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp34_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp34_ = folks_backend_store_get_enabled_backends (_data_->_tmp33_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp35_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp35_ = _data_->_tmp34_;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp36_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp36_ = gee_map_get_values (_data_->_tmp35_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp37_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp37_ = _data_->_tmp36_;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp38_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp38_ = _data_->_tmp37_;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp39_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp39_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp38_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp40_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp40_ = _data_->_tmp39_;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_tmp38_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_backend2_it = _data_->_tmp40_;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp41_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp41_ = _data_->_backend2_it;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp42_ = FALSE;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp42_ = gee_iterator_next (_data_->_tmp41_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_data_->_tmp42_) {
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 1616 "backend-loading.c"
				}
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp43_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp43_ = _data_->_backend2_it;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp44_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp44_ = gee_iterator_get (_data_->_tmp43_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->backend2 = (FolksBackend*) _data_->_tmp44_;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp45_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp45_ = _data_->backends_expected;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp46_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp46_ = _data_->backend2;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp47_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp47_ = folks_backend_get_name (_data_->_tmp46_);
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp48_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp48_ = _data_->_tmp47_;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp49_ = FALSE;
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp49_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp45_, _data_->_tmp48_);
#line 214 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_data_->_tmp49_, "backends_expected.contains (backend2.name)");
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp50_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp50_ = _data_->backends_expected;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp51_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp51_ = _data_->backend2;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp52_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp52_ = folks_backend_get_name (_data_->_tmp51_);
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp53_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp53_ = _data_->_tmp52_;
#line 215 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->_tmp50_, _data_->_tmp53_);
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (_data_->backend2);
#line 1670 "backend-loading.c"
			}
#line 212 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_backend2_it);
#line 1674 "backend-loading.c"
		}
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp54_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp54_ = _data_->backends_expected;
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp55_ = 0;
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp55_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp54_);
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp56_ = 0;
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp56_ = _data_->_tmp55_;
#line 218 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_data_->_tmp56_ == 0, "backends_expected.size == 0");
#line 1690 "backend-loading.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->e2 = _data_->_inner_error_;
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_inner_error_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp57_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp57_ = _data_->e2->message;
#line 222 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:222: Failed to load backends: %s", _data_->_tmp57_);
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (_data_->e2);
#line 1707 "backend-loading.c"
	}
	__finally4:
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data_->backends_expected);
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_data_->_inner_error_);
#line 208 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1720 "backend-loading.c"
	}
#line 228 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp58_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp58_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 228 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 228 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->backends_expected = _data_->_tmp58_;
#line 229 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp59_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp59_ = _data_->backends_expected;
#line 229 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp59_, "key-file");
#line 230 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp60_ = NULL;
#line 230 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp60_ = _data_->backends_expected;
#line 230 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp60_, "telepathy");
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp61_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp61_ = _data_->store;
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_state_ = 4;
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_enable_backend (_data_->_tmp61_, "key-file", backend_loading_tests_test_reloading_async_ready, _data_);
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 1752 "backend-loading.c"
	_state_4:
#line 233 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_backend_store_enable_backend_finish (_data_->_tmp61_, _data_->_res_);
#line 1756 "backend-loading.c"
	{
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp62_ = NULL;
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp62_ = _data_->store;
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_state_ = 5;
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends (_data_->_tmp62_, backend_loading_tests_test_reloading_async_ready, _data_);
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1768 "backend-loading.c"
		_state_5:
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data_->_tmp62_, _data_->_res_, &_data_->_inner_error_);
#line 238 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1774 "backend-loading.c"
			goto __catch5_g_error;
		}
		{
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp63_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp63_ = _data_->store;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp64_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp64_ = folks_backend_store_get_enabled_backends (_data_->_tmp63_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp65_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp65_ = _data_->_tmp64_;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp66_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp66_ = gee_map_get_values (_data_->_tmp65_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp67_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp67_ = _data_->_tmp66_;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp68_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp68_ = _data_->_tmp67_;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp69_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp69_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp68_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp70_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp70_ = _data_->_tmp69_;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_tmp68_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_backend3_it = _data_->_tmp70_;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp71_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp71_ = _data_->_backend3_it;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp72_ = FALSE;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp72_ = gee_iterator_next (_data_->_tmp71_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_data_->_tmp72_) {
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 1828 "backend-loading.c"
				}
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp73_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp73_ = _data_->_backend3_it;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp74_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp74_ = gee_iterator_get (_data_->_tmp73_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->backend3 = (FolksBackend*) _data_->_tmp74_;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp75_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp75_ = _data_->backends_expected;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp76_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp76_ = _data_->backend3;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp77_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp77_ = folks_backend_get_name (_data_->_tmp76_);
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp78_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp78_ = _data_->_tmp77_;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp79_ = FALSE;
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp79_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp75_, _data_->_tmp78_);
#line 242 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_data_->_tmp79_, "backends_expected.contains (backend3.name)");
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp80_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp80_ = _data_->backends_expected;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp81_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp81_ = _data_->backend3;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp82_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp82_ = folks_backend_get_name (_data_->_tmp81_);
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp83_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp83_ = _data_->_tmp82_;
#line 243 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->_tmp80_, _data_->_tmp83_);
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (_data_->backend3);
#line 1882 "backend-loading.c"
			}
#line 240 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_backend3_it);
#line 1886 "backend-loading.c"
		}
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp84_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp84_ = _data_->backends_expected;
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp85_ = 0;
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp85_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp84_);
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp86_ = 0;
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp86_ = _data_->_tmp85_;
#line 246 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_data_->_tmp86_ == 0, "backends_expected.size == 0");
#line 1902 "backend-loading.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->e3 = _data_->_inner_error_;
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_inner_error_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp87_ = NULL;
#line 250 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp87_ = _data_->e3->message;
#line 250 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:250: Failed to load backends: %s", _data_->_tmp87_);
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (_data_->e3);
#line 1919 "backend-loading.c"
	}
	__finally5:
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data_->backends_expected);
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_data_->_inner_error_);
#line 236 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1932 "backend-loading.c"
	}
#line 257 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp88_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp88_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 257 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 257 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->backends_expected = _data_->_tmp88_;
#line 258 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp89_ = NULL;
#line 258 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp89_ = _data_->backends_expected;
#line 258 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp89_, "key-file");
#line 259 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp90_ = NULL;
#line 259 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp90_ = _data_->backends_expected;
#line 259 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp90_, "telepathy");
#line 1954 "backend-loading.c"
	{
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp91_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp91_ = _data_->store;
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_state_ = 6;
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends (_data_->_tmp91_, backend_loading_tests_test_reloading_async_ready, _data_);
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 1966 "backend-loading.c"
		_state_6:
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		folks_backend_store_load_backends_finish (_data_->_tmp91_, _data_->_res_, &_data_->_inner_error_);
#line 264 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1972 "backend-loading.c"
			goto __catch6_g_error;
		}
		{
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp92_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp92_ = _data_->store;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp93_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp93_ = folks_backend_store_get_enabled_backends (_data_->_tmp92_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp94_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp94_ = _data_->_tmp93_;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp95_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp95_ = gee_map_get_values (_data_->_tmp94_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp96_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp96_ = _data_->_tmp95_;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp97_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp97_ = _data_->_tmp96_;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp98_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp98_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp97_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp99_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_tmp99_ = _data_->_tmp98_;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_tmp97_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_data_->_backend_it = _data_->_tmp99_;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			while (TRUE) {
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp100_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp100_ = _data_->_backend_it;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp101_ = FALSE;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp101_ = gee_iterator_next (_data_->_tmp100_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				if (!_data_->_tmp101_) {
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
					break;
#line 2026 "backend-loading.c"
				}
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp102_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp102_ = _data_->_backend_it;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp103_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp103_ = gee_iterator_get (_data_->_tmp102_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp103_;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp104_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp104_ = _data_->backends_expected;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp105_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp105_ = _data_->backend;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp106_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp106_ = folks_backend_get_name (_data_->_tmp105_);
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp107_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp107_ = _data_->_tmp106_;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp108_ = FALSE;
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp108_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _data_->_tmp104_, _data_->_tmp107_);
#line 268 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_vala_assert (_data_->_tmp108_, "backends_expected.contains (backend.name)");
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp109_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp109_ = _data_->backends_expected;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp110_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp110_ = _data_->backend;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp111_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp111_ = folks_backend_get_name (_data_->_tmp110_);
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp112_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_data_->_tmp112_ = _data_->_tmp111_;
#line 269 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				gee_abstract_collection_remove ((GeeAbstractCollection*) _data_->_tmp109_, _data_->_tmp112_);
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
				_g_object_unref0 (_data_->backend);
#line 2080 "backend-loading.c"
			}
#line 266 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 2084 "backend-loading.c"
		}
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp113_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp113_ = _data_->backends_expected;
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp114_ = 0;
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp114_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp113_);
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp115_ = 0;
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp115_ = _data_->_tmp114_;
#line 272 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_vala_assert (_data_->_tmp115_ == 0, "backends_expected.size == 0");
#line 2100 "backend-loading.c"
	}
	goto __finally6;
	__catch6_g_error:
	{
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->e4 = _data_->_inner_error_;
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_inner_error_ = NULL;
#line 276 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp116_ = NULL;
#line 276 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_data_->_tmp116_ = _data_->e4->message;
#line 276 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_error ("backend-loading.vala:276: Failed to load backends: %s", _data_->_tmp116_);
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_error_free0 (_data_->e4);
#line 2117 "backend-loading.c"
	}
	__finally6:
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		_g_object_unref0 (_data_->backends_expected);
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_clear_error (&_data_->_inner_error_);
#line 262 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		return FALSE;
#line 2130 "backend-loading.c"
	}
#line 279 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp117_ = NULL;
#line 279 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_data_->_tmp117_ = _data_->self->priv->main_loop;
#line 279 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_main_loop_quit (_data_->_tmp117_);
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (_data_->backends_expected);
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	if (_data_->_state_ == 0) {
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2144 "backend-loading.c"
	} else {
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2148 "backend-loading.c"
	}
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_object_unref (_data_->_async_result);
#line 170 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return FALSE;
#line 2154 "backend-loading.c"
}


static void backend_loading_tests_class_init (BackendLoadingTestsClass * klass) {
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	backend_loading_tests_parent_class = g_type_class_peek_parent (klass);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_type_class_add_private (klass, sizeof (BackendLoadingTestsPrivate));
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	((FolksTestCaseClass *) klass)->set_up = backend_loading_tests_real_set_up;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	((FolksTestCaseClass *) klass)->tear_down = backend_loading_tests_real_tear_down;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	G_OBJECT_CLASS (klass)->finalize = backend_loading_tests_finalize;
#line 2169 "backend-loading.c"
}


static void backend_loading_tests_instance_init (BackendLoadingTests * self) {
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self->priv = BACKEND_LOADING_TESTS_GET_PRIVATE (self);
#line 2176 "backend-loading.c"
}


static void backend_loading_tests_finalize (GObject* obj) {
	BackendLoadingTests * self;
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_BACKEND_LOADING_TESTS, BackendLoadingTests);
#line 25 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_main_loop_unref0 (self->priv->main_loop);
#line 23 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	G_OBJECT_CLASS (backend_loading_tests_parent_class)->finalize (obj);
#line 2188 "backend-loading.c"
}


GType backend_loading_tests_get_type (void) {
	static volatile gsize backend_loading_tests_type_id__volatile = 0;
	if (g_once_init_enter (&backend_loading_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BackendLoadingTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) backend_loading_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BackendLoadingTests), 0, (GInstanceInitFunc) backend_loading_tests_instance_init, NULL };
		GType backend_loading_tests_type_id;
		backend_loading_tests_type_id = g_type_register_static (TPF_TEST_TYPE_MIXED_TEST_CASE, "BackendLoadingTests", &g_define_type_info, 0);
		g_once_init_leave (&backend_loading_tests_type_id__volatile, backend_loading_tests_type_id);
	}
	return backend_loading_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	BackendLoadingTests* tests = NULL;
	BackendLoadingTests* _tmp0_ = NULL;
#line 285 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_test_init (&args_length1, &args, NULL);
#line 287 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_tmp0_ = backend_loading_tests_new ();
#line 287 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	tests = _tmp0_;
#line 288 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 289 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	g_test_run ();
#line 290 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 292 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	result = 0;
#line 292 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	_g_object_unref0 (tests);
#line 292 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return result;
#line 2226 "backend-loading.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 283 "/opt/gnome3/source/folks/tests/folks/backend-loading.vala"
	return _vala_main (argv, argc);
#line 2236 "backend-loading.c"
}



