/* store-removed.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from store-removed.vala, do not modify */

/*
 * Copyright (C) 2011 Philip Withnall
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Philip Withnall <philip@tecnocode.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_STORE_REMOVED_TESTS (store_removed_tests_get_type ())
#define STORE_REMOVED_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STORE_REMOVED_TESTS, StoreRemovedTests))
#define STORE_REMOVED_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STORE_REMOVED_TESTS, StoreRemovedTestsClass))
#define IS_STORE_REMOVED_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STORE_REMOVED_TESTS))
#define IS_STORE_REMOVED_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STORE_REMOVED_TESTS))
#define STORE_REMOVED_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STORE_REMOVED_TESTS, StoreRemovedTestsClass))

typedef struct _StoreRemovedTests StoreRemovedTests;
typedef struct _StoreRemovedTestsClass StoreRemovedTestsClass;
typedef struct _StoreRemovedTestsPrivate StoreRemovedTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _StoreRemovedTestsTestSingleStorePart1AsyncData StoreRemovedTestsTestSingleStorePart1AsyncData;
typedef struct _Block2Data Block2Data;
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
typedef struct _StoreRemovedTestsTestSingleStorePart2AsyncData StoreRemovedTestsTestSingleStorePart2AsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _StoreRemovedTests {
	EdsTestTestCase parent_instance;
	StoreRemovedTestsPrivate * priv;
};

struct _StoreRemovedTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _StoreRemovedTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
};

struct _Block1Data {
	int _ref_count_;
	StoreRemovedTests* self;
	gulong signal_id;
	gpointer _async_data_;
};

struct _StoreRemovedTestsTestSingleStorePart1AsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	StoreRemovedTests* self;
	Block1Data* _data1_;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gulong _tmp4_;
	FolksIndividualAggregator* _tmp5_;
	GError* e;
	GError* _tmp6_;
	const gchar* _tmp7_;
	GError * _inner_error_;
};

struct _Block2Data {
	int _ref_count_;
	StoreRemovedTests* self;
	gulong signal_id;
	gpointer _async_data_;
};

struct _StoreRemovedTestsTestSingleStorePart2AsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	StoreRemovedTests* self;
	Block2Data* _data2_;
	FolksIndividualAggregator* _tmp0_;
	gulong _tmp1_;
	EdsTestBackend* _tmp2_;
};


static gpointer store_removed_tests_parent_class = NULL;

GType store_removed_tests_get_type (void) G_GNUC_CONST;
#define STORE_REMOVED_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_STORE_REMOVED_TESTS, StoreRemovedTestsPrivate))
enum  {
	STORE_REMOVED_TESTS_DUMMY_PROPERTY
};
StoreRemovedTests* store_removed_tests_new (void);
StoreRemovedTests* store_removed_tests_construct (GType object_type);
void store_removed_tests_test_single_store (StoreRemovedTests* self);
static void _store_removed_tests_test_single_store_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _store_removed_tests_test_single_store_part1_async (StoreRemovedTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _store_removed_tests_test_single_store_part1_finish (StoreRemovedTests* self, GAsyncResult* _res_);
static void _store_removed_tests_test_single_store_part2_async (StoreRemovedTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _store_removed_tests_test_single_store_part2_finish (StoreRemovedTests* self, GAsyncResult* _res_);
static void _store_removed_tests_test_single_store_part1_async_data_free (gpointer _data);
static gboolean _store_removed_tests_test_single_store_part1_async_co (StoreRemovedTestsTestSingleStorePart1AsyncData* _data_);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void _store_removed_tests_test_single_store_part1_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda4_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _store_removed_tests_test_single_store_part2_async_data_free (gpointer _data);
static gboolean _store_removed_tests_test_single_store_part2_async_co (StoreRemovedTestsTestSingleStorePart2AsyncData* _data_);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda5_ (Block2Data* _data2_, GeeMultiMap* changes);
static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void store_removed_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _store_removed_tests_test_single_store_folks_test_case_test_method (gpointer self) {
#line 35 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	store_removed_tests_test_single_store ((StoreRemovedTests*) self);
#line 156 "store-removed.c"
}


StoreRemovedTests* store_removed_tests_construct (GType object_type) {
	StoreRemovedTests * self = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self = (StoreRemovedTests*) eds_test_test_case_construct (object_type, "StoreRemoved");
#line 35 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "single store", _store_removed_tests_test_single_store_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 31 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return self;
#line 168 "store-removed.c"
}


StoreRemovedTests* store_removed_tests_new (void) {
#line 31 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return store_removed_tests_construct (TYPE_STORE_REMOVED_TESTS);
#line 175 "store-removed.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 182 "store-removed.c"
}


static void _vala_GValue_free (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_value_unset (self);
#line 45 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_free (self);
#line 191 "store-removed.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return self ? _g_value_dup (self) : NULL;
#line 198 "store-removed.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 55 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return self ? g_object_ref (self) : NULL;
#line 205 "store-removed.c"
}


void store_removed_tests_test_single_store (StoreRemovedTests* self) {
	GMainLoop* _tmp0_ = NULL;
	EdsTestBackend* _tmp1_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GValue* v = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue _tmp10_ = {0};
	GValue _tmp11_ = {0};
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	EdsTestBackend* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GMainLoop* _tmp19_ = NULL;
	FolksIndividualAggregator* _tmp20_ = NULL;
	GeeMap* _tmp21_ = NULL;
	GeeMap* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gint _tmp24_ = 0;
	GMainLoop* _tmp25_ = NULL;
	FolksIndividualAggregator* _tmp26_ = NULL;
	GeeMap* _tmp27_ = NULL;
	GeeMap* _tmp28_ = NULL;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_return_if_fail (self != NULL);
#line 40 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 40 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 40 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self->priv->_main_loop = _tmp0_;
#line 42 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp1_ = ((EdsTestTestCase*) self)->eds_backend;
#line 42 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	eds_test_backend_reset (_tmp1_);
#line 45 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	c1 = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp4_ = _tmp3_;
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp6_ = _tmp5_;
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 47 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	v = _tmp6_;
#line 48 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp7_ = v;
#line 48 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_value_set_string (_tmp7_, "Chancellor Brian Blessed");
#line 49 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp8_ = v;
#line 49 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	v = NULL;
#line 49 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp9_ = _tmp8_;
#line 49 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp9_);
#line 49 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__vala_GValue_free0 (_tmp9_);
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_value_init (&_tmp10_, G_TYPE_STRING);
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp11_ = _tmp10_;
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp12_ = __g_value_dup0 (&_tmp11_);
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__vala_GValue_free0 (v);
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	v = _tmp12_;
#line 51 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	G_IS_VALUE (&_tmp11_) ? (g_value_unset (&_tmp11_), NULL) : NULL;
#line 52 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp13_ = v;
#line 52 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_value_set_string (_tmp13_, "brian@example.com");
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp14_ = EDSF_PERSONA_email_fields[0];
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp15_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	v = NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp16_ = _tmp15_;
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, _tmp14_, _tmp16_);
#line 53 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__vala_GValue_free0 (_tmp16_);
#line 55 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp17_ = ((EdsTestTestCase*) self)->eds_backend;
#line 55 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp18_ = _g_object_ref0 (c1);
#line 55 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	eds_test_backend_add_contact (_tmp17_, _tmp18_);
#line 58 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_store_removed_tests_test_single_store_part1_async (self, NULL, NULL);
#line 60 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp19_ = self->priv->_main_loop;
#line 60 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_test_utils_loop_run_with_timeout (_tmp19_, 5);
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp20_ = self->priv->_aggregator;
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp21_ = folks_individual_aggregator_get_individuals (_tmp20_);
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp22_ = _tmp21_;
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp23_ = gee_map_get_size (_tmp22_);
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp24_ = _tmp23_;
#line 63 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp24_ == 1, "this._aggregator.individuals.size == 1");
#line 66 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_store_removed_tests_test_single_store_part2_async (self, NULL, NULL);
#line 68 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp25_ = self->priv->_main_loop;
#line 68 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_test_utils_loop_run_with_timeout (_tmp25_, 5);
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp26_ = self->priv->_aggregator;
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp27_ = folks_individual_aggregator_get_individuals (_tmp26_);
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp28_ = _tmp27_;
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp29_ = gee_map_get_size (_tmp28_);
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp30_ = _tmp29_;
#line 71 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp30_ == 0, "this._aggregator.individuals.size == 0");
#line 38 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__vala_GValue_free0 (v);
#line 38 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (c1);
#line 359 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part1_async_data_free (gpointer _data) {
	StoreRemovedTestsTestSingleStorePart1AsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_slice_free (StoreRemovedTestsTestSingleStorePart1AsyncData, _data_);
#line 370 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part1_async (StoreRemovedTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	StoreRemovedTestsTestSingleStorePart1AsyncData* _data_;
	StoreRemovedTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_ = g_slice_new0 (StoreRemovedTestsTestSingleStorePart1AsyncData);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _store_removed_tests_test_single_store_part1_async);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _store_removed_tests_test_single_store_part1_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_store_removed_tests_test_single_store_part1_async_co (_data_);
#line 389 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part1_finish (StoreRemovedTests* self, GAsyncResult* _res_) {
	StoreRemovedTestsTestSingleStorePart1AsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 397 "store-removed.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return _data1_;
#line 406 "store-removed.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 415 "store-removed.c"
		StoreRemovedTests* self;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		self = _data1_->self;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (self);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_slice_free (Block1Data, _data1_);
#line 423 "store-removed.c"
	}
}


static void _store_removed_tests_test_single_store_part1_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	StoreRemovedTestsTestSingleStorePart1AsyncData* _data_;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_ = _user_data_;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_source_object_ = source_object;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_res_ = _res_;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_store_removed_tests_test_single_store_part1_async_co (_data_);
#line 438 "store-removed.c"
}


static void __lambda4_ (Block1Data* _data1_, GeeMultiMap* changes) {
	StoreRemovedTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	GMainLoop* _tmp24_ = NULL;
	FolksIndividualAggregator* _tmp25_ = NULL;
	gulong _tmp26_ = 0UL;
#line 85 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self = _data1_->self;
#line 85 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_return_if_fail (changes != NULL);
#line 87 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = changes;
#line 87 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 87 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	added = _tmp1_;
#line 88 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp2_ = changes;
#line 88 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 88 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	removed = _tmp3_;
#line 90 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp4_ = added;
#line 90 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 90 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp6_ = _tmp5_;
#line 90 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp6_ == 1, "added.size == 1");
#line 483 "store-removed.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp7_ = added;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_i_it = _tmp8_;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		while (TRUE) {
#line 496 "store-removed.c"
			GeeIterator* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp9_ = _i_it;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			if (!_tmp10_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
				break;
#line 511 "store-removed.c"
			}
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp11_ = _i_it;
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			i = (FolksIndividual*) _tmp12_;
#line 96 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp13_ = i;
#line 96 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_vala_assert (_tmp13_ != NULL, "i != null");
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_g_object_unref0 (i);
#line 525 "store-removed.c"
		}
#line 94 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (_i_it);
#line 529 "store-removed.c"
	}
#line 99 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp14_ = removed;
#line 99 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 99 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp16_ = _tmp15_;
#line 99 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp16_ == 1, "removed.size == 1");
#line 539 "store-removed.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp17_ = NULL;
		GeeIterator* _tmp18_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp17_ = removed;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_i_it = _tmp18_;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		while (TRUE) {
#line 552 "store-removed.c"
			GeeIterator* _tmp19_ = NULL;
			gboolean _tmp20_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp21_ = NULL;
			gpointer _tmp22_ = NULL;
			FolksIndividual* _tmp23_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp19_ = _i_it;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp20_ = gee_iterator_next (_tmp19_);
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			if (!_tmp20_) {
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
				break;
#line 567 "store-removed.c"
			}
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp21_ = _i_it;
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp22_ = gee_iterator_get (_tmp21_);
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			i = (FolksIndividual*) _tmp22_;
#line 103 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp23_ = i;
#line 103 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_vala_assert (_tmp23_ == NULL, "i == null");
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_g_object_unref0 (i);
#line 581 "store-removed.c"
		}
#line 101 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (_i_it);
#line 585 "store-removed.c"
	}
#line 107 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp24_ = self->priv->_main_loop;
#line 107 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_main_loop_quit (_tmp24_);
#line 108 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp25_ = self->priv->_aggregator;
#line 108 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp26_ = _data1_->signal_id;
#line 108 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_signal_handler_disconnect ((GObject*) _tmp25_, _tmp26_);
#line 85 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (removed);
#line 85 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (added);
#line 601 "store-removed.c"
}


static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__lambda4_ (self, changes);
#line 608 "store-removed.c"
}


static gboolean _store_removed_tests_test_single_store_part1_async_co (StoreRemovedTestsTestSingleStorePart1AsyncData* _data_) {
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	switch (_data_->_state_) {
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		case 0:
#line 617 "store-removed.c"
		goto _state_0;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		case 1:
#line 621 "store-removed.c"
		goto _state_1;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		case 2:
#line 625 "store-removed.c"
		goto _state_2;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		case 3:
#line 629 "store-removed.c"
		goto _state_3;
		default:
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_assert_not_reached ();
#line 634 "store-removed.c"
	}
	_state_0:
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_ = g_slice_new0 (Block1Data);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_->_ref_count_ = 1;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_->self = g_object_ref (_data_->self);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_->_async_data_ = _data_;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp0_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_state_ = 1;
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _store_removed_tests_test_single_store_part1_async_ready, _data_);
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return FALSE;
#line 655 "store-removed.c"
	_state_1:
#line 76 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 78 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp1_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 78 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->store = _data_->_tmp1_;
#line 79 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_state_ = 2;
#line 79 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_backend_store_prepare (_data_->store, _store_removed_tests_test_single_store_part1_async_ready, _data_);
#line 79 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return FALSE;
#line 671 "store-removed.c"
	_state_2:
#line 79 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 81 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp2_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 81 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 81 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 83 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_->signal_id = (gulong) 0;
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp3_ = NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp4_ = 0UL;
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp4_ = g_signal_connect_data (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda4__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data_->_data1_), (GClosureNotify) block1_data_unref, 0);
#line 84 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_->signal_id = _data_->_tmp4_;
#line 695 "store-removed.c"
	{
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp5_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp5_ = _data_->self->priv->_aggregator;
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_state_ = 3;
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		folks_individual_aggregator_prepare (_data_->_tmp5_, _store_removed_tests_test_single_store_part1_async_ready, _data_);
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		return FALSE;
#line 707 "store-removed.c"
		_state_3:
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 113 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 713 "store-removed.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->e = _data_->_inner_error_;
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_inner_error_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp6_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp6_ = _data_->e;
#line 117 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp7_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_tmp7_ = _data_->_tmp6_->message;
#line 117 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_critical ("store-removed.vala:117: Error when calling prepare: %s", _data_->_tmp7_);
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_error_free0 (_data_->e);
#line 736 "store-removed.c"
	}
	__finally0:
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (_data_->store);
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		block1_data_unref (_data_->_data1_);
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_data_->_data1_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_clear_error (&_data_->_inner_error_);
#line 111 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		return FALSE;
#line 753 "store-removed.c"
	}
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (_data_->store);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	block1_data_unref (_data_->_data1_);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data1_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	if (_data_->_state_ == 0) {
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 765 "store-removed.c"
	} else {
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 769 "store-removed.c"
	}
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_object_unref (_data_->_async_result);
#line 74 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return FALSE;
#line 775 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part2_async_data_free (gpointer _data) {
	StoreRemovedTestsTestSingleStorePart2AsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_slice_free (StoreRemovedTestsTestSingleStorePart2AsyncData, _data_);
#line 786 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part2_async (StoreRemovedTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	StoreRemovedTestsTestSingleStorePart2AsyncData* _data_;
	StoreRemovedTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_ = g_slice_new0 (StoreRemovedTestsTestSingleStorePart2AsyncData);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _store_removed_tests_test_single_store_part2_async);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _store_removed_tests_test_single_store_part2_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_store_removed_tests_test_single_store_part2_async_co (_data_);
#line 805 "store-removed.c"
}


static void _store_removed_tests_test_single_store_part2_finish (StoreRemovedTests* self, GAsyncResult* _res_) {
	StoreRemovedTestsTestSingleStorePart2AsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 813 "store-removed.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return _data2_;
#line 822 "store-removed.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 831 "store-removed.c"
		StoreRemovedTests* self;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		self = _data2_->self;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (self);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_slice_free (Block2Data, _data2_);
#line 839 "store-removed.c"
	}
}


static void __lambda5_ (Block2Data* _data2_, GeeMultiMap* changes) {
	StoreRemovedTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	GMainLoop* _tmp24_ = NULL;
	FolksIndividualAggregator* _tmp25_ = NULL;
	gulong _tmp26_ = 0UL;
#line 125 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self = _data2_->self;
#line 125 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_return_if_fail (changes != NULL);
#line 127 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = changes;
#line 127 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 127 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	added = _tmp1_;
#line 128 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp2_ = changes;
#line 128 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 128 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	removed = _tmp3_;
#line 130 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp4_ = added;
#line 130 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 130 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp6_ = _tmp5_;
#line 130 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp6_ == 1, "added.size == 1");
#line 885 "store-removed.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp7_ = added;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_i_it = _tmp8_;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		while (TRUE) {
#line 898 "store-removed.c"
			GeeIterator* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp9_ = _i_it;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			if (!_tmp10_) {
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
				break;
#line 913 "store-removed.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp11_ = _i_it;
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			i = (FolksIndividual*) _tmp12_;
#line 134 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp13_ = i;
#line 134 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_vala_assert (_tmp13_ == NULL, "i == null");
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_g_object_unref0 (i);
#line 927 "store-removed.c"
		}
#line 132 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (_i_it);
#line 931 "store-removed.c"
	}
#line 137 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp14_ = removed;
#line 137 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 137 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp16_ = _tmp15_;
#line 137 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_vala_assert (_tmp16_ == 1, "removed.size == 1");
#line 941 "store-removed.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp17_ = NULL;
		GeeIterator* _tmp18_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp17_ = removed;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_i_it = _tmp18_;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		while (TRUE) {
#line 954 "store-removed.c"
			GeeIterator* _tmp19_ = NULL;
			gboolean _tmp20_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp21_ = NULL;
			gpointer _tmp22_ = NULL;
			FolksIndividual* _tmp23_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp19_ = _i_it;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp20_ = gee_iterator_next (_tmp19_);
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			if (!_tmp20_) {
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
				break;
#line 969 "store-removed.c"
			}
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp21_ = _i_it;
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp22_ = gee_iterator_get (_tmp21_);
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			i = (FolksIndividual*) _tmp22_;
#line 143 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_tmp23_ = i;
#line 143 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_vala_assert (_tmp23_ != NULL, "i != null");
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
			_g_object_unref0 (i);
#line 983 "store-removed.c"
		}
#line 141 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		_g_object_unref0 (_i_it);
#line 987 "store-removed.c"
	}
#line 147 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp24_ = self->priv->_main_loop;
#line 147 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_main_loop_quit (_tmp24_);
#line 148 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp25_ = self->priv->_aggregator;
#line 148 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp26_ = _data2_->signal_id;
#line 148 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_signal_handler_disconnect ((GObject*) _tmp25_, _tmp26_);
#line 125 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (removed);
#line 125 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (added);
#line 1003 "store-removed.c"
}


static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	__lambda5_ (self, changes);
#line 1010 "store-removed.c"
}


static gboolean _store_removed_tests_test_single_store_part2_async_co (StoreRemovedTestsTestSingleStorePart2AsyncData* _data_) {
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	switch (_data_->_state_) {
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		case 0:
#line 1019 "store-removed.c"
		goto _state_0;
		default:
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_assert_not_reached ();
#line 1024 "store-removed.c"
	}
	_state_0:
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_ = g_slice_new0 (Block2Data);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_->_ref_count_ = 1;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_->self = g_object_ref (_data_->self);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_->_async_data_ = _data_;
#line 123 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_->signal_id = (gulong) 0;
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp0_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp0_ = _data_->self->priv->_aggregator;
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp1_ = 0UL;
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp1_ = g_signal_connect_data (_data_->_tmp0_, "individuals-changed-detailed", (GCallback) ___lambda5__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data_->_data2_), (GClosureNotify) block2_data_unref, 0);
#line 124 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_->signal_id = _data_->_tmp1_;
#line 153 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp2_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_tmp2_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 153 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	eds_test_backend_tear_down (_data_->_tmp2_);
#line 154 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_eds_test_backend_unref0 (((EdsTestTestCase*) _data_->self)->eds_backend);
#line 154 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	((EdsTestTestCase*) _data_->self)->eds_backend = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	block2_data_unref (_data_->_data2_);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_data_->_data2_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	if (_data_->_state_ == 0) {
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1065 "store-removed.c"
	} else {
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1069 "store-removed.c"
	}
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_object_unref (_data_->_async_result);
#line 121 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return FALSE;
#line 1075 "store-removed.c"
}


static void store_removed_tests_class_init (StoreRemovedTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	store_removed_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_type_class_add_private (klass, sizeof (StoreRemovedTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	G_OBJECT_CLASS (klass)->finalize = store_removed_tests_finalize;
#line 1086 "store-removed.c"
}


static void store_removed_tests_instance_init (StoreRemovedTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self->priv = STORE_REMOVED_TESTS_GET_PRIVATE (self);
#line 1093 "store-removed.c"
}


static void store_removed_tests_finalize (GObject* obj) {
	StoreRemovedTests * self;
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_STORE_REMOVED_TESTS, StoreRemovedTests);
#line 28 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	G_OBJECT_CLASS (store_removed_tests_parent_class)->finalize (obj);
#line 1107 "store-removed.c"
}


GType store_removed_tests_get_type (void) {
	static volatile gsize store_removed_tests_type_id__volatile = 0;
	if (g_once_init_enter (&store_removed_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (StoreRemovedTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) store_removed_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (StoreRemovedTests), 0, (GInstanceInitFunc) store_removed_tests_instance_init, NULL };
		GType store_removed_tests_type_id;
		store_removed_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "StoreRemovedTests", &g_define_type_info, 0);
		g_once_init_leave (&store_removed_tests_type_id__volatile, store_removed_tests_type_id);
	}
	return store_removed_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	StoreRemovedTests* tests = NULL;
	StoreRemovedTests* _tmp0_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_test_init (&args_length1, &args, NULL);
#line 162 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_tmp0_ = store_removed_tests_new ();
#line 162 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	tests = _tmp0_;
#line 163 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 164 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	g_test_run ();
#line 165 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 167 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	result = 0;
#line 167 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	_g_object_unref0 (tests);
#line 167 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return result;
#line 1145 "store-removed.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 158 "/opt/gnome3/source/folks/tests/eds/store-removed.vala"
	return _vala_main (argv, argc);
#line 1155 "store-removed.c"
}



