/* set-urls.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from set-urls.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <folks-test.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_SET_UR_LS_TESTS (set_ur_ls_tests_get_type ())
#define SET_UR_LS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_UR_LS_TESTS, SetURLsTests))
#define SET_UR_LS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_UR_LS_TESTS, SetURLsTestsClass))
#define IS_SET_UR_LS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_UR_LS_TESTS))
#define IS_SET_UR_LS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_UR_LS_TESTS))
#define SET_UR_LS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_UR_LS_TESTS, SetURLsTestsClass))

typedef struct _SetURLsTests SetURLsTests;
typedef struct _SetURLsTestsClass SetURLsTestsClass;
typedef struct _SetURLsTestsPrivate SetURLsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetUrLsTestsTestSetUrlsAsyncData SetUrLsTestsTestSetUrlsAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetURLsTests {
	TrackerTestTestCase parent_instance;
	SetURLsTestsPrivate * priv;
};

struct _SetURLsTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _SetURLsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	GeeHashMap* _urls;
};

struct _SetUrLsTestsTestSetUrlsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetURLsTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer set_ur_ls_tests_parent_class = NULL;

GType set_ur_ls_tests_get_type (void) G_GNUC_CONST;
#define SET_UR_LS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_UR_LS_TESTS, SetURLsTestsPrivate))
enum  {
	SET_UR_LS_TESTS_DUMMY_PROPERTY
};
SetURLsTests* set_ur_ls_tests_new (void);
SetURLsTests* set_ur_ls_tests_construct (GType object_type);
void set_ur_ls_tests_test_set_urls (SetURLsTests* self);
static void _set_ur_ls_tests_test_set_urls_folks_test_case_test_method (gpointer self);
static void _set_ur_ls_tests_test_set_urls_async (SetURLsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_ur_ls_tests_test_set_urls_finish (SetURLsTests* self, GAsyncResult* _res_);
static void _set_ur_ls_tests_test_set_urls_async_data_free (gpointer _data);
static gboolean _set_ur_ls_tests_test_set_urls_async_co (SetUrLsTestsTestSetUrlsAsyncData* _data_);
static void _set_ur_ls_tests_test_set_urls_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_ur_ls_tests_individuals_changed_cb (SetURLsTests* self, GeeMultiMap* changes);
static void __set_ur_ls_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_ur_ls_tests_notify_urls_cb (SetURLsTests* self, GObject* individual_obj, GParamSpec* ps);
static void __set_ur_ls_tests_notify_urls_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void set_ur_ls_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_ur_ls_tests_test_set_urls_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	set_ur_ls_tests_test_set_urls ((SetURLsTests*) self);
#line 117 "set-urls.c"
}


SetURLsTests* set_ur_ls_tests_construct (GType object_type) {
	SetURLsTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self = (SetURLsTests*) tracker_test_test_case_construct (object_type, "SetURLsTests");
#line 37 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test setting urls ", _set_ur_ls_tests_test_set_urls_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return self;
#line 129 "set-urls.c"
}


SetURLsTests* set_ur_ls_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return set_ur_ls_tests_construct (TYPE_SET_UR_LS_TESTS);
#line 136 "set-urls.c"
}


void set_ur_ls_tests_test_set_urls (SetURLsTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	GeeHashMap* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	TrackerTestBackend* _tmp8_ = NULL;
	TrackerTestBackend* _tmp9_ = NULL;
	GMainLoop* _tmp10_ = NULL;
	GeeHashMap* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (self != NULL);
#line 42 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 42 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 42 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self->priv->_main_loop = _tmp0_;
#line 43 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 43 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	c1 = _tmp1_;
#line 44 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 44 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 44 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self->priv->_persona_fullname = _tmp2_;
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp3_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (self->priv->_urls);
#line 45 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self->priv->_urls = _tmp3_;
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp4_ = self->priv->_urls;
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp4_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG, "http://one.example.org");
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp5_ = self->priv->_urls;
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE, "http://two.example.org");
#line 50 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp6_ = self->priv->_urls;
#line 50 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER, "http://three.example.org");
#line 53 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp7_ = self->priv->_persona_fullname;
#line 53 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp7_);
#line 54 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp8_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 54 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 56 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 56 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_set_ur_ls_tests_test_set_urls_async (self, NULL, NULL);
#line 60 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp10_ = self->priv->_main_loop;
#line 60 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_test_utils_loop_run_with_timeout (_tmp10_, 5);
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp11_ = self->priv->_urls;
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp12_ = gee_abstract_map_get_size ((GeeMap*) _tmp11_);
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp13_ = _tmp12_;
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_vala_assert (_tmp13_ == 0, "this._urls.size == 0");
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (c1);
#line 220 "set-urls.c"
}


static void _set_ur_ls_tests_test_set_urls_async_data_free (gpointer _data) {
	SetUrLsTestsTestSetUrlsAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_slice_free (SetUrLsTestsTestSetUrlsAsyncData, _data_);
#line 231 "set-urls.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return self ? g_object_ref (self) : NULL;
#line 238 "set-urls.c"
}


static void _set_ur_ls_tests_test_set_urls_async (SetURLsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetUrLsTestsTestSetUrlsAsyncData* _data_;
	SetURLsTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_ = g_slice_new0 (SetUrLsTestsTestSetUrlsAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_ur_ls_tests_test_set_urls_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_ur_ls_tests_test_set_urls_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_set_ur_ls_tests_test_set_urls_async_co (_data_);
#line 257 "set-urls.c"
}


static void _set_ur_ls_tests_test_set_urls_finish (SetURLsTests* self, GAsyncResult* _res_) {
	SetUrLsTestsTestSetUrlsAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 265 "set-urls.c"
}


static void _set_ur_ls_tests_test_set_urls_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetUrLsTestsTestSetUrlsAsyncData* _data_;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_ = _user_data_;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_source_object_ = source_object;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_res_ = _res_;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_set_ur_ls_tests_test_set_urls_async_co (_data_);
#line 279 "set-urls.c"
}


static void __set_ur_ls_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_set_ur_ls_tests_individuals_changed_cb ((SetURLsTests*) self, changes);
#line 286 "set-urls.c"
}


static gboolean _set_ur_ls_tests_test_set_urls_async_co (SetUrLsTestsTestSetUrlsAsyncData* _data_) {
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	switch (_data_->_state_) {
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		case 0:
#line 295 "set-urls.c"
		goto _state_0;
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		case 1:
#line 299 "set-urls.c"
		goto _state_1;
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		case 2:
#line 303 "set-urls.c"
		goto _state_2;
		default:
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_assert_not_reached ();
#line 308 "set-urls.c"
	}
	_state_0:
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp0_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->store = _data_->_tmp0_;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_state_ = 1;
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_backend_store_prepare (_data_->store, _set_ur_ls_tests_test_set_urls_async_ready, _data_);
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return FALSE;
#line 323 "set-urls.c"
	_state_1:
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp1_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp2_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 70 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __set_ur_ls_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 341 "set-urls.c"
	{
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp3_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_state_ = 2;
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _set_ur_ls_tests_test_set_urls_async_ready, _data_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		return FALSE;
#line 353 "set-urls.c"
		_state_2:
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 359 "set-urls.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->e = _data_->_inner_error_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_inner_error_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp4_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp4_ = _data_->e;
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp5_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_warning ("set-urls.vala:78: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_g_error_free0 (_data_->e);
#line 382 "set-urls.c"
	}
	__finally0:
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_g_object_unref0 (_data_->store);
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_clear_error (&_data_->_inner_error_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		return FALSE;
#line 395 "set-urls.c"
	}
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (_data_->store);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	if (_data_->_state_ == 0) {
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 403 "set-urls.c"
	} else {
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 407 "set-urls.c"
	}
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_object_unref (_data_->_async_result);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return FALSE;
#line 413 "set-urls.c"
}


static void __set_ur_ls_tests_notify_urls_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_set_ur_ls_tests_notify_urls_cb ((SetURLsTests*) self, _sender, pspec);
#line 420 "set-urls.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return result;
#line 429 "set-urls.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return result;
#line 438 "set-urls.c"
}


static void _set_ur_ls_tests_individuals_changed_cb (SetURLsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp50_ = NULL;
	gint _tmp51_ = 0;
	gint _tmp52_ = 0;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (self != NULL);
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (changes != NULL);
#line 85 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp0_ = changes;
#line 85 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	added = _tmp1_;
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp2_ = changes;
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	removed = _tmp3_;
#line 468 "set-urls.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_tmp4_ = added;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_i_it = _tmp5_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		while (TRUE) {
#line 481 "set-urls.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp6_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			if (!_tmp7_) {
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				break;
#line 500 "set-urls.c"
			}
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp8_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			i = (FolksIndividual*) _tmp9_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp10_ = i;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp11_ = i;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp13_ = _tmp12_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp14_ = self->priv->_persona_fullname;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 522 "set-urls.c"
				FolksIndividual* _tmp15_ = NULL;
				GeeHashSet* url_fds = NULL;
				GeeHashSet* _tmp16_ = NULL;
				FolksUrlFieldDetails* p1 = NULL;
				GeeHashMap* _tmp17_ = NULL;
				gpointer _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				FolksUrlFieldDetails* _tmp20_ = NULL;
				FolksUrlFieldDetails* _tmp21_ = NULL;
				FolksUrlFieldDetails* _tmp22_ = NULL;
				GeeHashSet* _tmp23_ = NULL;
				FolksUrlFieldDetails* _tmp24_ = NULL;
				FolksUrlFieldDetails* p2 = NULL;
				GeeHashMap* _tmp25_ = NULL;
				gpointer _tmp26_ = NULL;
				gchar* _tmp27_ = NULL;
				FolksUrlFieldDetails* _tmp28_ = NULL;
				FolksUrlFieldDetails* _tmp29_ = NULL;
				FolksUrlFieldDetails* _tmp30_ = NULL;
				GeeHashSet* _tmp31_ = NULL;
				FolksUrlFieldDetails* _tmp32_ = NULL;
				FolksUrlFieldDetails* p3 = NULL;
				GeeHashMap* _tmp33_ = NULL;
				gpointer _tmp34_ = NULL;
				gchar* _tmp35_ = NULL;
				FolksUrlFieldDetails* _tmp36_ = NULL;
				FolksUrlFieldDetails* _tmp37_ = NULL;
				GeeHashSet* _tmp38_ = NULL;
				FolksUrlFieldDetails* _tmp39_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp15_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::urls", (GCallback) __set_ur_ls_tests_notify_urls_cb_g_object_notify, self, 0);
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp16_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				url_fds = _tmp16_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp17_ = self->priv->_urls;
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp18_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp17_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG);
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp19_ = (gchar*) _tmp18_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp20_ = folks_url_field_details_new (_tmp19_, NULL);
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp21_ = _tmp20_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_free0 (_tmp19_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				p1 = _tmp21_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp22_ = p1;
#line 101 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp22_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG);
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp23_ = url_fds;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp24_ = p1;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, _tmp24_);
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp25_ = self->priv->_urls;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp26_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp25_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE);
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp27_ = (gchar*) _tmp26_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp28_ = folks_url_field_details_new (_tmp27_, NULL);
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp29_ = _tmp28_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_free0 (_tmp27_);
#line 103 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				p2 = _tmp29_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp30_ = p2;
#line 105 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp30_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE);
#line 106 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp31_ = url_fds;
#line 106 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp32_ = p2;
#line 106 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp31_, _tmp32_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp33_ = self->priv->_urls;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp34_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp33_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp35_ = (gchar*) _tmp34_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp36_ = folks_url_field_details_new (_tmp35_, NULL);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp37_ = _tmp36_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_free0 (_tmp35_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				p3 = _tmp37_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp38_ = url_fds;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp39_ = p3;
#line 109 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp38_, _tmp39_);
#line 628 "set-urls.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp40_ = NULL;
					GeeSet* _tmp41_ = NULL;
					GeeSet* _tmp42_ = NULL;
					GeeIterator* _tmp43_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp40_ = i;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp41_ = folks_individual_get_personas (_tmp40_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp42_ = _tmp41_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp43_ = gee_iterable_iterator ((GeeIterable*) _tmp42_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_p_it = _tmp43_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					while (TRUE) {
#line 647 "set-urls.c"
						GeeIterator* _tmp44_ = NULL;
						gboolean _tmp45_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp46_ = NULL;
						gpointer _tmp47_ = NULL;
						FolksPersona* _tmp48_ = NULL;
						GeeHashSet* _tmp49_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp44_ = _p_it;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp45_ = gee_iterator_next (_tmp44_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						if (!_tmp45_) {
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							break;
#line 663 "set-urls.c"
						}
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp46_ = _p_it;
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp47_ = gee_iterator_get (_tmp46_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						p = (FolksPersona*) _tmp47_;
#line 113 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp48_ = p;
#line 113 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp49_ = url_fds;
#line 113 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						folks_url_details_set_urls (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, FOLKS_TYPE_URL_DETAILS, FolksUrlDetails), (GeeSet*) _tmp49_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_g_object_unref0 (p);
#line 679 "set-urls.c"
					}
#line 111 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_g_object_unref0 (_p_it);
#line 683 "set-urls.c"
				}
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (p3);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (p2);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (p1);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (url_fds);
#line 693 "set-urls.c"
			}
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_g_object_unref0 (i);
#line 697 "set-urls.c"
		}
#line 88 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_g_object_unref0 (_i_it);
#line 701 "set-urls.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp50_ = removed;
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp51_ = gee_collection_get_size ((GeeCollection*) _tmp50_);
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp52_ = _tmp51_;
#line 118 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_vala_assert (_tmp52_ == 1, "removed.size == 1");
#line 711 "set-urls.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp53_ = NULL;
		GeeIterator* _tmp54_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_tmp53_ = removed;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_tmp54_ = gee_iterable_iterator ((GeeIterable*) _tmp53_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_i_it = _tmp54_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		while (TRUE) {
#line 724 "set-urls.c"
			GeeIterator* _tmp55_ = NULL;
			gboolean _tmp56_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp57_ = NULL;
			gpointer _tmp58_ = NULL;
			FolksIndividual* _tmp59_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp55_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp56_ = gee_iterator_next (_tmp55_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			if (!_tmp56_) {
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				break;
#line 739 "set-urls.c"
			}
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp57_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp58_ = gee_iterator_get (_tmp57_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			i = (FolksIndividual*) _tmp58_;
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp59_ = i;
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_vala_assert (_tmp59_ == NULL, "i == null");
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_g_object_unref0 (i);
#line 753 "set-urls.c"
		}
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_g_object_unref0 (_i_it);
#line 757 "set-urls.c"
	}
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (removed);
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (added);
#line 763 "set-urls.c"
}


static void _set_ur_ls_tests_notify_urls_cb (SetURLsTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GeeHashMap* _tmp49_ = NULL;
	gint _tmp50_ = 0;
	gint _tmp51_ = 0;
#line 126 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (self != NULL);
#line 126 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (individual_obj != NULL);
#line 126 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_return_if_fail (ps != NULL);
#line 128 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp0_ = individual_obj;
#line 128 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 128 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	i = _tmp1_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp2_ = i;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp4_ = _tmp3_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp5_ = self->priv->_persona_fullname;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 800 "set-urls.c"
		{
			GeeIterator* _p_it = NULL;
			FolksIndividual* _tmp6_ = NULL;
			GeeSet* _tmp7_ = NULL;
			GeeSet* _tmp8_ = NULL;
			GeeIterator* _tmp9_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp6_ = i;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp7_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp6_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp8_ = _tmp7_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_tmp9_ = gee_iterable_iterator ((GeeIterable*) _tmp8_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_p_it = _tmp9_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			while (TRUE) {
#line 819 "set-urls.c"
				GeeIterator* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				FolksUrlFieldDetails* p = NULL;
				GeeIterator* _tmp12_ = NULL;
				gpointer _tmp13_ = NULL;
				GeeCollection* type_p = NULL;
				FolksUrlFieldDetails* _tmp14_ = NULL;
				GeeCollection* _tmp15_ = NULL;
				gboolean _tmp16_ = FALSE;
				gboolean _tmp17_ = FALSE;
				GeeCollection* _tmp18_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp10_ = _p_it;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp11_ = gee_iterator_next (_tmp10_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				if (!_tmp11_) {
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					break;
#line 839 "set-urls.c"
				}
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp12_ = _p_it;
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp13_ = gee_iterator_get (_tmp12_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				p = (FolksUrlFieldDetails*) _tmp13_;
#line 133 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp14_ = p;
#line 133 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp15_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp14_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 133 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				type_p = _tmp15_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_tmp18_ = type_p;
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				if (_tmp18_ != NULL) {
#line 857 "set-urls.c"
					GeeCollection* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp19_ = type_p;
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp20_ = gee_collection_contains (_tmp19_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG);
#line 136 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp17_ = _tmp20_;
#line 866 "set-urls.c"
				} else {
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp17_ = FALSE;
#line 870 "set-urls.c"
				}
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				if (_tmp17_) {
#line 874 "set-urls.c"
					FolksUrlFieldDetails* _tmp21_ = NULL;
					gconstpointer _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
					GeeHashMap* _tmp24_ = NULL;
					gpointer _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp21_ = p;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp22_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp21_);
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp23_ = _tmp22_;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp24_ = self->priv->_urls;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp25_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp24_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG);
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp26_ = (gchar*) _tmp25_;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp16_ = g_strcmp0 ((const gchar*) _tmp23_, _tmp26_) == 0;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_g_free0 (_tmp26_);
#line 897 "set-urls.c"
				} else {
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp16_ = FALSE;
#line 901 "set-urls.c"
				}
#line 135 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				if (_tmp16_) {
#line 905 "set-urls.c"
					GeeHashMap* _tmp27_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp27_ = self->priv->_urls;
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp27_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG, NULL);
#line 911 "set-urls.c"
				} else {
					gboolean _tmp28_ = FALSE;
					gboolean _tmp29_ = FALSE;
					GeeCollection* _tmp30_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					_tmp30_ = type_p;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					if (_tmp30_ != NULL) {
#line 920 "set-urls.c"
						GeeCollection* _tmp31_ = NULL;
						gboolean _tmp32_ = FALSE;
#line 142 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp31_ = type_p;
#line 142 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp32_ = gee_collection_contains (_tmp31_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE);
#line 142 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp29_ = _tmp32_;
#line 929 "set-urls.c"
					} else {
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp29_ = FALSE;
#line 933 "set-urls.c"
					}
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					if (_tmp29_) {
#line 937 "set-urls.c"
						FolksUrlFieldDetails* _tmp33_ = NULL;
						gconstpointer _tmp34_ = NULL;
						const gchar* _tmp35_ = NULL;
						GeeHashMap* _tmp36_ = NULL;
						gpointer _tmp37_ = NULL;
						gchar* _tmp38_ = NULL;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp33_ = p;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp34_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp33_);
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp35_ = _tmp34_;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp36_ = self->priv->_urls;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp37_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp36_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE);
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp38_ = (gchar*) _tmp37_;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp28_ = g_strcmp0 ((const gchar*) _tmp35_, _tmp38_) == 0;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_g_free0 (_tmp38_);
#line 960 "set-urls.c"
					} else {
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp28_ = FALSE;
#line 964 "set-urls.c"
					}
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
					if (_tmp28_) {
#line 968 "set-urls.c"
						GeeHashMap* _tmp39_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp39_ = self->priv->_urls;
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						gee_abstract_map_unset ((GeeAbstractMap*) _tmp39_, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE, NULL);
#line 974 "set-urls.c"
					} else {
						gboolean _tmp40_ = FALSE;
						GeeCollection* _tmp41_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						_tmp41_ = type_p;
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						if (_tmp41_ == NULL) {
#line 982 "set-urls.c"
							FolksUrlFieldDetails* _tmp42_ = NULL;
							gconstpointer _tmp43_ = NULL;
							const gchar* _tmp44_ = NULL;
							GeeHashMap* _tmp45_ = NULL;
							gpointer _tmp46_ = NULL;
							gchar* _tmp47_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp42_ = p;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp43_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp42_);
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp44_ = _tmp43_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp45_ = self->priv->_urls;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp46_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp45_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp47_ = (gchar*) _tmp46_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp40_ = g_strcmp0 ((const gchar*) _tmp44_, _tmp47_) == 0;
#line 148 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_g_free0 (_tmp47_);
#line 1005 "set-urls.c"
						} else {
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp40_ = FALSE;
#line 1009 "set-urls.c"
						}
#line 147 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
						if (_tmp40_) {
#line 1013 "set-urls.c"
							GeeHashMap* _tmp48_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							_tmp48_ = self->priv->_urls;
#line 150 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
							gee_abstract_map_unset ((GeeAbstractMap*) _tmp48_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER, NULL);
#line 1019 "set-urls.c"
						}
					}
				}
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (type_p);
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
				_g_object_unref0 (p);
#line 1027 "set-urls.c"
			}
#line 131 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
			_g_object_unref0 (_p_it);
#line 1031 "set-urls.c"
		}
	}
#line 155 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp49_ = self->priv->_urls;
#line 155 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp50_ = gee_abstract_map_get_size ((GeeMap*) _tmp49_);
#line 155 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp51_ = _tmp50_;
#line 155 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	if (_tmp51_ == 0) {
#line 1042 "set-urls.c"
		GMainLoop* _tmp52_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		_tmp52_ = self->priv->_main_loop;
#line 156 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
		g_main_loop_quit (_tmp52_);
#line 1048 "set-urls.c"
	}
#line 126 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (i);
#line 1052 "set-urls.c"
}


static void set_ur_ls_tests_class_init (SetURLsTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	set_ur_ls_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_type_class_add_private (klass, sizeof (SetURLsTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	G_OBJECT_CLASS (klass)->finalize = set_ur_ls_tests_finalize;
#line 1063 "set-urls.c"
}


static void set_ur_ls_tests_instance_init (SetURLsTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self->priv = SET_UR_LS_TESTS_GET_PRIVATE (self);
#line 1070 "set-urls.c"
}


static void set_ur_ls_tests_finalize (GObject* obj) {
	SetURLsTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_UR_LS_TESTS, SetURLsTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 31 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (self->priv->_urls);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	G_OBJECT_CLASS (set_ur_ls_tests_parent_class)->finalize (obj);
#line 1088 "set-urls.c"
}


GType set_ur_ls_tests_get_type (void) {
	static volatile gsize set_ur_ls_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_ur_ls_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetURLsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_ur_ls_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetURLsTests), 0, (GInstanceInitFunc) set_ur_ls_tests_instance_init, NULL };
		GType set_ur_ls_tests_type_id;
		set_ur_ls_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "SetURLsTests", &g_define_type_info, 0);
		g_once_init_leave (&set_ur_ls_tests_type_id__volatile, set_ur_ls_tests_type_id);
	}
	return set_ur_ls_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetURLsTests* tests = NULL;
	SetURLsTests* _tmp0_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_test_init (&args_length1, &args, NULL);
#line 164 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_tmp0_ = set_ur_ls_tests_new ();
#line 164 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	tests = _tmp0_;
#line 165 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 166 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	g_test_run ();
#line 167 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 169 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	result = 0;
#line 169 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	_g_object_unref0 (tests);
#line 169 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return result;
#line 1126 "set-urls.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-urls.vala"
	return _vala_main (argv, argc);
#line 1136 "set-urls.c"
}



