/* set-properties-race.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from set-properties-race.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <folks/folks-eds.h>


#define TYPE_SET_PROPERTIES_RACE_TESTS (set_properties_race_tests_get_type ())
#define SET_PROPERTIES_RACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_PROPERTIES_RACE_TESTS, SetPropertiesRaceTests))
#define SET_PROPERTIES_RACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_PROPERTIES_RACE_TESTS, SetPropertiesRaceTestsClass))
#define IS_SET_PROPERTIES_RACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_PROPERTIES_RACE_TESTS))
#define IS_SET_PROPERTIES_RACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_PROPERTIES_RACE_TESTS))
#define SET_PROPERTIES_RACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_PROPERTIES_RACE_TESTS, SetPropertiesRaceTestsClass))

typedef struct _SetPropertiesRaceTests SetPropertiesRaceTests;
typedef struct _SetPropertiesRaceTestsClass SetPropertiesRaceTestsClass;
typedef struct _SetPropertiesRaceTestsPrivate SetPropertiesRaceTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetPropertiesRaceTestsTestSetPostalAddressesAsyncData SetPropertiesRaceTestsTestSetPostalAddressesAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetPropertiesRaceTests {
	EdsTestTestCase parent_instance;
	SetPropertiesRaceTestsPrivate * priv;
};

struct _SetPropertiesRaceTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _SetPropertiesRaceTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
	FolksPostalAddressFieldDetails* _pa_fd;
};

struct _SetPropertiesRaceTestsTestSetPostalAddressesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetPropertiesRaceTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer set_properties_race_tests_parent_class = NULL;

GType set_properties_race_tests_get_type (void) G_GNUC_CONST;
#define SET_PROPERTIES_RACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_PROPERTIES_RACE_TESTS, SetPropertiesRaceTestsPrivate))
enum  {
	SET_PROPERTIES_RACE_TESTS_DUMMY_PROPERTY
};
SetPropertiesRaceTests* set_properties_race_tests_new (void);
SetPropertiesRaceTests* set_properties_race_tests_construct (GType object_type);
static void set_properties_race_tests_test_set_postal_addresses (SetPropertiesRaceTests* self);
static void _set_properties_race_tests_test_set_postal_addresses_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _set_properties_race_tests_test_set_postal_addresses_async (SetPropertiesRaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_properties_race_tests_test_set_postal_addresses_finish (SetPropertiesRaceTests* self, GAsyncResult* _res_);
static void _set_properties_race_tests_test_set_postal_addresses_async_data_free (gpointer _data);
static gboolean _set_properties_race_tests_test_set_postal_addresses_async_co (SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_);
static void _set_properties_race_tests_test_set_postal_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_properties_race_tests_individuals_changed_cb (SetPropertiesRaceTests* self, GeeMultiMap* changes);
static void __set_properties_race_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_properties_race_tests_notify_postal_addresses_cb (SetPropertiesRaceTests* self, GObject* persona_obj, GParamSpec* ps);
static void __set_properties_race_tests_notify_postal_addresses_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void set_properties_race_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_properties_race_tests_test_set_postal_addresses_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	set_properties_race_tests_test_set_postal_addresses ((SetPropertiesRaceTests*) self);
#line 119 "set-properties-race.c"
}


SetPropertiesRaceTests* set_properties_race_tests_construct (GType object_type) {
	SetPropertiesRaceTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self = (SetPropertiesRaceTests*) eds_test_test_case_construct (object_type, "SetPropertiesRace");
#line 37 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "setting postal addresss on e-d-s persona", _set_properties_race_tests_test_set_postal_addresses_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return self;
#line 131 "set-properties-race.c"
}


SetPropertiesRaceTests* set_properties_race_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return set_properties_race_tests_construct (TYPE_SET_PROPERTIES_RACE_TESTS);
#line 138 "set-properties-race.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 145 "set-properties-race.c"
}


static void _vala_GValue_free (GValue* self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_value_unset (self);
#line 43 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_free (self);
#line 154 "set-properties-race.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return self ? _g_value_dup (self) : NULL;
#line 161 "set-properties-race.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 61 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return self ? g_object_ref (self) : NULL;
#line 168 "set-properties-race.c"
}


static void set_properties_race_tests_test_set_postal_addresses (SetPropertiesRaceTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	GValue* v = NULL;
	FolksPostalAddress* pa = NULL;
	FolksPostalAddress* _tmp2_ = NULL;
	FolksPostalAddressFieldDetails* _tmp3_ = NULL;
	FolksPostalAddressFieldDetails* _tmp4_ = NULL;
	EdsTestBackend* _tmp5_ = NULL;
	GValue _tmp6_ = {0};
	GValue _tmp7_ = {0};
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	EdsTestBackend* _tmp12_ = NULL;
	GeeHashMap* _tmp13_ = NULL;
	GMainLoop* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
#line 41 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	c1 = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp1_ = g_main_loop_new (NULL, FALSE);
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self->priv->_main_loop = _tmp1_;
#line 46 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp2_ = folks_postal_address_new ("123", "extension", "street", "locality", "region", "postal code", "country", "", "123");
#line 46 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	pa = _tmp2_;
#line 49 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp3_ = folks_postal_address_field_details_new (pa, NULL);
#line 49 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (self->priv->_pa_fd);
#line 49 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self->priv->_pa_fd = _tmp3_;
#line 50 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp4_ = self->priv->_pa_fd;
#line 50 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp4_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 53 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self->priv->_found_before_update = FALSE;
#line 54 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self->priv->_found_after_update = FALSE;
#line 56 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp5_ = ((EdsTestTestCase*) self)->eds_backend;
#line 56 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	eds_test_backend_reset (_tmp5_);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_value_init (&_tmp6_, G_TYPE_STRING);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp7_ = _tmp6_;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp8_ = __g_value_dup0 (&_tmp7_);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	__vala_GValue_free0 (v);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	v = _tmp8_;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	G_IS_VALUE (&_tmp7_) ? (g_value_unset (&_tmp7_), NULL) : NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp9_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_value_set_string (_tmp9_, "bernie h. innocenti");
#line 60 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp10_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	v = NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp11_ = _tmp10_;
#line 60 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp11_);
#line 60 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	__vala_GValue_free0 (_tmp11_);
#line 61 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp12_ = ((EdsTestTestCase*) self)->eds_backend;
#line 61 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp13_ = _g_object_ref0 (c1);
#line 61 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	eds_test_backend_add_contact (_tmp12_, _tmp13_);
#line 63 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_set_properties_race_tests_test_set_postal_addresses_async (self, NULL, NULL);
#line 65 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp14_ = self->priv->_main_loop;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_test_utils_loop_run_with_timeout (_tmp14_, 5);
#line 67 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp15_ = self->priv->_found_before_update;
#line 67 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_vala_assert (_tmp15_, "this._found_before_update");
#line 68 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp16_ = self->priv->_found_after_update;
#line 68 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_vala_assert (_tmp16_, "this._found_after_update");
#line 41 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (pa);
#line 41 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	__vala_GValue_free0 (v);
#line 41 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (c1);
#line 279 "set-properties-race.c"
}


static void _set_properties_race_tests_test_set_postal_addresses_async_data_free (gpointer _data) {
	SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_slice_free (SetPropertiesRaceTestsTestSetPostalAddressesAsyncData, _data_);
#line 290 "set-properties-race.c"
}


static void _set_properties_race_tests_test_set_postal_addresses_async (SetPropertiesRaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_;
	SetPropertiesRaceTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_ = g_slice_new0 (SetPropertiesRaceTestsTestSetPostalAddressesAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_properties_race_tests_test_set_postal_addresses_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_properties_race_tests_test_set_postal_addresses_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_set_properties_race_tests_test_set_postal_addresses_async_co (_data_);
#line 309 "set-properties-race.c"
}


static void _set_properties_race_tests_test_set_postal_addresses_finish (SetPropertiesRaceTests* self, GAsyncResult* _res_) {
	SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 317 "set-properties-race.c"
}


static void _set_properties_race_tests_test_set_postal_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_ = _user_data_;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_source_object_ = source_object;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_res_ = _res_;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_set_properties_race_tests_test_set_postal_addresses_async_co (_data_);
#line 331 "set-properties-race.c"
}


static void __set_properties_race_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_set_properties_race_tests_individuals_changed_cb ((SetPropertiesRaceTests*) self, changes);
#line 338 "set-properties-race.c"
}


static gboolean _set_properties_race_tests_test_set_postal_addresses_async_co (SetPropertiesRaceTestsTestSetPostalAddressesAsyncData* _data_) {
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	switch (_data_->_state_) {
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		case 0:
#line 347 "set-properties-race.c"
		goto _state_0;
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		case 1:
#line 351 "set-properties-race.c"
		goto _state_1;
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		case 2:
#line 355 "set-properties-race.c"
		goto _state_2;
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		case 3:
#line 359 "set-properties-race.c"
		goto _state_3;
		default:
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_assert_not_reached ();
#line 364 "set-properties-race.c"
	}
	_state_0:
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp0_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_state_ = 1;
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _set_properties_race_tests_test_set_postal_addresses_async_ready, _data_);
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return FALSE;
#line 377 "set-properties-race.c"
	_state_1:
#line 73 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 75 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp1_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 75 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->store = _data_->_tmp1_;
#line 76 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_state_ = 2;
#line 76 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_backend_store_prepare (_data_->store, _set_properties_race_tests_test_set_postal_addresses_async_ready, _data_);
#line 76 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return FALSE;
#line 393 "set-properties-race.c"
	_state_2:
#line 76 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 77 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp2_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 77 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 77 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp3_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __set_properties_race_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 411 "set-properties-race.c"
	{
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp4_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_state_ = 3;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _set_properties_race_tests_test_set_postal_addresses_async_ready, _data_);
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		return FALSE;
#line 423 "set-properties-race.c"
		_state_3:
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 429 "set-properties-race.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->e = _data_->_inner_error_;
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_inner_error_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp5_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp5_ = _data_->e;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp6_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_warning ("set-properties-race.vala:86: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_g_error_free0 (_data_->e);
#line 452 "set-properties-race.c"
	}
	__finally0:
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_g_object_unref0 (_data_->store);
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_clear_error (&_data_->_inner_error_);
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		return FALSE;
#line 465 "set-properties-race.c"
	}
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (_data_->store);
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	if (_data_->_state_ == 0) {
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 473 "set-properties-race.c"
	} else {
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 477 "set-properties-race.c"
	}
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_object_unref (_data_->_async_result);
#line 71 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return FALSE;
#line 483 "set-properties-race.c"
}


static void __set_properties_race_tests_notify_postal_addresses_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 108 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_set_properties_race_tests_notify_postal_addresses_cb ((SetPropertiesRaceTests*) self, _sender, pspec);
#line 490 "set-properties-race.c"
}


static void _set_properties_race_tests_individuals_changed_cb (SetPropertiesRaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	gint _tmp36_ = 0;
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (self != NULL);
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (changes != NULL);
#line 93 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp0_ = changes;
#line 93 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 93 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	added = _tmp1_;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp2_ = changes;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	removed = _tmp3_;
#line 520 "set-properties-race.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp4_ = added;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_i_it = _tmp5_;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		while (TRUE) {
#line 533 "set-properties-race.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksNameDetails* name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksNameDetails* _tmp12_ = NULL;
			FolksNameDetails* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp6_ = _i_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			if (!_tmp7_) {
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				break;
#line 554 "set-properties-race.c"
			}
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp8_ = _i_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			i = (FolksIndividual*) _tmp9_;
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp10_ = i;
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 100 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp11_ = i;
#line 100 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 100 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			name = _tmp12_;
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp13_ = name;
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp14_ = folks_name_details_get_full_name (_tmp13_);
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp15_ = _tmp14_;
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			if (g_strcmp0 (_tmp15_, "bernie h. innocenti") == 0) {
#line 104 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				self->priv->_found_before_update = TRUE;
#line 582 "set-properties-race.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeSet* _tmp18_ = NULL;
					GeeIterator* _tmp19_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_tmp16_ = i;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_tmp17_ = folks_individual_get_personas (_tmp16_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_tmp18_ = _tmp17_;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_p_it = _tmp19_;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					while (TRUE) {
#line 601 "set-properties-race.c"
						GeeIterator* _tmp20_ = NULL;
						gboolean _tmp21_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp22_ = NULL;
						gpointer _tmp23_ = NULL;
						FolksPersona* _tmp24_ = NULL;
						GeeHashSet* pa_fds = NULL;
						GeeHashSet* _tmp25_ = NULL;
						FolksPostalAddress* pa_1 = NULL;
						FolksPostalAddress* _tmp26_ = NULL;
						FolksPostalAddressFieldDetails* pa_fd_1 = NULL;
						FolksPostalAddress* _tmp27_ = NULL;
						FolksPostalAddressFieldDetails* _tmp28_ = NULL;
						FolksPostalAddressFieldDetails* _tmp29_ = NULL;
						GeeHashSet* _tmp30_ = NULL;
						FolksPostalAddressFieldDetails* _tmp31_ = NULL;
						FolksPersona* _tmp32_ = NULL;
						GeeHashSet* _tmp33_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp20_ = _p_it;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp21_ = gee_iterator_next (_tmp20_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						if (!_tmp21_) {
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
							break;
#line 628 "set-properties-race.c"
						}
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp22_ = _p_it;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp23_ = gee_iterator_get (_tmp22_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						p = (FolksPersona*) _tmp23_;
#line 108 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp24_ = p;
#line 108 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						g_signal_connect_object ((GObject*) _tmp24_, "notify::postal-addresses", (GCallback) __set_properties_race_tests_notify_postal_addresses_cb_g_object_notify, self, 0);
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp25_ = gee_hash_set_new (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						pa_fds = _tmp25_;
#line 111 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp26_ = folks_postal_address_new ("123", "extension", "street", "locality", "region", "postal code", "country", "format", "123");
#line 111 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						pa_1 = _tmp26_;
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp27_ = pa_1;
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp28_ = folks_postal_address_field_details_new (_tmp27_, NULL);
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						pa_fd_1 = _tmp28_;
#line 115 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp29_ = pa_fd_1;
#line 115 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp29_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 117 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp30_ = pa_fds;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp31_ = pa_fd_1;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 118 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp32_ = p;
#line 118 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_tmp33_ = pa_fds;
#line 118 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						folks_postal_address_details_set_postal_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, FOLKS_TYPE_POSTAL_ADDRESS_DETAILS, FolksPostalAddressDetails), (GeeSet*) _tmp33_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_g_object_unref0 (pa_fd_1);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_g_object_unref0 (pa_1);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_g_object_unref0 (pa_fds);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
						_g_object_unref0 (p);
#line 678 "set-properties-race.c"
					}
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
					_g_object_unref0 (_p_it);
#line 682 "set-properties-race.c"
				}
			}
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_g_object_unref0 (name);
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_g_object_unref0 (i);
#line 689 "set-properties-race.c"
		}
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_g_object_unref0 (_i_it);
#line 693 "set-properties-race.c"
	}
#line 123 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp34_ = removed;
#line 123 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 123 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp36_ = _tmp35_;
#line 123 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_vala_assert (_tmp36_ == 1, "removed.size == 1");
#line 703 "set-properties-race.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp37_ = NULL;
		GeeIterator* _tmp38_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp37_ = removed;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_i_it = _tmp38_;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		while (TRUE) {
#line 716 "set-properties-race.c"
			GeeIterator* _tmp39_ = NULL;
			gboolean _tmp40_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp41_ = NULL;
			gpointer _tmp42_ = NULL;
			FolksIndividual* _tmp43_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp39_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp40_ = gee_iterator_next (_tmp39_);
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			if (!_tmp40_) {
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				break;
#line 731 "set-properties-race.c"
			}
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp41_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp42_ = gee_iterator_get (_tmp41_);
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			i = (FolksIndividual*) _tmp42_;
#line 127 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp43_ = i;
#line 127 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_vala_assert (_tmp43_ == NULL, "i == null");
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_g_object_unref0 (i);
#line 745 "set-properties-race.c"
		}
#line 125 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_g_object_unref0 (_i_it);
#line 749 "set-properties-race.c"
	}
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (removed);
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (added);
#line 755 "set-properties-race.c"
}


static void _set_properties_race_tests_notify_postal_addresses_cb (SetPropertiesRaceTests* self, GObject* persona_obj, GParamSpec* ps) {
	EdsfPersona* p = NULL;
	GObject* _tmp0_ = NULL;
	EdsfPersona* _tmp1_ = NULL;
	EdsfPersona* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
#line 131 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (self != NULL);
#line 131 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (persona_obj != NULL);
#line 131 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_return_if_fail (ps != NULL);
#line 133 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp0_ = persona_obj;
#line 133 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, EDSF_TYPE_PERSONA, EdsfPersona));
#line 133 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	p = _tmp1_;
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp2_ = p;
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp3_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp2_);
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp4_ = _tmp3_;
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp6_ = _tmp5_;
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_vala_assert (_tmp6_ == 1, "p.postal_addresses.size == 1");
#line 792 "set-properties-race.c"
	{
		GeeIterator* _pa_fd_it = NULL;
		EdsfPersona* _tmp7_ = NULL;
		GeeSet* _tmp8_ = NULL;
		GeeSet* _tmp9_ = NULL;
		GeeIterator* _tmp10_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp7_ = p;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp8_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp7_);
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp9_ = _tmp8_;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_tmp10_ = gee_iterable_iterator ((GeeIterable*) _tmp9_);
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_pa_fd_it = _tmp10_;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		while (TRUE) {
#line 811 "set-properties-race.c"
			GeeIterator* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			FolksPostalAddressFieldDetails* pa_fd = NULL;
			GeeIterator* _tmp13_ = NULL;
			gpointer _tmp14_ = NULL;
			FolksPostalAddressFieldDetails* _tmp15_ = NULL;
			FolksPostalAddressFieldDetails* _tmp16_ = NULL;
			gconstpointer _tmp17_ = NULL;
			FolksPostalAddress* _tmp18_ = NULL;
			FolksPostalAddressFieldDetails* _tmp19_ = NULL;
			FolksPostalAddressFieldDetails* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			FolksPostalAddressFieldDetails* _tmp23_ = NULL;
			FolksPostalAddressFieldDetails* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp11_ = _pa_fd_it;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp12_ = gee_iterator_next (_tmp11_);
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			if (!_tmp12_) {
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				break;
#line 836 "set-properties-race.c"
			}
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp13_ = _pa_fd_it;
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp14_ = gee_iterator_get (_tmp13_);
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			pa_fd = (FolksPostalAddressFieldDetails*) _tmp14_;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp15_ = pa_fd;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS), "pa_fd is PostalAddressFieldDetails");
#line 142 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp16_ = pa_fd;
#line 142 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp17_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp16_);
#line 142 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp18_ = _tmp17_;
#line 142 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE ((FolksPostalAddress*) _tmp18_, FOLKS_TYPE_POSTAL_ADDRESS), "pa_fd.value is PostalAddress");
#line 144 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp19_ = pa_fd;
#line 144 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp20_ = self->priv->_pa_fd;
#line 144 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp21_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp20_);
#line 144 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp22_ = _tmp21_;
#line 144 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp19_, _tmp22_);
#line 145 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp23_ = pa_fd;
#line 145 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp24_ = self->priv->_pa_fd;
#line 145 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_tmp25_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp23_, (FolksAbstractFieldDetails*) _tmp24_);
#line 145 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			if (_tmp25_) {
#line 874 "set-properties-race.c"
				GMainLoop* _tmp26_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				self->priv->_found_after_update = TRUE;
#line 148 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				_tmp26_ = self->priv->_main_loop;
#line 148 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
				g_main_loop_quit (_tmp26_);
#line 882 "set-properties-race.c"
			}
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
			_g_object_unref0 (pa_fd);
#line 886 "set-properties-race.c"
		}
#line 138 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
		_g_object_unref0 (_pa_fd_it);
#line 890 "set-properties-race.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (p);
#line 894 "set-properties-race.c"
}


static void set_properties_race_tests_class_init (SetPropertiesRaceTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	set_properties_race_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_type_class_add_private (klass, sizeof (SetPropertiesRaceTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	G_OBJECT_CLASS (klass)->finalize = set_properties_race_tests_finalize;
#line 905 "set-properties-race.c"
}


static void set_properties_race_tests_instance_init (SetPropertiesRaceTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self->priv = SET_PROPERTIES_RACE_TESTS_GET_PRIVATE (self);
#line 912 "set-properties-race.c"
}


static void set_properties_race_tests_finalize (GObject* obj) {
	SetPropertiesRaceTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_PROPERTIES_RACE_TESTS, SetPropertiesRaceTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 28 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (self->priv->_pa_fd);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	G_OBJECT_CLASS (set_properties_race_tests_parent_class)->finalize (obj);
#line 928 "set-properties-race.c"
}


GType set_properties_race_tests_get_type (void) {
	static volatile gsize set_properties_race_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_properties_race_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetPropertiesRaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_properties_race_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetPropertiesRaceTests), 0, (GInstanceInitFunc) set_properties_race_tests_instance_init, NULL };
		GType set_properties_race_tests_type_id;
		set_properties_race_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "SetPropertiesRaceTests", &g_define_type_info, 0);
		g_once_init_leave (&set_properties_race_tests_type_id__volatile, set_properties_race_tests_type_id);
	}
	return set_properties_race_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetPropertiesRaceTests* tests = NULL;
	SetPropertiesRaceTests* _tmp0_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_test_init (&args_length1, &args, NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_tmp0_ = set_properties_race_tests_new ();
#line 158 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	tests = _tmp0_;
#line 159 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 160 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	g_test_run ();
#line 161 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 163 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	result = 0;
#line 163 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	_g_object_unref0 (tests);
#line 163 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return result;
#line 966 "set-properties-race.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 154 "/opt/gnome3/source/folks/tests/eds/set-properties-race.vala"
	return _vala_main (argv, argc);
#line 976 "set-properties-race.c"
}



