/* name-details.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from name-details.vala, do not modify */

/*
 * Copyright (C) 2011, 2015 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>


#define TYPE_NAME_DETAILS_TESTS (name_details_tests_get_type ())
#define NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTests))
#define NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))
#define IS_NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_DETAILS_TESTS))
#define IS_NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_DETAILS_TESTS))
#define NAME_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))

typedef struct _NameDetailsTests NameDetailsTests;
typedef struct _NameDetailsTestsClass NameDetailsTestsClass;
typedef struct _NameDetailsTestsPrivate NameDetailsTestsPrivate;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NameDetailsTests {
	EdsTestTestCase parent_instance;
	NameDetailsTestsPrivate * priv;
};

struct _NameDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};


static gpointer name_details_tests_parent_class = NULL;

GType name_details_tests_get_type (void) G_GNUC_CONST;
enum  {
	NAME_DETAILS_TESTS_DUMMY_PROPERTY
};
NameDetailsTests* name_details_tests_new (void);
NameDetailsTests* name_details_tests_construct (GType object_type);
void name_details_tests_test_names (NameDetailsTests* self);
static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name_details_tests_test_names ((NameDetailsTests*) self);
#line 81 "name-details.c"
}


NameDetailsTests* name_details_tests_construct (GType object_type) {
	NameDetailsTests * self = NULL;
#line 30 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self = (NameDetailsTests*) eds_test_test_case_construct (object_type, "NameDetails");
#line 32 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "name details interface", _name_details_tests_test_names_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 28 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self;
#line 93 "name-details.c"
}


NameDetailsTests* name_details_tests_new (void) {
#line 28 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return name_details_tests_construct (TYPE_NAME_DETAILS_TESTS);
#line 100 "name-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 107 "name-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_unset (self);
#line 38 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_free (self);
#line 116 "name-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 123 "name-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 130 "name-details.c"
}


void name_details_tests_test_names (NameDetailsTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* c2 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue* v = NULL;
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	GValue* _tmp4_ = NULL;
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue _tmp8_ = {0};
	GValue _tmp9_ = {0};
	GValue* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GValue _tmp14_ = {0};
	GValue _tmp15_ = {0};
	GValue* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	GValue* _tmp19_ = NULL;
	GValue _tmp20_ = {0};
	GValue _tmp21_ = {0};
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue _tmp26_ = {0};
	GValue _tmp27_ = {0};
	GValue* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GValue _tmp32_ = {0};
	GValue _tmp33_ = {0};
	GValue* _tmp34_ = NULL;
	GValue* _tmp35_ = NULL;
	GValue* _tmp36_ = NULL;
	GValue* _tmp37_ = NULL;
	GValue _tmp38_ = {0};
	GValue _tmp39_ = {0};
	GValue* _tmp40_ = NULL;
	GValue* _tmp41_ = NULL;
	GValue* _tmp42_ = NULL;
	GValue* _tmp43_ = NULL;
	EdsTestBackend* _tmp44_ = NULL;
	GeeHashMap* _tmp45_ = NULL;
	GValue _tmp46_ = {0};
	GValue _tmp47_ = {0};
	GValue* _tmp48_ = NULL;
	GValue* _tmp49_ = NULL;
	GValue* _tmp50_ = NULL;
	GValue* _tmp51_ = NULL;
	GValue _tmp52_ = {0};
	GValue _tmp53_ = {0};
	GValue* _tmp54_ = NULL;
	GValue* _tmp55_ = NULL;
	GValue* _tmp56_ = NULL;
	GValue* _tmp57_ = NULL;
	GValue _tmp58_ = {0};
	GValue _tmp59_ = {0};
	GValue* _tmp60_ = NULL;
	GValue* _tmp61_ = NULL;
	GValue* _tmp62_ = NULL;
	GValue* _tmp63_ = NULL;
	EdsTestBackend* _tmp64_ = NULL;
	GeeHashMap* _tmp65_ = NULL;
	EdsTestBackend* _tmp66_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp67_ = NULL;
	gchar* _tmp68_ = NULL;
	gchar* _tmp69_ = NULL;
	gchar** _tmp70_ = NULL;
	gchar** _tmp71_ = NULL;
	gint _tmp71__length1 = 0;
	gchar* s = NULL;
	FolksIndividual* i1 = NULL;
	FolksIndividual* _tmp72_ = NULL;
	FolksNameDetails* name1 = NULL;
	FolksNameDetails* _tmp73_ = NULL;
	FolksStructuredName* _tmp74_ = NULL;
	FolksStructuredName* _tmp75_ = NULL;
	gboolean _tmp76_ = FALSE;
	gpointer _tmp77_ = NULL;
	GValue* _tmp78_ = NULL;
	GValue _tmp79_ = {0};
	const gchar* _tmp80_ = NULL;
	gchar* _tmp81_ = NULL;
	const gchar* _tmp82_ = NULL;
	const gchar* _tmp83_ = NULL;
	const gchar* _tmp84_ = NULL;
	gpointer _tmp85_ = NULL;
	GValue* _tmp86_ = NULL;
	GValue _tmp87_ = {0};
	const gchar* _tmp88_ = NULL;
	gchar* _tmp89_ = NULL;
	const gchar* _tmp90_ = NULL;
	const gchar* _tmp91_ = NULL;
	const gchar* _tmp92_ = NULL;
	gpointer _tmp93_ = NULL;
	GValue* _tmp94_ = NULL;
	GValue _tmp95_ = {0};
	const gchar* _tmp96_ = NULL;
	gchar* _tmp97_ = NULL;
	FolksStructuredName* _tmp98_ = NULL;
	FolksStructuredName* _tmp99_ = NULL;
	const gchar* _tmp100_ = NULL;
	const gchar* _tmp101_ = NULL;
	const gchar* _tmp102_ = NULL;
	gpointer _tmp103_ = NULL;
	GValue* _tmp104_ = NULL;
	GValue _tmp105_ = {0};
	const gchar* _tmp106_ = NULL;
	gchar* _tmp107_ = NULL;
	FolksStructuredName* _tmp108_ = NULL;
	FolksStructuredName* _tmp109_ = NULL;
	const gchar* _tmp110_ = NULL;
	const gchar* _tmp111_ = NULL;
	const gchar* _tmp112_ = NULL;
	gpointer _tmp113_ = NULL;
	GValue* _tmp114_ = NULL;
	GValue _tmp115_ = {0};
	const gchar* _tmp116_ = NULL;
	gchar* _tmp117_ = NULL;
	FolksStructuredName* _tmp118_ = NULL;
	FolksStructuredName* _tmp119_ = NULL;
	const gchar* _tmp120_ = NULL;
	const gchar* _tmp121_ = NULL;
	const gchar* _tmp122_ = NULL;
	gpointer _tmp123_ = NULL;
	GValue* _tmp124_ = NULL;
	GValue _tmp125_ = {0};
	const gchar* _tmp126_ = NULL;
	gchar* _tmp127_ = NULL;
	FolksStructuredName* _tmp128_ = NULL;
	FolksStructuredName* _tmp129_ = NULL;
	const gchar* _tmp130_ = NULL;
	const gchar* _tmp131_ = NULL;
	const gchar* _tmp132_ = NULL;
	gpointer _tmp133_ = NULL;
	GValue* _tmp134_ = NULL;
	GValue _tmp135_ = {0};
	const gchar* _tmp136_ = NULL;
	gchar* _tmp137_ = NULL;
	FolksStructuredName* _tmp138_ = NULL;
	FolksStructuredName* _tmp139_ = NULL;
	const gchar* _tmp140_ = NULL;
	const gchar* _tmp141_ = NULL;
	const gchar* _tmp142_ = NULL;
	gint _tmp143_ = 0;
	gint _tmp144_ = 0;
	FolksIndividual* i2 = NULL;
	FolksIndividual* _tmp145_ = NULL;
	FolksNameDetails* name2 = NULL;
	FolksNameDetails* _tmp146_ = NULL;
	FolksStructuredName* _tmp147_ = NULL;
	FolksStructuredName* _tmp148_ = NULL;
	gboolean _tmp149_ = FALSE;
	gpointer _tmp150_ = NULL;
	GValue* _tmp151_ = NULL;
	GValue _tmp152_ = {0};
	const gchar* _tmp153_ = NULL;
	gchar* _tmp154_ = NULL;
	const gchar* _tmp155_ = NULL;
	const gchar* _tmp156_ = NULL;
	const gchar* _tmp157_ = NULL;
	gpointer _tmp158_ = NULL;
	GValue* _tmp159_ = NULL;
	GValue _tmp160_ = {0};
	const gchar* _tmp161_ = NULL;
	gchar* _tmp162_ = NULL;
	FolksStructuredName* _tmp163_ = NULL;
	FolksStructuredName* _tmp164_ = NULL;
	const gchar* _tmp165_ = NULL;
	const gchar* _tmp166_ = NULL;
	const gchar* _tmp167_ = NULL;
	gpointer _tmp168_ = NULL;
	GValue* _tmp169_ = NULL;
	GValue _tmp170_ = {0};
	const gchar* _tmp171_ = NULL;
	gchar* _tmp172_ = NULL;
	FolksStructuredName* _tmp173_ = NULL;
	FolksStructuredName* _tmp174_ = NULL;
	const gchar* _tmp175_ = NULL;
	const gchar* _tmp176_ = NULL;
	const gchar* _tmp177_ = NULL;
	gint _tmp178_ = 0;
	gint _tmp179_ = 0;
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (self != NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	c1 = _tmp0_;
#line 39 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 39 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	c2 = _tmp1_;
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp2_, G_TYPE_STRING);
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp3_ = _tmp2_;
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp4_ = __g_value_dup0 (&_tmp3_);
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp4_;
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp3_) ? (g_value_unset (&_tmp3_), NULL) : NULL;
#line 44 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp5_ = v;
#line 44 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp5_, "bernie h. innocenti");
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp6_ = v;
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp7_ = _tmp6_;
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp7_);
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp7_);
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp8_, G_TYPE_STRING);
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp9_ = _tmp8_;
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp10_ = __g_value_dup0 (&_tmp9_);
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp10_;
#line 46 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp9_) ? (g_value_unset (&_tmp9_), NULL) : NULL;
#line 47 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp11_ = v;
#line 47 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp11_, "bernie");
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp12_ = v;
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp13_ = _tmp12_;
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "nickname", _tmp13_);
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp13_);
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp14_, G_TYPE_STRING);
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp15_ = _tmp14_;
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp16_ = __g_value_dup0 (&_tmp15_);
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp16_;
#line 49 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp15_) ? (g_value_unset (&_tmp15_), NULL) : NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp17_ = v;
#line 50 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp17_, "Innocenti");
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp18_ = v;
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp19_ = _tmp18_;
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "contact_name_family", _tmp19_);
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp19_);
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp20_, G_TYPE_STRING);
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp21_ = _tmp20_;
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp22_ = __g_value_dup0 (&_tmp21_);
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp22_;
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp21_) ? (g_value_unset (&_tmp21_), NULL) : NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp23_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp23_, "Bernardo");
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp24_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp25_ = _tmp24_;
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "contact_name_given", _tmp25_);
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp25_);
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp26_, G_TYPE_STRING);
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp27_ = _tmp26_;
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp28_ = __g_value_dup0 (&_tmp27_);
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp28_;
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp27_) ? (g_value_unset (&_tmp27_), NULL) : NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp29_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp29_, "H.");
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp30_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp31_ = _tmp30_;
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "contact_name_additional", _tmp31_);
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp31_);
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp32_, G_TYPE_STRING);
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp33_ = _tmp32_;
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp34_ = __g_value_dup0 (&_tmp33_);
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp34_;
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp33_) ? (g_value_unset (&_tmp33_), NULL) : NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp35_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp35_, "Mr.");
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp36_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp37_ = _tmp36_;
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "contact_name_prefixes", _tmp37_);
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp37_);
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp38_, G_TYPE_STRING);
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp39_ = _tmp38_;
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp40_ = __g_value_dup0 (&_tmp39_);
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp40_;
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp39_) ? (g_value_unset (&_tmp39_), NULL) : NULL;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp41_ = v;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp41_, "(sysadmin FSF)");
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp42_ = v;
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp43_ = _tmp42_;
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "contact_name_suffixes", _tmp43_);
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp43_);
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp44_ = ((EdsTestTestCase*) self)->eds_backend;
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp45_ = _g_object_ref0 (c1);
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp44_, _tmp45_);
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp46_, G_TYPE_STRING);
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp47_ = _tmp46_;
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp48_ = __g_value_dup0 (&_tmp47_);
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp48_;
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp47_) ? (g_value_unset (&_tmp47_), NULL) : NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp49_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp49_, "richard m. stallman");
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp50_ = v;
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp51_ = _tmp50_;
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, "full_name", _tmp51_);
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp51_);
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp52_, G_TYPE_STRING);
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp53_ = _tmp52_;
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp54_ = __g_value_dup0 (&_tmp53_);
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp54_;
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp53_) ? (g_value_unset (&_tmp53_), NULL) : NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp55_ = v;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp55_, "Stallman");
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp56_ = v;
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp57_ = _tmp56_;
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, "contact_name_family", _tmp57_);
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp57_);
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp58_, G_TYPE_STRING);
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp59_ = _tmp58_;
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp60_ = __g_value_dup0 (&_tmp59_);
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp60_;
#line 73 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp59_) ? (g_value_unset (&_tmp59_), NULL) : NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp61_ = v;
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp61_, "Richard M.");
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp62_ = v;
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp63_ = _tmp62_;
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, "contact_name_given", _tmp63_);
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp63_);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp64_ = ((EdsTestTestCase*) self)->eds_backend;
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp65_ = _g_object_ref0 (c2);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp64_, _tmp65_);
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp66_ = ((EdsTestTestCase*) self)->eds_backend;
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_sync (_tmp66_);
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp67_ = folks_individual_aggregator_dup ();
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	aggregator = _tmp67_;
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp68_ = g_strdup ("bernie h. innocenti");
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp69_ = g_strdup ("richard m. stallman");
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp70_ = g_new0 (gchar*, 2 + 1);
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp70_[0] = _tmp68_;
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp70_[1] = _tmp69_;
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp71_ = _tmp70_;
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp71__length1 = 2;
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_individuals_sync_with_timeout (aggregator, _tmp71_, 2, 5);
#line 84 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp71_ = (_vala_array_free (_tmp71_, _tmp71__length1, (GDestroyNotify) g_free), NULL);
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp72_ = folks_test_utils_get_individual_by_name (aggregator, "bernie h. innocenti");
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	i1 = _tmp72_;
#line 92 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp73_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (i1, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 92 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name1 = _tmp73_;
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp74_ = folks_name_details_get_structured_name (name1);
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp75_ = _tmp74_;
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp76_ = folks_structured_name_is_empty (_tmp75_);
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp76_ == FALSE, "name1.structured_name.is_empty () == false");
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp77_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "full_name");
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp78_ = (GValue*) _tmp77_;
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp79_ = *_tmp78_;
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp80_ = g_value_get_string (&_tmp79_);
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp81_ = g_strdup (_tmp80_);
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp81_;
#line 96 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp78_);
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp82_ = folks_name_details_get_full_name (name1);
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp83_ = _tmp82_;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp84_ = s;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp83_, _tmp84_) == 0, "name1.full_name == s");
#line 98 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "full_name", NULL);
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp85_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "nickname");
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp86_ = (GValue*) _tmp85_;
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp87_ = *_tmp86_;
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp88_ = g_value_get_string (&_tmp87_);
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp89_ = g_strdup (_tmp88_);
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp89_;
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp86_);
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp90_ = folks_name_details_get_nickname (name1);
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp91_ = _tmp90_;
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp92_ = s;
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp91_, _tmp92_) == 0, "name1.nickname == s");
#line 102 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "nickname", NULL);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp93_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "contact_name_family");
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp94_ = (GValue*) _tmp93_;
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp95_ = *_tmp94_;
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp96_ = g_value_get_string (&_tmp95_);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp97_ = g_strdup (_tmp96_);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp97_;
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp94_);
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp98_ = folks_name_details_get_structured_name (name1);
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp99_ = _tmp98_;
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp100_ = folks_structured_name_get_family_name (_tmp99_);
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp101_ = _tmp100_;
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp102_ = s;
#line 105 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp101_, _tmp102_) == 0, "name1.structured_name.family_name == s");
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "contact_name_family", NULL);
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp103_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "contact_name_given");
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp104_ = (GValue*) _tmp103_;
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp105_ = *_tmp104_;
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp106_ = g_value_get_string (&_tmp105_);
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp107_ = g_strdup (_tmp106_);
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp107_;
#line 108 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp104_);
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp108_ = folks_name_details_get_structured_name (name1);
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp109_ = _tmp108_;
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp110_ = folks_structured_name_get_given_name (_tmp109_);
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp111_ = _tmp110_;
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp112_ = s;
#line 109 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp111_, _tmp112_) == 0, "name1.structured_name.given_name == s");
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "contact_name_given", NULL);
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp113_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "contact_name_additional");
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp114_ = (GValue*) _tmp113_;
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp115_ = *_tmp114_;
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp116_ = g_value_get_string (&_tmp115_);
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp117_ = g_strdup (_tmp116_);
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp117_;
#line 112 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp114_);
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp118_ = folks_name_details_get_structured_name (name1);
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp119_ = _tmp118_;
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp120_ = folks_structured_name_get_additional_names (_tmp119_);
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp121_ = _tmp120_;
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp122_ = s;
#line 113 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp121_, _tmp122_) == 0, "name1.structured_name.additional_names == s");
#line 114 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "contact_name_additional", NULL);
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp123_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "contact_name_prefixes");
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp124_ = (GValue*) _tmp123_;
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp125_ = *_tmp124_;
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp126_ = g_value_get_string (&_tmp125_);
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp127_ = g_strdup (_tmp126_);
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp127_;
#line 116 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp124_);
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp128_ = folks_name_details_get_structured_name (name1);
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp129_ = _tmp128_;
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp130_ = folks_structured_name_get_prefixes (_tmp129_);
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp131_ = _tmp130_;
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp132_ = s;
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp131_, _tmp132_) == 0, "name1.structured_name.prefixes == s");
#line 118 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "contact_name_prefixes", NULL);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp133_ = gee_abstract_map_get ((GeeAbstractMap*) c1, "contact_name_suffixes");
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp134_ = (GValue*) _tmp133_;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp135_ = *_tmp134_;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp136_ = g_value_get_string (&_tmp135_);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp137_ = g_strdup (_tmp136_);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp137_;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp134_);
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp138_ = folks_name_details_get_structured_name (name1);
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp139_ = _tmp138_;
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp140_ = folks_structured_name_get_suffixes (_tmp139_);
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp141_ = _tmp140_;
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp142_ = s;
#line 121 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp141_, _tmp142_) == 0, "name1.structured_name.suffixes == s");
#line 122 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c1, "contact_name_suffixes", NULL);
#line 124 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp143_ = gee_abstract_map_get_size ((GeeMap*) c1);
#line 124 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp144_ = _tmp143_;
#line 124 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp144_ == 0, "c1.size == 0");
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp145_ = folks_test_utils_get_individual_by_name (aggregator, "richard m. stallman");
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	i2 = _tmp145_;
#line 128 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp146_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (i2, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 128 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name2 = _tmp146_;
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp147_ = folks_name_details_get_structured_name (name2);
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp148_ = _tmp147_;
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp149_ = folks_structured_name_is_empty (_tmp148_);
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp149_ == FALSE, "name2.structured_name.is_empty () == false");
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp150_ = gee_abstract_map_get ((GeeAbstractMap*) c2, "full_name");
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp151_ = (GValue*) _tmp150_;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp152_ = *_tmp151_;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp153_ = g_value_get_string (&_tmp152_);
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp154_ = g_strdup (_tmp153_);
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp154_;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp151_);
#line 133 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp155_ = folks_name_details_get_full_name (name2);
#line 133 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp156_ = _tmp155_;
#line 133 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp157_ = s;
#line 133 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp156_, _tmp157_) == 0, "name2.full_name == s");
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c2, "full_name", NULL);
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp158_ = gee_abstract_map_get ((GeeAbstractMap*) c2, "contact_name_family");
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp159_ = (GValue*) _tmp158_;
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp160_ = *_tmp159_;
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp161_ = g_value_get_string (&_tmp160_);
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp162_ = g_strdup (_tmp161_);
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp162_;
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp159_);
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp163_ = folks_name_details_get_structured_name (name2);
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp164_ = _tmp163_;
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp165_ = folks_structured_name_get_family_name (_tmp164_);
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp166_ = _tmp165_;
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp167_ = s;
#line 137 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp166_, _tmp167_) == 0, "name2.structured_name.family_name == s");
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c2, "contact_name_family", NULL);
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp168_ = gee_abstract_map_get ((GeeAbstractMap*) c2, "contact_name_given");
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp169_ = (GValue*) _tmp168_;
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp170_ = *_tmp169_;
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp171_ = g_value_get_string (&_tmp170_);
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp172_ = g_strdup (_tmp171_);
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	s = _tmp172_;
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp169_);
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp173_ = folks_name_details_get_structured_name (name2);
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp174_ = _tmp173_;
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp175_ = folks_structured_name_get_given_name (_tmp174_);
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp176_ = _tmp175_;
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp177_ = s;
#line 141 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (g_strcmp0 (_tmp176_, _tmp177_) == 0, "name2.structured_name.given_name == s");
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) c2, "contact_name_given", NULL);
#line 144 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp178_ = gee_abstract_map_get_size ((GeeMap*) c2);
#line 144 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp179_ = _tmp178_;
#line 144 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp179_ == 0, "c2.size == 0");
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (name2);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (i2);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (name1);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (i1);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_free0 (s);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (aggregator);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (c2);
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (c1);
#line 983 "name-details.c"
}


static void name_details_tests_class_init (NameDetailsTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 990 "name-details.c"
}


static void name_details_tests_instance_init (NameDetailsTests * self) {
}


GType name_details_tests_get_type (void) {
	static volatile gsize name_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&name_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NameDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) name_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NameDetailsTests), 0, (GInstanceInitFunc) name_details_tests_instance_init, NULL };
		GType name_details_tests_type_id;
		name_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "NameDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&name_details_tests_type_id__volatile, name_details_tests_type_id);
	}
	return name_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	NameDetailsTests* tests = NULL;
	NameDetailsTests* _tmp0_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 152 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = name_details_tests_new ();
#line 152 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	tests = _tmp0_;
#line 153 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_test_run ();
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 157 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	result = 0;
#line 157 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (tests);
#line 157 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return result;
#line 1032 "name-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 148 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return _vala_main (argv, argc);
#line 1042 "name-details.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



