#ifndef __EXAMPLE_CONTACTLIST_H__
#define __EXAMPLE_CONTACTLIST_H__

#include <simple-account-manager.h>
#include <simple-account.h>
#include <backend.h>
#include <contacts-conn.h>
#include <contact-list-manager.h>

#endif /* __EXAMPLE_CONTACTLIST_H__ */
