/* postal-address-details.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from postal-address-details.vala, do not modify */

/*
 * Copyright (C) 2011, 2015 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks/folks-eds.h>


#define TYPE_POSTAL_ADDRESS_DETAILS_TESTS (postal_address_details_tests_get_type ())
#define POSTAL_ADDRESS_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTests))
#define POSTAL_ADDRESS_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTestsClass))
#define IS_POSTAL_ADDRESS_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS))
#define IS_POSTAL_ADDRESS_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POSTAL_ADDRESS_DETAILS_TESTS))
#define POSTAL_ADDRESS_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTestsClass))

typedef struct _PostalAddressDetailsTests PostalAddressDetailsTests;
typedef struct _PostalAddressDetailsTestsClass PostalAddressDetailsTestsClass;
typedef struct _PostalAddressDetailsTestsPrivate PostalAddressDetailsTestsPrivate;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PostalAddressDetailsTests {
	EdsTestTestCase parent_instance;
	PostalAddressDetailsTestsPrivate * priv;
};

struct _PostalAddressDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};


static gpointer postal_address_details_tests_parent_class = NULL;

GType postal_address_details_tests_get_type (void) G_GNUC_CONST;
enum  {
	POSTAL_ADDRESS_DETAILS_TESTS_DUMMY_PROPERTY
};
PostalAddressDetailsTests* postal_address_details_tests_new (void);
PostalAddressDetailsTests* postal_address_details_tests_construct (GType object_type);
void postal_address_details_tests_test_postal_address_details_interface (PostalAddressDetailsTests* self);
static void _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self) {
#line 31 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postal_address_details_tests_test_postal_address_details_interface ((PostalAddressDetailsTests*) self);
#line 82 "postal-address-details.c"
}


PostalAddressDetailsTests* postal_address_details_tests_construct (GType object_type) {
	PostalAddressDetailsTests * self = NULL;
#line 29 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self = (PostalAddressDetailsTests*) eds_test_test_case_construct (object_type, "PostalAddressDetailsTests");
#line 31 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test postal address details interface", _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 27 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self;
#line 94 "postal-address-details.c"
}


PostalAddressDetailsTests* postal_address_details_tests_new (void) {
#line 27 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return postal_address_details_tests_construct (TYPE_POSTAL_ADDRESS_DETAILS_TESTS);
#line 101 "postal-address-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 108 "postal-address-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_unset (self);
#line 38 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_free (self);
#line 117 "postal-address-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 124 "postal-address-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 131 "postal-address-details.c"
}


void postal_address_details_tests_test_postal_address_details_interface (PostalAddressDetailsTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GValue* v = NULL;
	gchar* pobox = NULL;
	gchar* _tmp1_ = NULL;
	gchar* locality = NULL;
	gchar* _tmp2_ = NULL;
	gchar* postalcode = NULL;
	gchar* _tmp3_ = NULL;
	gchar* street = NULL;
	gchar* _tmp4_ = NULL;
	gchar* extended = NULL;
	gchar* _tmp5_ = NULL;
	gchar* country = NULL;
	gchar* _tmp6_ = NULL;
	gchar* region = NULL;
	gchar* _tmp7_ = NULL;
	GValue _tmp8_ = {0};
	GValue _tmp9_ = {0};
	GValue* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	GeeHashMap* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	FolksPostalAddress* pa_copy = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	FolksPostalAddress* _tmp22_ = NULL;
	FolksPostalAddressFieldDetails* pa_fd_copy = NULL;
	FolksPostalAddress* _tmp23_ = NULL;
	FolksPostalAddressFieldDetails* _tmp24_ = NULL;
	FolksPostalAddressFieldDetails* _tmp25_ = NULL;
	GValue _tmp26_ = {0};
	GValue _tmp27_ = {0};
	GValue* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	FolksPostalAddressFieldDetails* _tmp30_ = NULL;
	GeeHashMap* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	GValue* _tmp33_ = NULL;
	GValue* _tmp34_ = NULL;
	EdsTestBackend* _tmp35_ = NULL;
	GeeHashMap* _tmp36_ = NULL;
	GeeHashMap* _tmp37_ = NULL;
	EdsTestBackend* _tmp38_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp39_ = NULL;
	FolksIndividualAggregator* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar** _tmp42_ = NULL;
	gchar** _tmp43_ = NULL;
	gint _tmp43__length1 = 0;
	FolksIndividual* i = NULL;
	FolksIndividualAggregator* _tmp44_ = NULL;
	FolksIndividual* _tmp45_ = NULL;
	FolksIndividual* _tmp46_ = NULL;
	GeeSet* _tmp47_ = NULL;
	GeeSet* _tmp48_ = NULL;
	gint _tmp49_ = 0;
	gint _tmp50_ = 0;
	FolksPostalAddress* pa = NULL;
	const gchar* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	const gchar* _tmp53_ = NULL;
	const gchar* _tmp54_ = NULL;
	const gchar* _tmp55_ = NULL;
	const gchar* _tmp56_ = NULL;
	const gchar* _tmp57_ = NULL;
	FolksPostalAddress* _tmp58_ = NULL;
	FolksPostalAddressFieldDetails* postal_address = NULL;
	FolksPostalAddress* _tmp59_ = NULL;
	FolksPostalAddressFieldDetails* _tmp60_ = NULL;
	FolksPostalAddressFieldDetails* _tmp61_ = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_return_if_fail (self != NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	c1 = _tmp0_;
#line 41 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp1_ = g_strdup ("12345");
#line 41 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pobox = _tmp1_;
#line 42 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp2_ = g_strdup ("example locality");
#line 42 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	locality = _tmp2_;
#line 43 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp3_ = g_strdup ("example postalcode");
#line 43 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postalcode = _tmp3_;
#line 44 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp4_ = g_strdup ("example street");
#line 44 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	street = _tmp4_;
#line 45 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp5_ = g_strdup ("example extended address");
#line 45 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	extended = _tmp5_;
#line 46 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp6_ = g_strdup ("example country");
#line 46 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	country = _tmp6_;
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp7_ = g_strdup ("example region");
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	region = _tmp7_;
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_init (&_tmp8_, G_TYPE_STRING);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp9_ = _tmp8_;
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp10_ = __g_value_dup0 (&_tmp9_);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = _tmp10_;
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_IS_VALUE (&_tmp9_) ? (g_value_unset (&_tmp9_), NULL) : NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp11_ = v;
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_set_string (_tmp11_, "persona #1");
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp12_ = c1;
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp13_ = v;
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = NULL;
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp14_ = _tmp13_;
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp12_, "full_name", _tmp14_);
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (_tmp14_);
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp15_ = pobox;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp16_ = extended;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp17_ = street;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp18_ = locality;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp19_ = region;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp20_ = postalcode;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp21_ = country;
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp22_ = folks_postal_address_new (_tmp15_, _tmp16_, _tmp17_, _tmp18_, _tmp19_, _tmp20_, _tmp21_, NULL, "eds_id");
#line 52 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa_copy = _tmp22_;
#line 61 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp23_ = pa_copy;
#line 61 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp24_ = folks_postal_address_field_details_new (_tmp23_, NULL);
#line 61 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa_fd_copy = _tmp24_;
#line 62 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp25_ = pa_fd_copy;
#line 62 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp25_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_init (&_tmp26_, FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS);
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp27_ = _tmp26_;
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp28_ = __g_value_dup0 (&_tmp27_);
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = _tmp28_;
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_IS_VALUE (&_tmp27_) ? (g_value_unset (&_tmp27_), NULL) : NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp29_ = v;
#line 65 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp30_ = pa_fd_copy;
#line 65 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_set_object (_tmp29_, (GObject*) _tmp30_);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp31_ = c1;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp32_ = EDSF_PERSONA_address_fields[0];
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp33_ = v;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp34_ = _tmp33_;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp31_, _tmp32_, _tmp34_);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (_tmp34_);
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp35_ = ((EdsTestTestCase*) self)->eds_backend;
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp36_ = c1;
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp37_ = _g_object_ref0 (_tmp36_);
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	eds_test_backend_add_contact (_tmp35_, _tmp37_);
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp38_ = ((EdsTestTestCase*) self)->eds_backend;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_sync (_tmp38_);
#line 74 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp39_ = folks_individual_aggregator_dup ();
#line 74 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	aggregator = _tmp39_;
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp40_ = aggregator;
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp41_ = g_strdup ("persona #1");
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp42_ = g_new0 (gchar*, 1 + 1);
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp42_[0] = _tmp41_;
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp43_ = _tmp42_;
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp43__length1 = 1;
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_individuals_sync_with_timeout (_tmp40_, _tmp43_, 1, 5);
#line 75 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 79 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp44_ = aggregator;
#line 79 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp45_ = folks_test_utils_get_individual_by_name (_tmp44_, "persona #1");
#line 79 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	i = _tmp45_;
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp46_ = i;
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp47_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp46_);
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp48_ = _tmp47_;
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp50_ = _tmp49_;
#line 81 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_vala_assert (_tmp50_ == 1, "i.postal_addresses.size == 1");
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp51_ = pobox;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp52_ = extended;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp53_ = street;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp54_ = locality;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp55_ = region;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp56_ = postalcode;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp57_ = country;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp58_ = folks_postal_address_new (_tmp51_, _tmp52_, _tmp53_, _tmp54_, _tmp55_, _tmp56_, _tmp57_, NULL, "eds_id");
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa = _tmp58_;
#line 92 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp59_ = pa;
#line 92 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp60_ = folks_postal_address_field_details_new (_tmp59_, NULL);
#line 92 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postal_address = _tmp60_;
#line 93 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp61_ = postal_address;
#line 93 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp61_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 414 "postal-address-details.c"
	{
		GeeIterator* _pa_fd_it = NULL;
		FolksIndividual* _tmp62_ = NULL;
		GeeSet* _tmp63_ = NULL;
		GeeSet* _tmp64_ = NULL;
		GeeIterator* _tmp65_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp62_ = i;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp63_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp62_);
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp64_ = _tmp63_;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp65_ = gee_iterable_iterator ((GeeIterable*) _tmp64_);
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_pa_fd_it = _tmp65_;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		while (TRUE) {
#line 433 "postal-address-details.c"
			GeeIterator* _tmp66_ = NULL;
			gboolean _tmp67_ = FALSE;
			FolksPostalAddressFieldDetails* pa_fd = NULL;
			GeeIterator* _tmp68_ = NULL;
			gpointer _tmp69_ = NULL;
			FolksPostalAddressFieldDetails* _tmp70_ = NULL;
			FolksPostalAddressFieldDetails* _tmp71_ = NULL;
			const gchar* _tmp72_ = NULL;
			const gchar* _tmp73_ = NULL;
			FolksPostalAddressFieldDetails* _tmp74_ = NULL;
			FolksPostalAddressFieldDetails* _tmp75_ = NULL;
			gboolean _tmp76_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp66_ = _pa_fd_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp67_ = gee_iterator_next (_tmp66_);
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			if (!_tmp67_) {
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
				break;
#line 454 "postal-address-details.c"
			}
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp68_ = _pa_fd_it;
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp69_ = gee_iterator_get (_tmp68_);
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			pa_fd = (FolksPostalAddressFieldDetails*) _tmp69_;
#line 102 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp70_ = postal_address;
#line 102 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp71_ = pa_fd;
#line 102 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp72_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp71_);
#line 102 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp73_ = _tmp72_;
#line 102 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp70_, _tmp73_);
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp74_ = pa_fd;
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp75_ = postal_address;
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp76_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp74_, (FolksAbstractFieldDetails*) _tmp75_);
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_vala_assert (_tmp76_, "pa_fd.equal (postal_address)");
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_g_object_unref0 (pa_fd);
#line 482 "postal-address-details.c"
		}
#line 96 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_g_object_unref0 (_pa_fd_it);
#line 486 "postal-address-details.c"
	}
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (postal_address);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (i);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (aggregator);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa_fd_copy);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa_copy);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (region);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (country);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (extended);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (street);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (postalcode);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (locality);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (pobox);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (c1);
#line 518 "postal-address-details.c"
}


static void postal_address_details_tests_class_init (PostalAddressDetailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postal_address_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 525 "postal-address-details.c"
}


static void postal_address_details_tests_instance_init (PostalAddressDetailsTests * self) {
}


GType postal_address_details_tests_get_type (void) {
	static volatile gsize postal_address_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&postal_address_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PostalAddressDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) postal_address_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PostalAddressDetailsTests), 0, (GInstanceInitFunc) postal_address_details_tests_instance_init, NULL };
		GType postal_address_details_tests_type_id;
		postal_address_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "PostalAddressDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&postal_address_details_tests_type_id__volatile, postal_address_details_tests_type_id);
	}
	return postal_address_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PostalAddressDetailsTests* tests = NULL;
	PostalAddressDetailsTests* _tmp0_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 112 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = postal_address_details_tests_new ();
#line 112 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	tests = _tmp0_;
#line 113 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_test_run ();
#line 115 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 117 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	result = 0;
#line 117 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (tests);
#line 117 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return result;
#line 567 "postal-address-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return _vala_main (argv, argc);
#line 577 "postal-address-details.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



