/* extended-info.c generated by valac 0.29.3.10-b87a, the Vala compiler
 * generated from extended-info.vala, do not modify */

/*
 * Copyright (C) 2013 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Rodrigo Moya <rodrigo.moya@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_EXTENDED_INFO_TESTS (extended_info_tests_get_type ())
#define EXTENDED_INFO_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXTENDED_INFO_TESTS, ExtendedInfoTests))
#define EXTENDED_INFO_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXTENDED_INFO_TESTS, ExtendedInfoTestsClass))
#define IS_EXTENDED_INFO_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXTENDED_INFO_TESTS))
#define IS_EXTENDED_INFO_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXTENDED_INFO_TESTS))
#define EXTENDED_INFO_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXTENDED_INFO_TESTS, ExtendedInfoTestsClass))

typedef struct _ExtendedInfoTests ExtendedInfoTests;
typedef struct _ExtendedInfoTestsClass ExtendedInfoTestsClass;
typedef struct _ExtendedInfoTestsPrivate ExtendedInfoTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ExtendedInfoTestsTestExtendedInfoAsyncData ExtendedInfoTestsTestExtendedInfoAsyncData;
typedef struct _ExtendedInfoTestsTestAddExtendedInfoAsyncData ExtendedInfoTestsTestAddExtendedInfoAsyncData;
typedef struct _Block1Data Block1Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ExtendedInfoTests {
	EdsTestTestCase parent_instance;
	ExtendedInfoTestsPrivate * priv;
};

struct _ExtendedInfoTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _ExtendedInfoTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gboolean _found_field_1;
	gboolean _found_field_2;
};

struct _ExtendedInfoTestsTestExtendedInfoAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ExtendedInfoTests* self;
	EdsTestBackend* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	const gchar* _tmp4_;
	GError * _inner_error_;
};

struct _ExtendedInfoTestsTestAddExtendedInfoAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ExtendedInfoTests* self;
	EdsTestBackend* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	const gchar* _tmp4_;
	GError * _inner_error_;
};

struct _Block1Data {
	int _ref_count_;
	ExtendedInfoTests* self;
	FolksIndividual* i;
};


static gpointer extended_info_tests_parent_class = NULL;

GType extended_info_tests_get_type (void) G_GNUC_CONST;
#define EXTENDED_INFO_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EXTENDED_INFO_TESTS, ExtendedInfoTestsPrivate))
enum  {
	EXTENDED_INFO_TESTS_DUMMY_PROPERTY
};
#define EXTENDED_INFO_TESTS__FULL_NAME "persona #1"
ExtendedInfoTests* extended_info_tests_new (void);
ExtendedInfoTests* extended_info_tests_construct (GType object_type);
void extended_info_tests_test_extended_info (ExtendedInfoTests* self);
static void _extended_info_tests_test_extended_info_folks_test_case_test_method (gpointer self);
void extended_info_tests_test_add_extended_info (ExtendedInfoTests* self);
static void _extended_info_tests_test_add_extended_info_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _extended_info_tests_test_extended_info_async (ExtendedInfoTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _extended_info_tests_test_extended_info_finish (ExtendedInfoTests* self, GAsyncResult* _res_);
static void _extended_info_tests_test_extended_info_async_data_free (gpointer _data);
static gboolean _extended_info_tests_test_extended_info_async_co (ExtendedInfoTestsTestExtendedInfoAsyncData* _data_);
static void _extended_info_tests_test_extended_info_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _extended_info_tests_individuals_changed_cb (ExtendedInfoTests* self, GeeMultiMap* changes);
static void __extended_info_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _extended_info_tests_test_add_extended_info_async (ExtendedInfoTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _extended_info_tests_test_add_extended_info_finish (ExtendedInfoTests* self, GAsyncResult* _res_);
static void _extended_info_tests_test_add_extended_info_async_data_free (gpointer _data);
static gboolean _extended_info_tests_test_add_extended_info_async_co (ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_);
static void _extended_info_tests_test_add_extended_info_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _extended_info_tests_add_individuals_changed_cb (ExtendedInfoTests* self, GeeMultiMap* changes);
static void __extended_info_tests_add_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void ____lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void _____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void extended_info_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _extended_info_tests_test_extended_info_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	extended_info_tests_test_extended_info ((ExtendedInfoTests*) self);
#line 152 "extended-info.c"
}


static void _extended_info_tests_test_add_extended_info_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	extended_info_tests_test_add_extended_info ((ExtendedInfoTests*) self);
#line 159 "extended-info.c"
}


ExtendedInfoTests* extended_info_tests_construct (GType object_type) {
	ExtendedInfoTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self = (ExtendedInfoTests*) eds_test_test_case_construct (object_type, "ExtendedInfo");
#line 37 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "extended info interface", _extended_info_tests_test_extended_info_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 38 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "add extended info", _extended_info_tests_test_add_extended_info_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return self;
#line 173 "extended-info.c"
}


ExtendedInfoTests* extended_info_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return extended_info_tests_construct (TYPE_EXTENDED_INFO_TESTS);
#line 180 "extended-info.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 187 "extended-info.c"
}


static void _vala_GValue_free (GValue* self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_unset (self);
#line 44 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_free (self);
#line 196 "extended-info.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return self ? _g_value_dup (self) : NULL;
#line 203 "extended-info.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 59 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return self ? g_object_ref (self) : NULL;
#line 210 "extended-info.c"
}


void extended_info_tests_test_extended_info (ExtendedInfoTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue _tmp9_ = {0};
	GValue _tmp10_ = {0};
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	GValue _tmp15_ = {0};
	GValue _tmp16_ = {0};
	GValue* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	GValue* _tmp19_ = NULL;
	GValue* _tmp20_ = NULL;
	EdsTestBackend* _tmp21_ = NULL;
	GeeHashMap* _tmp22_ = NULL;
	GMainLoop* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp25_ = FALSE;
#line 41 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 43 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_main_loop = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	c1 = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 47 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_reset (_tmp2_);
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp4_ = _tmp3_;
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = _tmp5_;
#line 49 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp6_ = v;
#line 50 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_set_string (_tmp6_, EXTENDED_INFO_TESTS__FULL_NAME);
#line 51 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp7_ = v;
#line 51 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = NULL;
#line 51 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp8_ = _tmp7_;
#line 51 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp8_);
#line 51 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (_tmp8_);
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_init (&_tmp9_, G_TYPE_STRING);
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp10_ = _tmp9_;
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp11_ = __g_value_dup0 (&_tmp10_);
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = _tmp11_;
#line 52 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_IS_VALUE (&_tmp10_) ? (g_value_unset (&_tmp10_), NULL) : NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp12_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_set_string (_tmp12_, "value1");
#line 54 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp13_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp14_ = _tmp13_;
#line 54 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "X-FIELD-1", _tmp14_);
#line 54 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (_tmp14_);
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_init (&_tmp15_, G_TYPE_STRING);
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp16_ = _tmp15_;
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp17_ = __g_value_dup0 (&_tmp16_);
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = _tmp17_;
#line 55 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_IS_VALUE (&_tmp16_) ? (g_value_unset (&_tmp16_), NULL) : NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp18_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_set_string (_tmp18_, "value2");
#line 57 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp19_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp20_ = _tmp19_;
#line 57 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "X-FIELD-2", _tmp20_);
#line 57 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (_tmp20_);
#line 59 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp21_ = ((EdsTestTestCase*) self)->eds_backend;
#line 59 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp22_ = _g_object_ref0 (c1);
#line 59 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_add_contact (_tmp21_, _tmp22_);
#line 61 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_found_field_1 = FALSE;
#line 62 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_found_field_2 = FALSE;
#line 64 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_extended_info_async (self, NULL, NULL);
#line 66 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp23_ = self->priv->_main_loop;
#line 66 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_utils_loop_run_with_timeout (_tmp23_, 5);
#line 68 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp24_ = self->priv->_found_field_1;
#line 68 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_vala_assert (_tmp24_ == TRUE, "this._found_field_1 == true");
#line 69 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp25_ = self->priv->_found_field_2;
#line 69 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_vala_assert (_tmp25_ == TRUE, "this._found_field_2 == true");
#line 71 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 71 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_aggregator = NULL;
#line 72 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 72 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_main_loop = NULL;
#line 41 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 41 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (c1);
#line 373 "extended-info.c"
}


static void _extended_info_tests_test_extended_info_async_data_free (gpointer _data) {
	ExtendedInfoTestsTestExtendedInfoAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_slice_free (ExtendedInfoTestsTestExtendedInfoAsyncData, _data_);
#line 384 "extended-info.c"
}


static void _extended_info_tests_test_extended_info_async (ExtendedInfoTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ExtendedInfoTestsTestExtendedInfoAsyncData* _data_;
	ExtendedInfoTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = g_slice_new0 (ExtendedInfoTestsTestExtendedInfoAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _extended_info_tests_test_extended_info_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _extended_info_tests_test_extended_info_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_extended_info_async_co (_data_);
#line 403 "extended-info.c"
}


static void _extended_info_tests_test_extended_info_finish (ExtendedInfoTests* self, GAsyncResult* _res_) {
	ExtendedInfoTestsTestExtendedInfoAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 411 "extended-info.c"
}


static void _extended_info_tests_test_extended_info_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ExtendedInfoTestsTestExtendedInfoAsyncData* _data_;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = _user_data_;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_source_object_ = source_object;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_res_ = _res_;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_extended_info_async_co (_data_);
#line 425 "extended-info.c"
}


static void __extended_info_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 80 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_individuals_changed_cb ((ExtendedInfoTests*) self, changes);
#line 432 "extended-info.c"
}


static gboolean _extended_info_tests_test_extended_info_async_co (ExtendedInfoTestsTestExtendedInfoAsyncData* _data_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	switch (_data_->_state_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 0:
#line 441 "extended-info.c"
		goto _state_0;
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 1:
#line 445 "extended-info.c"
		goto _state_1;
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 2:
#line 449 "extended-info.c"
		goto _state_2;
		default:
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_assert_not_reached ();
#line 454 "extended-info.c"
	}
	_state_0:
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp0_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_state_ = 1;
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _extended_info_tests_test_extended_info_async_ready, _data_);
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return FALSE;
#line 467 "extended-info.c"
	_state_1:
#line 77 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 79 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp1_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 79 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 79 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 80 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp2_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 80 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __extended_info_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 485 "extended-info.c"
	{
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp3_ = NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_state_ = 2;
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _extended_info_tests_test_extended_info_async_ready, _data_);
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		return FALSE;
#line 497 "extended-info.c"
		_state_2:
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 84 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 503 "extended-info.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->e = _data_->_inner_error_;
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_inner_error_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp4_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp4_ = _data_->e->message;
#line 88 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_error ("extended-info.vala:88: Error when calling prepare: %s", _data_->_tmp4_);
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_error_free0 (_data_->e);
#line 522 "extended-info.c"
	}
	__finally0:
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_clear_error (&_data_->_inner_error_);
#line 82 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		return FALSE;
#line 533 "extended-info.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (_data_->_state_ == 0) {
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 539 "extended-info.c"
	} else {
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 543 "extended-info.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_object_unref (_data_->_async_result);
#line 75 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return FALSE;
#line 549 "extended-info.c"
}


static void _extended_info_tests_individuals_changed_cb (ExtendedInfoTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gint _tmp24_ = 0;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
#line 92 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (self != NULL);
#line 92 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (changes != NULL);
#line 95 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = changes;
#line 95 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 95 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	added = _tmp1_;
#line 96 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp2_ = changes;
#line 96 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 96 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	removed = _tmp3_;
#line 581 "extended-info.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp4_ = added;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_i_it = _tmp5_;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		while (TRUE) {
#line 594 "extended-info.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp6_ = _i_it;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (!_tmp7_) {
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				break;
#line 612 "extended-info.c"
			}
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp8_ = _i_it;
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			i = (FolksIndividual*) _tmp9_;
#line 100 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp10_ = i;
#line 100 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 102 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp11_ = i;
#line 102 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 102 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp13_ = _tmp12_;
#line 102 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (g_strcmp0 (_tmp13_, EXTENDED_INFO_TESTS__FULL_NAME) == 0) {
#line 632 "extended-info.c"
				FolksIndividual* _tmp14_ = NULL;
				FolksExtendedFieldDetails* _tmp15_ = NULL;
				FolksExtendedFieldDetails* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				FolksIndividual* _tmp18_ = NULL;
				FolksExtendedFieldDetails* _tmp19_ = NULL;
				FolksExtendedFieldDetails* _tmp20_ = NULL;
				gboolean _tmp21_ = FALSE;
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp14_ = i;
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp15_ = folks_extended_info_get_extended_field ((FolksExtendedInfo*) _tmp14_, "X-FIELD-1");
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp16_ = _tmp15_;
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp17_ = _tmp16_ != NULL;
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_g_object_unref0 (_tmp16_);
#line 104 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				if (_tmp17_) {
#line 105 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
					self->priv->_found_field_1 = TRUE;
#line 655 "extended-info.c"
				}
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp18_ = i;
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp19_ = folks_extended_info_get_extended_field ((FolksExtendedInfo*) _tmp18_, "X-FIELD-2");
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp20_ = _tmp19_;
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_tmp21_ = _tmp20_ != NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_g_object_unref0 (_tmp20_);
#line 106 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				if (_tmp21_) {
#line 107 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
					self->priv->_found_field_2 = TRUE;
#line 671 "extended-info.c"
				}
			}
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_g_object_unref0 (i);
#line 676 "extended-info.c"
		}
#line 98 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (_i_it);
#line 680 "extended-info.c"
	}
#line 111 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp22_ = removed;
#line 111 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp23_ = gee_collection_get_size ((GeeCollection*) _tmp22_);
#line 111 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp24_ = _tmp23_;
#line 111 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_vala_assert (_tmp24_ == 1, "removed.size == 1");
#line 690 "extended-info.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp25_ = NULL;
		GeeIterator* _tmp26_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp25_ = removed;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp26_ = gee_iterable_iterator ((GeeIterable*) _tmp25_);
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_i_it = _tmp26_;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		while (TRUE) {
#line 703 "extended-info.c"
			GeeIterator* _tmp27_ = NULL;
			gboolean _tmp28_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp29_ = NULL;
			gpointer _tmp30_ = NULL;
			FolksIndividual* _tmp31_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp27_ = _i_it;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp28_ = gee_iterator_next (_tmp27_);
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (!_tmp28_) {
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				break;
#line 718 "extended-info.c"
			}
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp29_ = _i_it;
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp30_ = gee_iterator_get (_tmp29_);
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			i = (FolksIndividual*) _tmp30_;
#line 115 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp31_ = i;
#line 115 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_vala_assert (_tmp31_ == NULL, "i == null");
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_g_object_unref0 (i);
#line 732 "extended-info.c"
		}
#line 113 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (_i_it);
#line 736 "extended-info.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp33_ = self->priv->_found_field_1;
#line 118 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (_tmp33_ == TRUE) {
#line 742 "extended-info.c"
		gboolean _tmp34_ = FALSE;
#line 119 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp34_ = self->priv->_found_field_2;
#line 119 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp32_ = _tmp34_ == TRUE;
#line 748 "extended-info.c"
	} else {
#line 118 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp32_ = FALSE;
#line 752 "extended-info.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (_tmp32_) {
#line 756 "extended-info.c"
		GMainLoop* _tmp35_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp35_ = self->priv->_main_loop;
#line 121 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_main_loop_quit (_tmp35_);
#line 762 "extended-info.c"
	}
#line 92 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (removed);
#line 92 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (added);
#line 768 "extended-info.c"
}


void extended_info_tests_test_add_extended_info (ExtendedInfoTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	EdsTestBackend* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GMainLoop* _tmp11_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (self != NULL);
#line 129 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 129 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 129 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_main_loop = _tmp0_;
#line 130 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 130 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	c1 = _tmp1_;
#line 133 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 133 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_reset (_tmp2_);
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp4_ = _tmp3_;
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = _tmp5_;
#line 135 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp6_ = v;
#line 136 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_value_set_string (_tmp6_, EXTENDED_INFO_TESTS__FULL_NAME);
#line 137 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp7_ = v;
#line 137 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	v = NULL;
#line 137 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp8_ = _tmp7_;
#line 137 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp8_);
#line 137 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (_tmp8_);
#line 139 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp9_ = ((EdsTestTestCase*) self)->eds_backend;
#line 139 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp10_ = _g_object_ref0 (c1);
#line 139 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_add_contact (_tmp9_, _tmp10_);
#line 141 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_add_extended_info_async (self, NULL, NULL);
#line 142 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp11_ = self->priv->_main_loop;
#line 142 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_utils_loop_run_with_timeout (_tmp11_, 5);
#line 144 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 144 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_aggregator = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 145 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv->_main_loop = NULL;
#line 127 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	__vala_GValue_free0 (v);
#line 127 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (c1);
#line 853 "extended-info.c"
}


static void _extended_info_tests_test_add_extended_info_async_data_free (gpointer _data) {
	ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_slice_free (ExtendedInfoTestsTestAddExtendedInfoAsyncData, _data_);
#line 864 "extended-info.c"
}


static void _extended_info_tests_test_add_extended_info_async (ExtendedInfoTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_;
	ExtendedInfoTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = g_slice_new0 (ExtendedInfoTestsTestAddExtendedInfoAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _extended_info_tests_test_add_extended_info_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _extended_info_tests_test_add_extended_info_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_add_extended_info_async_co (_data_);
#line 883 "extended-info.c"
}


static void _extended_info_tests_test_add_extended_info_finish (ExtendedInfoTests* self, GAsyncResult* _res_) {
	ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 891 "extended-info.c"
}


static void _extended_info_tests_test_add_extended_info_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_ = _user_data_;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_source_object_ = source_object;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_res_ = _res_;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_test_add_extended_info_async_co (_data_);
#line 905 "extended-info.c"
}


static void __extended_info_tests_add_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 153 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_extended_info_tests_add_individuals_changed_cb ((ExtendedInfoTests*) self, changes);
#line 912 "extended-info.c"
}


static gboolean _extended_info_tests_test_add_extended_info_async_co (ExtendedInfoTestsTestAddExtendedInfoAsyncData* _data_) {
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	switch (_data_->_state_) {
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 0:
#line 921 "extended-info.c"
		goto _state_0;
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 1:
#line 925 "extended-info.c"
		goto _state_1;
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		case 2:
#line 929 "extended-info.c"
		goto _state_2;
		default:
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_assert_not_reached ();
#line 934 "extended-info.c"
	}
	_state_0:
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp0_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_state_ = 1;
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _extended_info_tests_test_add_extended_info_async_ready, _data_);
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return FALSE;
#line 947 "extended-info.c"
	_state_1:
#line 150 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 152 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp1_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 152 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 152 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 153 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp2_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 153 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __extended_info_tests_add_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 965 "extended-info.c"
	{
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp3_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_state_ = 2;
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _extended_info_tests_test_add_extended_info_async_ready, _data_);
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		return FALSE;
#line 977 "extended-info.c"
		_state_2:
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 157 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 983 "extended-info.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->e = _data_->_inner_error_;
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_inner_error_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp4_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_data_->_tmp4_ = _data_->e->message;
#line 161 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_error ("extended-info.vala:161: Error when calling prepare: %s", _data_->_tmp4_);
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_error_free0 (_data_->e);
#line 1002 "extended-info.c"
	}
	__finally1:
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_clear_error (&_data_->_inner_error_);
#line 155 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		return FALSE;
#line 1013 "extended-info.c"
	}
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (_data_->_state_ == 0) {
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1019 "extended-info.c"
	} else {
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1023 "extended-info.c"
	}
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_object_unref (_data_->_async_result);
#line 148 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return FALSE;
#line 1029 "extended-info.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return _data1_;
#line 1038 "extended-info.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1047 "extended-info.c"
		ExtendedInfoTests* self;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		self = _data1_->self;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (_data1_->i);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (self);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_slice_free (Block1Data, _data1_);
#line 1057 "extended-info.c"
	}
}


static void ____lambda4_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	ExtendedInfoTests* self;
	GError * _inner_error_ = NULL;
#line 182 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self = _data1_->self;
#line 182 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (r != NULL);
#line 1069 "extended-info.c"
	{
		FolksIndividual* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		FolksExtendedFieldDetails* efd = NULL;
		FolksIndividual* _tmp2_ = NULL;
		FolksExtendedFieldDetails* _tmp3_ = NULL;
		gconstpointer _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GMainLoop* _tmp6_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp0_ = _data1_->i;
#line 186 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp1_ = r;
#line 186 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		folks_extended_info_change_extended_field_finish ((FolksExtendedInfo*) _tmp0_, _tmp1_, &_inner_error_);
#line 186 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1087 "extended-info.c"
			goto __catch2_g_error;
		}
#line 188 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp2_ = _data1_->i;
#line 188 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp3_ = folks_extended_info_get_extended_field ((FolksExtendedInfo*) _tmp2_, "X-FOLKS-EXTENDED-INFO");
#line 188 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		efd = _tmp3_;
#line 191 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_vala_assert (efd != NULL, "efd != null");
#line 192 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp4_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) efd);
#line 192 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp5_ = _tmp4_;
#line 192 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_vala_assert (g_strcmp0 ((const gchar*) _tmp5_, "folks-test") == 0, "efd.value == \"folks-test\"");
#line 195 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp6_ = self->priv->_main_loop;
#line 195 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_main_loop_quit (_tmp6_);
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (efd);
#line 1110 "extended-info.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		e = _inner_error_;
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_inner_error_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp7_ = e->message;
#line 199 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_error ("extended-info.vala:199: Failed to change extended field: %s", _tmp7_);
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_error_free0 (e);
#line 1127 "extended-info.c"
	}
	__finally2:
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		g_clear_error (&_inner_error_);
#line 184 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		return;
#line 1138 "extended-info.c"
	}
}


static void _____lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	____lambda4_ (self, source_object, res);
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	block1_data_unref (self);
#line 1148 "extended-info.c"
}


static void _extended_info_tests_add_individuals_changed_cb (ExtendedInfoTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
#line 165 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (self != NULL);
#line 165 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_return_if_fail (changes != NULL);
#line 168 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = changes;
#line 168 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 168 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	added = _tmp1_;
#line 169 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp2_ = changes;
#line 169 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 169 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	removed = _tmp3_;
#line 1178 "extended-info.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp4_ = added;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_i_it = _tmp5_;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		while (TRUE) {
#line 1191 "extended-info.c"
			Block1Data* _data1_;
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			FolksIndividual* _tmp14_ = NULL;
			FolksExtendedFieldDetails* _tmp15_ = NULL;
			FolksExtendedFieldDetails* _tmp16_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_data1_ = g_slice_new0 (Block1Data);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_data1_->_ref_count_ = 1;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_data1_->self = g_object_ref (self);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp6_ = _i_it;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (!_tmp7_) {
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				block1_data_unref (_data1_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_data1_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				break;
#line 1222 "extended-info.c"
			}
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp8_ = _i_it;
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_data1_->i = (FolksIndividual*) _tmp9_;
#line 173 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp10_ = _data1_->i;
#line 173 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 175 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp11_ = _data1_->i;
#line 175 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 175 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp13_ = _tmp12_;
#line 175 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (g_strcmp0 (_tmp13_, EXTENDED_INFO_TESTS__FULL_NAME) != 0) {
#line 176 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				block1_data_unref (_data1_);
#line 176 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				_data1_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				continue;
#line 1248 "extended-info.c"
			}
#line 178 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			g_debug ("extended-info.vala:178: Adding an extended field");
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp14_ = _data1_->i;
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp15_ = folks_extended_field_details_new ("folks-test", NULL);
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp16_ = _tmp15_;
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			folks_extended_info_change_extended_field ((FolksExtendedInfo*) _tmp14_, "X-FOLKS-EXTENDED-INFO", _tmp16_, _____lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 181 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_g_object_unref0 (_tmp16_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			block1_data_unref (_data1_);
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_data1_ = NULL;
#line 1266 "extended-info.c"
		}
#line 171 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (_i_it);
#line 1270 "extended-info.c"
	}
#line 204 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp17_ = removed;
#line 204 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 204 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp19_ = _tmp18_;
#line 204 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_vala_assert (_tmp19_ == 1, "removed.size == 1");
#line 1280 "extended-info.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp20_ = removed;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_i_it = _tmp21_;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		while (TRUE) {
#line 1293 "extended-info.c"
			GeeIterator* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp24_ = NULL;
			gpointer _tmp25_ = NULL;
			FolksIndividual* _tmp26_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp22_ = _i_it;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp23_ = gee_iterator_next (_tmp22_);
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			if (!_tmp23_) {
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
				break;
#line 1308 "extended-info.c"
			}
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp24_ = _i_it;
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp25_ = gee_iterator_get (_tmp24_);
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			i = (FolksIndividual*) _tmp25_;
#line 208 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_tmp26_ = i;
#line 208 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_vala_assert (_tmp26_ == NULL, "i == null");
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
			_g_object_unref0 (i);
#line 1322 "extended-info.c"
		}
#line 206 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
		_g_object_unref0 (_i_it);
#line 1326 "extended-info.c"
	}
#line 165 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (removed);
#line 165 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (added);
#line 1332 "extended-info.c"
}


static void extended_info_tests_class_init (ExtendedInfoTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	extended_info_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_type_class_add_private (klass, sizeof (ExtendedInfoTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_OBJECT_CLASS (klass)->finalize = extended_info_tests_finalize;
#line 1343 "extended-info.c"
}


static void extended_info_tests_instance_init (ExtendedInfoTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self->priv = EXTENDED_INFO_TESTS_GET_PRIVATE (self);
#line 1350 "extended-info.c"
}


static void extended_info_tests_finalize (GObject* obj) {
	ExtendedInfoTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EXTENDED_INFO_TESTS, ExtendedInfoTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 25 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	G_OBJECT_CLASS (extended_info_tests_parent_class)->finalize (obj);
#line 1364 "extended-info.c"
}


GType extended_info_tests_get_type (void) {
	static volatile gsize extended_info_tests_type_id__volatile = 0;
	if (g_once_init_enter (&extended_info_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ExtendedInfoTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) extended_info_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ExtendedInfoTests), 0, (GInstanceInitFunc) extended_info_tests_instance_init, NULL };
		GType extended_info_tests_type_id;
		extended_info_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "ExtendedInfoTests", &g_define_type_info, 0);
		g_once_init_leave (&extended_info_tests_type_id__volatile, extended_info_tests_type_id);
	}
	return extended_info_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	ExtendedInfoTests* tests = NULL;
	ExtendedInfoTests* _tmp0_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_test_init (&args_length1, &args, NULL);
#line 217 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_tmp0_ = extended_info_tests_new ();
#line 217 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	tests = _tmp0_;
#line 218 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 219 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	g_test_run ();
#line 220 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 222 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	result = 0;
#line 222 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	_g_object_unref0 (tests);
#line 222 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return result;
#line 1402 "extended-info.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 213 "/opt/gnome3/source/folks/tests/eds/extended-info.vala"
	return _vala_main (argv, argc);
#line 1412 "extended-info.c"
}



