/* set-duplicate-email.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from set-duplicate-email.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_SET_DUPLICATE_EMAIL_TESTS (set_duplicate_email_tests_get_type ())
#define SET_DUPLICATE_EMAIL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_DUPLICATE_EMAIL_TESTS, SetDuplicateEmailTests))
#define SET_DUPLICATE_EMAIL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_DUPLICATE_EMAIL_TESTS, SetDuplicateEmailTestsClass))
#define IS_SET_DUPLICATE_EMAIL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_DUPLICATE_EMAIL_TESTS))
#define IS_SET_DUPLICATE_EMAIL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_DUPLICATE_EMAIL_TESTS))
#define SET_DUPLICATE_EMAIL_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_DUPLICATE_EMAIL_TESTS, SetDuplicateEmailTestsClass))

typedef struct _SetDuplicateEmailTests SetDuplicateEmailTests;
typedef struct _SetDuplicateEmailTestsClass SetDuplicateEmailTestsClass;
typedef struct _SetDuplicateEmailTestsPrivate SetDuplicateEmailTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData;
typedef struct _SetDuplicateEmailTestsTryToAddData SetDuplicateEmailTestsTryToAddData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _SetDuplicateEmailTestsAddPersonasData SetDuplicateEmailTestsAddPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetDuplicateEmailTests {
	TrackerTestTestCase parent_instance;
	SetDuplicateEmailTestsPrivate * priv;
};

struct _SetDuplicateEmailTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _SetDuplicateEmailTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _email_1;
	gboolean _added_personas;
	TrfPersonaStore* _pstore;
	gboolean _email_found;
};

struct _SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetDuplicateEmailTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GeeIterator* _backend_it;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	FolksBackend* backend;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	TrfPersonaStore* _tmp19_;
	TrfPersonaStore* _tmp20_;
	TrfPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _SetDuplicateEmailTestsTryToAddData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetDuplicateEmailTests* self;
	gboolean _tmp0_;
	TrfPersonaStore* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
};

struct _SetDuplicateEmailTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetDuplicateEmailTests* self;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* val;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	GValue* _tmp10_;
	GValue _tmp11_;
	GValue _tmp12_;
	GValue* _tmp13_;
	GeeHashSet* emails1;
	GeeHashSet* _tmp14_;
	FolksEmailFieldDetails* email_1;
	const gchar* _tmp15_;
	FolksEmailFieldDetails* _tmp16_;
	GValue* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	GValue* _tmp20_;
	FolksIndividualAggregator* _tmp21_;
	TrfPersonaStore* _tmp22_;
	FolksPersona* _tmp23_;
	FolksPersona* _tmp24_;
	GError* e;
	GError* _tmp25_;
	const gchar* _tmp26_;
	GError * _inner_error_;
};


static gpointer set_duplicate_email_tests_parent_class = NULL;

GType set_duplicate_email_tests_get_type (void) G_GNUC_CONST;
#define SET_DUPLICATE_EMAIL_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_DUPLICATE_EMAIL_TESTS, SetDuplicateEmailTestsPrivate))
enum  {
	SET_DUPLICATE_EMAIL_TESTS_DUMMY_PROPERTY
};
SetDuplicateEmailTests* set_duplicate_email_tests_new (void);
SetDuplicateEmailTests* set_duplicate_email_tests_construct (GType object_type);
void set_duplicate_email_tests_test_set_duplicate_email (SetDuplicateEmailTests* self);
static void _set_duplicate_email_tests_test_set_duplicate_email_folks_test_case_test_method (gpointer self);
static void _set_duplicate_email_tests_test_set_duplicate_email_async (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_duplicate_email_tests_test_set_duplicate_email_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_);
static void _set_duplicate_email_tests_test_set_duplicate_email_async_data_free (gpointer _data);
static gboolean _set_duplicate_email_tests_test_set_duplicate_email_async_co (SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_);
static void _set_duplicate_email_tests_test_set_duplicate_email_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_duplicate_email_tests_individuals_changed_cb (SetDuplicateEmailTests* self, GeeMultiMap* changes);
static void __set_duplicate_email_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _set_duplicate_email_tests_notify_pstore_cb (SetDuplicateEmailTests* self, GObject* _pstore, GParamSpec* ps);
static void __set_duplicate_email_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _set_duplicate_email_tests_try_to_add (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_duplicate_email_tests_try_to_add_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_);
static void _set_duplicate_email_tests_reset_email_address (SetDuplicateEmailTests* self, FolksIndividual* i);
static gboolean _set_duplicate_email_tests_has_email (SetDuplicateEmailTests* self, TrfPersona* persona, const gchar* email);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _set_duplicate_email_tests_email_addresses_cb (SetDuplicateEmailTests* self, GObject* p, GParamSpec* ps);
static void __set_duplicate_email_tests_email_addresses_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _set_duplicate_email_tests_try_to_add_data_free (gpointer _data);
static gboolean _set_duplicate_email_tests_try_to_add_co (SetDuplicateEmailTestsTryToAddData* _data_);
static void _set_duplicate_email_tests_add_personas (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_duplicate_email_tests_add_personas_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_);
static void _set_duplicate_email_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_duplicate_email_tests_add_personas_data_free (gpointer _data);
static gboolean _set_duplicate_email_tests_add_personas_co (SetDuplicateEmailTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static void _set_duplicate_email_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void set_duplicate_email_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_duplicate_email_tests_test_set_duplicate_email_folks_test_case_test_method (gpointer self) {
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	set_duplicate_email_tests_test_set_duplicate_email ((SetDuplicateEmailTests*) self);
#line 216 "set-duplicate-email.c"
}


SetDuplicateEmailTests* set_duplicate_email_tests_construct (GType object_type) {
	SetDuplicateEmailTests * self = NULL;
#line 38 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self = (SetDuplicateEmailTests*) tracker_test_test_case_construct (object_type, "SetDuplicateEmailTests");
#line 40 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test re-setting an existing e-mail address", _set_duplicate_email_tests_test_set_duplicate_email_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 36 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return self;
#line 228 "set-duplicate-email.c"
}


SetDuplicateEmailTests* set_duplicate_email_tests_new (void) {
#line 36 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return set_duplicate_email_tests_construct (TYPE_SET_DUPLICATE_EMAIL_TESTS);
#line 235 "set-duplicate-email.c"
}


void set_duplicate_email_tests_test_set_duplicate_email (SetDuplicateEmailTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 44 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (self != NULL);
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 46 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv->_main_loop = _tmp0_;
#line 48 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv->_email_found = FALSE;
#line 49 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_test_set_duplicate_email_async (self, NULL, NULL);
#line 51 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp1_ = self->priv->_main_loop;
#line 51 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_test_utils_loop_run_with_timeout (_tmp1_, 5);
#line 55 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp2_ = self->priv->_email_found;
#line 55 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_vala_assert (_tmp2_ == TRUE, "this._email_found == true");
#line 263 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_test_set_duplicate_email_async_data_free (gpointer _data) {
	SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_slice_free (SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData, _data_);
#line 274 "set-duplicate-email.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return self ? g_object_ref (self) : NULL;
#line 281 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_test_set_duplicate_email_async (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_;
	SetDuplicateEmailTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_slice_new0 (SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_duplicate_email_tests_test_set_duplicate_email_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_duplicate_email_tests_test_set_duplicate_email_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_test_set_duplicate_email_async_co (_data_);
#line 300 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_test_set_duplicate_email_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_) {
	SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 308 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_test_set_duplicate_email_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = _user_data_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_source_object_ = source_object;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_res_ = _res_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_test_set_duplicate_email_async_co (_data_);
#line 322 "set-duplicate-email.c"
}


static void __set_duplicate_email_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_individuals_changed_cb ((SetDuplicateEmailTests*) self, changes);
#line 329 "set-duplicate-email.c"
}


static void __set_duplicate_email_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 77 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_notify_pstore_cb ((SetDuplicateEmailTests*) self, _sender, pspec);
#line 336 "set-duplicate-email.c"
}


static gboolean _set_duplicate_email_tests_test_set_duplicate_email_async_co (SetDuplicateEmailTestsTestSetDuplicateEmailAsyncData* _data_) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	switch (_data_->_state_) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 0:
#line 345 "set-duplicate-email.c"
		goto _state_0;
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 1:
#line 349 "set-duplicate-email.c"
		goto _state_1;
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 2:
#line 353 "set-duplicate-email.c"
		goto _state_2;
		default:
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_assert_not_reached ();
#line 358 "set-duplicate-email.c"
	}
	_state_0:
#line 60 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp0_ = NULL;
#line 60 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 60 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->store = _data_->_tmp0_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_state_ = 1;
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_backend_store_prepare (_data_->store, _set_duplicate_email_tests_test_set_duplicate_email_async_ready, _data_);
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return FALSE;
#line 373 "set-duplicate-email.c"
	_state_1:
#line 61 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 62 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = NULL;
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 63 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __set_duplicate_email_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 391 "set-duplicate-email.c"
	{
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp3_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_state_ = 2;
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _set_duplicate_email_tests_test_set_duplicate_email_async_ready, _data_);
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		return FALSE;
#line 403 "set-duplicate-email.c"
		_state_2:
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 67 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 409 "set-duplicate-email.c"
			goto __catch0_g_error;
		}
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 68 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->self->priv->_pstore = NULL;
#line 416 "set-duplicate-email.c"
		{
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp4_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp5_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp6_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp7_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp8_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp9_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp10_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			while (TRUE) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp11_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp12_ = FALSE;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				if (!_data_->_tmp12_) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					break;
#line 464 "set-duplicate-email.c"
				}
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp13_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp14_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp15_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp15_ = _data_->backend;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp16_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp17_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp18_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 71 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->self->priv->_pstore = G_TYPE_CHECK_INSTANCE_CAST ((FolksPersonaStore*) _data_->_tmp18_, TRF_TYPE_PERSONA_STORE, TrfPersonaStore);
#line 73 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp19_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_data_->_tmp19_ = _data_->self->priv->_pstore;
#line 73 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				if (_data_->_tmp19_ != NULL) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					_g_object_unref0 (_data_->backend);
#line 74 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					break;
#line 506 "set-duplicate-email.c"
				}
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_g_object_unref0 (_data_->backend);
#line 510 "set-duplicate-email.c"
			}
#line 69 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 514 "set-duplicate-email.c"
		}
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp20_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp20_ = _data_->self->priv->_pstore;
#line 76 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_vala_assert (_data_->_tmp20_ != NULL, "this._pstore != null");
#line 77 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp21_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp21_ = _data_->self->priv->_pstore;
#line 77 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __set_duplicate_email_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 78 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_set_duplicate_email_tests_try_to_add (_data_->self, NULL, NULL);
#line 530 "set-duplicate-email.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->e = _data_->_inner_error_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_inner_error_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp22_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp22_ = _data_->e;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp23_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 82 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_warning ("set-duplicate-email.vala:82: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_error_free0 (_data_->e);
#line 551 "set-duplicate-email.c"
	}
	__finally0:
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_data_->store);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_clear_error (&_data_->_inner_error_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		return FALSE;
#line 564 "set-duplicate-email.c"
	}
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->store);
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_data_->_state_ == 0) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 572 "set-duplicate-email.c"
	} else {
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 576 "set-duplicate-email.c"
	}
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_object_unref (_data_->_async_result);
#line 58 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return FALSE;
#line 582 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_individuals_changed_cb (SetDuplicateEmailTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (changes != NULL);
#line 89 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = changes;
#line 89 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 89 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	added = _tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp2_ = changes;
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	removed = _tmp3_;
#line 612 "set-duplicate-email.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp4_ = added;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_i_it = _tmp5_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		while (TRUE) {
#line 625 "set-duplicate-email.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp6_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (!_tmp7_) {
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				break;
#line 644 "set-duplicate-email.c"
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp8_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			i = (FolksIndividual*) _tmp9_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp10_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp11_ = i;
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp13_ = _tmp12_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp14_ = self->priv->_persona_fullname_1;
#line 96 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 666 "set-duplicate-email.c"
				FolksIndividual* _tmp15_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp15_ = i;
#line 98 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_set_duplicate_email_tests_reset_email_address (self, _tmp15_);
#line 672 "set-duplicate-email.c"
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (i);
#line 676 "set-duplicate-email.c"
		}
#line 92 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_i_it);
#line 680 "set-duplicate-email.c"
	}
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp16_ = removed;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp18_ = _tmp17_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_vala_assert (_tmp18_ == 1, "removed.size == 1");
#line 690 "set-duplicate-email.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp19_ = removed;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_i_it = _tmp20_;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		while (TRUE) {
#line 703 "set-duplicate-email.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			FolksIndividual* _tmp25_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp21_ = _i_it;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (!_tmp22_) {
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				break;
#line 718 "set-duplicate-email.c"
			}
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp23_ = _i_it;
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			i = (FolksIndividual*) _tmp24_;
#line 106 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp25_ = i;
#line 106 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_vala_assert (_tmp25_ == NULL, "i == null");
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (i);
#line 732 "set-duplicate-email.c"
		}
#line 104 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_i_it);
#line 736 "set-duplicate-email.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (removed);
#line 86 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (added);
#line 742 "set-duplicate-email.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return result;
#line 751 "set-duplicate-email.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return result;
#line 760 "set-duplicate-email.c"
}


static void __set_duplicate_email_tests_email_addresses_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_email_addresses_cb ((SetDuplicateEmailTests*) self, _sender, pspec);
#line 767 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_reset_email_address (SetDuplicateEmailTests* self, FolksIndividual* i) {
#line 110 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (self != NULL);
#line 110 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (i != NULL);
#line 776 "set-duplicate-email.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp0_ = i;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp1_ = folks_individual_get_personas (_tmp0_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp2_ = _tmp1_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_p_it = _tmp3_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		while (TRUE) {
#line 795 "set-duplicate-email.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksPersona* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp4_ = _p_it;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (!_tmp5_) {
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				break;
#line 812 "set-duplicate-email.c"
			}
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp6_ = _p_it;
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			p = (FolksPersona*) _tmp7_;
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp8_ = p;
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp9_ = self->priv->_email_1;
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp10_ = _set_duplicate_email_tests_has_email (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TRF_TYPE_PERSONA, TrfPersona), _tmp9_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (_tmp10_) {
#line 828 "set-duplicate-email.c"
				GeeHashSet* emails1 = NULL;
				GeeHashSet* _tmp11_ = NULL;
				FolksEmailFieldDetails* email_1 = NULL;
				const gchar* _tmp12_ = NULL;
				FolksEmailFieldDetails* _tmp13_ = NULL;
				GeeHashSet* _tmp14_ = NULL;
				FolksEmailFieldDetails* _tmp15_ = NULL;
				FolksPersona* _tmp16_ = NULL;
				GeeHashSet* _tmp17_ = NULL;
				FolksPersona* _tmp18_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp11_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 116 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				emails1 = _tmp11_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp12_ = self->priv->_email_1;
#line 119 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp13_ = folks_email_field_details_new (_tmp12_, NULL);
#line 119 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				email_1 = _tmp13_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp14_ = emails1;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp15_ = email_1;
#line 120 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, _tmp15_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp16_ = p;
#line 121 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp17_ = emails1;
#line 121 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				folks_email_details_set_email_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, FOLKS_TYPE_EMAIL_DETAILS, FolksEmailDetails), (GeeSet*) _tmp17_);
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp18_ = p;
#line 122 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				g_signal_connect_object ((GObject*) _tmp18_, "notify::email-addresses", (GCallback) __set_duplicate_email_tests_email_addresses_cb_g_object_notify, self, 0);
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_g_object_unref0 (email_1);
#line 114 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_g_object_unref0 (emails1);
#line 869 "set-duplicate-email.c"
			}
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (p);
#line 873 "set-duplicate-email.c"
		}
#line 112 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_p_it);
#line 877 "set-duplicate-email.c"
	}
}


static void _set_duplicate_email_tests_email_addresses_cb (SetDuplicateEmailTests* self, GObject* p, GParamSpec* ps) {
	TrfPersona* persona = NULL;
	GObject* _tmp0_ = NULL;
	TrfPersona* _tmp1_ = NULL;
	TrfPersona* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (self != NULL);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (p != NULL);
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (ps != NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = p;
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TRF_TYPE_PERSONA, TrfPersona));
#line 129 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	persona = _tmp1_;
#line 130 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp2_ = persona;
#line 130 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp3_ = self->priv->_email_1;
#line 130 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp4_ = _set_duplicate_email_tests_has_email (self, _tmp2_, _tmp3_);
#line 130 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_tmp4_) {
#line 909 "set-duplicate-email.c"
		GMainLoop* _tmp5_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		self->priv->_email_found = TRUE;
#line 133 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_tmp5_ = self->priv->_main_loop;
#line 133 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_main_loop_quit (_tmp5_);
#line 917 "set-duplicate-email.c"
	}
#line 127 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (persona);
#line 921 "set-duplicate-email.c"
}


static gboolean _set_duplicate_email_tests_has_email (SetDuplicateEmailTests* self, TrfPersona* persona, const gchar* email) {
	gboolean result = FALSE;
	TrfPersona* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_val_if_fail (persona != NULL, FALSE);
#line 137 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_val_if_fail (email != NULL, FALSE);
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = persona;
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp1_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp0_);
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp2_ = _tmp1_;
#line 139 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_tmp2_ != NULL) {
#line 944 "set-duplicate-email.c"
		{
			GeeIterator* _fd_it = NULL;
			TrfPersona* _tmp3_ = NULL;
			GeeSet* _tmp4_ = NULL;
			GeeSet* _tmp5_ = NULL;
			GeeIterator* _tmp6_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp3_ = persona;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp4_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp3_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp5_ = _tmp4_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_fd_it = _tmp6_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			while (TRUE) {
#line 963 "set-duplicate-email.c"
				GeeIterator* _tmp7_ = NULL;
				gboolean _tmp8_ = FALSE;
				FolksEmailFieldDetails* fd = NULL;
				GeeIterator* _tmp9_ = NULL;
				gpointer _tmp10_ = NULL;
				FolksEmailFieldDetails* _tmp11_ = NULL;
				gconstpointer _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp7_ = _fd_it;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp8_ = gee_iterator_next (_tmp7_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				if (!_tmp8_) {
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					break;
#line 981 "set-duplicate-email.c"
				}
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp9_ = _fd_it;
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp10_ = gee_iterator_get (_tmp9_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				fd = (FolksEmailFieldDetails*) _tmp10_;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp11_ = fd;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp12_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp11_);
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp13_ = _tmp12_;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_tmp14_ = email;
#line 143 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				if (g_strcmp0 ((const gchar*) _tmp13_, _tmp14_) == 0) {
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					result = TRUE;
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					_g_object_unref0 (fd);
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					_g_object_unref0 (_fd_it);
#line 145 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
					return result;
#line 1007 "set-duplicate-email.c"
				}
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
				_g_object_unref0 (fd);
#line 1011 "set-duplicate-email.c"
			}
#line 141 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (_fd_it);
#line 1015 "set-duplicate-email.c"
		}
	}
#line 150 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	result = FALSE;
#line 150 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return result;
#line 1022 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_notify_pstore_cb (SetDuplicateEmailTests* self, GObject* _pstore, GParamSpec* ps) {
#line 153 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (self != NULL);
#line 153 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (_pstore != NULL);
#line 153 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_return_if_fail (ps != NULL);
#line 155 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_try_to_add (self, NULL, NULL);
#line 1035 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_try_to_add_data_free (gpointer _data) {
	SetDuplicateEmailTestsTryToAddData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_slice_free (SetDuplicateEmailTestsTryToAddData, _data_);
#line 1046 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_try_to_add (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetDuplicateEmailTestsTryToAddData* _data_;
	SetDuplicateEmailTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_slice_new0 (SetDuplicateEmailTestsTryToAddData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_duplicate_email_tests_try_to_add);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_duplicate_email_tests_try_to_add_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_try_to_add_co (_data_);
#line 1065 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_try_to_add_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_) {
	SetDuplicateEmailTestsTryToAddData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1073 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetDuplicateEmailTestsTryToAddData* _data_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = _user_data_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_source_object_ = source_object;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_res_ = _res_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_try_to_add_co (_data_);
#line 1087 "set-duplicate-email.c"
}


static gboolean _set_duplicate_email_tests_try_to_add_co (SetDuplicateEmailTestsTryToAddData* _data_) {
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	switch (_data_->_state_) {
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 0:
#line 1096 "set-duplicate-email.c"
		goto _state_0;
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 1:
#line 1100 "set-duplicate-email.c"
		goto _state_1;
		default:
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_assert_not_reached ();
#line 1105 "set-duplicate-email.c"
	}
	_state_0:
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = _data_->self->priv->_pstore;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = FALSE;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = folks_persona_store_get_is_prepared ((FolksPersonaStore*) _data_->_tmp1_);
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp3_ = FALSE;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_data_->_tmp3_) {
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp4_ = FALSE;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp4_ = _data_->self->priv->_added_personas;
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp0_ = _data_->_tmp4_ == FALSE;
#line 1128 "set-duplicate-email.c"
	} else {
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp0_ = FALSE;
#line 1132 "set-duplicate-email.c"
	}
#line 160 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_data_->_tmp0_) {
#line 162 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->self->priv->_added_personas = TRUE;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_state_ = 1;
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_set_duplicate_email_tests_add_personas (_data_->self, _set_duplicate_email_tests_try_to_add_ready, _data_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		return FALSE;
#line 1144 "set-duplicate-email.c"
		_state_1:
#line 163 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_set_duplicate_email_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 1148 "set-duplicate-email.c"
	}
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_data_->_state_ == 0) {
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1154 "set-duplicate-email.c"
	} else {
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1158 "set-duplicate-email.c"
	}
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_object_unref (_data_->_async_result);
#line 158 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return FALSE;
#line 1164 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_add_personas_data_free (gpointer _data) {
	SetDuplicateEmailTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_slice_free (SetDuplicateEmailTestsAddPersonasData, _data_);
#line 1175 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_add_personas (SetDuplicateEmailTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetDuplicateEmailTestsAddPersonasData* _data_;
	SetDuplicateEmailTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_slice_new0 (SetDuplicateEmailTestsAddPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_duplicate_email_tests_add_personas);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_duplicate_email_tests_add_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_add_personas_co (_data_);
#line 1194 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_add_personas_finish (SetDuplicateEmailTests* self, GAsyncResult* _res_) {
	SetDuplicateEmailTestsAddPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1202 "set-duplicate-email.c"
}


/**
   * Add 1 persona and once we've seen it try to re-set it's
   * e-mail address (the Tracker backend should figure it already
   * exist so we don't bump into a constraint error).
   * See https://bugzilla.gnome.org/show_bug.cgi?id=647331 */
static void _g_free0_ (gpointer var) {
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	var = (g_free (var), NULL);
#line 1214 "set-duplicate-email.c"
}


static void _vala_GValue_free (GValue* self) {
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_value_unset (self);
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_free (self);
#line 1223 "set-duplicate-email.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1230 "set-duplicate-email.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1237 "set-duplicate-email.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1244 "set-duplicate-email.c"
}


static void _set_duplicate_email_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetDuplicateEmailTestsAddPersonasData* _data_;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_ = _user_data_;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_source_object_ = source_object;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_res_ = _res_;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_set_duplicate_email_tests_add_personas_co (_data_);
#line 1258 "set-duplicate-email.c"
}


static gboolean _set_duplicate_email_tests_add_personas_co (SetDuplicateEmailTestsAddPersonasData* _data_) {
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	switch (_data_->_state_) {
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 0:
#line 1267 "set-duplicate-email.c"
		goto _state_0;
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		case 1:
#line 1271 "set-duplicate-email.c"
		goto _state_1;
		default:
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_assert_not_reached ();
#line 1276 "set-duplicate-email.c"
	}
	_state_0:
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp0_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp0_ = g_str_hash;
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp1_ = g_str_equal;
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 174 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->details1 = _data_->_tmp2_;
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp5_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	__vala_GValue_free0 (_data_->val);
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->val = _data_->_tmp5_;
#line 178 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp6_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp6_ = _data_->val;
#line 179 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp7_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp7_ = _data_->self->priv->_persona_fullname_1;
#line 179 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_value_set_string (_data_->_tmp6_, _data_->_tmp7_);
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp8_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp8_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp9_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp9_ = g_strdup (_data_->_tmp8_);
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp10_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp10_ = _data_->val;
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->val = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_hash_table_insert (_data_->details1, _data_->_tmp9_, _data_->_tmp10_);
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	memset (&_data_->_tmp11_, 0, sizeof (GValue));
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_value_init (&_data_->_tmp11_, GEE_TYPE_SET);
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	memset (&_data_->_tmp12_, 0, sizeof (GValue));
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp13_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp13_ = __g_value_dup0 (&_data_->_tmp12_);
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	__vala_GValue_free0 (_data_->val);
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->val = _data_->_tmp13_;
#line 183 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	G_IS_VALUE (&_data_->_tmp12_) ? (g_value_unset (&_data_->_tmp12_), NULL) : NULL;
#line 184 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp14_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp14_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 184 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->emails1 = _data_->_tmp14_;
#line 187 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp15_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp15_ = _data_->self->priv->_email_1;
#line 187 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp16_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp16_ = folks_email_field_details_new (_data_->_tmp15_, NULL);
#line 187 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->email_1 = _data_->_tmp16_;
#line 188 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails1, _data_->email_1);
#line 189 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp17_ = NULL;
#line 189 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp17_ = _data_->val;
#line 189 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_value_set_object (_data_->_tmp17_, (GObject*) _data_->emails1);
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp18_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp18_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp19_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp19_ = g_strdup (_data_->_tmp18_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp20_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->_tmp20_ = _data_->val;
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_data_->val = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_hash_table_insert (_data_->details1, _data_->_tmp19_, _data_->_tmp20_);
#line 1395 "set-duplicate-email.c"
	{
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp21_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp21_ = _data_->self->priv->_aggregator;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp22_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp22_ = _data_->self->priv->_pstore;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_state_ = 1;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp21_, NULL, (FolksPersonaStore*) _data_->_tmp22_, _data_->details1, _set_duplicate_email_tests_add_personas_ready, _data_);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		return FALSE;
#line 1411 "set-duplicate-email.c"
		_state_1:
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp23_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp23_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp21_, _data_->_res_, &_data_->_inner_error_);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp24_ = NULL;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp24_ = _data_->_tmp23_;
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_data_->_tmp24_);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1427 "set-duplicate-email.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (_data_->email_1);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_object_unref0 (_data_->emails1);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			__vala_GValue_free0 (_data_->val);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			g_clear_error (&_data_->_inner_error_);
#line 196 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
			return FALSE;
#line 1444 "set-duplicate-email.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->e = _data_->_inner_error_;
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_inner_error_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp25_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp25_ = _data_->e;
#line 201 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp26_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_data_->_tmp26_ = _data_->_tmp25_->message;
#line 201 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_warning ("set-duplicate-email.vala:201: [AddPersonaError] add_persona_from_detai" \
"ls: %s\n", _data_->_tmp26_);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_error_free0 (_data_->e);
#line 1466 "set-duplicate-email.c"
	}
	__finally1:
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_data_->email_1);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_object_unref0 (_data_->emails1);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		__vala_GValue_free0 (_data_->val);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_clear_error (&_data_->_inner_error_);
#line 194 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		return FALSE;
#line 1485 "set-duplicate-email.c"
	}
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->email_1);
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (_data_->emails1);
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	__vala_GValue_free0 (_data_->val);
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	if (_data_->_state_ == 0) {
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1499 "set-duplicate-email.c"
	} else {
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1503 "set-duplicate-email.c"
	}
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_object_unref (_data_->_async_result);
#line 172 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return FALSE;
#line 1509 "set-duplicate-email.c"
}


static void set_duplicate_email_tests_class_init (SetDuplicateEmailTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	set_duplicate_email_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_type_class_add_private (klass, sizeof (SetDuplicateEmailTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	G_OBJECT_CLASS (klass)->finalize = set_duplicate_email_tests_finalize;
#line 1520 "set-duplicate-email.c"
}


static void set_duplicate_email_tests_instance_init (SetDuplicateEmailTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv = SET_DUPLICATE_EMAIL_TESTS_GET_PRIVATE (self);
#line 30 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = g_strdup ("persona #1");
#line 30 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv->_persona_fullname_1 = _tmp0_;
#line 31 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp1_ = g_strdup ("some-address@example.org");
#line 31 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv->_email_1 = _tmp1_;
#line 32 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self->priv->_added_personas = FALSE;
#line 1539 "set-duplicate-email.c"
}


static void set_duplicate_email_tests_finalize (GObject* obj) {
	SetDuplicateEmailTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_DUPLICATE_EMAIL_TESTS, SetDuplicateEmailTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_free0 (self->priv->_email_1);
#line 33 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	G_OBJECT_CLASS (set_duplicate_email_tests_parent_class)->finalize (obj);
#line 1559 "set-duplicate-email.c"
}


GType set_duplicate_email_tests_get_type (void) {
	static volatile gsize set_duplicate_email_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_duplicate_email_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetDuplicateEmailTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_duplicate_email_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetDuplicateEmailTests), 0, (GInstanceInitFunc) set_duplicate_email_tests_instance_init, NULL };
		GType set_duplicate_email_tests_type_id;
		set_duplicate_email_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "SetDuplicateEmailTests", &g_define_type_info, 0);
		g_once_init_leave (&set_duplicate_email_tests_type_id__volatile, set_duplicate_email_tests_type_id);
	}
	return set_duplicate_email_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetDuplicateEmailTests* tests = NULL;
	SetDuplicateEmailTests* _tmp0_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_test_init (&args_length1, &args, NULL);
#line 211 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_tmp0_ = set_duplicate_email_tests_new ();
#line 211 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	tests = _tmp0_;
#line 212 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 213 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	g_test_run ();
#line 214 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 216 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	result = 0;
#line 216 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	_g_object_unref0 (tests);
#line 216 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return result;
#line 1597 "set-duplicate-email.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 207 "/opt/gnome3/source/folks/tests/tracker/set-duplicate-email.vala"
	return _vala_main (argv, argc);
#line 1607 "set-duplicate-email.c"
}



