/* trf-util.c generated by valac 0.34.0.3-63fa6, the Vala compiler
 * generated from trf-util.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <string.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <folks/folks.h>


#define TYPE_EVENT (event_get_type ())
typedef struct _Event Event;

#define TYPE_RESOURCES (resources_get_type ())
#define RESOURCES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RESOURCES, Resources))
#define IS_RESOURCES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RESOURCES))
#define RESOURCES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_RESOURCES, ResourcesIface))

typedef struct _Resources Resources;
typedef struct _ResourcesIface ResourcesIface;

#define TYPE_RESOURCES_PROXY (resources_proxy_get_type ())
typedef GDBusProxy ResourcesProxy;
typedef GDBusProxyClass ResourcesProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TRF_TYPE_AFFL_INFO (trf_affl_info_get_type ())
#define TRF_AFFL_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRF_TYPE_AFFL_INFO, TrfAfflInfo))
#define TRF_AFFL_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRF_TYPE_AFFL_INFO, TrfAfflInfoClass))
#define TRF_IS_AFFL_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRF_TYPE_AFFL_INFO))
#define TRF_IS_AFFL_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRF_TYPE_AFFL_INFO))
#define TRF_AFFL_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRF_TYPE_AFFL_INFO, TrfAfflInfoClass))

typedef struct _TrfAfflInfo TrfAfflInfo;
typedef struct _TrfAfflInfoClass TrfAfflInfoClass;
typedef struct _TrfAfflInfoPrivate TrfAfflInfoPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TRF_TYPE_ONTOLOGY_DEFS (trf_ontology_defs_get_type ())
#define TRF_ONTOLOGY_DEFS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRF_TYPE_ONTOLOGY_DEFS, TrfOntologyDefs))
#define TRF_ONTOLOGY_DEFS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TRF_TYPE_ONTOLOGY_DEFS, TrfOntologyDefsClass))
#define TRF_IS_ONTOLOGY_DEFS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TRF_TYPE_ONTOLOGY_DEFS))
#define TRF_IS_ONTOLOGY_DEFS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TRF_TYPE_ONTOLOGY_DEFS))
#define TRF_ONTOLOGY_DEFS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TRF_TYPE_ONTOLOGY_DEFS, TrfOntologyDefsClass))

typedef struct _TrfOntologyDefs TrfOntologyDefs;
typedef struct _TrfOntologyDefsClass TrfOntologyDefsClass;
typedef struct _TrfOntologyDefsPrivate TrfOntologyDefsPrivate;

struct _Event {
	gint graph_id;
	gint subject_id;
	gint pred_id;
	gint object_id;
};

struct _ResourcesIface {
	GTypeInterface parent_iface;
};

struct _TrfAfflInfo {
	GObject parent_instance;
	TrfAfflInfoPrivate * priv;
	FolksPostalAddressFieldDetails* postal_address_fd;
};

struct _TrfAfflInfoClass {
	GObjectClass parent_class;
};

struct _TrfAfflInfoPrivate {
	gchar* _im_tracker_id;
	gchar* _im_proto;
	gchar* _im_account_id;
	gchar* _im_nickname;
	gchar* _affl_tracker_id;
	gchar* _title;
	gchar* _org;
	gchar* _role;
	gchar* _email;
	gchar* _phone;
	gchar* _website;
	gchar* _blog;
	gchar* _url;
};

struct _TrfOntologyDefs {
	GObject parent_instance;
	TrfOntologyDefsPrivate * priv;
};

struct _TrfOntologyDefsClass {
	GObjectClass parent_class;
};


static gpointer trf_affl_info_parent_class = NULL;
static gpointer trf_ontology_defs_parent_class = NULL;

GType event_get_type (void) G_GNUC_CONST;
Event* event_dup (const Event* self);
void event_free (Event* self);
GType resources_get_type (void) G_GNUC_CONST;
GType resources_proxy_get_type (void) G_GNUC_CONST;
guint resources_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
static void g_cclosure_user_marshal_VOID__STRING_POINTER_INT_POINTER_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void resources_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static void _dbus_handle_resources_graph_updated (Resources* self, GVariant* parameters);
static void resources_proxy_resources_interface_init (ResourcesIface* iface);
static void resources_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* resources_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean resources_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_resources_graph_updated (GObject* _sender, const gchar* class_name, Event* deletes, int deletes_length1, Event* inserts, int inserts_length1, gpointer* _data);
static void _resources_unregister_object (gpointer user_data);
GType trf_affl_info_get_type (void) G_GNUC_CONST;
#define TRF_AFFL_INFO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRF_TYPE_AFFL_INFO, TrfAfflInfoPrivate))
enum  {
	TRF_AFFL_INFO_DUMMY_PROPERTY,
	TRF_AFFL_INFO_IM_TRACKER_ID,
	TRF_AFFL_INFO_IM_PROTO,
	TRF_AFFL_INFO_IM_ACCOUNT_ID,
	TRF_AFFL_INFO_IM_NICKNAME,
	TRF_AFFL_INFO_AFFL_TRACKER_ID,
	TRF_AFFL_INFO_TITLE,
	TRF_AFFL_INFO_ORG,
	TRF_AFFL_INFO_ROLE,
	TRF_AFFL_INFO_EMAIL,
	TRF_AFFL_INFO_PHONE,
	TRF_AFFL_INFO_WEBSITE,
	TRF_AFFL_INFO_BLOG,
	TRF_AFFL_INFO_URL
};
gchar* trf_affl_info_to_string (TrfAfflInfo* self);
TrfAfflInfo* trf_affl_info_new (void);
TrfAfflInfo* trf_affl_info_construct (GType object_type);
const gchar* trf_affl_info_get_im_tracker_id (TrfAfflInfo* self);
void trf_affl_info_set_im_tracker_id (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_im_proto (TrfAfflInfo* self);
void trf_affl_info_set_im_proto (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_im_account_id (TrfAfflInfo* self);
void trf_affl_info_set_im_account_id (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_im_nickname (TrfAfflInfo* self);
void trf_affl_info_set_im_nickname (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_affl_tracker_id (TrfAfflInfo* self);
void trf_affl_info_set_affl_tracker_id (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_title (TrfAfflInfo* self);
void trf_affl_info_set_title (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_org (TrfAfflInfo* self);
void trf_affl_info_set_org (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_role (TrfAfflInfo* self);
void trf_affl_info_set_role (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_email (TrfAfflInfo* self);
void trf_affl_info_set_email (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_phone (TrfAfflInfo* self);
void trf_affl_info_set_phone (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_website (TrfAfflInfo* self);
void trf_affl_info_set_website (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_blog (TrfAfflInfo* self);
void trf_affl_info_set_blog (TrfAfflInfo* self, const gchar* value);
const gchar* trf_affl_info_get_url (TrfAfflInfo* self);
void trf_affl_info_set_url (TrfAfflInfo* self, const gchar* value);
static void trf_affl_info_finalize (GObject* obj);
static void _vala_trf_affl_info_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_trf_affl_info_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType trf_ontology_defs_get_type (void) G_GNUC_CONST;
enum  {
	TRF_ONTOLOGY_DEFS_DUMMY_PROPERTY
};
#define TRF_ONTOLOGY_DEFS_DEFAULT_CONTACT_URN "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#default-conta" \
"ct-me"
#define TRF_ONTOLOGY_DEFS_PERSON_CLASS "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#PersonContact"
#define TRF_ONTOLOGY_DEFS_NCO_FULLNAME "nco:fullname"
#define TRF_ONTOLOGY_DEFS_NCO_FAMILY "nco:nameFamily"
#define TRF_ONTOLOGY_DEFS_NCO_GIVEN "nco:nameGiven"
#define TRF_ONTOLOGY_DEFS_NCO_ADDITIONAL "nco:nameAdditional"
#define TRF_ONTOLOGY_DEFS_NCO_SUFFIX "nco:nameHonorificSuffix"
#define TRF_ONTOLOGY_DEFS_NCO_PREFIX "nco:nameHonorificPrefix"
#define TRF_ONTOLOGY_DEFS_NCO_NICKNAME "nco:nickname"
#define TRF_ONTOLOGY_DEFS_RDF_TYPE "ns:type"
#define TRF_ONTOLOGY_DEFS_NCO_PERSON "nco:PersonContact"
#define TRF_ONTOLOGY_DEFS_NCO_URL "nco:url"
#define TRF_ONTOLOGY_DEFS_NCO_WEBSITE "nco:websiteUrl"
#define TRF_ONTOLOGY_DEFS_NCO_BLOG "nco:blogUrl"
#define TRF_ONTOLOGY_DEFS_NAO_FAVORITE "nao:predefined-tag-favorite"
#define TRF_ONTOLOGY_DEFS_NAO_TAG "nao:hasTag"
#define TRF_ONTOLOGY_DEFS_NAO_PROPERTY "nao:Property"
#define TRF_ONTOLOGY_DEFS_NAO_HAS_PROPERTY "nao:hasProperty"
#define TRF_ONTOLOGY_DEFS_NAO_PROPERTY_NAME "nao:propertyName"
#define TRF_ONTOLOGY_DEFS_NAO_PROPERTY_VALUE "nao:propertyValue"
#define TRF_ONTOLOGY_DEFS_NCO_HAS_EMAIL "nco:hasEmailAddress"
#define TRF_ONTOLOGY_DEFS_NCO_EMAIL "nco:EmailAddress"
#define TRF_ONTOLOGY_DEFS_NCO_EMAIL_PROP "nco:emailAddress"
#define TRF_ONTOLOGY_DEFS_NCO_HAS_PHONE "nco:hasPhoneNumber"
#define TRF_ONTOLOGY_DEFS_NCO_PHONE "nco:PhoneNumber"
#define TRF_ONTOLOGY_DEFS_NCO_PHONE_PROP "nco:phoneNumber"
#define TRF_ONTOLOGY_DEFS_NCO_HAS_AFFILIATION "nco:hasAffiliation"
#define TRF_ONTOLOGY_DEFS_NCO_AFFILIATION "nco:Affiliation"
#define TRF_ONTOLOGY_DEFS_NCO_BIRTHDAY "nco:birthDate"
#define TRF_ONTOLOGY_DEFS_NCO_NOTE "nco:note"
#define TRF_ONTOLOGY_DEFS_NCO_GENDER "nco:gender"
#define TRF_ONTOLOGY_DEFS_NCO_MALE "nco:gender-male"
#define TRF_ONTOLOGY_DEFS_NCO_FEMALE "nco:gender-female"
#define TRF_ONTOLOGY_DEFS_NCO_PHOTO "nco:photo"
#define TRF_ONTOLOGY_DEFS_NIE_URL "nie:url"
#define TRF_ONTOLOGY_DEFS_NFO_IMAGE "nfo:Image"
#define TRF_ONTOLOGY_DEFS_NIE_DATAOBJECT "nie:DataObject"
#define TRF_ONTOLOGY_DEFS_NCO_IMADDRESS "nco:IMAddress"
#define TRF_ONTOLOGY_DEFS_NCO_HAS_IMADDRESS "nco:hasIMAddress"
#define TRF_ONTOLOGY_DEFS_NCO_IMPROTOCOL "nco:imProtocol"
#define TRF_ONTOLOGY_DEFS_NCO_IMID "nco:imID"
#define TRF_ONTOLOGY_DEFS_NCO_IM_NICKNAME "nco:imNickname"
#define TRF_ONTOLOGY_DEFS_NCO_POSTAL_ADDRESS "nco:PostalAddress"
#define TRF_ONTOLOGY_DEFS_NCO_HAS_POSTAL_ADDRESS "nco:hasPostalAddress"
#define TRF_ONTOLOGY_DEFS_NCO_POBOX "nco:pobox"
#define TRF_ONTOLOGY_DEFS_NCO_DISTRICT "nco:district"
#define TRF_ONTOLOGY_DEFS_NCO_COUNTY "nco:county"
#define TRF_ONTOLOGY_DEFS_NCO_LOCALITY "nco:locality"
#define TRF_ONTOLOGY_DEFS_NCO_POSTALCODE "nco:postalcode"
#define TRF_ONTOLOGY_DEFS_NCO_STREET_ADDRESS "nco:streetAddress"
#define TRF_ONTOLOGY_DEFS_NCO_ADDRESS_LOCATION "nco:addressLocation"
#define TRF_ONTOLOGY_DEFS_NCO_EXTENDED_ADDRESS "nco:extendedAddress"
#define TRF_ONTOLOGY_DEFS_NCO_COUNTRY "nco:country"
#define TRF_ONTOLOGY_DEFS_NCO_REGION "nco:region"
#define TRF_ONTOLOGY_DEFS_NCO_ROLE "nco:role"
#define TRF_ONTOLOGY_DEFS_NCO_TITLE "nco:title"
#define TRF_ONTOLOGY_DEFS_NCO_ORG "nco:org"
#define TRF_ONTOLOGY_DEFS_NCO_URL_PREFIX "<http://www.semanticdesktop.org/ontologies/2007/03/22/"
#define TRF_ONTOLOGY_DEFS_NAO_URL_PREFIX "<http://www.semanticdesktop.org/ontologies/2007/08/15/"
#define TRF_ONTOLOGY_DEFS_RDF_URL_PREFIX "<http://www.w3.org/1999/02/"
TrfOntologyDefs* trf_ontology_defs_new (void);
TrfOntologyDefs* trf_ontology_defs_construct (GType object_type);

static const GDBusMethodInfo * const _resources_dbus_method_info[] = {NULL};
static const GDBusArgInfo _resources_dbus_arg_info_graph_updated_class_name = {-1, "class_name", "s"};
static const GDBusArgInfo _resources_dbus_arg_info_graph_updated_deletes = {-1, "deletes", "a(iiii)"};
static const GDBusArgInfo _resources_dbus_arg_info_graph_updated_inserts = {-1, "inserts", "a(iiii)"};
static const GDBusArgInfo * const _resources_dbus_arg_info_graph_updated[] = {&_resources_dbus_arg_info_graph_updated_class_name, &_resources_dbus_arg_info_graph_updated_deletes, &_resources_dbus_arg_info_graph_updated_inserts, NULL};
static const GDBusSignalInfo _resources_dbus_signal_info_graph_updated = {-1, "GraphUpdated", (GDBusArgInfo **) (&_resources_dbus_arg_info_graph_updated)};
static const GDBusSignalInfo * const _resources_dbus_signal_info[] = {&_resources_dbus_signal_info_graph_updated, NULL};
static const GDBusPropertyInfo * const _resources_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _resources_dbus_interface_info = {-1, "org.freedesktop.Tracker1.Resources", (GDBusMethodInfo **) (&_resources_dbus_method_info), (GDBusSignalInfo **) (&_resources_dbus_signal_info), (GDBusPropertyInfo **) (&_resources_dbus_property_info)};
static const GDBusInterfaceVTable _resources_dbus_interface_vtable = {resources_dbus_interface_method_call, resources_dbus_interface_get_property, resources_dbus_interface_set_property};

Event* event_dup (const Event* self) {
	Event* dup;
	dup = g_new0 (Event, 1);
	memcpy (dup, self, sizeof (Event));
	return dup;
}


void event_free (Event* self) {
	g_free (self);
}


GType event_get_type (void) {
	static volatile gsize event_type_id__volatile = 0;
	if (g_once_init_enter (&event_type_id__volatile)) {
		GType event_type_id;
		event_type_id = g_boxed_type_register_static ("Event", (GBoxedCopyFunc) event_dup, (GBoxedFreeFunc) event_free);
		g_once_init_leave (&event_type_id__volatile, event_type_id);
	}
	return event_type_id__volatile;
}


static void g_cclosure_user_marshal_VOID__STRING_POINTER_INT_POINTER_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_POINTER_INT_POINTER_INT) (gpointer data1, const char* arg_1, gpointer arg_2, gint arg_3, gpointer arg_4, gint arg_5, gpointer data2);
	register GMarshalFunc_VOID__STRING_POINTER_INT_POINTER_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 6);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_POINTER_INT_POINTER_INT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_pointer (param_values + 2), g_value_get_int (param_values + 3), g_value_get_pointer (param_values + 4), g_value_get_int (param_values + 5), data2);
}


static void resources_base_init (ResourcesIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_signal_new ("graph_updated", TYPE_RESOURCES, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_POINTER_INT_POINTER_INT, G_TYPE_NONE, 5, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT, G_TYPE_POINTER, G_TYPE_INT);
	}
}


GType resources_get_type (void) {
	static volatile gsize resources_type_id__volatile = 0;
	if (g_once_init_enter (&resources_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ResourcesIface), (GBaseInitFunc) resources_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType resources_type_id;
		resources_type_id = g_type_register_static (G_TYPE_INTERFACE, "Resources", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (resources_type_id, G_TYPE_DBUS_PROXY);
		g_type_set_qdata (resources_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) resources_proxy_get_type);
		g_type_set_qdata (resources_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.Tracker1.Resources");
		g_type_set_qdata (resources_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_resources_dbus_interface_info));
		g_type_set_qdata (resources_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) resources_register_object);
		g_once_init_leave (&resources_type_id__volatile, resources_type_id);
	}
	return resources_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (ResourcesProxy, resources_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (TYPE_RESOURCES, resources_proxy_resources_interface_init) )
static void resources_proxy_class_init (ResourcesProxyClass* klass) {
	G_DBUS_PROXY_CLASS (klass)->g_signal = resources_proxy_g_signal;
}


static void _dbus_handle_resources_graph_updated (Resources* self, GVariant* parameters) {
	GVariantIter _arguments_iter;
	gchar* class_name = NULL;
	GVariant* _tmp0_;
	Event* deletes = NULL;
	int deletes_length1;
	GVariant* _tmp1_;
	Event* _tmp2_;
	int _tmp2__length;
	int _tmp2__size;
	int _tmp2__length1;
	GVariantIter _tmp3_;
	GVariant* _tmp4_;
	Event* inserts = NULL;
	int inserts_length1;
	GVariant* _tmp11_;
	Event* _tmp12_;
	int _tmp12__length;
	int _tmp12__size;
	int _tmp12__length1;
	GVariantIter _tmp13_;
	GVariant* _tmp14_;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp0_ = g_variant_iter_next_value (&_arguments_iter);
	class_name = g_variant_dup_string (_tmp0_, NULL);
	g_variant_unref (_tmp0_);
	deletes_length1 = 0;
	_tmp1_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp2_ = g_new (Event, 5);
	_tmp2__length = 0;
	_tmp2__size = 4;
	_tmp2__length1 = 0;
	g_variant_iter_init (&_tmp3_, _tmp1_);
	for (; (_tmp4_ = g_variant_iter_next_value (&_tmp3_)) != NULL; _tmp2__length1++) {
		Event _tmp5_;
		GVariantIter _tmp6_;
		GVariant* _tmp7_;
		GVariant* _tmp8_;
		GVariant* _tmp9_;
		GVariant* _tmp10_;
		if (_tmp2__size == _tmp2__length) {
			_tmp2__size = 2 * _tmp2__size;
			_tmp2_ = g_renew (Event, _tmp2_, _tmp2__size + 1);
		}
		g_variant_iter_init (&_tmp6_, _tmp4_);
		_tmp7_ = g_variant_iter_next_value (&_tmp6_);
		_tmp5_.graph_id = g_variant_get_int32 (_tmp7_);
		g_variant_unref (_tmp7_);
		_tmp8_ = g_variant_iter_next_value (&_tmp6_);
		_tmp5_.subject_id = g_variant_get_int32 (_tmp8_);
		g_variant_unref (_tmp8_);
		_tmp9_ = g_variant_iter_next_value (&_tmp6_);
		_tmp5_.pred_id = g_variant_get_int32 (_tmp9_);
		g_variant_unref (_tmp9_);
		_tmp10_ = g_variant_iter_next_value (&_tmp6_);
		_tmp5_.object_id = g_variant_get_int32 (_tmp10_);
		g_variant_unref (_tmp10_);
		_tmp2_[_tmp2__length++] = _tmp5_;
		g_variant_unref (_tmp4_);
	}
	deletes_length1 = _tmp2__length1;
	deletes = _tmp2_;
	g_variant_unref (_tmp1_);
	inserts_length1 = 0;
	_tmp11_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp12_ = g_new (Event, 5);
	_tmp12__length = 0;
	_tmp12__size = 4;
	_tmp12__length1 = 0;
	g_variant_iter_init (&_tmp13_, _tmp11_);
	for (; (_tmp14_ = g_variant_iter_next_value (&_tmp13_)) != NULL; _tmp12__length1++) {
		Event _tmp15_;
		GVariantIter _tmp16_;
		GVariant* _tmp17_;
		GVariant* _tmp18_;
		GVariant* _tmp19_;
		GVariant* _tmp20_;
		if (_tmp12__size == _tmp12__length) {
			_tmp12__size = 2 * _tmp12__size;
			_tmp12_ = g_renew (Event, _tmp12_, _tmp12__size + 1);
		}
		g_variant_iter_init (&_tmp16_, _tmp14_);
		_tmp17_ = g_variant_iter_next_value (&_tmp16_);
		_tmp15_.graph_id = g_variant_get_int32 (_tmp17_);
		g_variant_unref (_tmp17_);
		_tmp18_ = g_variant_iter_next_value (&_tmp16_);
		_tmp15_.subject_id = g_variant_get_int32 (_tmp18_);
		g_variant_unref (_tmp18_);
		_tmp19_ = g_variant_iter_next_value (&_tmp16_);
		_tmp15_.pred_id = g_variant_get_int32 (_tmp19_);
		g_variant_unref (_tmp19_);
		_tmp20_ = g_variant_iter_next_value (&_tmp16_);
		_tmp15_.object_id = g_variant_get_int32 (_tmp20_);
		g_variant_unref (_tmp20_);
		_tmp12_[_tmp12__length++] = _tmp15_;
		g_variant_unref (_tmp14_);
	}
	inserts_length1 = _tmp12__length1;
	inserts = _tmp12_;
	g_variant_unref (_tmp11_);
	g_signal_emit_by_name (self, "graph-updated", class_name, deletes, deletes_length1, inserts, inserts_length1);
	_g_free0 (class_name);
	deletes = (g_free (deletes), NULL);
	inserts = (g_free (inserts), NULL);
}


static void resources_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
	if (strcmp (signal_name, "GraphUpdated") == 0) {
		_dbus_handle_resources_graph_updated ((Resources*) proxy, parameters);
	}
}


static void resources_proxy_init (ResourcesProxy* self) {
}


static void resources_proxy_resources_interface_init (ResourcesIface* iface) {
}


static void resources_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	g_object_unref (invocation);
}


static GVariant* resources_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}


static gboolean resources_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}


static void _dbus_resources_graph_updated (GObject* _sender, const gchar* class_name, Event* deletes, int deletes_length1, Event* inserts, int inserts_length1, gpointer* _data) {
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	Event* _tmp21_;
	GVariantBuilder _tmp22_;
	int _tmp23_;
	Event* _tmp25_;
	GVariantBuilder _tmp26_;
	int _tmp27_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (class_name));
	_tmp21_ = deletes;
	g_variant_builder_init (&_tmp22_, G_VARIANT_TYPE ("a(iiii)"));
	for (_tmp23_ = 0; _tmp23_ < deletes_length1; _tmp23_++) {
		GVariantBuilder _tmp24_;
		g_variant_builder_init (&_tmp24_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp24_, g_variant_new_int32 ((*_tmp21_).graph_id));
		g_variant_builder_add_value (&_tmp24_, g_variant_new_int32 ((*_tmp21_).subject_id));
		g_variant_builder_add_value (&_tmp24_, g_variant_new_int32 ((*_tmp21_).pred_id));
		g_variant_builder_add_value (&_tmp24_, g_variant_new_int32 ((*_tmp21_).object_id));
		g_variant_builder_add_value (&_tmp22_, g_variant_builder_end (&_tmp24_));
		_tmp21_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp22_));
	_tmp25_ = inserts;
	g_variant_builder_init (&_tmp26_, G_VARIANT_TYPE ("a(iiii)"));
	for (_tmp27_ = 0; _tmp27_ < inserts_length1; _tmp27_++) {
		GVariantBuilder _tmp28_;
		g_variant_builder_init (&_tmp28_, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_tmp28_, g_variant_new_int32 ((*_tmp25_).graph_id));
		g_variant_builder_add_value (&_tmp28_, g_variant_new_int32 ((*_tmp25_).subject_id));
		g_variant_builder_add_value (&_tmp28_, g_variant_new_int32 ((*_tmp25_).pred_id));
		g_variant_builder_add_value (&_tmp28_, g_variant_new_int32 ((*_tmp25_).object_id));
		g_variant_builder_add_value (&_tmp26_, g_variant_builder_end (&_tmp28_));
		_tmp25_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp26_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.freedesktop.Tracker1.Resources", "GraphUpdated", _arguments, NULL);
}


guint resources_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_resources_dbus_interface_info), &_resources_dbus_interface_vtable, data, _resources_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "graph-updated", (GCallback) _dbus_resources_graph_updated, data);
	return result;
}


static void _resources_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_resources_graph_updated, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


gchar* trf_affl_info_to_string (TrfAfflInfo* self) {
	gchar* result = NULL;
	gchar* ret = NULL;
	gchar* _tmp0_ = NULL;
	gboolean first = FALSE;
	GParamSpec** properties = NULL;
	GObjectClass* _tmp1_ = NULL;
	guint _tmp2_;
	GParamSpec** _tmp3_ = NULL;
	gint properties_length1 = 0;
	gint _properties_size_ = 0;
	GParamSpec** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_strdup (" { ");
	ret = _tmp0_;
	first = TRUE;
	_tmp1_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp3_ = g_object_class_list_properties (_tmp1_, &_tmp2_);
	properties = _tmp3_;
	properties_length1 = _tmp2_;
	_properties_size_ = properties_length1;
	_tmp4_ = properties;
	_tmp4__length1 = properties_length1;
	{
		GParamSpec** pspec_collection = NULL;
		gint pspec_collection_length1 = 0;
		gint _pspec_collection_size_ = 0;
		gint pspec_it = 0;
		pspec_collection = _tmp4_;
		pspec_collection_length1 = _tmp4__length1;
		for (pspec_it = 0; pspec_it < _tmp4__length1; pspec_it = pspec_it + 1) {
			GParamSpec* pspec = NULL;
			pspec = pspec_collection[pspec_it];
			{
				gchar* property = NULL;
				GParamSpec* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				gchar* _tmp7_ = NULL;
				GValue prop_value = {0};
				GParamSpec* _tmp8_ = NULL;
				GType _tmp9_ = 0UL;
				GValue _tmp10_ = {0};
				const gchar* _tmp11_ = NULL;
				gchar* value = NULL;
				const gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				const gchar* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				_tmp5_ = pspec;
				_tmp6_ = g_param_spec_get_name (_tmp5_);
				_tmp7_ = g_strdup (_tmp6_);
				property = _tmp7_;
				_tmp8_ = pspec;
				_tmp9_ = _tmp8_->value_type;
				g_value_init (&_tmp10_, _tmp9_);
				prop_value = _tmp10_;
				_tmp11_ = property;
				g_object_get_property ((GObject*) self, _tmp11_, &prop_value);
				_tmp12_ = g_value_get_string (&prop_value);
				_tmp13_ = g_strdup (_tmp12_);
				value = _tmp13_;
				_tmp14_ = first;
				if (_tmp14_ == FALSE) {
					const gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					_tmp15_ = ret;
					_tmp16_ = g_strconcat (_tmp15_, ", ", NULL);
					_g_free0 (ret);
					ret = _tmp16_;
				}
				_tmp17_ = ret;
				_tmp18_ = property;
				_tmp19_ = value;
				_tmp20_ = g_strdup_printf ("%s : %s", _tmp18_, _tmp19_);
				_tmp21_ = _tmp20_;
				_tmp22_ = g_strconcat (_tmp17_, _tmp21_, NULL);
				_g_free0 (ret);
				ret = _tmp22_;
				_g_free0 (_tmp21_);
				first = FALSE;
				_g_free0 (value);
				G_IS_VALUE (&prop_value) ? (g_value_unset (&prop_value), NULL) : NULL;
				_g_free0 (property);
			}
		}
	}
	_tmp23_ = ret;
	_tmp24_ = g_strconcat (_tmp23_, " } ", NULL);
	_g_free0 (ret);
	ret = _tmp24_;
	result = ret;
	properties = (g_free (properties), NULL);
	return result;
}


TrfAfflInfo* trf_affl_info_construct (GType object_type) {
	TrfAfflInfo * self = NULL;
	self = (TrfAfflInfo*) g_object_new (object_type, NULL);
	return self;
}


TrfAfflInfo* trf_affl_info_new (void) {
	return trf_affl_info_construct (TRF_TYPE_AFFL_INFO);
}


const gchar* trf_affl_info_get_im_tracker_id (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_im_tracker_id;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_im_tracker_id (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_im_tracker_id);
	self->priv->_im_tracker_id = _tmp1_;
	g_object_notify ((GObject *) self, "im-tracker-id");
}


const gchar* trf_affl_info_get_im_proto (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_im_proto;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_im_proto (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_im_proto);
	self->priv->_im_proto = _tmp1_;
	g_object_notify ((GObject *) self, "im-proto");
}


const gchar* trf_affl_info_get_im_account_id (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_im_account_id;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_im_account_id (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_im_account_id);
	self->priv->_im_account_id = _tmp1_;
	g_object_notify ((GObject *) self, "im-account-id");
}


const gchar* trf_affl_info_get_im_nickname (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_im_nickname;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_im_nickname (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_im_nickname);
	self->priv->_im_nickname = _tmp1_;
	g_object_notify ((GObject *) self, "im-nickname");
}


const gchar* trf_affl_info_get_affl_tracker_id (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_affl_tracker_id;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_affl_tracker_id (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_affl_tracker_id);
	self->priv->_affl_tracker_id = _tmp1_;
	g_object_notify ((GObject *) self, "affl-tracker-id");
}


const gchar* trf_affl_info_get_title (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_title (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_title);
	self->priv->_title = _tmp1_;
	g_object_notify ((GObject *) self, "title");
}


const gchar* trf_affl_info_get_org (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_org;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_org (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_org);
	self->priv->_org = _tmp1_;
	g_object_notify ((GObject *) self, "org");
}


const gchar* trf_affl_info_get_role (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_role;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_role (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_role);
	self->priv->_role = _tmp1_;
	g_object_notify ((GObject *) self, "role");
}


const gchar* trf_affl_info_get_email (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_email;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_email (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_email);
	self->priv->_email = _tmp1_;
	g_object_notify ((GObject *) self, "email");
}


const gchar* trf_affl_info_get_phone (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_phone;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_phone (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_phone);
	self->priv->_phone = _tmp1_;
	g_object_notify ((GObject *) self, "phone");
}


const gchar* trf_affl_info_get_website (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_website;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_website (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_website);
	self->priv->_website = _tmp1_;
	g_object_notify ((GObject *) self, "website");
}


const gchar* trf_affl_info_get_blog (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_blog;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_blog (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_blog);
	self->priv->_blog = _tmp1_;
	g_object_notify ((GObject *) self, "blog");
}


const gchar* trf_affl_info_get_url (TrfAfflInfo* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}


void trf_affl_info_set_url (TrfAfflInfo* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_url);
	self->priv->_url = _tmp1_;
	g_object_notify ((GObject *) self, "url");
}


static void trf_affl_info_class_init (TrfAfflInfoClass * klass) {
	trf_affl_info_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (TrfAfflInfoPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_trf_affl_info_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_trf_affl_info_set_property;
	G_OBJECT_CLASS (klass)->finalize = trf_affl_info_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_IM_TRACKER_ID, g_param_spec_string ("im-tracker-id", "im-tracker-id", "im-tracker-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_IM_PROTO, g_param_spec_string ("im-proto", "im-proto", "im-proto", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_IM_ACCOUNT_ID, g_param_spec_string ("im-account-id", "im-account-id", "im-account-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_IM_NICKNAME, g_param_spec_string ("im-nickname", "im-nickname", "im-nickname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_AFFL_TRACKER_ID, g_param_spec_string ("affl-tracker-id", "affl-tracker-id", "affl-tracker-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_TITLE, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_ORG, g_param_spec_string ("org", "org", "org", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_ROLE, g_param_spec_string ("role", "role", "role", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_EMAIL, g_param_spec_string ("email", "email", "email", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_PHONE, g_param_spec_string ("phone", "phone", "phone", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_WEBSITE, g_param_spec_string ("website", "website", "website", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_BLOG, g_param_spec_string ("blog", "blog", "blog", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TRF_AFFL_INFO_URL, g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void trf_affl_info_instance_init (TrfAfflInfo * self) {
	self->priv = TRF_AFFL_INFO_GET_PRIVATE (self);
}


static void trf_affl_info_finalize (GObject* obj) {
	TrfAfflInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TRF_TYPE_AFFL_INFO, TrfAfflInfo);
	_g_free0 (self->priv->_im_tracker_id);
	_g_free0 (self->priv->_im_proto);
	_g_free0 (self->priv->_im_account_id);
	_g_free0 (self->priv->_im_nickname);
	_g_free0 (self->priv->_affl_tracker_id);
	_g_free0 (self->priv->_title);
	_g_free0 (self->priv->_org);
	_g_free0 (self->priv->_role);
	_g_object_unref0 (self->postal_address_fd);
	_g_free0 (self->priv->_email);
	_g_free0 (self->priv->_phone);
	_g_free0 (self->priv->_website);
	_g_free0 (self->priv->_blog);
	_g_free0 (self->priv->_url);
	G_OBJECT_CLASS (trf_affl_info_parent_class)->finalize (obj);
}


GType trf_affl_info_get_type (void) {
	static volatile gsize trf_affl_info_type_id__volatile = 0;
	if (g_once_init_enter (&trf_affl_info_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TrfAfflInfoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) trf_affl_info_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TrfAfflInfo), 0, (GInstanceInitFunc) trf_affl_info_instance_init, NULL };
		GType trf_affl_info_type_id;
		trf_affl_info_type_id = g_type_register_static (G_TYPE_OBJECT, "TrfAfflInfo", &g_define_type_info, 0);
		g_once_init_leave (&trf_affl_info_type_id__volatile, trf_affl_info_type_id);
	}
	return trf_affl_info_type_id__volatile;
}


static void _vala_trf_affl_info_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	TrfAfflInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TRF_TYPE_AFFL_INFO, TrfAfflInfo);
	switch (property_id) {
		case TRF_AFFL_INFO_IM_TRACKER_ID:
		g_value_set_string (value, trf_affl_info_get_im_tracker_id (self));
		break;
		case TRF_AFFL_INFO_IM_PROTO:
		g_value_set_string (value, trf_affl_info_get_im_proto (self));
		break;
		case TRF_AFFL_INFO_IM_ACCOUNT_ID:
		g_value_set_string (value, trf_affl_info_get_im_account_id (self));
		break;
		case TRF_AFFL_INFO_IM_NICKNAME:
		g_value_set_string (value, trf_affl_info_get_im_nickname (self));
		break;
		case TRF_AFFL_INFO_AFFL_TRACKER_ID:
		g_value_set_string (value, trf_affl_info_get_affl_tracker_id (self));
		break;
		case TRF_AFFL_INFO_TITLE:
		g_value_set_string (value, trf_affl_info_get_title (self));
		break;
		case TRF_AFFL_INFO_ORG:
		g_value_set_string (value, trf_affl_info_get_org (self));
		break;
		case TRF_AFFL_INFO_ROLE:
		g_value_set_string (value, trf_affl_info_get_role (self));
		break;
		case TRF_AFFL_INFO_EMAIL:
		g_value_set_string (value, trf_affl_info_get_email (self));
		break;
		case TRF_AFFL_INFO_PHONE:
		g_value_set_string (value, trf_affl_info_get_phone (self));
		break;
		case TRF_AFFL_INFO_WEBSITE:
		g_value_set_string (value, trf_affl_info_get_website (self));
		break;
		case TRF_AFFL_INFO_BLOG:
		g_value_set_string (value, trf_affl_info_get_blog (self));
		break;
		case TRF_AFFL_INFO_URL:
		g_value_set_string (value, trf_affl_info_get_url (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_trf_affl_info_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	TrfAfflInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TRF_TYPE_AFFL_INFO, TrfAfflInfo);
	switch (property_id) {
		case TRF_AFFL_INFO_IM_TRACKER_ID:
		trf_affl_info_set_im_tracker_id (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_IM_PROTO:
		trf_affl_info_set_im_proto (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_IM_ACCOUNT_ID:
		trf_affl_info_set_im_account_id (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_IM_NICKNAME:
		trf_affl_info_set_im_nickname (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_AFFL_TRACKER_ID:
		trf_affl_info_set_affl_tracker_id (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_TITLE:
		trf_affl_info_set_title (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_ORG:
		trf_affl_info_set_org (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_ROLE:
		trf_affl_info_set_role (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_EMAIL:
		trf_affl_info_set_email (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_PHONE:
		trf_affl_info_set_phone (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_WEBSITE:
		trf_affl_info_set_website (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_BLOG:
		trf_affl_info_set_blog (self, g_value_get_string (value));
		break;
		case TRF_AFFL_INFO_URL:
		trf_affl_info_set_url (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


TrfOntologyDefs* trf_ontology_defs_construct (GType object_type) {
	TrfOntologyDefs * self = NULL;
	self = (TrfOntologyDefs*) g_object_new (object_type, NULL);
	return self;
}


TrfOntologyDefs* trf_ontology_defs_new (void) {
	return trf_ontology_defs_construct (TRF_TYPE_ONTOLOGY_DEFS);
}


static void trf_ontology_defs_class_init (TrfOntologyDefsClass * klass) {
	trf_ontology_defs_parent_class = g_type_class_peek_parent (klass);
}


static void trf_ontology_defs_instance_init (TrfOntologyDefs * self) {
}


GType trf_ontology_defs_get_type (void) {
	static volatile gsize trf_ontology_defs_type_id__volatile = 0;
	if (g_once_init_enter (&trf_ontology_defs_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TrfOntologyDefsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) trf_ontology_defs_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TrfOntologyDefs), 0, (GInstanceInitFunc) trf_ontology_defs_instance_init, NULL };
		GType trf_ontology_defs_type_id;
		trf_ontology_defs_type_id = g_type_register_static (G_TYPE_OBJECT, "TrfOntologyDefs", &g_define_type_info, 0);
		g_once_init_leave (&trf_ontology_defs_type_id__volatile, trf_ontology_defs_type_id);
	}
	return trf_ontology_defs_type_id__volatile;
}



