/* name-details-interface.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from name-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_NAME_DETAILS_INTERFACE_TESTS (name_details_interface_tests_get_type ())
#define NAME_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_DETAILS_INTERFACE_TESTS, NameDetailsInterfaceTests))
#define NAME_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_DETAILS_INTERFACE_TESTS, NameDetailsInterfaceTestsClass))
#define IS_NAME_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_DETAILS_INTERFACE_TESTS))
#define IS_NAME_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_DETAILS_INTERFACE_TESTS))
#define NAME_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_DETAILS_INTERFACE_TESTS, NameDetailsInterfaceTestsClass))

typedef struct _NameDetailsInterfaceTests NameDetailsInterfaceTests;
typedef struct _NameDetailsInterfaceTestsClass NameDetailsInterfaceTestsClass;
typedef struct _NameDetailsInterfaceTestsPrivate NameDetailsInterfaceTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NameDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	NameDetailsInterfaceTestsPrivate * priv;
};

struct _NameDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _NameDetailsInterfaceTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
};

struct _NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	NameDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer name_details_interface_tests_parent_class = NULL;

GType name_details_interface_tests_get_type (void) G_GNUC_CONST;
#define NAME_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_NAME_DETAILS_INTERFACE_TESTS, NameDetailsInterfaceTestsPrivate))
enum  {
	NAME_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
NameDetailsInterfaceTests* name_details_interface_tests_new (void);
NameDetailsInterfaceTests* name_details_interface_tests_construct (GType object_type);
void name_details_interface_tests_test_name_details_interface (NameDetailsInterfaceTests* self);
static void _name_details_interface_tests_test_name_details_interface_folks_test_case_test_method (gpointer self);
static void _name_details_interface_tests_test_name_details_interface_async (NameDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _name_details_interface_tests_test_name_details_interface_finish (NameDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _name_details_interface_tests_test_name_details_interface_async_data_free (gpointer _data);
static gboolean _name_details_interface_tests_test_name_details_interface_async_co (NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_);
static void _name_details_interface_tests_test_name_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _name_details_interface_tests_individuals_changed_cb (NameDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __name_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void name_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _name_details_interface_tests_test_name_details_interface_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	name_details_interface_tests_test_name_details_interface ((NameDetailsInterfaceTests*) self);
#line 113 "name-details-interface.c"
}


NameDetailsInterfaceTests* name_details_interface_tests_construct (GType object_type) {
	NameDetailsInterfaceTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self = (NameDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "NameDetailsInterfaceTests");
#line 37 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test name details interface", _name_details_interface_tests_test_name_details_interface_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 33 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return self;
#line 125 "name-details-interface.c"
}


NameDetailsInterfaceTests* name_details_interface_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return name_details_interface_tests_construct (TYPE_NAME_DETAILS_INTERFACE_TESTS);
#line 132 "name-details-interface.c"
}


void name_details_interface_tests_test_name_details_interface (NameDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	GeeHashMap* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GeeHashMap* _tmp7_ = NULL;
	GeeHashMap* _tmp8_ = NULL;
	TrackerTestBackend* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GeeHashMap* _tmp11_ = NULL;
	TrackerTestBackend* _tmp12_ = NULL;
	GeeHashMap* _tmp13_ = NULL;
	TrackerTestBackend* _tmp14_ = NULL;
	GMainLoop* _tmp15_ = NULL;
	GeeHashMap* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	GeeHashMap* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	gint _tmp21_ = 0;
#line 41 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 43 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 44 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (self->priv->_c1);
#line 44 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self->priv->_c1 = _tmp1_;
#line 45 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (self->priv->_c2);
#line 45 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self->priv->_c2 = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp3_ = self->priv->_c1;
#line 47 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp3_, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, "persona #1");
#line 48 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp4_ = self->priv->_c1;
#line 48 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp4_, TRF_ONTOLOGY_DEFS_NCO_FAMILY, "p #1 Family");
#line 49 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp5_ = self->priv->_c1;
#line 49 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, TRF_ONTOLOGY_DEFS_NCO_GIVEN, "p #1 Given");
#line 50 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp6_ = self->priv->_c1;
#line 50 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, TRF_ONTOLOGY_DEFS_NCO_ADDITIONAL, "p #1 Additional");
#line 51 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp7_ = self->priv->_c1;
#line 51 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, TRF_ONTOLOGY_DEFS_NCO_PREFIX, "Mr");
#line 52 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp8_ = self->priv->_c1;
#line 52 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, TRF_ONTOLOGY_DEFS_NCO_SUFFIX, "Jr");
#line 53 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 53 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp10_ = self->priv->_c1;
#line 53 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp10_);
#line 55 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp11_ = self->priv->_c2;
#line 55 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp11_, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, "persona #2");
#line 56 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp12_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 56 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp13_ = self->priv->_c2;
#line 56 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp13_);
#line 58 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp14_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 58 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 60 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_name_details_interface_tests_test_name_details_interface_async (self, NULL, NULL);
#line 62 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp15_ = self->priv->_main_loop;
#line 62 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp15_, 5);
#line 64 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp16_ = self->priv->_c1;
#line 64 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp17_ = gee_abstract_map_get_size ((GeeMap*) _tmp16_);
#line 64 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp18_ = _tmp17_;
#line 64 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_vala_assert (_tmp18_ == 0, "this._c1.size == 0");
#line 65 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp19_ = self->priv->_c2;
#line 65 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp20_ = gee_abstract_map_get_size ((GeeMap*) _tmp19_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp21_ = _tmp20_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_vala_assert (_tmp21_ == 0, "this._c2.size == 0");
#line 245 "name-details-interface.c"
}


static void _name_details_interface_tests_test_name_details_interface_async_data_free (gpointer _data) {
	NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_slice_free (NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData, _data_);
#line 256 "name-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 263 "name-details-interface.c"
}


static void _name_details_interface_tests_test_name_details_interface_async (NameDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_;
	NameDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_ = g_slice_new0 (NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _name_details_interface_tests_test_name_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _name_details_interface_tests_test_name_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_name_details_interface_tests_test_name_details_interface_async_co (_data_);
#line 282 "name-details-interface.c"
}


static void _name_details_interface_tests_test_name_details_interface_finish (NameDetailsInterfaceTests* self, GAsyncResult* _res_) {
	NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 290 "name-details-interface.c"
}


static void _name_details_interface_tests_test_name_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_ = _user_data_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_res_ = _res_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_name_details_interface_tests_test_name_details_interface_async_co (_data_);
#line 304 "name-details-interface.c"
}


static void __name_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 73 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_name_details_interface_tests_individuals_changed_cb ((NameDetailsInterfaceTests*) self, changes);
#line 311 "name-details-interface.c"
}


static gboolean _name_details_interface_tests_test_name_details_interface_async_co (NameDetailsInterfaceTestsTestNameDetailsInterfaceAsyncData* _data_) {
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	switch (_data_->_state_) {
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		case 0:
#line 320 "name-details-interface.c"
		goto _state_0;
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		case 1:
#line 324 "name-details-interface.c"
		goto _state_1;
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		case 2:
#line 328 "name-details-interface.c"
		goto _state_2;
		default:
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_assert_not_reached ();
#line 333 "name-details-interface.c"
	}
	_state_0:
#line 70 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 70 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_state_ = 1;
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _name_details_interface_tests_test_name_details_interface_async_ready, _data_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return FALSE;
#line 348 "name-details-interface.c"
	_state_1:
#line 71 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 72 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 72 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 72 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 73 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 73 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __name_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 366 "name-details-interface.c"
	{
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_state_ = 2;
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _name_details_interface_tests_test_name_details_interface_async_ready, _data_);
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		return FALSE;
#line 378 "name-details-interface.c"
		_state_2:
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 77 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 384 "name-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 81 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 81 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_warning ("name-details-interface.vala:81: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 407 "name-details-interface.c"
	}
	__finally0:
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 75 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		return FALSE;
#line 420 "name-details-interface.c"
	}
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 428 "name-details-interface.c"
	} else {
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 432 "name-details-interface.c"
	}
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 68 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return FALSE;
#line 438 "name-details-interface.c"
}


static void _name_details_interface_tests_individuals_changed_cb (NameDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp75_ = FALSE;
	GeeHashMap* _tmp76_ = NULL;
	gint _tmp77_ = 0;
	gint _tmp78_ = 0;
	GeeSet* _tmp83_ = NULL;
	gint _tmp84_ = 0;
	gint _tmp85_ = 0;
#line 85 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 85 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 88 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp0_ = changes;
#line 88 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	added = _tmp1_;
#line 89 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp2_ = changes;
#line 89 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 89 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	removed = _tmp3_;
#line 472 "name-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp4_ = added;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_i_it = _tmp5_;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		while (TRUE) {
#line 485 "name-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp6_ = _i_it;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			if (!_tmp7_) {
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				break;
#line 506 "name-details-interface.c"
			}
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp8_ = _i_it;
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 93 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp10_ = i;
#line 93 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 95 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp11_ = i;
#line 95 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 95 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 95 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 95 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			full_name = _tmp14_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp15_ = full_name;
#line 96 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			if (_tmp15_ != NULL) {
#line 532 "name-details-interface.c"
				FolksStructuredName* sname = NULL;
				FolksIndividual* _tmp16_ = NULL;
				FolksStructuredName* _tmp17_ = NULL;
				FolksStructuredName* _tmp18_ = NULL;
				FolksStructuredName* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_tmp16_ = i;
#line 98 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_tmp17_ = folks_name_details_get_structured_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 98 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_tmp18_ = _tmp17_;
#line 98 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_tmp19_ = _g_object_ref0 (_tmp18_);
#line 98 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				sname = _tmp19_;
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_tmp20_ = full_name;
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				if (g_strcmp0 (_tmp20_, "persona #1") == 0) {
#line 553 "name-details-interface.c"
					GeeHashMap* _tmp21_ = NULL;
					gchar* family = NULL;
					FolksStructuredName* _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					gchar* _tmp25_ = NULL;
					GeeHashMap* _tmp26_ = NULL;
					gpointer _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					const gchar* _tmp29_ = NULL;
					GeeHashMap* _tmp30_ = NULL;
					gchar* given = NULL;
					FolksStructuredName* _tmp31_ = NULL;
					const gchar* _tmp32_ = NULL;
					const gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					GeeHashMap* _tmp35_ = NULL;
					gpointer _tmp36_ = NULL;
					gchar* _tmp37_ = NULL;
					const gchar* _tmp38_ = NULL;
					GeeHashMap* _tmp39_ = NULL;
					gchar* additional = NULL;
					FolksStructuredName* _tmp40_ = NULL;
					const gchar* _tmp41_ = NULL;
					const gchar* _tmp42_ = NULL;
					gchar* _tmp43_ = NULL;
					GeeHashMap* _tmp44_ = NULL;
					gpointer _tmp45_ = NULL;
					gchar* _tmp46_ = NULL;
					const gchar* _tmp47_ = NULL;
					GeeHashMap* _tmp48_ = NULL;
					gchar* prefix = NULL;
					FolksStructuredName* _tmp49_ = NULL;
					const gchar* _tmp50_ = NULL;
					const gchar* _tmp51_ = NULL;
					gchar* _tmp52_ = NULL;
					GeeHashMap* _tmp53_ = NULL;
					gpointer _tmp54_ = NULL;
					gchar* _tmp55_ = NULL;
					const gchar* _tmp56_ = NULL;
					GeeHashMap* _tmp57_ = NULL;
					gchar* suffix = NULL;
					FolksStructuredName* _tmp58_ = NULL;
					const gchar* _tmp59_ = NULL;
					const gchar* _tmp60_ = NULL;
					gchar* _tmp61_ = NULL;
					GeeHashMap* _tmp62_ = NULL;
					gpointer _tmp63_ = NULL;
					gchar* _tmp64_ = NULL;
					const gchar* _tmp65_ = NULL;
					GeeHashMap* _tmp66_ = NULL;
					FolksStructuredName* _tmp67_ = NULL;
					gboolean _tmp68_ = FALSE;
#line 103 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp21_ = self->priv->_c1;
#line 103 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp21_, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, NULL);
#line 105 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp22_ = sname;
#line 105 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp23_ = folks_structured_name_get_family_name (_tmp22_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp24_ = _tmp23_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp25_ = g_strdup (_tmp24_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					family = _tmp25_;
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp26_ = self->priv->_c1;
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp27_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp26_, TRF_ONTOLOGY_DEFS_NCO_FAMILY);
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp28_ = (gchar*) _tmp27_;
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp29_ = family;
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (g_strcmp0 (_tmp28_, _tmp29_) == 0, "this._c1.get (Trf.OntologyDefs.NCO_FAMILY) ==                        family");
#line 106 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (_tmp28_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp30_ = self->priv->_c1;
#line 108 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp30_, TRF_ONTOLOGY_DEFS_NCO_FAMILY, NULL);
#line 110 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp31_ = sname;
#line 110 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp32_ = folks_structured_name_get_given_name (_tmp31_);
#line 110 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp33_ = _tmp32_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp34_ = g_strdup (_tmp33_);
#line 110 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					given = _tmp34_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp35_ = self->priv->_c1;
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp36_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp35_, TRF_ONTOLOGY_DEFS_NCO_GIVEN);
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp37_ = (gchar*) _tmp36_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp38_ = given;
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (g_strcmp0 (_tmp37_, _tmp38_) == 0, "this._c1.get (Trf.OntologyDefs.NCO_GIVEN) == given");
#line 111 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (_tmp37_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp39_ = self->priv->_c1;
#line 112 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp39_, TRF_ONTOLOGY_DEFS_NCO_GIVEN, NULL);
#line 114 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp40_ = sname;
#line 114 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp41_ = folks_structured_name_get_additional_names (_tmp40_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp42_ = _tmp41_;
#line 114 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp43_ = g_strdup (_tmp42_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					additional = _tmp43_;
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp44_ = self->priv->_c1;
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp45_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp44_, TRF_ONTOLOGY_DEFS_NCO_ADDITIONAL);
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp46_ = (gchar*) _tmp45_;
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp47_ = additional;
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (g_strcmp0 (_tmp46_, _tmp47_) == 0, "this._c1.get (Trf.OntologyDefs.NCO_ADDITIONAL) ==                        additional");
#line 115 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (_tmp46_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp48_ = self->priv->_c1;
#line 117 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp48_, TRF_ONTOLOGY_DEFS_NCO_ADDITIONAL, NULL);
#line 119 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp49_ = sname;
#line 119 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp50_ = folks_structured_name_get_prefixes (_tmp49_);
#line 119 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp51_ = _tmp50_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp52_ = g_strdup (_tmp51_);
#line 119 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					prefix = _tmp52_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp53_ = self->priv->_c1;
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp54_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp53_, TRF_ONTOLOGY_DEFS_NCO_PREFIX);
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp55_ = (gchar*) _tmp54_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp56_ = prefix;
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (g_strcmp0 (_tmp55_, _tmp56_) == 0, "this._c1.get (Trf.OntologyDefs.NCO_PREFIX) ==                        prefix");
#line 120 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (_tmp55_);
#line 122 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp57_ = self->priv->_c1;
#line 122 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp57_, TRF_ONTOLOGY_DEFS_NCO_PREFIX, NULL);
#line 124 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp58_ = sname;
#line 124 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp59_ = folks_structured_name_get_suffixes (_tmp58_);
#line 124 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp60_ = _tmp59_;
#line 124 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp61_ = g_strdup (_tmp60_);
#line 124 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					suffix = _tmp61_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp62_ = self->priv->_c1;
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp63_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp62_, TRF_ONTOLOGY_DEFS_NCO_SUFFIX);
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp64_ = (gchar*) _tmp63_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp65_ = suffix;
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (g_strcmp0 (_tmp64_, _tmp65_) == 0, "this._c1.get (Trf.OntologyDefs.NCO_SUFFIX) ==                        suffix");
#line 125 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (_tmp64_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp66_ = self->priv->_c1;
#line 127 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp66_, TRF_ONTOLOGY_DEFS_NCO_SUFFIX, NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp67_ = sname;
#line 129 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp68_ = folks_structured_name_is_empty (_tmp67_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_vala_assert (_tmp68_ == FALSE, "sname.is_empty () == false");
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (suffix);
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (prefix);
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (additional);
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (given);
#line 101 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_g_free0 (family);
#line 757 "name-details-interface.c"
				} else {
					const gchar* _tmp69_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					_tmp69_ = full_name;
#line 131 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
					if (g_strcmp0 (_tmp69_, "persona #2") == 0) {
#line 764 "name-details-interface.c"
						GeeHashMap* _tmp70_ = NULL;
						gboolean _tmp71_ = FALSE;
						FolksStructuredName* _tmp72_ = NULL;
#line 133 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
						_tmp70_ = self->priv->_c2;
#line 133 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
						gee_abstract_map_unset ((GeeAbstractMap*) _tmp70_, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, NULL);
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
						_tmp72_ = sname;
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
						if (_tmp72_ == NULL) {
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
							_tmp71_ = TRUE;
#line 778 "name-details-interface.c"
						} else {
							FolksStructuredName* _tmp73_ = NULL;
							gboolean _tmp74_ = FALSE;
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
							_tmp73_ = sname;
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
							_tmp74_ = folks_structured_name_is_empty (_tmp73_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
							_tmp71_ = _tmp74_ == TRUE;
#line 788 "name-details-interface.c"
						}
#line 135 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
						_vala_assert (_tmp71_, "sname == null || sname.is_empty () == true");
#line 792 "name-details-interface.c"
					}
				}
#line 96 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				_g_object_unref0 (sname);
#line 797 "name-details-interface.c"
			}
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_g_free0 (full_name);
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_g_object_unref0 (i);
#line 803 "name-details-interface.c"
		}
#line 91 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 807 "name-details-interface.c"
	}
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp76_ = self->priv->_c1;
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp77_ = gee_abstract_map_get_size ((GeeMap*) _tmp76_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp78_ = _tmp77_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	if (_tmp78_ == 0) {
#line 817 "name-details-interface.c"
		GeeHashMap* _tmp79_ = NULL;
		gint _tmp80_ = 0;
		gint _tmp81_ = 0;
#line 141 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp79_ = self->priv->_c2;
#line 141 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp80_ = gee_abstract_map_get_size ((GeeMap*) _tmp79_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp81_ = _tmp80_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp75_ = _tmp81_ == 0;
#line 829 "name-details-interface.c"
	} else {
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp75_ = FALSE;
#line 833 "name-details-interface.c"
	}
#line 140 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	if (_tmp75_) {
#line 837 "name-details-interface.c"
		GMainLoop* _tmp82_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp82_ = self->priv->_main_loop;
#line 142 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		g_main_loop_quit (_tmp82_);
#line 843 "name-details-interface.c"
	}
#line 144 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp83_ = removed;
#line 144 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp84_ = gee_collection_get_size ((GeeCollection*) _tmp83_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp85_ = _tmp84_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_vala_assert (_tmp85_ == 1, "removed.size == 1");
#line 853 "name-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp86_ = NULL;
		GeeIterator* _tmp87_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp86_ = removed;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_tmp87_ = gee_iterable_iterator ((GeeIterable*) _tmp86_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_i_it = _tmp87_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		while (TRUE) {
#line 866 "name-details-interface.c"
			GeeIterator* _tmp88_ = NULL;
			gboolean _tmp89_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp90_ = NULL;
			gpointer _tmp91_ = NULL;
			FolksIndividual* _tmp92_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp88_ = _i_it;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp89_ = gee_iterator_next (_tmp88_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			if (!_tmp89_) {
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
				break;
#line 881 "name-details-interface.c"
			}
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp90_ = _i_it;
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp91_ = gee_iterator_get (_tmp90_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			i = (FolksIndividual*) _tmp91_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_tmp92_ = i;
#line 148 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_vala_assert (_tmp92_ == NULL, "i == null");
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
			_g_object_unref0 (i);
#line 895 "name-details-interface.c"
		}
#line 146 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 899 "name-details-interface.c"
	}
#line 85 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (removed);
#line 85 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (added);
#line 905 "name-details-interface.c"
}


static void name_details_interface_tests_class_init (NameDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	name_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_type_class_add_private (klass, sizeof (NameDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = name_details_interface_tests_finalize;
#line 916 "name-details-interface.c"
}


static void name_details_interface_tests_instance_init (NameDetailsInterfaceTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self->priv = NAME_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 923 "name-details-interface.c"
}


static void name_details_interface_tests_finalize (GObject* obj) {
	NameDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_NAME_DETAILS_INTERFACE_TESTS, NameDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 30 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (self->priv->_c1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (self->priv->_c2);
#line 26 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	G_OBJECT_CLASS (name_details_interface_tests_parent_class)->finalize (obj);
#line 941 "name-details-interface.c"
}


GType name_details_interface_tests_get_type (void) {
	static volatile gsize name_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&name_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NameDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) name_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NameDetailsInterfaceTests), 0, (GInstanceInitFunc) name_details_interface_tests_instance_init, NULL };
		GType name_details_interface_tests_type_id;
		name_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "NameDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&name_details_interface_tests_type_id__volatile, name_details_interface_tests_type_id);
	}
	return name_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	NameDetailsInterfaceTests* tests = NULL;
	NameDetailsInterfaceTests* _tmp0_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 157 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_tmp0_ = name_details_interface_tests_new ();
#line 157 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	tests = _tmp0_;
#line 158 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 159 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	g_test_run ();
#line 160 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 162 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	result = 0;
#line 162 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	_g_object_unref0 (tests);
#line 162 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return result;
#line 979 "name-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 153 "/opt/gnome3/source/folks/tests/tracker/name-details-interface.vala"
	return _vala_main (argv, argc);
#line 989 "name-details-interface.c"
}



