/* favourite-details-interface.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from favourite-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS (favourite_details_interface_tests_get_type ())
#define FAVOURITE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS, FavouriteDetailsInterfaceTests))
#define FAVOURITE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS, FavouriteDetailsInterfaceTestsClass))
#define IS_FAVOURITE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS))
#define IS_FAVOURITE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS))
#define FAVOURITE_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS, FavouriteDetailsInterfaceTestsClass))

typedef struct _FavouriteDetailsInterfaceTests FavouriteDetailsInterfaceTests;
typedef struct _FavouriteDetailsInterfaceTestsClass FavouriteDetailsInterfaceTestsClass;
typedef struct _FavouriteDetailsInterfaceTestsPrivate FavouriteDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FavouriteDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	FavouriteDetailsInterfaceTestsPrivate * priv;
};

struct _FavouriteDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _FavouriteDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	gchar* _fullname_p1;
	gchar* _fullname_p2;
	gchar* _fullname_p3;
	gboolean _found_p1;
	gboolean _found_p2;
	gboolean _found_p3;
	FolksIndividualAggregator* _aggregator;
};

struct _FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FavouriteDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer favourite_details_interface_tests_parent_class = NULL;

GType favourite_details_interface_tests_get_type (void) G_GNUC_CONST;
#define FAVOURITE_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS, FavouriteDetailsInterfaceTestsPrivate))
enum  {
	FAVOURITE_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
FavouriteDetailsInterfaceTests* favourite_details_interface_tests_new (void);
FavouriteDetailsInterfaceTests* favourite_details_interface_tests_construct (GType object_type);
void favourite_details_interface_tests_test_favourite_details_interface (FavouriteDetailsInterfaceTests* self);
static void _favourite_details_interface_tests_test_favourite_details_interface_folks_test_case_test_method (gpointer self);
static void _favourite_details_interface_tests_test_favourite_details_interface_async (FavouriteDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _favourite_details_interface_tests_test_favourite_details_interface_finish (FavouriteDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _favourite_details_interface_tests_test_favourite_details_interface_async_data_free (gpointer _data);
static gboolean _favourite_details_interface_tests_test_favourite_details_interface_async_co (FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_);
static void _favourite_details_interface_tests_test_favourite_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _favourite_details_interface_tests_individuals_changed_cb (FavouriteDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __favourite_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void favourite_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _favourite_details_interface_tests_test_favourite_details_interface_folks_test_case_test_method (gpointer self) {
#line 41 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	favourite_details_interface_tests_test_favourite_details_interface ((FavouriteDetailsInterfaceTests*) self);
#line 117 "favourite-details-interface.c"
}


FavouriteDetailsInterfaceTests* favourite_details_interface_tests_construct (GType object_type) {
	FavouriteDetailsInterfaceTests * self = NULL;
#line 39 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self = (FavouriteDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "FavouriteDetailsInterfaceTests");
#line 41 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test favourite details interface", _favourite_details_interface_tests_test_favourite_details_interface_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 37 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return self;
#line 129 "favourite-details-interface.c"
}


FavouriteDetailsInterfaceTests* favourite_details_interface_tests_new (void) {
#line 37 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return favourite_details_interface_tests_construct (TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS);
#line 136 "favourite-details-interface.c"
}


void favourite_details_interface_tests_test_favourite_details_interface (FavouriteDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashMap* c2 = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GeeHashMap* c3 = NULL;
	GeeHashMap* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	TrackerTestBackend* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	TrackerTestBackend* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	TrackerTestBackend* _tmp12_ = NULL;
	TrackerTestBackend* _tmp13_ = NULL;
	GMainLoop* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
#line 45 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 47 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 47 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 47 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 48 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 48 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	c1 = _tmp1_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 49 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	c2 = _tmp2_;
#line 50 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp3_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 50 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	c3 = _tmp3_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp4_ = g_strdup ("favourite persona #1");
#line 51 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p1);
#line 51 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_fullname_p1 = _tmp4_;
#line 52 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp5_ = g_strdup ("favourite persona #2");
#line 52 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p2);
#line 52 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_fullname_p2 = _tmp5_;
#line 53 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp6_ = g_strdup ("favourite persona #3");
#line 53 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p3);
#line 53 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_fullname_p3 = _tmp6_;
#line 55 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp7_ = self->priv->_fullname_p1;
#line 55 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp7_);
#line 56 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NAO_TAG, "");
#line 57 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp8_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 57 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 59 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp9_ = self->priv->_fullname_p2;
#line 59 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp9_);
#line 60 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, TRF_ONTOLOGY_DEFS_NAO_TAG, "");
#line 61 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp10_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 61 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c2);
#line 63 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp11_ = self->priv->_fullname_p3;
#line 63 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c3, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp11_);
#line 64 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp12_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 64 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c3);
#line 66 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp13_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 66 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 68 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_found_p1 = FALSE;
#line 69 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_found_p2 = FALSE;
#line 70 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv->_found_p3 = FALSE;
#line 72 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_favourite_details_interface_tests_test_favourite_details_interface_async (self, NULL, NULL);
#line 74 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp14_ = self->priv->_main_loop;
#line 74 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp14_, 5);
#line 76 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp15_ = self->priv->_found_p1;
#line 76 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_vala_assert (_tmp15_ == TRUE, "this._found_p1 == true");
#line 77 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp16_ = self->priv->_found_p2;
#line 77 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_vala_assert (_tmp16_ == TRUE, "this._found_p2 == true");
#line 78 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp17_ = self->priv->_found_p3;
#line 78 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_vala_assert (_tmp17_ == TRUE, "this._found_p3 == true");
#line 45 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (c3);
#line 45 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (c2);
#line 45 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (c1);
#line 262 "favourite-details-interface.c"
}


static void _favourite_details_interface_tests_test_favourite_details_interface_async_data_free (gpointer _data) {
	FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_slice_free (FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData, _data_);
#line 273 "favourite-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 280 "favourite-details-interface.c"
}


static void _favourite_details_interface_tests_test_favourite_details_interface_async (FavouriteDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_;
	FavouriteDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_ = g_slice_new0 (FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _favourite_details_interface_tests_test_favourite_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _favourite_details_interface_tests_test_favourite_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_favourite_details_interface_tests_test_favourite_details_interface_async_co (_data_);
#line 299 "favourite-details-interface.c"
}


static void _favourite_details_interface_tests_test_favourite_details_interface_finish (FavouriteDetailsInterfaceTests* self, GAsyncResult* _res_) {
	FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 307 "favourite-details-interface.c"
}


static void _favourite_details_interface_tests_test_favourite_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_ = _user_data_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_res_ = _res_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_favourite_details_interface_tests_test_favourite_details_interface_async_co (_data_);
#line 321 "favourite-details-interface.c"
}


static void __favourite_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 86 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_favourite_details_interface_tests_individuals_changed_cb ((FavouriteDetailsInterfaceTests*) self, changes);
#line 328 "favourite-details-interface.c"
}


static gboolean _favourite_details_interface_tests_test_favourite_details_interface_async_co (FavouriteDetailsInterfaceTestsTestFavouriteDetailsInterfaceAsyncData* _data_) {
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	switch (_data_->_state_) {
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		case 0:
#line 337 "favourite-details-interface.c"
		goto _state_0;
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		case 1:
#line 341 "favourite-details-interface.c"
		goto _state_1;
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		case 2:
#line 345 "favourite-details-interface.c"
		goto _state_2;
		default:
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_assert_not_reached ();
#line 350 "favourite-details-interface.c"
	}
	_state_0:
#line 83 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 83 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_state_ = 1;
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _favourite_details_interface_tests_test_favourite_details_interface_async_ready, _data_);
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return FALSE;
#line 365 "favourite-details-interface.c"
	_state_1:
#line 84 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 85 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 85 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 86 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 86 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __favourite_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 383 "favourite-details-interface.c"
	{
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_state_ = 2;
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _favourite_details_interface_tests_test_favourite_details_interface_async_ready, _data_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		return FALSE;
#line 395 "favourite-details-interface.c"
		_state_2:
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 401 "favourite-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 94 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 94 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_warning ("favourite-details-interface.vala:94: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 424 "favourite-details-interface.c"
	}
	__finally0:
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		return FALSE;
#line 437 "favourite-details-interface.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 445 "favourite-details-interface.c"
	} else {
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 449 "favourite-details-interface.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 81 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return FALSE;
#line 455 "favourite-details-interface.c"
}


static void _favourite_details_interface_tests_individuals_changed_cb (FavouriteDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
	GeeSet* _tmp37_ = NULL;
	gint _tmp38_ = 0;
	gint _tmp39_ = 0;
#line 98 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 98 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 101 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp0_ = changes;
#line 101 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 101 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	added = _tmp1_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp2_ = changes;
#line 102 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	removed = _tmp3_;
#line 488 "favourite-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp4_ = added;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_i_it = _tmp5_;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		while (TRUE) {
#line 501 "favourite-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp6_ = _i_it;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			if (!_tmp7_) {
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
				break;
#line 522 "favourite-details-interface.c"
			}
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp8_ = _i_it;
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 106 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp10_ = i;
#line 106 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 108 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp11_ = i;
#line 108 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			full_name = _tmp14_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp15_ = full_name;
#line 109 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			if (_tmp15_ != NULL) {
#line 548 "favourite-details-interface.c"
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
				_tmp16_ = full_name;
#line 111 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
				_tmp17_ = self->priv->_fullname_p1;
#line 111 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
				if (g_strcmp0 (_tmp16_, _tmp17_) == 0) {
#line 557 "favourite-details-interface.c"
					FolksIndividual* _tmp18_ = NULL;
					gboolean _tmp19_ = FALSE;
					gboolean _tmp20_ = FALSE;
#line 113 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_tmp18_ = i;
#line 113 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_tmp19_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp18_);
#line 113 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_tmp20_ = _tmp19_;
#line 113 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_vala_assert (_tmp20_ == TRUE, "i.is_favourite == true");
#line 114 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					self->priv->_found_p1 = TRUE;
#line 571 "favourite-details-interface.c"
				} else {
					const gchar* _tmp21_ = NULL;
					const gchar* _tmp22_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_tmp21_ = full_name;
#line 116 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					_tmp22_ = self->priv->_fullname_p2;
#line 116 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
					if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 581 "favourite-details-interface.c"
						FolksIndividual* _tmp23_ = NULL;
						gboolean _tmp24_ = FALSE;
						gboolean _tmp25_ = FALSE;
#line 118 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_tmp23_ = i;
#line 118 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_tmp24_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp23_);
#line 118 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_tmp25_ = _tmp24_;
#line 118 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_vala_assert (_tmp25_ == TRUE, "i.is_favourite == true");
#line 119 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						self->priv->_found_p2 = TRUE;
#line 595 "favourite-details-interface.c"
					} else {
						const gchar* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_tmp26_ = full_name;
#line 121 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						_tmp27_ = self->priv->_fullname_p3;
#line 121 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
						if (g_strcmp0 (_tmp26_, _tmp27_) == 0) {
#line 605 "favourite-details-interface.c"
							FolksIndividual* _tmp28_ = NULL;
							gboolean _tmp29_ = FALSE;
							gboolean _tmp30_ = FALSE;
#line 123 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
							_tmp28_ = i;
#line 123 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
							_tmp29_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp28_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
							_tmp30_ = _tmp29_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
							_vala_assert (_tmp30_ == FALSE, "i.is_favourite == false");
#line 124 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
							self->priv->_found_p3 = TRUE;
#line 619 "favourite-details-interface.c"
						}
					}
				}
			}
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_g_free0 (full_name);
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_g_object_unref0 (i);
#line 628 "favourite-details-interface.c"
		}
#line 104 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 632 "favourite-details-interface.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp33_ = self->priv->_found_p1;
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	if (_tmp33_) {
#line 638 "favourite-details-interface.c"
		gboolean _tmp34_ = FALSE;
#line 130 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp34_ = self->priv->_found_p2;
#line 130 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp32_ = _tmp34_;
#line 644 "favourite-details-interface.c"
	} else {
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp32_ = FALSE;
#line 648 "favourite-details-interface.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	if (_tmp32_) {
#line 652 "favourite-details-interface.c"
		gboolean _tmp35_ = FALSE;
#line 131 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp35_ = self->priv->_found_p3;
#line 131 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp31_ = _tmp35_;
#line 658 "favourite-details-interface.c"
	} else {
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp31_ = FALSE;
#line 662 "favourite-details-interface.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	if (_tmp31_) {
#line 666 "favourite-details-interface.c"
		GMainLoop* _tmp36_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp36_ = self->priv->_main_loop;
#line 132 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		g_main_loop_quit (_tmp36_);
#line 672 "favourite-details-interface.c"
	}
#line 134 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp37_ = removed;
#line 134 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp38_ = gee_collection_get_size ((GeeCollection*) _tmp37_);
#line 134 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp39_ = _tmp38_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_vala_assert (_tmp39_ == 1, "removed.size == 1");
#line 682 "favourite-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp40_ = NULL;
		GeeIterator* _tmp41_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp40_ = removed;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_tmp41_ = gee_iterable_iterator ((GeeIterable*) _tmp40_);
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_i_it = _tmp41_;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		while (TRUE) {
#line 695 "favourite-details-interface.c"
			GeeIterator* _tmp42_ = NULL;
			gboolean _tmp43_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp44_ = NULL;
			gpointer _tmp45_ = NULL;
			FolksIndividual* _tmp46_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp42_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp43_ = gee_iterator_next (_tmp42_);
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			if (!_tmp43_) {
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
				break;
#line 710 "favourite-details-interface.c"
			}
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp44_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp45_ = gee_iterator_get (_tmp44_);
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			i = (FolksIndividual*) _tmp45_;
#line 138 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_tmp46_ = i;
#line 138 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_vala_assert (_tmp46_ == NULL, "i == null");
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
			_g_object_unref0 (i);
#line 724 "favourite-details-interface.c"
		}
#line 136 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 728 "favourite-details-interface.c"
	}
#line 98 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (removed);
#line 98 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (added);
#line 734 "favourite-details-interface.c"
}


static void favourite_details_interface_tests_class_init (FavouriteDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	favourite_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_type_class_add_private (klass, sizeof (FavouriteDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = favourite_details_interface_tests_finalize;
#line 745 "favourite-details-interface.c"
}


static void favourite_details_interface_tests_instance_init (FavouriteDetailsInterfaceTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self->priv = FAVOURITE_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 752 "favourite-details-interface.c"
}


static void favourite_details_interface_tests_finalize (GObject* obj) {
	FavouriteDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FAVOURITE_DETAILS_INTERFACE_TESTS, FavouriteDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p1);
#line 30 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p2);
#line 31 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_free0 (self->priv->_fullname_p3);
#line 35 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	G_OBJECT_CLASS (favourite_details_interface_tests_parent_class)->finalize (obj);
#line 772 "favourite-details-interface.c"
}


GType favourite_details_interface_tests_get_type (void) {
	static volatile gsize favourite_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&favourite_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FavouriteDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) favourite_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FavouriteDetailsInterfaceTests), 0, (GInstanceInitFunc) favourite_details_interface_tests_instance_init, NULL };
		GType favourite_details_interface_tests_type_id;
		favourite_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "FavouriteDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&favourite_details_interface_tests_type_id__volatile, favourite_details_interface_tests_type_id);
	}
	return favourite_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	FavouriteDetailsInterfaceTests* tests = NULL;
	FavouriteDetailsInterfaceTests* _tmp0_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 147 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_tmp0_ = favourite_details_interface_tests_new ();
#line 147 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	tests = _tmp0_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 149 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	g_test_run ();
#line 150 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	result = 0;
#line 152 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	_g_object_unref0 (tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return result;
#line 810 "favourite-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 143 "/opt/gnome3/source/folks/tests/tracker/favourite-details-interface.vala"
	return _vala_main (argv, argc);
#line 820 "favourite-details-interface.c"
}



